/* Generate and recreate SIPP datafiles for use with many projects */
/* Author: Ben Griffy */
/* Date: Apr., 2018 */
/* Website: https://www.bengriffy.com */
/* Note: much of the original code incorporates the work of the CEPR to clean the data, and Chetty (2008) to incorporate wealth, UI, and spells */

clear all
pause on
set more off

local i = 1
global projname = "Long Project Name"
global shortname = "LPN"

if `i' == 1{
    global pd = "/media/ben/workA/shared/Dropbox/Research/$projname"
    global progdir = "/media/ben/workA/shared/Dropbox/Research/$projname/programs/data/SIPP"
    global modeldatadir = "$pd/data/modeluse_data/"
    global sippprogdir = "/media/ben/workA/datasets/SIPP/programs"
    global datadir = "/media/ben/workA/datasets/SIPP"
    global alldatadir = "/media/ben/workA/datasets"
    global projdir = "/media/ben/workA/datasets/SIPP/projects/$shortname"
    global tmpdir = "$datadir/data/tmp"
}
if `i' == 2{
    global pd = "E:\Dropbox\Research\$projname"
    global progdir = "E:\Dropbox\Research\$projname\Programs\data\SIPP"
    global modeldatadir = "$pd\data\modeluse_data"
    global sippprogdir = "E:\data\SIPP\programs\do-files\wealth"
    global datadir = "E:\data\SIPP\data"
    global alldatadir = "E:\data"
    global projdir = "E:\data\SIPP\projects\$shortname"
    global tmpdir = "$datadir\tmp"
}
if `i' == 3{
    global pd = "C:\Users\Ben\Dropbox\Research\$projname"
    global progdir = "C:\Users\Ben\Dropbox\Research\\$projname\programs\data\SIPP"
    global modeldatadir = "$pd\data\modeluse_data"
    global datadir = "D:\data\sipp\data"
    global sippprogdir = "C:\Users\Ben\Dropbox\data\SIPP\programs\do-files\wealth"
    global alldatadir = "D:\data"
    global projdir = "D:\data\sipp/$shortname"
    global tmpdir = "$datadir\tmp"
}

global graphicpath = "$pd/figures/graphics"
global tablepath = "$pd/figures/tables"

capture confirm file $projdir/
if _rc mkdir $projdir/

capture confirm file $tmpdir/

if _rc mkdir $tmpdir/
local alldata = 0
local extractdata = 0
local recodedata = 0
local cleansipp = 0
local unempprep = 0
local unempspellsprep = 0
local wealthprep = 0
local wealthmerge = 0
local uiprep = 0
local unempdursprep = 0
local empdursprep = 0
local unempallmerge = 0

local allanalysis = 0
local sumstats = 0
local reemphazards = 0
local reempwages = 0
local papertables = 0

global getmodeldata = 0
global getpaperevidence = 0

local cleartmp = 0
local datalevel = "spell"


if `extractdata' == 1 | `alldata' == 1{
    cd "$progdir/data_prep/"
    do ExtractData
}

if `recodedata' == 1 | `alldata' == 1{
    cd "$progdir/data_recode/"
    do InitialCEPRRecode
}

if `cleansipp' == 1 | `alldata' == 1{
    cd "$progdir/data_prep/"
    do RawData_Clean
}

if `wealthprep' == 1 | `alldata' == 1{
    cd "$progdir/data_prep/"
    do PrepWealth
}

if `wealthmerge' == 1 | `alldata' == 1{
    cd "$progdir/data_prep/"
    do MergeWealth
}

if `unempprep' == 1 | `alldata' == 1{
    cd "$progdir/data_prep/"
    do PrepData_Unemp
}

if `unempspellsprep' == 1 | `alldata' == 1{
    cd "$progdir/data_prep/"
    do PrepSpells_Unemp
}
if `uiprep' == 1 | `alldata' == 1{
    cd "$progdir/data_prep/"
    do PrepUI
}

if `wealthprep' == 1 | `alldata' == 1{
    cd "$progdir/data_prep/"
    do PrepWealth
}

if `unempallmerge' == 1 | `alldata' == 1{
    cd "$progdir/data_prep/"
    do MergeWealth_Unemp
    cd "$progdir/data_prep/"
    do MergeWealthUI_Unemp
    cd "$progdir/data_prep/"
    do PrepFinal_Unemp
}

/* Analysis */

if `papertables' == 1 | `allanalysis' == 1{
    cd "$progdir/analysis"
    do SIPP_ReEmp_Final
}
