** SIPP_ReEmpHazards: Generate re-employment hazards and associated statistics for "Borrowing Constraints, Search, and Life-Cycle Inequality"
* This code largely follows Chetty (2008): "Moral Hazard vs. Liquidity"
* Data generated by running SIPPMaster.do

clear
cap log close
set more off
set mem 750m
set matsize 600

***0 Setup

cd "$projdir"

use SIPP_durations_pre_split, replace

svyset spellpsuvar [pweight = spellwgt], strata(spellstratavar) singleunit(certainty)

egen earn6wks = rowtotal(earn_f1 earn_f2 earn_f3 earn_f4 earn_f5 earn_f6)
egen inc6wks  = rowtotal(inc_f1 inc_f2 inc_f3 inc_f4 inc_f5 inc_f6)

gen l_earn6wks = log(earn6wks)
gen l_inc6wks  = log(inc6wks)

gen hasmortg = hh_mortg>0 if hh_mortg<.
gen l_hh_twlth = log(hh_twlth)
gen l_hh_netliq = log(hh_netliq)
gen renter = hh_theq==0&hh_mortg==0 if hh_theq~=.&hh_mortg~=.
gen wba = avgwba
gen reprate = wba*52/annwg_hat

*Censor at 50, stset and split data
replace censrd = 1 if dur>50&dur<.
replace dur=50 if dur>50&dur<.
stset dur [pweight=spellwgt], id(id) failure(censrd==0)
*stset dur, id(id) failure(censrd==0)
stsplit, at(failures) nopreserve
bys id: egen totaldur=max(dur)

gen onseam = dur==seam1wks|dur==seam2wks

gen l_maxwba = l_avgwba
gen l_wba = l_avgwba

gen durmaxwba = l_maxwba*dur
gen duravgwba = l_avgwba*dur
gen duractwba = l_wba*dur


xtile netliq_qtile = hh_netliq if uirec==1&templayoff==0, nq(5)
xtile avgwba_qtile = avgwba if templayoff==0&uirec==1, nq(2)

gen netliq_1stq = .
replace netliq_1stq = 1 if netliq_q == 1
replace netliq_1stq = 2 if inrange(netliq_q,2,5)


***1 SUMMARY STATISTICS

*Make usdbt into a real var since it wasn't done in original file
sort year
gen compdur = min(totaldur,26)


**Table 1

*Pooled summary stats
sum totaldur compdur wba annwg ed age mardum spwork_yn renter hasmortg hh_netliq hh_usdbt hh_theq reprate if _t==1&ui_yn==1&templayoff==0
centile totaldur compdur annwg hh_netliq hh_usdbt hh_theq if _t==1&ui_yn==1&templayoff==0

*Quintile breakdown
table netliq_q, c(mean totaldur mean compdur mean wba mean annwg mean hh_netliq), if _t==1&ui_yn==1&templayoff==0
table netliq_q, c(mean hh_usdbt mean ed mean age mean mardum mean spwork_yn), if _t==1&ui_yn==1&templayoff==0
table netliq_q, c(mean renter mean hasmortg mean hh_theq mean reprate), if _t==1&ui_yn==1&templayoff==0

*Quintile Medians, to be listed below means
table netliq_q, c(median totaldur median compdur median annwg), if _t==1&ui_yn==1&templayoff==0
table netliq_q, c(median hh_netliq median hh_usdbt median hh_theq), if _t==1&ui_yn==1&templayoff==0


***Non-parametric graphs/tests

*Actual benefits and rep rates by quartile to be listed in graphs
table netliq_q avgwba_qtile, c(mean wba), if ui_yn==1&templayoff==0&a_wave<wave&_t==1
table netliq_q avgwba_qtile, c(mean reprate), if ui_yn==1&templayoff==0&a_wave<wave&_t==1


***3 Hazard Model Estimates

*Drop obs to save memory
keep if ui_yn==1&templay==0

*Includes full occ, ind, and wage interacts with netliq_q for 2.2 on

* No Wealth interactions, full controls

qui: eststo haz1: stcox l_avgwba onseam  age mardum i.ed i.year i.occ i.ind i.sippst l_annwg hh_twlth if ui_yn==1&templayoff==0&netliq_q~=., strata(netliq_q) cluster(sippst) nohr

unique pid if e(sample) == 1
local hazN1 = r(unique)

*2.3 Interaction regress with all four asset quartiles, full controls

qui: eststo haz3: stcox i.netliq_q#c.l_avgwba onseam  age mardum i.ed i.year i.occ#i.netliq_q i.ind#i.netliq_q i.sippst l_annwg hh_twlth if ui_yn==1&templayoff==0&netliq_q~=., strata(netliq_q) cluster(sippst) nohr

test 1b.netliq_q#c.l_avgwba=5.netliq_q#c.l_avgwba

unique pid if e(sample) == 1
local hazN3 = r(unique)

*2.3 Interaction regress with all four asset quartiles, full controls

qui: eststo haz2: stcox i.netliq_1stq#c.l_avgwba onseam age mardum i.ed i.year i.occ#i.netliq_1stq i.ind#i.netliq_1stq i.sippst l_annwg hh_twlth if ui_yn==1&templayoff==0&netliq_1stq~=., strata(netliq_1stq) cluster(sippst) nohr

/* test 1b.netliq_1stq#c.l_avgwba=2.netliq_1stq#c.l_avgwba */

unique pid if e(sample) == 1
local hazN2 = r(unique)


if $getmodeldata == 1{
   cd "$modeldatadir"
   esttab using "./HazardReEmploymentElasticities_SIPP.csv", keep(1.netliq_1stq#c.l_avgwba 2.netliq_1stq#c.l_avgwba age l_annwg) not plain replace
   esttab e(V) using "./HazardReEmploymentElasticities_SIPP_Weighting.csv", keep(1b.netliq_1stq#c.l_avgwba 2.netliq_1stq#c.l_avgwba age l_annwg) not plain replace
}
