** SIPP_ReEmpWages: Generate re-employment hazards and associated statistics for "Borrowing Constraints, Search, and Life-Cycle Inequality"
* This code largely follows Chetty (2008): "Moral Hazard vs. Liquidity"
* Data generated by running SIPPMaster.do

clear
cap log close
set more off
set mem 750m
set matsize 11000

***0 Setup

cd "$projdir"

use SIPP_durations_pre_split

svyset spellpsuvar [pweight = spellwgt], strata(spellstratavar) singleunit(certainty)

gen l_nextearn = log(nextearn)
label var l_nextearn "Log of Next Weekly Earnings"
gen l_nextwage = log(nextwage)
label var l_nextwage "Log of Next Monthly Earnings"

gen nextmostenure = ceil(nexttenure/4)
gen hasmortg = hh_mortg>0 if hh_mortg<.
gen l_hh_twlth = log(hh_twlth)
gen l_hh_netliq = log(hh_netliq)
gen renter = hh_theq==0&hh_mortg==0 if hh_theq~=.&hh_mortg~=.
gen wba = avgwba
gen reprate = wba*52/annwg_hat

gen l_qavgwba = log(avgwba*13)
gen l_qavgwbaqtr = log(avgwbaqtr*13)
gen l_qavgwbamth = log(avgwbamth*13)

*Censor at 52, stset and split data
replace censrd = 1 if dur>52&dur!=.
replace dur=52 if dur>52&dur!=.
bys id: egen totaldur=max(dur)

gen onseam = dur==seam1wks|dur==seam2wks

gen l_maxwba = l_avgwba
label var l_avgwba "Log of Average UI in State of Residence"
gen l_wba = l_avgwba

gen durmaxwba = l_maxwba*dur
gen duravgwba = l_avgwba*dur
gen duractwba = l_wba*dur

xtile netliq_qtile = hh_netliq if uirec==1&templayoff==0&age>21 [pweight = spellwgt], nq(5)
xtile avgwba_qtile = avgwba if templayoff==0&uirec==1&age>21 [pweight = spellwgt], nq(2)

xtile netliq_cntrl_qtile = hh_netliq if uirec==0, nq(5)
xtile homeeq_qtile = hh_theq if uirec==1&templayoff==0&hh_theq>0, nq(5)

***1 SUMMARY STATISTICS

*Make usdbt into a real var since it wasn't done in original file
sort year
label var avgwba_qtile "Average UI in State Above Median"
label var netliq_qtile "Net Liquidity Quintile"

gen compdur = min(totaldur,26)


tab netliq_q, sum(hh_netliq)

label define netliq_qtile 1 "Net Liq Q1 X" 2 "Net Liq Q2 X" 3 "Net Liq Q3 X" 4 "Net Liq Q4 X" 5 "Net Liq Q5 X"
label define avgwba_qtile 1 "St UI < Med" 2 "St UI > Med"
label variable dur "Duration of Unemployment"
label variable nextwage "Re-Employment Monthly Wage"
label variable avgwba "Average UI in State of Residence"
label variable annwg "Previous Annual Wage"
label variable hh_netliq "Net Liquid Assets"
label variable age "Age"

label values netliq_qtile netliq_qtile
label values avgwba_qtile avgwba_qtile

***3 Create Interactions

*Drop obs to save memory
keep if ui_yn==1&templay==0

**Define Quartile benefit interactions

set more off

*Includes full occ, ind, and wage interacts with netliq_q for 2.2 on

gen netliq_1stq = .
replace netliq_1stq = 1 if netliq_q == 1
replace netliq_1stq = 2 if inrange(netliq_q,2,5)

gen subpop1 = (ui_yn==1&templayoff==0&netliq_q~=.&nextwage>0&nextwage!=.&age>=23)

* Approximately Chetty (2008) specification for wages

qui: eststo reg1: reg l_nextwage l_avgwbamth dur onseam  age mardum i.ed i.year i.occ i.ind i.sippst i.race hh_twlth i.netliq_qtile##c.l_annwg if subpop1==1 [pweight=spellwgt], cluster(sippst)


local regN1 = e(N)

qui: eststo reg3: reg l_nextwage i.netliq_qtile##c.l_avgwbamth i.netliq_qtile#c.dur onseam  age mardum i.ed i.year i.occ#i.netliq_qtile i.ind#i.netliq_qtile i.sippst i.race hh_twlth i.netliq_qtile##c.l_annwg if subpop1==1 [pweight=spellwgt], cluster(sippst)

local regN3 = e(N)

qui: eststo reg2: reg l_nextwage i.netliq_1stq##c.l_avgwbamth i.netliq_1stq#c.dur onseam  age mardum i.ed i.year i.occ#i.netliq_1stq i.ind#i.netliq_1stq i.sippst i.race hh_twlth i.netliq_1stq##c.l_annwg if subpop1==1 [pweight=spellwgt], cluster(sippst)

local regN2 = e(N)

estimates table, keep(_cons l_avgwbamth 2.netliq_1stq 2.netliq_1stq#c.l_avgwbamth age l_annwg 2.netliq_1stq#c.l_annwg) b star(0.1 0.05 0.01)
