/* Generate and recreate SIPP datafiles for use with many projects */
/* Author: Ben Griffy */
/* Date: Apr., 2018 */
/* Website: https://www.bengriffy.com */
/* Note: much of the original code incorporates the work of the CEPR to clean the data, and Chetty (2008) to incorporate wealth, UI, and spells */


*This is an omnibus program that attaches various variables to the original spells data and generates
*the final dataset for empirical analysis, allmerged.dta
*NOTE: MUST RUN unemp*.do, spells*.do, full_asset_merge.do, and merge_marital.do before running this program
*NOTE: after merging panels, need to merge by panel suid pnum, since suid/pnum not unique across panels

set more off

clear
/*
use uilaws
sort year part sippst
keep if sippst~=.
save, replace

use statecodes
sort sippst
keep if sippst~=.
save, replace

use cpiseries
sort year
save, replace

use spells85, clear
for num 86/93: append using spellsX
replace year=year+1900

append using spells96
*/
cd "$datadir/cleaned_data"
use SIPPUnemp_SpellsWealthPanel.dta, replace
*drop _merge
*keep if sippst<60

cd "$datadir/cleaned_data"
sort cpsst
*merge sippst using statecodes, nokeep
merge cpsst using statecodes
tab _merge
keep if _merge==3
drop _merge
/*
gen part=1
replace part=2 if mth>=7
gen nndate=year*10000+mth*100+1

sort year part sippst
merge year part sippst using uilaws, nokeep
tab _merge
keep if _merge==3
drop _merge

sort sippst year mth
merge sippst year mth using unemprates, nokeep
rename unemp unemprate
drop _merge

sort year
merge year using cpiseries, nokeep
drop _merge cpi_levels

sort year mth
merge year mth using ~/Research/freelunch/interestrates, nokeep
drop _merge
*/
*rename ws1ind indly
*rename ws1occ occly
rename ws1ind ind
rename ws1occ occ
*do indocc

cd "$datadir/cleaned_data"
sort year cpsst
merge m:1 year cpsst using fullavguibens.dta
tab _merge
drop _merge

cd "$datadir/cleaned_data"
sort year cpsst calqtr
merge m:1 year calqtr cpsst using avguibensqtrfullpanel.dta
tab _merge
drop _merge

cd "$datadir/cleaned_data"
sort year cpsst mth
merge m:1 year mth cpsst using avguibensmthfullpanel.dta
tab _merge
drop _merge

cd "$datadir/cleaned_data"
sort cpsst
merge m:1 cpsst using maxuibensfullpanel.dta
tab _merge
drop _merge

replace annwg=4*qearn_l1 if annwg==.

cd $projdir
save SIPPUnemp_FinalPanel.dta, replace


***Now merge data for instruments to housing purchase/mrtg date and veh purchase/mrtg date
/*
use ~/Research/freelunch/annintrates, clear
rename mortg_rate Mrtg1_avgrate
rename bank_car_rate MVeh1_avgrate
gen MVeh2_avgrate = MVeh1_avgrate
gen Mrtg1Year = year
gen MVeh1Year = year
gen MVeh2Year = year
sort Mrtg1Year
save temp, replace

use allmerged
rename Mrtg1YearOb Mrtg1Year
sort Mrtg1Year
merge Mrtg1Year using temp, keep(Mrtg1_avgrate) nokeep
drop _merge
save, replace

use temp
sort MVeh1Year
save, replace
use allmerged
sort MVeh1Year
merge MVeh1Year using temp, keep(MVeh1_avgrate) nokeep
drop _merge
save, replace

use temp
sort MVeh2Year
save, replace
use allmerged
sort MVeh2Year
merge MVeh2Year using temp, keep(MVeh2_avgrate) nokeep
drop _merge

save allmerged, replace

*Merge intrate monthly series for marriage data
use ~/Research/freelunch/interestrates, clear
rename fincomp mar_avgcarrate
rename mortg mar_avgmortgrate
rename year maryr
rename mth marmth
keep mar*
sort maryr marmth
save temp, replace

use allmerged
sort maryr marmth
merge maryr marmth using temp, nokeep
drop _merge

save, replace

*Merge birthdate interest rate data
use temp
rename mar_avgcarrate brth1_avgcarrate
rename mar_avgmortgrate brth1_avgmortgrate
rename maryr brth1yr
rename marmth brth1mth
sort brth1yr brth1mth
save, replace

use allmerged
sort brth1yr brth1mth
merge brth1yr brth1mth using temp, nokeep
drop _merge


***LAWASSIGN WITH TRUE WAGES

gen tao=.1
do lawassign
do elig
rename wba wba_act
drop maxdur

***CALL LAWASSIGN AGAIN AFTER PREDICTING WAGES
*/
set matsize 10000
gen l_annwg = log(annwg)
replace occ=99 if occ==.
replace ind=99 if ind==.
*replace gind=99 if gind==.
gen usable = sex==0&templayoff==0&ui_yn==1&searchdur>0
*xi: areg l_annwg tenure empcens i.year i.occ i.ind i.mth age ed unemprate if usable==1, absorb(sippst)
xi: areg l_annwg tenure empcens i.year i.occ i.ind i.mth age ed if usable==1 [pweight = wpfinwgt], absorb(sippst)
predict l_annwg_hat
gen annwg_hat = exp(l_annwg_hat)
drop l_annwg l_annwg_hat usable _I*
/*
rename hq1w hq1w_saved
rename hq2w hq2w_saved
rename bpw bpw_saved
rename annwg annwg_saved
gen annwg=annwg_hat
gen bpw=annwg
gen hq1w=bpw/4
gen hq2w=bpw/4
do lawassign
drop hq1w
drop hq2w
drop bpw
drop annwg
rename hq1w_saved hq1w
rename hq2w_saved hq2w
rename bpw_saved bpw
rename annwg_saved annwg
*/

***DEFINE REAL VARIABLES in 1990 dollars


cpigen

gen hh_liq = hh_twlth-hh_theq-hh_vehcl
gen hh_netliq=hh_liq-hh_usdbt

/* rename annwg annwg_nom */
/* rename annwg_hat annwg_hat_nom */
/* *rename wba_act wba_act_nom */
/* rename hh_theq hh_theq_nom */
/* rename hh_liq hh_liq_nom */
/* rename hh_netliq hh_netliq_nom */
/* rename hh_twlth hh_twlth_nom */
/* rename hh_tnw hh_tnw_nom */

ren avgwba_nom avgwba
ren avgwbaqtr_nom avgwbaqtr
ren avgwbamth_nom avgwbamth

forval X = 1/36{
   sort panel suid entry pnum spell year mth
   qui by panel suid entry pnum spell: replace nextearn`X' = nextearn`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextsumearn`X' = nextsumearn`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextprimwage`X' = nextprimwage`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextprimearn`X' = nextprimearn`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextsumprimearn`X' = nextsumprimearn`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextm1earn`X' = nextm1earn`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextsumm1earn`X' = nextsumm1earn`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextm2earn`X' = nextm2earn`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextsumm2earn`X' = nextsumm2earn`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextm1wage`X' = nextm1wage`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextm2wage`X' = nextm2wage`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nexttotearn`X' = nexttotearn`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextsumtotearn`X' = nextsumtotearn`X'/cpi*1.304
   *qui by panel suid entry pnum spell: replace nextinc`X' = nextinc`X'/cpi*1.304
   *qui by panel suid entry pnum spell: replace nextspinc`X' = nextspinc`X'/cpi*1.304
   *qui by panel suid entry pnum spell: replace nextfinc`X' = nextfinc`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextearnrate`X' = nextearnrate`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextprimrate`X' = nextprimrate`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nextm1earnrate`X' = nextm1earnrate`X'/cpi*1.304
   qui by panel suid entry pnum spell: replace nexttotearnrate`X' = nexttotearnrate`X'/cpi*1.304
}

/* ren aveuiamt avguiamt_nom */
/* ren totuiamt totuiamt_nom */
/* ren uiamt uiamt_nom */
/* ren nextearn nextearn_nom */
/* ren nextearn2 nextearn2_nom */
/* ren nextprimwage nextprimwage_nom */
/* ren nextprimwage2 nextprimwage2_nom */
/* ren nextprimearn nextprimearn_nom */
/* ren nextprimearn2 nextprimearn2_nom */
/* ren nextm1earn nextm1earn_nom */
/* ren nextm1earn2 nextm1earn2_nom */
/* ren nextm2earn nextm2earn_nom */
/* ren nextm2earn2 nextm2earn2_nom */
/* ren nextm1wage nextm1wage_nom */
/* ren nextm1wage2 nextm1wage2_nom */
/* ren nextm2wage nextm2wage_nom */
/* ren nextm2wage2 nextm2wage2_nom */
/* ren nexttotearn nexttotearn_nom */
/* ren nexttotinc nexttotinc_nom */
/* ren nextspinc nextspinc_nom */
/* ren nextfinc nextfinc_nom */
/* ren nextqwage1 nextqwage1_nom */
/* ren nextqwage2 nextqwage2_nom */
/* ren nextqearnm1 nextqearnm1_nom */
/* ren nextqearnm2 nextqearnm2_nom */
/* ren nextqprimwage nextqprimwage_nom */
/* ren nextqprimearn nextqprimearn_nom */
/* ren nextqearntot nextqearntot_nom */
/* ren nextws1qearn nextws1qearn_nom */
/* ren nextqinc nextqinc_nom */
/* ren nextspqinc nextspqinc_nom */
/* ren nextfqinc nextfqinc_nom */
/* ren nextannwg nextannwg_nom */

replace annwg = annwg/cpi*1.304
replace annwg_hat = annwg_hat/cpi*1.304
*replace wba_act = wba_act*cpi
replace aveuiamt = aveuiamt/cpi*1.304
replace totuiamt = totuiamt/cpi*1.304
replace uiamt = uiamt/cpi*1.304
replace avgwba = avgwba/cpi*1.304
replace avgwbaqtr = avgwbaqtr/cpi*1.304
replace avgwbamth = avgwbamth/cpi*1.304
replace hh_theq = hh_theq/cpi*1.304
replace hh_liq = hh_liq/cpi*1.304
replace hh_netliq = hh_netliq/cpi*1.304
replace hh_twlth = hh_twlth/cpi*1.304
replace hh_tnw = hh_tnw/cpi*1.304
replace nextqwage1 = nextqwage1/cpi*1.304
replace nextqwage2 = nextqwage2/cpi*1.304
replace nextqearnm1 = nextqearnm1/cpi*1.304
replace nextqearnm2 = nextqearnm2/cpi*1.304
replace nextqprimwage = nextqprimwage/cpi*1.304
replace nextqprimearn = nextqprimearn/cpi*1.304
replace nextqearntot = nextqearntot/cpi*1.304
replace nextws1qearn = nextws1qearn/cpi*1.304
replace nextqinc = nextqinc/cpi*1.304
replace nextspqinc = nextspqinc/cpi*1.304
replace nextfqinc = nextfqinc/cpi*1.304
replace nextannwg = nextannwg/cpi*1.304


*bys sippst year: egen samp_avgwba = mean(wba)

*save allmerged, replace

***RELABEL STATES
#delimit;

label values sippst  P101L;
label define P101L
	1           "Alabama"
	4           "Arizona"
	5           "Arkansas"
	6           "California"
	8           "Colorado"
	9           "Connecticut"
	10          "Delaware"
	11          "District of Columbia"
	12          "Florida"
	13          "Georgia"
	15          "Hawaii"
	17          "Illinois"
	18          "Indiana"
	20          "Kansas"
	21          "Kentucky"
	22          "Louisiana"
	24          "Maryland"
	25          "Massachusetts"
	26          "Michigan"
	27          "Minnesota"
	28          "Mississippi"
	29          "Missouri"
	31          "Nebraska"
	32          "Nevada"
	33          "New Hampshire"
	34          "New Jersey"
	35          "New Mexico"
	36          "New York"
	37          "North Carolina"
	39          "Ohio"
	40          "Oklahoma"
	41          "Oregon"
	42          "Pennsylvania"
	44          "Rhode Island"
	45          "South Carolina"
	47          "Tennessee"
	48          "Texas"
	49          "Utah"
	51          "Virginia"
	53          "Washington"
	54          "West Virginia"
	55          "Wisconsin"
	61          "Maine,Vermont"
	62          "Iowa,North Dakota,South Dakota"
	63          "Alaska,Idaho,Montana,Wyoming"
;

cd $projdir;
save SIPPUnemp_FinalPanel.dta, replace;
