/* Generate and recreate SIPP datafiles for use with many projects */
/* Author: Ben Griffy */
/* Date: Apr., 2018 */
/* Website: https://www.bengriffy.com */
/* Note: much of the original code incorporates the work of the CEPR to clean the data, and Chetty (2008) to incorporate wealth, UI, and spells */

*log using unemp, replace

set more off
clear
 
cd "$datadir/cleaned_data/"

use SIPPBase_Panel.dta, clear
/*
destring esr1, replace
destring esr2, replace
gen esr = esr1
replace esr = 1 if esr2 == 1 & esr1 != 1
replace esr = 2 if esr2 == 2 & esr1 != 1
replace esr = 3 if esr2 == 3 & esr > 2
*/

*1. Keep only those who experience a job separation
qui {
    sort panel suid entry pnum TimeID
    gen job2U=0
    by panel suid entry pnum: replace job2U = esr[_n-1]==1&esr>=3&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])
    by panel suid entry pnum: egen mark=sum(job2U)
    keep if mark>0
    drop mark
}

quietly bysort panel suid entry pnum TimeID:  gen dup = cond(_N==1,0,_n)
tab dup
drop dup

*Other eliminations

*1
qui {
    keep if age>=18&age<65

    *2. Drop repeats
    sort panel suid entry pnum TimeID
    drop if panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1]&TimeID==TimeID[_n-1]

    *3. Generate variable that will count month in sample and drop any second interviews 
    /* I'm not sure this is the correct thing to do, but I will follow for now. This drops individuals who have gaps in their records during which they were not interviewed. */
    sort panel suid entry pnum TimeID
    gen count=1
    replace count=count[_n-1]+1 if (suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])&((mth==(mth[_n-1]+1)&year==year[_n-1]&panel==panel[_n-1])|(year==(year[_n-1]+1)&mth==1)) in 2/l
    gen index=0 
    replace index=1 if count==1 
    replace index=2 if count==1&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1]) 
    tab index
    qui by panel suid entry pnum: replace index=index[_n-1] if index==0 
    tab index
    gen intvwgap = 0
    replace intvwgap = 1 if index == 2
    /* I'm changing the code here because I don't think this is correct originally. I'll run it with and without both specifications. */
    /* replace index = 1 if index == 2 */
    drop if index>1 
    label var count "month in panel" 
}

quietly bysort panel suid entry pnum TimeID:  gen dup = cond(_N==1,0,_n)
tab dup
drop dup

* OLD EXCLUSIONS from JACULLEN
qui {
    *4. getting rid of anyone not there for at least 3 months
    egen mark=sum(index), by (panel suid entry pnum) 
    drop if mark<3
    drop mark index
}

quietly bysort panel suid entry pnum TimeID:  gen dup = cond(_N==1,0,_n)
tab dup
drop dup


/*5. Now sorting according to month and locating first 3 consecutive months
 where individual is working, defined as esr=1|2, ws1amt>0, and selfemp~=2
 Get rid of those with less than three months work history
 */

qui {
    gen mark=0
    *ren earn1 ws1amt
    *ren earn2 ws2amt
    gen selfemp = 0
    replace selfemp = 2 if (selfinc1 > 0 & selfinc1 != .) | (selfinc2 > 0 & selfinc2 != .)
    replace mark=1 if (esr==1|esr==2)&ws1amt>=0&ws1amt~=.&selfemp~=2
    sort panel suid entry pnum TimeID
    replace mark=mark[_n-1]+1 if (panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])&mark[_n-1]>0&mark>0 in 2/l
    qui by panel suid entry pnum: replace mark=0 if mark==1&mark[_n+2]~=3
    qui by panel suid entry pnum: replace mark=0 if mark==2&mark[_n+1]~=3
    qui by panel suid entry pnum: replace mark=0 if mark~=1
    replace mark=mark[_n-1] if mark[_n-1]>0&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1]) in 2/l
    drop if mark==0
    drop mark
}

quietly bysort panel suid entry pnum TimeID:  gen dup = cond(_N==1,0,_n)
tab dup
drop dup

***GENERATE NEW VARIABLES
qui {
    *months in sample
    gen mark=1
    by panel suid entry pnum: egen mthsinsamp = sum(mark)
    drop mark
}

quietly bysort panel suid entry pnum TimeID:  gen dup = cond(_N==1,0,_n)
tab dup
drop dup

qui {
    *kids
    rename famkid kids

    *education
    gen ed = educ
    /*
    replace higrade=higrade-1 if grdcmpl==2&higrade>0 
    gen ed=higrade
    replace ed=12 if higrade==20
    replace ed=ed-8 if higrade>20 
    drop grdcmpl 
    */
    *marital dummy and other indicators
    gen mardum=0 
    replace mardum=1 if ms==1|ms==2 
    gen white=1
    replace white=0 if race>1 
    gen seamth=0
    replace seamth=1 if refmth==4 
    egen uhours = rowmax(job1hrs job2hrs)
    sort panel suid entry pnum TimeID
    gen fulltime = uhours[_n-1]>35&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1]) 
}

quietly bysort panel suid entry pnum TimeID:  gen dup = cond(_N==1,0,_n)
tab dup
drop dup

*generate calendar qtr indicator
qui {
    gen calqtr=0
    replace calqtr=1 if mth>=1&mth<=3
    replace calqtr=2 if mth>=4&mth<=6
    replace calqtr=3 if mth>=7&mth<=9
    replace calqtr=4 if mth>=10&mth<=12
    label var calqtr "calendar quarter"
}

quietly bysort panel suid entry pnum TimeID:  gen dup = cond(_N==1,0,_n)
tab dup
drop dup

*generate quarter in sample (calendar quarter #1-8 for each obs so we can collapse)
qui {
    replace count=1
    sort panel suid entry pnum TimeID
    replace count=count[_n-1]+1 if (panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1]) in 2/l
}

quietly bysort panel suid entry pnum TimeID:  gen dup = cond(_N==1,0,_n)
tab dup
drop dup

qui {
    gen mark=1
    egen check=sum(mark), by (panel suid entry pnum year calqtr)
    gen qtr=1 if count==1
    replace qtr=0 if count==1&check<3
    drop check mark
    gen mark=0
    replace mark=1 if qtr~=.
    replace mark=1 if (panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])&calqtr~=calqtr[_n-1] in 2/l
    sort panel suid entry pnum mark count
    qui by panel suid entry pnum: replace qtr=qtr[_n-1]+1 if mark==1&mark[_n-1]==1&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])
    drop mark
    sort panel suid entry pnum count
    replace qtr=qtr[_n-1] if qtr==.&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1]) 
    label var qtr "quarter in sample"

    sort pnsp TimeID
    save SIPPUnemp_Panel.dta, replace
}

*generate spwork_yn and spinc (spouse working dummy and spouse total income in each month)
*Match only by suid and pnum -- broad definition

cd "$datadir/cleaned_data/"

use SIPPBase_Panel.dta, clear
gen spwork_yn = (esr==1|esr==2|esr==3)
gen spinc=totinc
keep panel id pnsp TimeID year mth spwork_yn spinc
replace id = pnsp
keep if pnsp != ""
quietly bysort panel id TimeID:  gen dup = cond(_N==1,0,_n)
drop if dup > 0
keep id TimeID panel spwork_yn spinc
order panel id TimeID
sort panel id TimeID

save "$tmpdir/temp", replace
/*
keep if spouseid != .
duplicates drop panel spouseid TimeID, force
sort panel spouseid TimeID
save temp_1, replace
use SIPP_panel.dta, clear
gen spwork_yn2 = (esr==1|esr==2|esr==3)
gen spinc2=totinc
keep panel spousesuid spouseentry spousepnum TimeID year mth spwork_yn2 spinc2
keep if spousesuid !=. & spouseentry != . & spousepnum != .
sort panel spousesuid spouseentry spousepnum TimeID
save temp_2, replace
*/
use SIPPUnemp_Panel.dta, clear
*gen pnsp_bak = pnsp
*replace pnsp = id
/*
keep if spouseid == . & spousesuid ==. & spouseentry == . & spousepnum == .
save no_spouse_data, replace
use unemp_panel.dta, clear
*/
sort panel id TimeID
merge 1:1 panel id TimeID using "$tmpdir/temp"
tabulate _merge
drop if _merge == 2
drop _merge


***CREATE WEEKLY INCOME PROFILE LOOKING FORWARD FOR FUTURE USE
ren wksper wks
sort panel suid entry pnum TimeID
replace job1hrs = 0 if job1hrs < 0
replace job2hrs = 0 if job2hrs < 0
gen temp1 = round(earnm1/(wks*wage1)) if (job1hrs == . | job1hrs == 0) & earnm1 ~= . & wage1 ~= . & wage1 ~= 0
gen temp2 = round(earnm2/(wks*wage2)) if (job2hrs == . | job2hrs == 0) & earnm2 ~= . & wage2 ~= . & wage2 ~= 0
replace job1hrs = temp1 if (job1hrs == . | job1hrs == 0) & temp1 > 0 & temp1 ~= .
replace job2hrs = temp2 if (job2hrs == . | job2hrs == 0) & temp2 > 0 & temp2 ~= .
drop temp1 temp2

gen temp1 = earnm1/(wks*job1hrs) if job1hrs ~= . & job1hrs ~= 0 & earnm1 ~= . & earnm1 ~= 0 & (wage1 == . | wage1 == 0)
gen temp2 = earnm2/(wks*job2hrs) if job2hrs ~= . & job2hrs ~= 0 & earnm2 ~= . & earnm2 ~= 0 & (wage2 == . | wage2 == 0)
replace wage1 = temp1 if wage1 == . & temp1 ~= .
replace wage2 = temp2 if wage2 == . & temp2 ~= .
drop temp1 temp2

*gen temp1 = job1hrs*5 if (job1hrs + job2hrs) < 40 & fulltime == 1 & job1hrs < 20 & wage1 > 300


gen primwage = wage1 if primary == 1
replace primwage = wage2 if primary == 2
gen primearn = earnm1 if primary == 1
replace primearn = earnm2 if primary == 2
gen primhrs = job1hrs if primary == 1
replace primhrs = job2hrs if primary == 2
gen tothrs = job1hrs+job2hrs

gen wksunemp = (wesr1>=3)+(wesr2>=3)+(wesr3>=3)+(wesr4>=3)+(wesr5>=3&wesr5!=.)
gen wksemp = (wesr1==1|wesr1==2)+(wesr2==1|wesr2==2)+ ///
   (wesr3==1|wesr3==2)+(wesr4==1|wesr4==2)+((wesr5==1|wesr5==2)&wesr5!=.)
gen searchwks = (wesr1==4)+(wesr2==4)+(wesr3==4)+(wesr4==4)+(wesr5==4&wesr5!=.)


gen ws1amt_tot = ws1amt
replace ws1amt_tot = 0 if ws1amt == .
gen ws2amt_tot = ws2amt
replace ws2amt_tot = 0 if ws2amt == .

egen totearn=rowtotal(ws1amt_tot ws2amt_tot)

forval X = 1/36{
   sort panel suid entry pnum TimeID
   qui by panel suid entry pnum: gen wks_f`X'=wks[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X'])
   egen sumwks_f`X'=rowtotal(wks_f*)
   qui by panel suid entry pnum: gen empwks_f`X'=wksemp[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X'])
   egen sumempwks_f`X'=rowtotal(empwks_f*)
   qui by panel suid entry pnum: gen earn_f`X'=earn[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X'])
   egen sumearn_f`X'=rowtotal(earn_f*)
   qui by panel suid entry pnum: gen primwage_f`X'=primwage[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen primearn_f`X'=primearn[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X'])
   egen sumprimearn_f`X'=rowtotal(primearn_f*)
   qui by panel suid entry pnum: gen hrs1_f`X'=job1hrs[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X'])
   egen sumhrs1_f`X'=rowtotal(hrs1_f*)
   qui by panel suid entry pnum: gen primhrs_f`X'=primhrs[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X'])
   egen sumprimhrs_f`X'=rowtotal(primhrs_f*) 
   qui by panel suid entry pnum: gen tothrs_f`X'=tothrs[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   egen sumtothrs_f`X'=rowtotal(tothrs_f*)
   qui by panel suid entry pnum: gen earnm1_f`X'=earnm1[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   egen sumearnm1_f`X'=rowtotal(earnm1_f*)
   qui by panel suid entry pnum: gen earnm2_f`X'=earnm2[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   egen sumearnm2_f`X'=rowtotal(earnm2_f*)
   qui by panel suid entry pnum: gen wage1_f`X'=wage1[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen wage2_f`X'=wage2[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen totearn_f`X'=totearn[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   egen sumtotearn_f`X'=rowtotal(totearn_f*)
   *qui by panel suid entry pnum: gen inc_f`X'=totinc[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   *qui by panel suid entry pnum: gen spinc_f`X'=spinc[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   *qui by panel suid entry pnum: gen finc_f`X'=finc[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
}


egen qwage1=mean(wage1), by (panel suid entry pnum qtr year)
egen qwage2=mean(wage2), by (panel suid entry pnum qtr year)
egen qearnm1=sum(earnm1), by (panel suid entry pnum qtr year)
egen qearnm2=sum(earnm2), by (panel suid entry pnum qtr year)
egen qprimwage=mean(primwage), by (panel suid entry pnum qtr year)
egen qprimearn=sum(primearn), by (panel suid entry pnum qtr year)
egen qearn=sum(earn), by (panel suid entry pnum qtr year)
egen qhrs1=sum(job1hrs), by (panel suid entry pnum qtr year)
egen qprimhrs=sum(primhrs), by (panel suid entry pnum qtr year)
egen qhrs=sum(tothrs), by (panel suid entry pnum qtr year)
egen qearntot=sum(ws1amt_tot+ws2amt_tot), by (panel suid entry pnum qtr year)
egen ws1qearn=sum(ws1amt_tot), by (panel suid entry pnum qtr year)
egen qinc=sum(totinc), by (panel suid entry pnum qtr year)
egen fqinc=sum(finc), by (panel suid entry pnum qtr year)
egen spqinc = sum(spinc), by (panel suid entry pnum qtr year)
egen qwks = sum(wks), by (panel suid entry pnum qtr year)
egen qempwks = sum(wksemp), by (panel suid entry pnum qtr year)

drop wksunemp wksemp searchwks

cd "$datadir/cleaned_data/"
save SIPPUnemp_Panel.dta, replace


***CREATE QUARTERLY WAGE HISTORY AND DEFINE INPUTS FOR UI LAWS
/* -own earnings, total income
  spouse total income, and family total income are all computed
  */
*nominal wages
*Note: use info only from ws1 for own earn because 2nd job is usually job gotten after unemp ends
cd "$datadir/cleaned_data/"
use SIPPUnemp_Panel.dta, replace
/*
gen ws1amt_tot = ws1amt
replace ws1amt_tot = 0 if ws1amt == .
gen ws2amt_tot = ws2amt
replace ws2amt_tot = 0 if ws2amt == .

egen qearn=sum(ws1amt_tot+ws2amt_tot), by (panel suid entry pnum qtr year)
egen ws1qearn=sum(ws1amt_tot), by (panel suid entry pnum qtr year)
egen fqinc=sum(finc), by (panel suid entry pnum qtr year)
egen spqinc = sum(spinc), by (panel suid entry pnum qtr year)
egen qwks = sum(wks), by (panel suid entry pnum qtr year)
*/
*generate 3-month sums if agent loses job before calendar quarter of info
gen mark=0
replace mark=1 if count<4
egen temp1=mean(wage1), by (panel suid entry pnum year mark)
egen temp2=mean(wage2), by (panel suid entry pnum year mark)
egen temp3=sum(earnm1), by (panel suid entry pnum year mark)
egen temp4=sum(earnm2), by (panel suid entry pnum year mark)
egen temp5=mean(primwage), by (panel suid entry pnum year mark)
egen temp6=sum(primearn), by (panel suid entry pnum year mark)
egen temp7=sum(earn), by (panel suid entry pnum year mark)
egen temp8=sum(job1hrs), by (panel suid entry pnum year mark)
egen temp9=sum(primhrs), by (panel suid entry pnum year mark)
egen temp10=sum(tothrs), by (panel suid entry pnum year mark)
egen temp11=sum(ws1amt_tot+ws2amt_tot), by (panel suid entry pnum year mark)
egen temp12=sum(ws1amt_tot), by (panel suid entry pnum year mark)
egen temp13=sum(totinc), by (panel suid entry pnum year mark)
egen temp14=sum(finc), by (panel suid entry pnum year mark)
egen temp15=sum(spinc), by (panel suid entry pnum year mark)
egen temp16=sum(wks), by (panel suid entry pnum year mark)
replace qwage1=temp1 if qtr==0
replace qwage2=temp2 if qtr==0
replace qearnm1=temp3 if qtr==0
replace qearnm2=temp4 if qtr==0
replace qprimwage=temp5 if qtr==0
replace qprimearn=temp6 if qtr==0
replace qearn=temp7 if qtr==0
replace qhrs1=temp8 if qtr==0
replace qprimhrs=temp9 if qtr==0
replace qhrs=temp10 if qtr==0
replace qearntot=temp11 if qtr==0
replace ws1qearn=temp12 if qtr==0
replace qinc=temp13 if qtr==0
replace fqinc=temp14 if qtr==0
replace spqinc=temp15 if qtr==0
replace qwks=temp16 if qtr==0

drop tem* mark count

collapse (mean) qwage* qearn* qprim* qhrs* ws1qearn qinc fqinc spqinc qwks, by (panel suid entry pnum qtr year)

forval X = 1/5{
   sort panel suid entry pnum qtr year
   qui by panel suid entry pnum: gen qwage1_f`X'=qwage1[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qwage2_f`X'=qwage2[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qearnm1_f`X'=qearnm1[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qearnm2_f`X'=qearnm2[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qprimwage_f`X'=qprimwage[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qprimearn_f`X'=qprimearn[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qearn_f`X'=qearn[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qhrs1_f`X'=qhrs1[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qprimhrs_f`X'=qprimhrs[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qhrs_f`X'=qhrs[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qearntot_f`X'=qearntot[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen ws1qearn_f`X'=ws1qearn[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qinc_f`X'=qinc[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen spqinc_f`X'=spqinc[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen fqinc_f`X'=fqinc[_n + `X'] if (panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
   qui by panel suid entry pnum: gen qwks_f`X'=qwks[_n + `X'] &(panel==panel[_n+`X']&suid==suid[_n+`X']&entry==entry[_n+`X']&pnum==pnum[_n+`X']) 
}

*Compute base period earn, but ignore the lag when data limits it
gen bpwf=4*qearn_f1 if qtr<=2
replace bpwf=2*(qearn_f1+qearn_f2) if qtr==3
replace bpwf=(4/3)*(qearn_f1+qearn_f2+qearn_f3) if qtr==4
replace bpwf=(qearn_f1+qearn_f2+qearn_f3+qearn_f4) if qtr==5
replace bpwf=(qearn_f2+qearn_f3+qearn_f4+qearn_f5) if qtr>=6

gen annwgf=bpwf if qtr<=4
replace annwgf=(qearn_f1+qearn_f2+qearn_f3+qearn_f4) if qtr>=5

*generate lagged quarterly wages
forval X = 1/5{
	sort panel suid entry pnum qtr year
	qui by panel suid entry pnum: gen qearn_l`X'=qearn[_n-`X'] &(panel==panel[_n-`X']&suid==suid[_n-`X']&entry==entry[_n-`X']&pnum==pnum[_n-`X']) 
	qui by panel suid entry pnum: gen ws1qearn_l`X'=ws1qearn[_n-`X'] &(panel==panel[_n-`X']&suid==suid[_n-`X']&entry==entry[_n-`X']&pnum==pnum[_n-`X']) 
	qui by panel suid entry pnum: gen qwks_l`X'=qwks[_n-`X'] &(panel==panel[_n-`X']&suid==suid[_n-`X']&entry==entry[_n-`X']&pnum==pnum[_n-`X']) 
}
*Compute base period wage, but ignore the lag when data limits it
gen bpw=4*qearn_l1 if qtr<=2
replace bpw=2*(qearn_l1+qearn_l2) if qtr==3
replace bpw=(4/3)*(qearn_l1+qearn_l2+qearn_l3) if qtr==4
replace bpw=(qearn_l1+qearn_l2+qearn_l3+qearn_l4) if qtr==5
replace bpw=(qearn_l2+qearn_l3+qearn_l4+qearn_l5) if qtr>=6

/* Annual wage at previous work */
gen annwg=bpw if qtr<=4
replace annwg=(qearn_l1+qearn_l2+qearn_l3+qearn_l4) if qtr>=5

gen hq1w=qearn_l1 if qtr<=2
replace hq1w=max(qearn_l1,qearn_l2) if qtr==3
replace hq1w=max(qearn_l1,qearn_l2,qearn_l3) if qtr==4
replace hq1w=max(qearn_l1,qearn_l2,qearn_l3,qearn_l4) if qtr>=5

gen hq2w=qearn_l1 if qtr<=2
replace hq2w=min(qearn_l1,qearn_l2) if qtr==3
replace hq2w=max((qearn_l1<hq1w)*qearn_l1,(qearn_l2<hq1w)*qearn_l2,(qearn_l3<hq1w)*qearn_l3) if qtr==4
replace hq2w=max((qearn_l1<hq1w)*qearn_l1,(qearn_l2<hq1w)*qearn_l2, ///
		     (qearn_l3<hq1w)*qearn_l3,(qearn_l4<hq1w)*qearn_l4) if qtr>=5

gen cv_earn=sqrt(((qearn_l1-bpw/4)^2+(qearn_l2-bpw/4)^2)/2)/(bpw/4) if qtr==3
replace cv_earn=sqrt(((qearn_l1-bpw/4)^2+(qearn_l2-bpw/4)^2+(qearn_l3-bpw/4)^2)/3)/(bpw/4) if qtr==4
replace cv_earn=sqrt(((qearn_l1-bpw/4)^2+(qearn_l2-bpw/4)^2+ ///
		(qearn_l3-bpw/4)^2+(qearn_l4-bpw/4)^2)/4)/(bpw/4) if qtr>=5

*Generate annual family info

forval X = 1/4{ 
	qui by panel suid entry pnum: gen fqinc_l`X'=fqinc[_n-`X']
	} 
gen fanninc=4*fqinc_l1 if qtr<=2
replace fanninc=2*(fqinc_l1+fqinc_l2) if qtr==3
replace fanninc=(4/3)*(fqinc_l1+fqinc_l2+fqinc_l3) if qtr==4
replace fanninc=(fqinc_l1+fqinc_l2+fqinc_l3+fqinc_l4) if qtr>=5

forval X = 1/4{ 
	qui by panel suid entry pnum: gen spqinc_l`X'=spqinc[_n-`X']
	}
gen spanninc=4*spqinc_l1 if qtr<=2
replace spanninc=2*(spqinc_l1+spqinc_l2) if qtr==3
replace spanninc=(4/3)*(spqinc_l1+spqinc_l2+spqinc_l3) if qtr==4
replace spanninc=(spqinc_l1+spqinc_l2+spqinc_l3+spqinc_l4) if qtr>=5


keep panel suid entry pnum qtr fanninc spanninc ws1q* spq* fq* q* bpw* hq1w hq2w annwg* cv_earn
save "$tmpdir/temp", replace
cd "$datadir/cleaned_data/"
use SIPPUnemp_Panel.dta, replace
sort panel suid entry pnum qtr year
merge panel suid entry pnum qtr using "$tmpdir/temp"
tabulate _merge
drop _merge
cd "$datadir/cleaned_data/"
save SIPPUnemp_Panel.dta, replace
rm "$tmpdir/temp.dta"

