/* Generate and recreate SIPP datafiles for use with many projects */
/* Author: Ben Griffy */
/* Date: Apr., 2018 */
/* Website: https://www.bengriffy.com */
/* Note: much of the original code incorporates the work of the CEPR to clean the data, and Chetty (2008) to incorporate wealth, UI, and spells */

*log using spells, replace
set more off
clear
set type double



*8-11-02 This program creates a dataset of unemp spells from individual monthly SIPP data
 *Input dataset: unemp$Y
 *Output dataset: spells$Y
cd "$datadir/cleaned_data/"
*use SIPPUnemp_Panel.dta, replace
use SIPPUnemp_Panel.dta, replace

*** JOB SEPARATION DEFINED IN UNEMP.DO

sort panel suid entry pnum TimeID
drop if panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1]&TimeID==TimeID[_n-1]
/*
*List of vars potentially useful to discern job separation: 
   esr weeks wesr1 wesr2 wesr3 wesr4 wesr5 wksjob wkswop wkslok reasab takjob
   takjobn cwork uhours wkspt wksptr empled w1stop w2stop
*	Could add &wksjob[_n-2]==wks[_n-2]&....
	(for further stability of pre-unemp job in sample if desired)
	(defs below include partial unemployment)
*/
*Other possibilties: change in wesr status, diff options in 96 SIPP
*Definitions below are problematic for various reasons: see exploratory notes
/*
 gen job2U4=0
 by panelid: replace job2U4 = notfullemp==1&notfullemp[_n-1]~=1
 gen job2U3=0
 replace job2U3=w1stop_yn==1
 gen job2U1=0
 by panelid: replace job2U1 = wksjob<wks&wksjob[_n-1]==wks[_n-1]
 */
*by panelid: replace job2U = esr[_n-1]==1&(esr==3|esr==5|esr==6|esr==7)
* Note: this def ignores problems of partial unemployment for now and only looks at jobs that last for at least one month
*OLD Def of wksunemp below excludes weeks not looking
*NEW DEF of wksunemp INCLUDES weeks not looking
*gen wksunemp2 = (wesr1==4|wesr1==3)+(wesr2==4|wesr2==3)+(wesr3==4|wesr3==3)+(wesr4==4|wesr4==3)+(wesr5==4|wesr5==3)
*ren weeks wks
/* Define weeks of employment status */
drop if wks == 0
gen wksunemp = (wesr1>=3)+(wesr2>=3)+(wesr3>=3)+(wesr4>=3)+(wesr5>=3&wesr5!=.)
gen wksemp = (wesr1==1|wesr1==2)+(wesr2==1|wesr2==2)+ ///
   (wesr3==1|wesr3==2)+(wesr4==1|wesr4==2)+((wesr5==1|wesr5==2)&wesr5!=.)
gen searchwks = (wesr1==4)+(wesr2==4)+(wesr3==4)+(wesr4==4)+(wesr5==4&wesr5!=.)
gen unempmth = (wksunemp==wks)


sort panel suid entry pnum TimeID
/* Use data to define job separation */
by panel suid entry pnum: gen job2U1 = wksemp<wks&wksemp[_n-1]==wks[_n-1] & wksemp != . & wks != .&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])
by panel suid entry pnum: gen job2U2 = wksunemp>0&wksemp[_n-1]==wks[_n-1] & wksunemp != . & wks != .&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])

*create weight for each person by spell
* Note: this is the suggested method for creating weights from the documentation
gen spellwgt=.
sort panel suid entry pnum job2U year mth
by panel suid entry pnum job2U: replace spellwgt = wpfinwgt if job2U==1
sort panel suid entry pnum year mth
by panel suid entry pnum: replace spellwgt=spellwgt[_n-1] if wksunemp>0&job2U~=1&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])
gen spellgvar=.
gen spellpsu=.
gen spellstratavar=.
gen spellpsuvar=.
destring gvarstr, replace
destring ghlfsam, replace
destring stratavar, replace
destring psuvar, replace
sort panel suid entry pnum job2U year mth
by panel suid entry pnum job2U: replace spellgvar = gvarstr if job2U==1
by panel suid entry pnum job2U: replace spellpsu = ghlfsam if job2U==1
by panel suid entry pnum job2U: replace spellstratavar = stratavar if job2U==1
by panel suid entry pnum job2U: replace spellpsuvar = psuvar if job2U==1
sort panel suid entry pnum year mth
by panel suid entry pnum: replace spellstratavar=spellstratavar[_n-1] if wksunemp>0&job2U~=1&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])
by panel suid entry pnum: replace spellpsuvar=spellpsuvar[_n-1] if wksunemp>0&job2U~=1&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])

*Label each spell of unemployment for each person
gen spell=.
sort panel suid entry pnum job2U year mth
by panel suid entry pnum job2U: replace spell = _n if job2U==1
tab spell
sort panel suid entry pnum year mth
by panel suid entry pnum: replace spell=spell[_n-1] if wksunemp>0&job2U~=1&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])

*Add weeks and uiamt in each spell to compute dur and totuiamt
sort panel suid entry pnum spell
by panel suid entry pnum spell: egen dur = sum(wksunemp)
by panel suid entry pnum spell: egen searchdur = sum(searchwks)
by panel suid entry pnum spell: egen totuiamt = sum(uiamt)
by panel suid entry pnum spell: egen aveuiamt = mean(uiamt)

*Add weeks remaining in a wave for seam calculation
gen unempwk = (wesr1>=3)*1 ///
   +(wesr1<3&wesr2>=3)*2 ///
   +(wesr1<3&wesr2<3&wesr3>=3)*3 ///
   +(wesr1<3&wesr2<3&wesr3<3&wesr4>=3)*4 ///
   +(wesr1<3&wesr2<3&wesr3<3&wesr4<3&(wesr5>=3&wesr5!=.))*5

sort panel suid entry pnum wave refmth
by panel suid entry pnum wave: egen refwks = sum(wks)
replace refwks=. if refwks<17
tab refwks

sort panel suid entry pnum TimeID
gen seam1wks = refwks-(unempwk-1) if job2U==1&refmth==1&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])
replace seam1wks = refwks-wks[_n-1]-(unempwk-1) if job2U==1&refmth==2&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])
replace seam1wks = refwks-wks[_n-1]-wks[_n-2]-(unempwk-1) if job2U==1&refmth==3&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])&(panel==panel[_n-2]&suid==suid[_n-2]&entry==entry[_n-2]&pnum==pnum[_n-2])
replace seam1wks = wks-(unempwk-1) if job2U==1&refmth==4&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])

sort panel suid entry pnum TimeID
gen ref2wks = refwks[_n+1] if suid==suid[_n+1]&pnum==pnum[_n+1]&(wave[_n+1]-wave==1)
gen ref3wks = ref2wks[_n+1] if suid==suid[_n+1]&pnum==pnum[_n+1]&(wave[_n+1]-wave==1)
sort panel suid entry pnum TimeID
gen seam2wks = seam1wks+ref2wks if job2U==1
gen seam3wks = seam1wks+ref2wks+ref3wks if job2U==1

*Label right-censored spells
sort panel suid entry pnum year mth
by panel suid entry pnum: gen mthsleft = _N-_n
gen censrd=0
replace censrd=1 if mthsleft==0&unempmth==1
sort panel suid entry pnum spell year mth
by panel suid entry pnum spell: replace censrd=censrd[_N]

*Compute tenure -- weeks employed before job separation
*Need to reverse sorting order to execute replace mark statement
gsort +panel suid entry pnum -year -mth
gen mark=spell
by panel suid entry pnum: replace mark=mark[_n-1] if wksemp>0&job2U==0&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])
sort panel suid entry pnum mark
by panel suid entry pnum mark: egen tenure=sum(wksemp)

*Identify censored tenures  
sort panel suid entry pnum year mth
by panel suid entry pnum: gen cummths = _n
gen empcens=0
replace empcens=1 if cummths==1&wksemp==wks
by panel suid entry pnum: replace empcens=1 if wksemp==wks&empcens[_n-1]==1&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])
by panel suid entry pnum: replace empcens=1 if job2U==1&empcens[_n-1]==1&(panel==panel[_n-1]&suid==suid[_n-1]&entry==entry[_n-1]&pnum==pnum[_n-1])
/*
forval X = 1/6{
   qui by panel suid entry pnum: gen wksemp_f`X'=wksemp[_n + `X']
   qui by panel suid entry pnum: gen mospctemp_f`X'=wksemp[_n + `X']/wks_f`X'
}

egen tempearn_f = rowtotal(earn_f1 earn_f2 earn_f3 earn_f4 earn_f5 earn_f6)
egen tempwage_f = rowtotal(wage_f1 wage_f2 wage_f3 wage_f4 wage_f5 wage_f6)
gen tempcountearn_f = (earn_f1>0&earn_f1!=.)+(earn_f2>0&earn_f2!=.)+(earn_f3>0&earn_f3!=.) ///
	+(earn_f4>0&earn_f4!=.)+(earn_f5>0&earn_f5!=.)+(earn_f6>0&earn_f6!=.)
gen tempcountwage_f = (wage_f1>0&wage_f1!=.)+(wage_f2>0&wage_f2!=.)+(wage_f3>0&wage_f3!=.) ///
	+(wage_f4>0&wage_f4!=.)+(wage_f5>0&wage_f5!=.)+(wage_f6>0&wage_f6!=.)

gen meanearn_f6 = tempearn_f/tempcountearn_f if tempcountearn_f >0 & tempcountearn_f != .
gen meanwage_f6 = tempwage_f/tempcountwage_f if tempcountwage_f >0 & tempcountwage_f != .

gen tempearn_f12 = earn_f1
gen tempcountearn_f12 = (earn_f1>0&earn_f1!=.)
gen tempwage_f12 = wage_f1
gen tempcountwage_f12 = (wage_f1>0&wage_f1!=.)

forval X = 2/12{
   qui by panel suid entry pnum: replace tempearn_f12 = tempearn_f12 + earn_f`X' if earn_f`X' != .
   qui by panel suid entry pnum: replace tempcountearn_f12 = tempcountearn_f12 + (earn_f`X'>0&earn_f`X'!=.)
   qui by panel suid entry pnum: replace tempwage_f12 = tempwage_f12 + wage_f`X' if wage_f`X' != .
   qui by panel suid entry pnum: replace tempcountwage_f12 = tempcountwage_f12 + (wage_f`X'>0&wage_f`X'!=.)
}

gen meanearn_f12 = tempearn_f12/tempcountearn_f12 if tempcountearn_f12 >0 & tempcountearn_f12 != .
gen totearn_f12  = tempearn_f12
gen meanwage_f12 = tempwage_f12/tempcountwage_f12 if tempcountwage_f12 >0 & tempcountwage_f12 != .
gen totalwage_f12  = tempwage_f12

gen tempearn_f24 = earn_f1
gen tempcountearn_f24 = (earn_f1>0&earn_f1!=.)
gen tempwage_f24 = wage_f1
gen tempcountwage_f24 = (wage_f1>0&wage_f1!=.)

forval X = 2/24{
   qui by panel suid entry pnum: replace tempearn_f24 = tempearn_f24 + earn_f`X' if earn_f`X' != .
   qui by panel suid entry pnum: replace tempcountearn_f24 = tempcountearn_f24 + (earn_f`X'>0&earn_f`X'!=.)
   qui by panel suid entry pnum: replace tempwage_f24 = tempwage_f24 + wage_f`X' if wage_f`X' != .
   qui by panel suid entry pnum: replace tempcountwage_f24 = tempcountwage_f24 + (wage_f`X'>0&wage_f`X'!=.)
}

gen meanearn_f24 = tempearn_f24/tempcountearn_f24 if tempcountearn_f24 >0 & tempcountearn_f24 != .
gen totearn_f24  = tempearn_f24
gen meanwage_f24 = tempwage_f24/tempcountwage_f24 if tempcountwage_f24 >0 & tempcountwage_f24 != .
gen totalwage_f24  = tempwage_f24

gen tempearn_f36 = earn_f1
gen tempcountearn_f36 = (earn_f1>0&earn_f1!=.)
gen tempwage_f36 = wage_f1
gen tempcountwage_f36 = (wage_f1>0&wage_f1!=.)

forval X = 2/36{
   qui by panel suid entry pnum: replace tempearn_f36 = tempearn_f36 + earn_f`X' if earn_f`X' != .
   qui by panel suid entry pnum: replace tempcountearn_f36 = tempcountearn_f36 + (earn_f`X'>0&earn_f`X'!=.)
   qui by panel suid entry pnum: replace tempwage_f36 = tempwage_f36 + wage_f`X' if wage_f`X' != .
   qui by panel suid entry pnum: replace tempcountwage_f36 = tempcountwage_f36 + (wage_f`X'>0&wage_f`X'!=.)
}

gen meanearn_f36 = tempearn_f36/tempcountearn_f36 if tempcountearn_f36 >0 & tempcountearn_f36 != .
gen totearn_f36  = tempearn_f36
gen meanwage_f36 = tempwage_f36/tempcountwage_f36 if tempcountwage_f36 >0 & tempcountwage_f36 != .
gen totalwage_f36  = tempwage_f36
*/

*Compute actual weekly wage after job find and dummy for spell ending on seam
forval X = 1/36{
   sort panel suid entry pnum TimeID
   qui by panel suid entry pnum: gen nextwks`X' = wks_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextsumwks`X' = sumwks_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextempwks`X' = empwks_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextsumempwks`X' = sumempwks_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextearn`X' = earn_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextsumearn`X' = sumearn_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextprimwage`X' = primwage_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextprimearn`X' = primearn_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextsumprimearn`X' = sumprimearn_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextm1hrs`X' = hrs1_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextsumm1hrs`X' = sumhrs1_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextprimhrs`X' = primhrs_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextsumprimhrs`X' = sumprimhrs_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nexttothrs`X' = tothrs_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextsumtothrs`X' = sumtothrs_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextm1earn`X' = earnm1_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextsumm1earn`X' = sumearnm1_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextm2earn`X' = earnm2_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextsumm2earn`X' = sumearnm2_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextm1wage`X' = wage1_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextm2wage`X' = wage2_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nexttotearn`X' = totearn_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextsumtotearn`X' = sumtotearn_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   *qui by panel suid entry pnum: gen nextinc`X' = inc_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   *qui by panel suid entry pnum: gen nextspinc`X' = spinc_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   *qui by panel suid entry pnum: gen nextfinc`X' = finc_f`X' if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextearnrate`X' = nextsumearn`X'/(nextsumempwks`X'*nextsumtothrs`X') if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextprimrate`X' = nextsumprimearn`X'/(nextsumempwks`X'*nextsumprimhrs`X') if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextm1earnrate`X' = nextsumm1earn`X'/(nextsumempwks`X'*nextsumm1hrs`X') if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nextm2earnrate`X' = nextsumm2earn`X'/(nextsumempwks`X'*(nextsumtothrs`X'-nextsumm1hrs`X')) if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
   qui by panel suid entry pnum: gen nexttotearnrate`X' = nextsumtotearn`X'/(nextsumempwks`X'*nextsumtothrs`X') if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
}

forval X = 1/36{
   sort panel suid entry pnum spell year mth
   qui by panel suid entry pnum spell: replace nextwks`X' = nextwks`X'[_N]
   qui by panel suid entry pnum spell: replace nextsumwks`X' = nextsumwks`X'[_N]
   qui by panel suid entry pnum spell: replace nextempwks`X' = nextempwks`X'[_N]
   qui by panel suid entry pnum spell: replace nextsumempwks`X' = nextsumempwks`X'[_N]
   qui by panel suid entry pnum spell: replace nextearn`X' = nextearn`X'[_N]
   qui by panel suid entry pnum spell: replace nextsumearn`X' = nextsumearn`X'[_N]
   qui by panel suid entry pnum spell: replace nextprimwage`X' = nextprimwage`X'[_N]
   qui by panel suid entry pnum spell: replace nextprimearn`X' = nextprimearn`X'[_N]
   qui by panel suid entry pnum spell: replace nextsumprimearn`X' = nextsumprimearn`X'[_N]
   qui by panel suid entry pnum spell: replace nextm1hrs`X' = nextm1hrs`X'[_N]
   qui by panel suid entry pnum spell: replace nextsumm1hrs`X' = nextsumm1hrs`X'[_N]
   qui by panel suid entry pnum spell: replace nextprimhrs`X' = nextprimhrs`X'[_N]
   qui by panel suid entry pnum spell: replace nextsumprimhrs`X' = nextsumprimhrs`X'[_N]
   qui by panel suid entry pnum spell: replace nexttothrs`X' = nexttothrs`X'[_N]
   qui by panel suid entry pnum spell: replace nextsumtothrs`X' = nextsumtothrs`X'[_N]
   qui by panel suid entry pnum spell: replace nextm1earn`X' = nextm1earn`X'[_N]
   qui by panel suid entry pnum spell: replace nextsumm1earn`X' = nextsumm1earn`X'[_N]
   qui by panel suid entry pnum spell: replace nextm2earn`X' = nextm2earn`X'[_N]
   qui by panel suid entry pnum spell: replace nextsumm2earn`X' = nextsumm2earn`X'[_N]
   qui by panel suid entry pnum spell: replace nextm1wage`X' = nextm1wage`X'[_N]
   qui by panel suid entry pnum spell: replace nextm2wage`X' = nextm2wage`X'[_N]
   qui by panel suid entry pnum spell: replace nexttotearn`X' = nexttotearn`X'[_N]
   qui by panel suid entry pnum spell: replace nextsumtotearn`X' = nextsumtotearn`X'[_N]
   *qui by panel suid entry pnum spell: replace nextinc`X' = nextinc`X'[_N]
   *qui by panel suid entry pnum spell: replace nextspinc`X' = nextspinc`X'[_N]
   *qui by panel suid entry pnum spell: replace nextfinc`X' = nextfinc`X'[_N]
   qui by panel suid entry pnum spell: replace nextearnrate`X' = nextearnrate`X'[_N]
   qui by panel suid entry pnum spell: replace nextprimrate`X' = nextprimrate`X'[_N]
   qui by panel suid entry pnum spell: replace nextm1earnrate`X' = nextm1earnrate`X'[_N]
   qui by panel suid entry pnum spell: replace nexttotearnrate`X' = nexttotearnrate`X'[_N]
}
/*
sort panel suid entry pnum year mth
by panel suid entry pnum: gen nextearn = earn_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextearn2 = earn_f2 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextprimwage = primwage_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextprimwage2 = primwage_f2 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextprimearn = primearn_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextprimearn2 = primearn_f2 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen next1hrs = hrs1_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nexttothrs = tothrs_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextprimhrs = primhrs_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextwks = wks_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
/*by panel suid entry pnum: gen nextprimhrs = hrs_f1 if spell~=spell[_n+1]
by panel suid entry pnum: gen nextprimhrs2 = hrs_f2 if spell~=spell[_n+1]
by panel suid entry pnum: gen nexttothrs = hrs_f1 if spell~=spell[_n+1]
by panel suid entry pnum: gen nexttothrs2 = hrs_f2 if spell~=spell[_n+1]*/
by panel suid entry pnum: gen nextm1earn = earnm1_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextm1earn2 = earnm1_f2 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextm2earn = earnm2_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextm2earn2 = earnm2_f2 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextm1wage = wage1_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextm1wage2 = wage1_f2 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextm2wage = wage2_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextm2wage2 = wage2_f2 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nexttotearn = totearn_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nexttotinc = inc_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextspinc = spinc_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextfinc = finc_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqwage1 = qwage1_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqwage2 = qwage2_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqearnm1 = qearnm1_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqearnm2 = qearnm2_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqprimwage = qprimwage_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqprimearn = qprimearn_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqearn = qearn_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqhrs1 = qhrs1_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqhrs = qhrs_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqprimhrs = qprimhrs_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqearntot = qearntot_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextws1qearn = ws1qearn_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqinc = qinc_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextspqinc = spqinc_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextfqinc = fqinc_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextannwg = annwgf if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen tempnexttenure = tenure if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen seamend = refmth==4&spell~=spell[_n+1]&unempmth==1&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
sort panel suid entry pnum spell year mth
by panel suid entry pnum spell: replace nextearn = nextearn[_N]
by panel suid entry pnum spell: replace nextearn2 = nextearn2[_N]
by panel suid entry pnum spell: replace nextprimwage = nextprimwage[_N]
by panel suid entry pnum spell: replace nextprimwage2 = nextprimwage2[_N]
by panel suid entry pnum spell: replace nextprimearn = nextprimearn[_N]
by panel suid entry pnum spell: replace nextprimearn2 = nextprimearn2[_N]
by panel suid entry pnum spell: replace nextprimhrs = nextprimhrs[_N]
by panel suid entry pnum spell: replace next1hrs = next1hrs[_N]
by panel suid entry pnum spell: replace nextprimhrs = nextprimhrs[_N]
by panel suid entry pnum spell: replace nexttothrs = nexttothrs[_N]
by panel suid entry pnum spell: replace nextwks = nextwks[_N]
by panel suid entry pnum spell: replace nextm1earn = nextm1earn[_N]
by panel suid entry pnum spell: replace nextm1earn2 = nextm1earn2[_N]
by panel suid entry pnum spell: replace nextm2earn = nextm2earn[_N]
by panel suid entry pnum spell: replace nextm2earn2 = nextm2earn2[_N]
by panel suid entry pnum spell: replace nextm1wage = nextm1wage[_N]
by panel suid entry pnum spell: replace nextm1wage2 = nextm1wage2[_N]
by panel suid entry pnum spell: replace nextm2wage = nextm2wage[_N]
by panel suid entry pnum spell: replace nextm2wage2 = nextm2wage2[_N]
by panel suid entry pnum spell: replace nexttotearn = nexttotearn[_N]
by panel suid entry pnum spell: replace nexttotinc = nexttotinc[_N]
by panel suid entry pnum spell: replace nextspinc = nextspinc[_N]
by panel suid entry pnum spell: replace nextfinc = nextfinc[_N]
by panel suid entry pnum spell: replace nextqwage1 = nextqwage1[_N]
by panel suid entry pnum spell: replace nextqwage2 = nextqwage2[_N]
by panel suid entry pnum spell: replace nextqearnm1 = nextqearnm1[_N]
by panel suid entry pnum spell: replace nextqearnm2 = nextqearnm2[_N]
by panel suid entry pnum spell: replace nextqprimwage = nextqprimwage[_N]
by panel suid entry pnum spell: replace nextqprimearn = nextqprimearn[_N]
by panel suid entry pnum spell: replace nextqhrs1 = nextqhrs1[_N]
by panel suid entry pnum spell: replace nextqprimhrs = nextqhrs[_N]
by panel suid entry pnum spell: replace nextqhrs = nextqhrs[_N]
by panel suid entry pnum spell: replace nextqearntot = nextqearntot[_N]
by panel suid entry pnum spell: replace nextws1qearn = nextws1qearn[_N]
by panel suid entry pnum spell: replace nextqinc = nextqinc[_N]
by panel suid entry pnum spell: replace nextspqinc = nextspqinc[_N]
by panel suid entry pnum spell: replace nextfqinc = nextfqinc[_N]
by panel suid entry pnum spell: replace nextannwg = nextannwg[_N]
*/
sort panel suid entry pnum year mth
by panel suid entry pnum: gen nextqwage1 = qwage1_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqwage2 = qwage2_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqearnm1 = qearnm1_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqearnm2 = qearnm2_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqprimwage = qprimwage_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqprimearn = qprimearn_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqearn = qearn_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqhrs1 = qhrs1_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqhrs = qhrs_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqprimhrs = qprimhrs_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqearntot = qearntot_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextws1qearn = ws1qearn_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextqinc = qinc_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextspqinc = spqinc_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextfqinc = fqinc_f1 if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen nextannwg = annwgf if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen tempnexttenure = tenure if spell~=spell[_n+1]&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
by panel suid entry pnum: gen seamend = refmth==4&spell~=spell[_n+1]&unempmth==1&(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1])
sort panel suid entry pnum spell year mth
by panel suid entry pnum spell: replace nextqwage1 = nextqwage1[_N]
by panel suid entry pnum spell: replace nextqwage2 = nextqwage2[_N]
by panel suid entry pnum spell: replace nextqearnm1 = nextqearnm1[_N]
by panel suid entry pnum spell: replace nextqearnm2 = nextqearnm2[_N]
by panel suid entry pnum spell: replace nextqprimwage = nextqprimwage[_N]
by panel suid entry pnum spell: replace nextqprimearn = nextqprimearn[_N]
by panel suid entry pnum spell: replace nextqhrs1 = nextqhrs1[_N]
by panel suid entry pnum spell: replace nextqprimhrs = nextqhrs[_N]
by panel suid entry pnum spell: replace nextqhrs = nextqhrs[_N]
by panel suid entry pnum spell: replace nextqearntot = nextqearntot[_N]
by panel suid entry pnum spell: replace nextws1qearn = nextws1qearn[_N]
by panel suid entry pnum spell: replace nextqinc = nextqinc[_N]
by panel suid entry pnum spell: replace nextspqinc = nextspqinc[_N]
by panel suid entry pnum spell: replace nextfqinc = nextfqinc[_N]
by panel suid entry pnum spell: replace nextannwg = nextannwg[_N]
by panel suid entry pnum spell: egen nexttenure = max(tempnexttenure)
by panel suid entry pnum spell: replace seamend = seamend[_N]
replace seamend=0 if censrd==1
gen seambeg = refmth==1&job2U==1&unempmth==1

*Define UI receipt (during any point in spell) variable
sort panel suid entry pnum year mth
replace uiamt=0 if uiamt==.
gen ui_yn2 = uiamt>0|(panel==panel[_n+1]&suid==suid[_n+1]&entry==entry[_n+1]&pnum==pnum[_n+1]&spell==spell[_n+1]&uiamt[_n+1]>0)
sort panel suid entry pnum spell year mth
by panel suid entry pnum spell: egen uireceipt=sum(ui_yn)
replace uireceipt=uireceipt>0

*Identify temporary layoffs (by esr==3 at ANY point in spell)
by panel suid entry pnum spell: egen templayoff=sum(esr==3)
replace templayoff=templayoff>0

sort panel suid entry pnum year mth

***COLLAPSE dataset into spells -- note that all cross-sectional data, e.g. wave, refers to date of job sep
keep if job2U==1
count
ren ethnic ethncty
/*	 
keep panel suid entry pnum TimeID wave mth year calqtr refmth seamth qtr state ///
     wpfinwgt gvarstr ghlfsam spellwgt spellgvar spellpsu spellstratavar spellpsuvar ///
	 age sex race ethncty mardum ed ws1ind ws1occ kids ///
     qearn_l* cv_earn bpw hq1w hq2w annwg* fanninc spanninc ///
     ui_yn *uiamt suppui_yn otherui_yn wksunemp ///
     spell dur spwork_yn templayoff censrd tenure empcens *hrs* ///
     seambeg seamend next* wks_f* earn_f* inc_f* spinc_f* finc_f* ///
     ui_yn2 uireceipt uhours searchdur qwks_l* mthsinsamp ///
     seam1wks seam2wks seam3wks

order panel suid entry pnum TimeID wave mth year calqtr refmth seamth qtr state ///
     wpfinwgt gvarstr ghlfsam spellwgt spellgvar spellpsu spellstratavar spellpsuvar ///
	 age sex race ethncty mardum ed ws1ind ws1occ kids ///
     qearn_l* cv_earn bpw hq1w hq2w annwg* fanninc spanninc ///
     ui_yn *uiamt suppui_yn otherui_yn wksunemp ///
     spell dur spwork_yn templayoff censrd tenure empcens *hrs* ///
     seambeg seamend next* wks_f* earn_f* inc_f* spinc_f* finc_f* ///
     ui_yn2 uireceipt uhours searchdur qwks_l* mthsinsamp ///
     seam1wks seam2wks seam3wks
*/
keep panel suid entry pnum TimeID wave mth year calqtr refmth seamth qtr state ///
     wpfinwgt gvarstr ghlfsam spellwgt spellgvar spellpsu spellstratavar spellpsuvar ///
	 age sex race ethncty mardum ed ws1ind ws1occ kids ///
     qearn_l* cv_earn bpw hq1w hq2w annwg* fanninc spanninc ///
     ui_yn *uiamt suppui_yn otherui_yn wksunemp ///
     spell dur spwork_yn templayoff censrd tenure empcens *hrs* ///
     seambeg seamend next* wks_f* earn_f* ///
     ui_yn2 uireceipt uhours searchdur qwks_l* mthsinsamp ///
     seam1wks seam2wks seam3wks

order panel suid entry pnum TimeID wave mth year calqtr refmth seamth qtr state ///
     wpfinwgt gvarstr ghlfsam spellwgt spellgvar spellpsu spellstratavar spellpsuvar ///
	 age sex race ethncty mardum ed ws1ind ws1occ kids ///
     qearn_l* cv_earn bpw hq1w hq2w annwg* fanninc spanninc ///
     ui_yn *uiamt suppui_yn otherui_yn wksunemp ///
     spell dur spwork_yn templayoff censrd tenure empcens *hrs* ///
     seambeg seamend next* wks_f* earn_f* ///
     ui_yn2 uireceipt uhours searchdur qwks_l* mthsinsamp ///
     seam1wks seam2wks seam3wks



cd "$datadir/cleaned_data/"
*save SIPPUnemp_SpellsPanel.dta, replace
save SIPPUnemp_SpellsPanel.dta, replace

*log close
