/* Please do not attempt to run this program without reading the accompanying documentation. */


version 8.0
set more off
prog drop _all


/*
File: clean a (id and weights).do
Date: May 2012
Desc: Clean-file to create Set A
Note: See acknowledgements and copyright notice in new_master.do.
*/


/*
This program is to be run embedded within new_master.do. It 
cleans the variables necessary for Set A and generates a codebook.
*/

cd "$tempdata"

notes: All variables are monthly except where noted.
notes: All variables come from the longitudinal panel except where noted.
notes: SIPP raw variable names used unless noted. See Crosswalk for more information on consistent names.


* recode all -1 to missing values
mvdecode _all, mv(-1)

sum

/* 
This program creates a sub-file with the identifying variables, weights, and variance stratum codes. 
The extraction from the raw Census data created a variable <id> that is a unique identifier for each 
person in the SIPP, so these variables should not be necessary for most uses. The <id> variable is 
created from the identifying variables (with the 1993 panel and earlier names in parentheses), 
SSUID (SUID), EENTAID (ENTRY), and EPPPNUM  (PNUM). See: SIPP Users Guide, chapter 10 for more information.


The other variables in this file are the weights. From the SIPP96 longitudinal codebook, p. 8-3:


        Use of Weights. Each household and each person within each household on each wave tape has
        four weights. These four weights are reference month specific and therefore can be used only to
        form reference month estimates. Reference month estimates can be averaged to form estimates
        of monthly averages over some period of time.


        Example, using the proper weights, one can estimate the monthly average number of
        households in a specified income range over November and December 1996. To estimate
        monthly averages of a given measure (such as, total, mean) over a number of consecutive
        months, sum the monthly estimates and divide by the number of months.


        To form an estimate for a particular month, use the reference month weight for the month of
        interest, summing over all persons or households with the characteristic of interest whose
        reference period includes the month of interest. Multiply the sum by a factor to account for the
        number of rotations contributing data for the month. This factor equals four divided by the
        number of rotations contributing data for the month. For example, December 1995 data is only
        available from rotation 1 for Wave 1 of the 1996 Panel (See Table 2), so a factor of 4/1 must be
        applied.


        When estimates for months with less than four rotations worth of data are constructed from a
        wave file, factors greater than 1 must be applied. However, when core data from consecutive
        waves are used together, data from all four rotations may be available, in which case the factors
        are equal to 1.


        These tapes contain no weight for characteristics that involve a persons's or household's status
        over two or more months (such as, number of households with a 50 percent increase in income
        between November and December 1995).


Further, if you are doing an analyis of metropolitan areas or regions, you need to use an adjustment factor. 
For the 1996 panel, see the SIPP96 longitudinal codebook, p. 8-4 for more information about this issue.


The variance stratum codes are for use with statistical packages that allow you to adjust your standard 
errors. However, you may need to do this manually. See the SIPP96 longitudinal codebook for more details 
(chapter 8).


For 1993 and earlier, analysis should only be done on observations where <pp_mis==1>. This is the only
reliable guide for whether or not to include an individual. See SIPP User's Guide, p. 9-5.

*/

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	* to match to 1993 name
	rename rhcalyr year
	notes year: SIPP: rhcalyr (96,01,04)
	rename rhcalmn month
	notes month: SIPP: rhcalmn (96,01,04)
	rename spanel panel
	notes panel: SIPP: spanel (96,01,04)
	}

if $p==93 | $p==92 | $p==91 | $p==90 {
	replace year = year+1900
	replace panel = panel+1900

	* to match to 1996 name
	destring hh_add, replace
	rename hh_add shhadid
	notes shhadid: SIPP: hh_add (90,91,92,93)
	rename varstrat gvarstr
	notes gvarstr: SIPP: varstrat (90,91,92,93)
	rename halfsamp ghlfsam
	notes ghlfsam: SIPP: halfsamp (90,91,92,93)
	rename hstrat gvarstr_wv
	notes gvarstr_wv: SIPP: hstrat (90,91,92,93)
	rename hhsc ghlfsam_wv
	notes ghlfsam_wv: SIPP: hhsc (90,91,92,93)
	rename pp_intv eppintvw
	notes eppintvw: SIPP: pp_intv (92,93)
	rename pp_pnum epppnum
	notes epppnum: SIPP: pp_pnum (92,93)
	rename pp_entry eentaid
	notes eentaid: SIPP: pp_entry (92,93)
	rename fnlwgt wpfinwgt 
	notes wpfinwgt: SIPP: fnlwgt (92,93)
	rename hwgt whfnwgt
	notes whfnwgt: SIPP: hgwt (92,93)
	rename fwgt wffinwgt
	notes wffinwgt: SIPP: fgwt (92,93)
	rename swgt wsfinwgt
	notes wsfinwgt: SIPP: sgwt (92,93)
	rename suseqnum ssuseq
	notes ssuseq: SIPP: suseqnum (92,93)
	rename suid ssuid
	notes ssuid: SIPP: suid (92,93)

	label var age "Age in this month"
	label var shhadid "Address ID. - This field identifies the entry address"
	label var eppintv "Person's interview status for interview"     
	label var pp_mis "Person's interview status for this month"
	label var id "Unique ID"
	label var wffinwgt "Family weight for the reference month"
	label var whfnwgt "Household weight for the reference month"
	label var wpfinwgt "Person weight for the reference month"
	label var wsfinwgt "Related subfamily weight for the reference month"
	}

if $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	replace year = year+1900
	replace panel = panel+1900

	* to match to 1996 name
	destring hh_add, replace
	rename hh_add shhadid
	notes shhadid: SIPP: hh_add (90,91,92,93)
	rename varstrat gvarstr
	notes gvarstr: SIPP: varstrat (90,91,92,93)
	rename halfsamp ghlfsam
	notes ghlfsam: SIPP: halfsamp (90,91,92,93)
	rename hstrat gvarstr_wv
	notes gvarstr_wv: SIPP: hstrat (90,91,92,93)
	rename hhsc ghlfsam_wv
	notes ghlfsam_wv: SIPP: hhsc (90,91,92,93)
	rename pp_intv eppintvw
	notes eppintvw: SIPP: pp_intv (92,93)
	rename pp_pnum epppnum
	notes epppnum: SIPP: pp_pnum (92,93)
	rename pp_entry eentaid
	notes eentaid: SIPP: pp_entry (92,93)
	rename fnlwgt wpfinwgt 
	notes wpfinwgt: SIPP: fnlwgt (92,93)
	rename hwgt whfnwgt
	notes whfnwgt: SIPP: hgwt (92,93)
	rename fwgt wffinwgt
	notes wffinwgt: SIPP: fgwt (92,93)
	rename swgt wsfinwgt
	notes wsfinwgt: SIPP: sgwt (92,93)
	rename suseqnum ssuseq
	notes ssuseq: SIPP: suseqnum (92,93)
	rename suid ssuid
	notes ssuid: SIPP: suid (92,93)

	label var age "Age in this month"
	label var shhadid "Address ID. - This field identifies the entry address"
	label var eppintv "Person's interview status for interview"     
	label var pp_mis "Person's interview status for this month"
	label var id "Unique ID"
	label var wffinwgt "Family weight for the reference month"
	label var whfnwgt "Household weight for the reference month"
	label var wpfinwgt "Person weight for the reference month"
	label var wsfinwgt "Related subfamily weight for the reference month"
	}

if $p==93 {
	replace fnlwgt93 = fnlwgt93*10000
	replace fnlwgt94 = fnlwgt94*10000
	replace pnlwgt = pnlwgt*10000
	}

if $p==92 {
	replace fnlwgt92 = fnlwgt92*10000
	replace fnlwgt93 = fnlwgt93*10000
	replace fnlwgt94 = fnlwgt94*10000
	replace pnlwgt = pnlwgt*10000
	}
	
if $p==91 {
	replace fnlwgt92 = fnlwgt92*10000
	replace fnlwgt91 = fnlwgt91*10000
	replace pnlwgt = pnlwgt*10000
	}
	
if $p==90 {
	replace fnlwgt90 = fnlwgt90*10000
	replace fnlwgt91 = fnlwgt91*10000
	replace pnlwgt = pnlwgt*10000
	}

if $p==89 {
	replace fnlwgt89 = fnlwgt89*10000
	replace fnlwgt90 = fnlwgt90*10000
	replace pnlwgt = pnlwgt*10000
	}

if $p==88 {
	replace fnlwgt88 = fnlwgt88*10000
	replace fnlwgt89 = fnlwgt89*10000
	replace pnlwgt = pnlwgt*10000
	}

if $p==87 {
	replace fnlwgt87 = fnlwgt87*10000
	replace fnlwgt88 = fnlwgt88*10000
	replace pnlwgt = pnlwgt*10000
	}

if $p==86 {
	replace fnlwgt86 = fnlwgt86*10000
	replace fnlwgt87 = fnlwgt87*10000
	replace pnlwgt = pnlwgt*10000
	}

if $p==85 {
	replace fnlwgt85 = fnlwgt85*10000
	replace fnlwgt86 = fnlwgt86*10000
	replace pnlwgt = pnlwgt*10000
	}

if $p==84 {
	replace fnlwgt84 = fnlwgt84*10000
	replace fnlwgt85 = fnlwgt85*10000
	replace pnlwgt = pnlwgt*10000
	}
	
******************************************************************

aorder
sum

compress
sort $ids
label data "Set A: ID and Weights, $p SIPP ($ver)"

cd "$output"
saveold set_a, replace
log close

