/* Please do not attempt to run this program without reading the accompanying documentation. */

version 8.0
set more off
prog drop _all

/*
File: clean b (demographics).do
Date: May 2012
Desc: Clean-file to create Set B
Note: See acknowledgements and copyright notice in new_master.do.
*/

/*
This program is to be run embedded within new_master.do. It 
cleans the variables necessary for Set B and generates a codebook.
*/

cd "$tempdata"
use test, clear

notes: All variables are monthly except where noted.
notes: All variables come from the longitudinal panel except where noted.
notes: SIPP raw variable names used unless noted. See Crosswalk for more information on consistent names.

* recode all -1 to missing values
mvdecode _all, mv(-1)

sum

********************************

rename sex female
notes female: SIPP: sex (92,93); esex (96,01)
recode female 1=0
recode female 2=1
label define female 0 "Male" 1 "Female"
label values female female
label var female "Female"

label var age "Age"

if $p==93 | $p==92 |$p==91 | $p==90 | $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	label define ethnic 1 "Germany" 2 "England" 3 "Ireland" 4 "France" 5 "Italy" /*
	*/ 6 "Scotland" 7 "Poland" 8 "Holland" 9 "Sweden" 10 "Norway" 11 "Russia" /*
	*/ 12 "Ukraine" 13 "Wales" 14 "Mex-Amer" 15 "Chicano" 16 "Mexico" 17 "PRico" /*
	*/ 18 "Cuba" 19 "C/S Amer" 20 "Oth Span" 21 "AfroAmer" 30 "Other" 39 "DK"
	label values ethnic ethnic
	}
if $p==96 | $p==01 {
	label define ethnic 1 "Canadian" 2 "Dutch" 3 "English" 4 "French" 5 /*
	*/ "French-Canadian" 6 "German" 7 "Hungarian" 8 "Irish" 9 "Italian" 10 "Polish" /*
	*/  11 "Russian" 12 "Scandinavian" 13 "Scotch-Irish" 14 "Scottish" 15 "Slovak" /*
	*/  16 "Welsh" 17 "Other European" 20 "Mexican" 21 "Mexican-American" /*
	*/  22 "Chicano" 23 "Puerto Rican" 24 "Cuban" 25 "Central American" /*
	*/  26 "South American" 27 "Dominican Republic" 28 "Other Hispanic" /*
	*/  30 "African-American or Afro-American" 31 "American Indian, Eskimo, or Aleut" /*
	*/  32 "Arab" 33 "Asian" 34 "Pacific Islander" 35 "West Indian" /*
	*/  39 "Another group not listed" 40 "American"
	label values ethnic ethnic
	}
if "$p" == "04" | "$p" == "08" {
	label define ethnic 1 "Spanish, Hispanic or Latino" 2 "Not Spanish or Hispanic or Latino"
        label values ethnic ethnic
}

label variable ethnic "Ethnic Origin (96,01,04 differ)"
notes ethnic: SIPP: ethnicty (92,93); eorigin (96,01) ; not avail (04)

rename race race1
gen race04 = race1
label define race1 1 "White" 2 "Black" 3 "IndOrEsk" 4 "AsianPac"
label values race1 race1
label define erace04 1 "White alone" 2 "Black alone" 3 "Asian alone" 4 "Residual"
label val race04 erace04 
label var race1 "SIPP race (unedited), 2001 panel and before"
label var race04 "SIPP race (unedited), 2004,2008 panels"

if $p==01 | $p==96 | $p==93 | $p==92 |$p==91 | $p==90 | $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	replace race04 = .
}

if "$p" == "04" | "$p" == "08"{
	replace race1 = .
}

// generate cepr race
if $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	gen race = 1 if race1==1 & (ethnic<14 | ethnic>20)
	replace race = 2 if race1==2 & (ethnic<14 | ethnic>20)
	replace race = 3 if (ethnic>=14 & ethnic<=20)
	replace race = 4 if race1>2 & (ethnic<14 | ethnic>20) & race1~=.
	}
if $p==93 | $p==92 |$p==91 | $p==90 {
	gen race = 1 if race1==1 & (ethnic<14 | ethnic>20)
	replace race = 2 if race1==2 & (ethnic<14 | ethnic>20)
	replace race = 3 if (ethnic>=14 & ethnic<=20)
	replace race = 4 if race1>2 & (ethnic<14 | ethnic>20) & race1~=.
	}
if $p==96 | $p==01 {
	gen race = 1 if race1==1 & (ethnic<20 | ethnic>28)
	replace race = 2 if race1==2 & (ethnic<20 | ethnic>28)
	replace race = 3 if (ethnic>=20 & ethnic<=28)
	replace race = 4 if race1>2 & (ethnic<20 | ethnic>28) & race1~=.
	}
if "$p" == "04" | "$p" == "08" {
	gen race = race04
	recode race (3 = 4)
	replace race = 3 if ethnic == 1
} 

label define race_cepr 1 "White" 2 "Black" 3 "Hispanic" 4 "Other"
label values race race_cepr
label var race "Race (W,B,H,O)"
notes race: 92-93 panels, generated from SIPP race and ethnicty
notes race: 96-04 panels, generated from SIPP erace and eorigin


        *use id rot tm8732 tm8734 tm8400 tm8408 tm8416 tm8422 tm8430 using sipp90t2, clear
        *use id rot tm8172 tm8174 tm8002 tm8024 tm8022 tm8028 tm8034 using sipp84rt8, clear
	
if $p==85 | $p==84 {
	gen citizen = 1 if tm8172==2 | tm8172==0 | tm8174==2
	replace citizen = 2 if tm8174==1
	replace citizen = 3 if tm8174==3
	notes citizen: SIPP: tm8172 & tm8174 (93)
	}
if $p<=93 & $p>=86 {
	gen citizen = 1 if tm8732==2 | tm8732==0 | tm8734==3
	replace citizen = 2 if tm8734==1
	replace citizen = 3 if tm8734==2
	notes citizen: SIPP: tm8732 & tm8734 (93)
	}
if $p==96 {
	tab rcitiznt
	rename rcitiznt citizen
	notes citizen: SIPP: rcitiznt (96)
	}
if $p==01 {
	tab tcitiznt
	rename tcitiznt citizen
	notes citizen: SIPP: tcitiznt (01)
	}
if "$p" == "04"  | "$p" == "08"{
	tab ecitiznt
	rename ecitiznt citizen
	recode citizen (2 = 3)
	replace citizen = 2 if enatcitt == 1
	notes citizen: SIPP: ecitiznt and enatcitt (04)
}

label define citizen 1 "Native" 2 "Naturalized" 3 "Not a naturalized citizen", modify
label values citizen citizen
label var citizen "Citizenship status"
tab citizen
notes citizen: "citizen" is constant over the entire panel.
notes citizen: "citizen" is from T2.
	
tab disabled

recode disabled 2 = 0
label var disabled "Disability that limits work"
notes disabled: "disabled" is asked once per wave.
label define lmtwk 1 "disabled" 0 "not disabled", modify
label values disabled lmtwk
notes disabled: SIPP: disab (92,93); edisabl (96,01,04,08)
tab disabled

label var ms "Marital Status"
notes ms: SIPP: ems (96,01,04)
tab ms, m

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	egen cohab = eqany(erelat01-erelat30), values(2)
	tab wave cohab, m
	egen cohab_ = max(cohab), by(id)
	drop cohab
	rename cohab_ cohab
	drop erelat*
	notes cohab: SIPP: erelat01-erelat30
	notes cohab: "cohab" is constant over the entire panel.
	notes cohab: "cohab" is from T2.
	}

* HUMAN CAPITAL

compress

label define ststat 1 "ft" 2 "pt" 3 "not enrolled"
label values ststat
label var ststat "school status"
notes ststat: SIPP: att_sch (92,93); renroll (96,01,04)
notes ststat: "ststat" is asked once per wave.

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	recode student 2=0
        label define student 0 "student this wave, but not this month" 1 "student this month" 
        label values student student
        *recode student .=0 /*this makes "student" consistent with earlier panels that code all others as 0*/
}

if $p==93 | $p==92 | $p==91 | $p==90 | ($p<=89 & $p>=84) {
        label define student 0 "not student or not in univers/sample" 1 "student this month"
        label values student student
}
label var student "student this month"
notes student: SIPP: enrl_m (92,93); eenrlm (96,01,04)
tab student, m

        *use id rot tm8732 tm8734 tm8400 tm8408 tm8416 tm8422 tm8430 using sipp90t2, clear
        *use id rot tm8172 tm8174 tm8002 tm8024 tm8022 tm8028 tm8034 using sipp84rt8, clear

label define educ 1 "less than high school" 2 "high school grad" /*
*/ 3 "some college" 4 "college degree" 5 "post-college"
label define educ_deg 1 "less than high school" 2 "high school grad" /*
*/ 3 "some college" 4 "vocational or trade school" 5 "associates" 6 "bachelors" ///
	7 "masters degree" 8 "professional degree" 9 "phd" 0 "missing"
if $p==85 | $p==84 {
	gen educ = 1 if higrade<=12 & higrade~=.
	replace educ = 2 if higrade==12 & grd_cmp==1
	replace educ = 3 if higrade>=21 & higrade<=24
	replace educ = 4 if higrade==24 & grd_cmp==1
	replace educ = 5 if higrade>24 & higrade~=. & grd_cmp==1
	drop higrad grd_cmp
	notes educ: SIPP: higrade & grd_cmp (92,93)

	* highest grade 12 or less and no hs diploma or ged
	gen educ_tm2 = 1 if tm8002==1 & tm8024==2
	* highest grade 12 or less and has hs diploma or ged
	replace educ_tm2 = 2 if tm8002==1 & tm8024==1
	replace educ_tm2 = 2 if tm8002==2
	* highest grade 1 year of college and  ass., voc, or no degree
	replace educ_tm2 = 3 if tm8022==1 & tm8028>=5 & tm8028<=7
	* highest grade 1 year of college and ba degree
	replace educ_tm2 = 4 if tm8022==1 & tm8028==4
	* highest grade 1 year of college and adv. degree
	replace educ_tm2 = 5 if tm8022==1 & tm8028>=1 & tm8028<=3 & tm8034==1
	gen educ_deg = 1 if tm8002==1 & tm8024==2 
	replace educ_deg = 2 if tm8002==1 & tm8024==1
	replace educ_deg = 2 if tm8002==2 
	replace educ_deg = 3 if tm8022==1&(tm8028==7|tm8028==0)
	replace educ_deg = 4 if tm8028==6
	replace educ_deg = 5 if tm8022==1 & tm8028==5
	replace educ_deg = 6 if tm8022==1 & tm8028==6
	replace educ_deg = 7 if tm8022==1 & tm8028==3
	replace educ_deg = 8 if tm8022==1 & tm8028==2
	replace educ_deg = 9 if tm8022==1 & tm8028==1
	replace educ_deg = 0 if educ_deg == . & tm8002==0
	label values educ_tm2 educ
	label var educ_tm2 "TM2 Educational Attainment"
}

if $p<=93 & $p>=86 {
	gen educ = 1 if higrade<=12 & higrade~=.
	replace educ = 2 if higrade==12 & grd_cmp==1
	replace educ = 3 if higrade>=21 & higrade<=24
	replace educ = 4 if higrade==24 & grd_cmp==1
	replace educ = 5 if higrade>24 & higrade~=. & grd_cmp==1
	drop higrad grd_cmp
	notes educ: SIPP: higrade & grd_cmp (92,93)

	* highest grade 12 or less and no hs diploma or ged
	gen educ_tm2 = 1 if tm8400==1 & tm8408==2
	* highest grade 12 or less and has hs diploma or ged
	replace educ_tm2 = 2 if tm8400==1 & tm8408==1
	replace educ_tm2 = 2 if tm8400==2
	* highest grade 1 year of college and  ass., voc, or no degree
	replace educ_tm2 = 3 if tm8416==1 & tm8422>=5 & tm8422<=7
	* highest grade 1 year of college and ba degree
	replace educ_tm2 = 4 if tm8416==1 & tm8422==4
	* highest grade 1 year of college and adv. degree
	replace educ_tm2 = 5 if tm8416==1 & tm8422>=1 & tm8422<=3 & tm8430==1
	gen educ_deg = 1 if tm8400==1 & tm8408==2 
	replace educ_deg = 2 if tm8400==1 & tm8408==1
	replace educ_deg = 2 if tm8400==2 
	replace educ_deg = 3 if tm8416==1&(tm8422==7|tm8422==0)
	replace educ_deg = 4 if tm8422==6
	replace educ_deg = 5 if tm8416==1 & tm8422==5
	replace educ_deg = 6 if tm8416==1 & tm8422==6
	replace educ_deg = 7 if tm8416==1 & tm8422==3
	replace educ_deg = 8 if tm8416==1 & tm8422==2
	replace educ_deg = 9 if tm8416==1 & tm8422==1
	replace educ_deg = 0 if educ_deg == . & tm8400==0
	label values educ_tm2 educ
	label var educ_tm2 "TM2 Educational Attainment"
}

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	gen educ_deg = 1 if eeducate <=38 & eeducate !=. & eeducate != 39
	replace educ_deg = 2 if eeducate==39 & eeducate !=.
	replace educ_deg = 3 if eeducate==40 & eeducate !=.
	replace educ_deg = 4 if eeducate==41 & eeducate !=.
	replace educ_deg = 5 if (eeducate==42|eeducate==43)& eeducate !=.
	replace educ_deg = 6 if eeducate==44 & eeducate !=.
	replace educ_deg = 7 if eeducate==45 & eeducate !=.
	replace educ_deg = 8 if eeducate==46 & eeducate !=.
	replace educ_deg = 9 if eeducate==47 & eeducate !=.
	replace educ_deg = 0 if eeducate==-1 | eeducate == .
	gen educ = 1 if eeducate<=38 & eeducate~=.
	replace educ = 2 if eeducate==39
	replace educ = 3 if eeducate>=40 & eeducate<=43
	replace educ = 4 if eeducate==44
	replace educ = 5 if eeducate>=45 & eeducate<=48
	replace educ = 0 if eeducate==-1 | eeducate == .
	drop eeducate
	notes educ: "educ" is asked once per wave.
	notes educ: SIPP: eeducate (96,01,04,08)
	}
label var educ "Educational Attainment"
label var educ_deg "Highest Degree"
label values educ_deg educ_deg
label values educ educ

* Geography

tab metro
recode metro (2 = 0)
if "$p" == "04" recode metro (3 = 0)
label define metro 1 "Metro" 0 "Residual", modify
label values metro metro
label var metro "Metropolitan Residence"
notes metro: SIPP: hmetro (92,93); tmetro (96,01,04,08)
tab metro

if "$p" == "04" | "$p" == "08" gen msa = .
notes msa: SIPP: hmsa (92,93); tmsa (96,01); not avail. (04,08)


recode sipp_st 0=.
gen state=sipp_st
* recode SIPP Code to CPS Code
tab state
if $p== 01 | $p==96 | $p==93 | $p==92 | $p==91 | $p==90 | ($p<=89 & $p>=84) {
recode state 63=103
recode state 1=63

recode state 2=94
recode state 4=86
recode state 5=71
recode state 6=93
recode state 8=84

recode state 16=82
recode state 9=16

recode state 35=85
recode state 55=35
recode state 54=55
recode state 51=54
recode state 10=51

recode state 53=91
recode state 11=53

recode state 12=59
recode state 13=58
recode state 15=95

recode state 33=12
recode state 17=33

recode state 32=88
recode state 18=32

recode state 23=11
recode state 42=23
recode state 19=42

recode state 62=102

recode state 47=62
recode state 20=47

recode state 61=101
recode state 21=61

recode state 22=72
recode state 24=52
recode state 25=14

recode state 34=22
recode state 26=34

recode state 41=92
recode state 27=41

recode state 28=64
recode state 29=43
recode state 30=81

recode state 45=57
recode state 46=45
recode state 31=46
recode state 39=31

recode state 36=21

recode state 56=83
recode state 37=56

recode state 44=15
recode state 38=44

recode state 40=73
recode state 48=74
recode state 49=87

recode state 50=13
}

if "$p" == "04" | "$p" == "08" {
* recode FIPS SIPP state code to CPS state codes
# delimit ;
recode state 
 (56=83) /* Wyoming */
 (55=35) /* Wisconsin */
 (54=55) /* West Virginia */
 (53=91) /* Washington */
 (51=54) /* Virginia */
 (50=13) /* Vermont */
 (49=87) /* Utah */
 (48=74) /* Texas */
 (47=62) /* Tennessee */
 (46=45) /* South Dakota */
 (45=57) /* South Carolina */
 (44=15) /* Rhode Island */
 (42=23) /* Pennsylvania */
 (41=92) /* Oregon */
 (40=73) /* Oklahoma */
 (39=31) /* Ohio */
 (38=44) /* North Dakota */
 (37=56) /* North Carolina */
 (36=21) /* New York */
 (35=85) /* New Mexico */
 (34=22) /* New Jersey */
 (33=12) /* New Hampshire */
 (32=88) /* Nevada */
 (31=46) /* Nebraska */
 (30=81) /* Montana */
 (29=43) /* Missouri */
 (28=64) /* Mississippi */
 (27=41) /* Minnesota */
 (26=34) /* Michigan */
 (25=14) /* Massachusetts */
 (24=52) /* Maryland */
 (23=11) /* Maine */
 (22=72) /* Louisiana */
 (21=61) /* Kentucky */
 (20=47) /* Kansas */
 (19=42) /* Iowa */
 (18=32) /* Indiana */
 (17=33) /* Illinois */
 (16=82) /* Idaho */
 (15=95) /* Hawaii */
 (13=58) /* Georgia */
 (12=59) /* Florida */
 (11=53) /* DC */
 (10=51) /* Delaware */
 (9=16) /* Connecticut */
 (8=84) /* Colorado */
 (6=93) /* California */
 (5=71) /* Arkansas */
 (4=86) /* Arizona */
 (2=94) /* Alaska */
 (1=63) /* Alabama */
;
#delimit cr ;
}

if $p==93 | $p==92 |$p==91 | $p==90 | ($p<=89 & $p>=84) {
	label define state_cps 11 "ME" 12 "NH" 13 "VT" 14 "MA" 15 "RI" 16 "CT" 21 "NY" 22 "NJ" 23 "PA" 31 "OH" /*
	*/32 "IN" 33 "IL" 34 "MI" 35 "WI" 41 "MN" 42 "IA" 43 "MO" 44 "ND" 45 "SD" 46 "NE" 47 "KS" 51 "DE" /*
	*/52 "MD" 53 "DC" 54 "VA" 55 "WV" 56 "NC" 57 "SC" 58 "GA" 59 "FL" 61 "KY" 62 "TN" 63 "AL" 64 "MS" /*
	*/71 "AR" 72 "LA" 73 "OK" 74 "TX" 81 "MT" 82 "ID" 83 "WY" 84 "CO" 85 "NM" 86 "AZ" 87 "UT" 88 "NV" /*
	*/91 "WA" 92 "OR" 93 "CA" 94 "AK" 95 "HI" 101 "ME, VT" 102 "IA, ND, SD" 103 "AK, ID, MT, WY", modify 
	}
if $p==96 | $p==01{
	label define state_cps 11 "ME" 12 "NH" 13 "VT" 14 "MA" 15 "RI" 16 "CT" 21 "NY" 22 "NJ" 23 "PA" 31 "OH" /*
	*/32 "IN" 33 "IL" 34 "MI" 35 "WI" 41 "MN" 42 "IA" 43 "MO" 44 "ND" 45 "SD" 46 "NE" 47 "KS" 51 "DE" /*
	*/52 "MD" 53 "DC" 54 "VA" 55 "WV" 56 "NC" 57 "SC" 58 "GA" 59 "FL" 61 "KY" 62 "TN" 63 "AL" 64 "MS" /*
	*/71 "AR" 72 "LA" 73 "OK" 74 "TX" 81 "MT" 82 "ID" 83 "WY" 84 "CO" 85 "NM" 86 "AZ" 87 "UT" 88 "NV" /*
	*/91 "WA" 92 "OR" 93 "CA" 94 "AK" 95 "HI" 101 "ME, VT" 102 "WY, ND, SD", modify
	}
if "$p" == "04" | "$p" == "08" {
	#delimit ;
	label define state_cps 
		11 "ME"
		12 "NH"
		13 "VT"
		14 "MA"
		15 "RI"
		16 "CT"
		21 "NY"
		22 "NJ"
		23 "PA"
		31 "OH"
		32 "IN"
		33 "IL"
		34 "MI"
		35 "WI"
		41 "MN"
		42 "IA"
		43 "MO"
		44 "ND"
		45 "SD"
		46 "NE"
		47 "KS"
		51 "DE"
		52 "MD"
		53 "DC"
		54 "VA"
		55 "WV"
		56 "NC"
		57 "SC"
		58 "GA"
		59 "FL"
		61 "KY"
		62 "TN"
		63 "AL"
		64 "MS"
		71 "AR"
		72 "LA"
		73 "OK"
		74 "TX"
		81 "MT"
		82 "ID"
		83 "WY"
		84 "CO"
		85 "NM"
		86 "AZ"
		87 "UT"
		88 "NV"
		91 "WA"
		92 "OR"
		93 "CA"
		94 "AK"
		95 "HI"
	, modify ;
	#delimit cr ;
	}
label values state state_cps
label variable state "CPS State Code (w/SIPP aggreg.)"
notes state: SIPP: geo_ste (92,93); tfipsst (96,01,04,08)
tab state
table state, c(mean sipp_st)

gen region = 1 if state==11 | state == 12 | state == 13 | state == 14 | state == 15 | state == 16 
replace region = 2 if state==21 | state == 22 | state == 23 
replace region = 3 if state==31 | state == 32 | state == 33 | state == 34 | state == 35 
replace region = 4 if state==41 | state == 42 | state == 43 | state == 44 | state == 45 | state == 46 | state == 47
replace region = 5 if state==51 | state == 52 | state == 53 | state == 54 | state == 55 | state == 56 | state == 57 | state == 58 | state == 59
replace region = 6 if state==61 | state == 62 | state == 63 | state == 64
replace region = 7 if state==71 | state == 72 | state == 73 | state == 74
replace region = 8 if state==81 | state == 82 | state == 83 | state == 84 | state == 85 | state == 86 | state == 87 | state == 88
replace region = 9 if state==91 | state == 92 | state == 93 | state == 94 | state == 95
label var region "Census Region (9)"
label define reglbl 1 "New England" 2 "Middle Atlantic" 3 "E. North Central" 4 "W. North Central" 5 "South Atlantic" 6 "E. South Central" 7 "W. South Central" 8 "Mountain" 9 "Pacific"
label values region reglbl
notes region: SIPP: geo_ste (92,93); tfipsst (96,01,04)

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	notes age: SIPP: tage (96,01,04,08)
	}

******************************************************************
if $p==93 | $p==92 | $p==91 | $p==90 | ($p<=89 & $p>=84) {
	keep $ids age female race* ethnic citizen disabled ms educ educ_tm2 educ_deg student ststat metro msa region state sipp_st
	}

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	keep $ids age female race* ethnic citizen disabled ms cohab educ educ_deg student ststat metro msa region state sipp_st
	}

aorder
sum
compress
sort $ids
label data "Set B: Demographics, $p SIPP ($ver)"

cd "$output"
saveold set_b, replace
capture log close

