/* Please do not attempt to run this program without reading the accompanying documentation*/

version 8.0
set more off
prog drop _all

/*
File: clean c (household and family relations).do
Date: July, 2005
Desc: Clean-file to create Set C
Note: See acknowledgments and copyright notice in new_master.do
*/

/* 
This program is to be run embedded within new_master.do.
It cleans the variables necessary for Set C and generates a codebook.
*/

cd "$tempdata"
if "$p" == "04" | "$p" == "08" use test, clear

notes: All variables are monthly except where noted.
notes: All variables come from the longitudinal panel except where noted.
notes: See Crosswalk for more information on consistent names
notes: For (96,01) it is necessary to download "tostring.ado" package dm80_1 from http://www.stata.com/stb/stb57 
notes: For (96,01) save "tostring.ado" in C:\Stata8\ado\base\t

* Changes by Joe 5.10.04: use shhadid instead of eentaid for merge variables for mom and dad
* also, create m and d variables for 92, 93

********************************


* recode all -1 to missing values
mvdecode _all, mv(-1)

*Gender
rename esex female
notes female: SIPP: sex (90,91,92,93); esex (96,01,04,08)
recode female (1=0) (2=1)
label define female 0 "Male" 1 "Female"
label values female female
label var female "Female"

* Generate household/family identifiers; See SIPP User's Guide, pp. 10.9 to 10.14.
* Households
recode rfid .=0
recode rfid2 .=0
recode rsid .=0

/*generate id based on current address, rather than entry address*/
if "$p" == "04" | "$p" == "08"{
	egen add_id = concat(ssuid shhadid epppnum)
	replace add_id = "" if epppnum==""
	label var add_id "ID with current address"
	count if add_id==""
	drop epppnum
}

if $p==01 | $p==96 {
mvdecode epppnum, mv(9999)
gen a = epppnum
tostring a, replace
gen str1 t = "0"
egen pnum2 = concat(t a)
gen pnum = substr(pnum2, -4, 4)
drop a pnum2

sort ssuid shhadid pnum
egen s = concat(ssuid shhadid pnum)
replace s = "" if epppnum==""
rename s add_id
label var add_id "ID with current address"
count if add_id==""
drop pnum t epppnum
}

if $p==93 | $p==92 | $p==91 | $p==90 {
mvdecode pnum, mv(9999)
gen a = pnum
rename pnum pnum_orig
tostring a, replace
gen str1 t = "0"
egen pnum2 = concat(t a)
gen pnum = substr(pnum2, -4, 4)
drop a pnum2 

sort ssuid shhadid pnum
egen s = concat(ssuid shhadid pnum)
replace s = "" if pnum_orig==""
rename s add_id
label var add_id "ID with current address"
count if add_id==""
drop pnum t pnum_orig
}

if $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
mvdecode pnum, mv(9999)
gen a = pnum
rename pnum pnum_orig
tostring a, replace
gen str1 t = "0"
egen pnum2 = concat(t a)
gen pnum = substr(pnum2, -4, 4)
drop a pnum2 

sort ssuid shhadid pnum
egen s = concat(ssuid shhadid pnum)
replace s = "" if pnum_orig==""
rename s add_id
label var add_id "ID with current address"
count if add_id==""
drop pnum t pnum_orig
}


sort ssuid shhadid
egen hhid = group(ssuid shhadid)
label var hhid "Unique household ID"
* Familes, including both primary and subfamlies
sort ssuid shhadid rfid
egen pfid = group(ssuid shhadid rfid)
label var pfid "Unique family ID (Total)"
* Families, with sub and primary families counted separately
sort ssuid shhadid rfid2 rsid
egen sfid = group(ssuid shhadid rfid2 rsid)
label var sfid "Unique family ID (sub/prim separate)"
drop rfid rfid2 rsid

sum
sort id wave srefmon 

* To match spouses and children, use household id, not entry id.
* This must be made into a string variable.
tostring shhadid, replace

* Generate a variable to match spouses
if "$p" == "08" | "$p" == "04" | $p==01 | $p==96 {	
	mvdecode epnspous, mv(9999)	
	gen a_spouse = epnspous
	tostring a_spouse, replace
	gen str1 t = "0"
	egen spouse2 = concat(t a_spouse)
	gen spouse = substr(spouse2, -4, 4)
	drop a_spouse spouse2 

	egen shhadid2 = concat(t shhadid)
	drop shhadid
	gen shhadid = substr(shhadid2, -3, 3)
	drop shhadid2
}
if $p>=90 & $p<=93 {
	mvdecode epnspous, mv(999)
	mvdecode epnspous, mv(000)
	gen a_spouse = epnspous
	tostring a_spouse, replace
	gen str1 t = "00"
	egen spouse2 = concat(t a_spouse)
	gen spouse = substr(spouse2,-3,3)
	drop a_spouse spouse2

	egen shhadid2 = concat(t shhadid)
	drop shhadid
	gen shhadid = substr(shhadid2, -2, 2)
	drop shhadid2
	}
if $p>=84 & $p<=89 {
	mvdecode epnspous, mv(999)
	mvdecode epnspous, mv(000)
	gen a_spouse = epnspous
	tostring a_spouse, replace
	gen str1 t = "00"
	egen spouse2 = concat(t a_spouse)
	gen spouse = substr(spouse2,-3,3)
	drop a_spouse spouse2

	egen shhadid2 = concat(t shhadid)
	drop shhadid
	gen shhadid = substr(shhadid2, -2, 2)
	drop shhadid2
	}

sort ssuid shhadid spouse
egen s = concat(ssuid shhadid spouse) 
replace s = "" if epnspous==.
rename s spouseid
label var spouseid "ID number of spouse"
drop epnspous spouse

* Parents are attached to children
* Generate a person number for each mother, father, and guardian: variables are 4 characters long (96,01)
if "$p" == "08" | "$p" == "04" | $p==01 | $p==96 {	
	mvdecode epnmom epndad epnguard, mv(9999)
	gen a_mom = epnmom
	gen a_dad = epndad
	gen a_guard = epnguard
	tostring a_mom a_dad a_guard, replace
	egen mom2 = concat(t a_mom)
	egen dad2 = concat(t a_dad)
	egen guard2 = concat(t a_guard)
	gen mom = substr(mom2, -4, 4)
	gen dad = substr(dad2, -4, 4)
	gen guard = substr(guard2, -4, 4)
	drop a_* mom2 dad2 guard2 t
}

* Generate a person number for each parent and guardian:  variables are 3 characters long
if $p==92 | $p==93 | $p==91 | $p==90{
	gen a_guard = u_pngd
	tostring a_guard, replace
	egen guard2 = concat(t a_guard)
	gen guard = substr(guard2,-3,3)
	drop a_guard guard2 t

	gen parnt = pnpt
	tostring parnt, replace
	}

* Generate a person number for each parent and guardian:  variables are 3 characters long
if $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	gen a_guard = u_pngd
	tostring a_guard, replace
	egen guard2 = concat(t a_guard)
	gen guard = substr(guard2,-3,3)
	drop a_guard guard2 t

	gen parnt = pnpt
	tostring parnt, replace
	}


* Generate an id for each mother, father, and guardian.(96,01)
if "$p" == "08" | "$p" == "04" | $p==01 | $p==96 {
	sort ssuid shhadid mom
	egen m = concat(ssuid shhadid mom) 
	sort ssuid shhadid dad
	egen d = concat(ssuid shhadid dad)
	sort ssuid shhadid guard
	egen g = concat(ssuid shhadid guard)
	drop eentaid mom dad guard
	replace m = "" if epnmom==.
	replace d = "" if epndad==.
	replace g = "" if epnguard==.
	drop epn*
	}

* Generate an id for each parent and guardian. (92,93) 
if $p==93 | $p==92 | $p==91 | $p==90 {
	sort ssuid shhadid parnt
	egen p = concat(ssuid shhadid parnt)
	sort ssuid shhadid guard
	egen g = concat(ssuid shhadid guard)
	drop parnt guard ssuid shhadid 
	
	* probably want to recode all g as p??
	gen m = p if p~="" & female==1
	gen d = p if p~="" & female==0
	replace m = g if g~=""  & p==""  & female==1
	replace d = g if g~=""  & p==""  & female==0
	}

* Generate an id for each parent and guardian. (92,93) 
if $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	sort ssuid shhadid parnt
	egen p = concat(ssuid shhadid parnt)
	sort ssuid shhadid guard
	egen g = concat(ssuid shhadid guard)
	drop parnt guard ssuid shhadid 
	
	* probably want to recode all g as p??
	gen m = p if p~="" & female==1
	gen d = p if p~="" & female==0
	replace m = g if g~=""  & p==""  & female==1
	replace d = g if g~=""  & p==""  & female==0
	}


* Recode guardian as missing if same as mother or father
if "$p" == "08" | "$p" == "04" | $p==01 | $p==96 {	
	replace g = "" if m==g
	replace g = "" if d==g

	* Recode Guardians as mothers or fathers
	replace g = "NA" if g==""
	sort g srefmon wave
	compress
	save chpt, replace
	keep id female srefmon wave
	rename female psex
	rename id g
	sort g srefmon wave
	merge g srefmon wave using chpt
	tab _merge
	keep if _merge==2 | _merge==3
	drop _merge

	replace m = g if m=="" & psex==0 & g~="NA"
	replace d = g if d=="" & psex==1 & g~="NA"

	drop g psex
}

*Generate child and adult dummies
gen byte child = age<18 & age>=0 & age~=.
gen byte adult = age>=18 & age~=.
sum child adult

* gen numeric id variable
gen str10 ida = substr(id,1,10)
gen str10 idb = substr(id,11,.)
gen double idax = real(ida)
gen double idbx = real(idb)
egen idx = group(idax idbx)
drop ida* idb*

/*
Generate a unique sub-family id which can be used as the categorical equivalent of m,d,p,g 
so later we can use sfid/hhid as the categorical equivalent of id to identify subfamilies/hh
*/
gen s = sfid
gen h = hhid

sort hhid wave srefmon
egen hh_ads = sum(adult), by(hhid wave srefmon)
label var hh_ads "Number of adults in hh"
* compare my numbers to Census
egen hh = count(idx), by(hhid wave srefmon)
tab hh, m
tab ehhnumpp, m

sort pfid wave srefmon
egen fam_ads = sum(adult), by(pfid wave srefmon)
label var fam_ads "Number of adults in family (incl. subfamily)"
* compare my numbers to Census
egen fam = count(idx), by(pfid wave srefmon)
tab fam efnp, m
egen famkid = sum(child), by(pfid wave srefmon)

* NEXT TWO TABLES IN REPORT
tab famkid rfnkids, m
tab famkid rfoklt18, m
*drop famkid
sort sfid wave srefmon
egen sfam_ads = sum(adult), by(sfid wave srefmon)
label var sfam_ads "Number of adults in family (subfamily sep.)"
* compare my numbers to Census
egen sfam = count(idx), by(sfid wave srefmon)
tab sfam esfnp, m

drop idx ehhnumpp efnp
* dataset with child id, parent ids only.

save chpt, replace

keep if child==1

if "$p" == "08" | "$p" == "04" | $p==01 | $p==96 {
	keep age m d s h child wave srefmon
	}
if $p==93 | $p==92 |$p==91 | $p==90 {
	keep age m d p s h child wave srefmon
	}
if $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	keep age m d p s h child wave srefmon
	}
save child_only, replace

capture program drop attach
program define attach
*set trace on
* This program appends children to their parents and guardians 
version 8.0
	while "`1'"~="" {
		use child_only, clear
		
		gen byte kid0_ = age==0 & age~=.
		gen byte kid1_ = age==1 & age~=.
		gen byte kid2_ = age==2 & age~=.
		gen byte kid3_ = age==3 & age~=.
		gen byte kid4_ = age==4 & age~=.
		gen byte kid5_ = age==5 & age~=.
		gen byte kid6t12_ = age<=12 & age>=6 & age~=.
		gen byte kid13t17_ = age<18 & age>=13 & age~=.
		gen byte kid0t17_ = age<18 & age>=0 & age~=.
		sort `1' wave srefmon
		* generate total number of children, by age, for each parent by time frame
		egen `1'kid0 = sum(kid0_), by(`1' wave srefmon)
		egen `1'kid1 = sum(kid1_), by(`1' wave srefmon)
		egen `1'kid2 = sum(kid2_), by(`1' wave srefmon)
		egen `1'kid3 = sum(kid3_), by(`1' wave srefmon)
		egen `1'kid4 = sum(kid4_), by(`1' wave srefmon)
		egen `1'kid5 = sum(kid5_), by(`1' wave srefmon)
		egen `1'kid6t12 = sum(kid6t12_), by(`1' wave srefmon)
		egen `1'kid13t17 = sum(kid13t17_), by(`1' wave srefmon)
		egen `1'kid0t17 = sum(kid0t17_), by (`1' wave srefmon)
		egen `1'yngst = min(age), by(`1' wave srefmon)
		label var `1'kid0 "Infant (first year)"
		label var `1'kid1 "One year"
		label var `1'kid2 "Two years"
		label var `1'kid3 "Three years"
		label var `1'kid4 "Four years"
		label var `1'kid5 "Five years"
		label var `1'kid6t12 "No. children 6 to 12"
		label var `1'kid13t17 "No. children 13 to 17"
		label var `1'kid0t17  "No. children 0 to 17"
		label var `1'yngst "age of youngest child"

		gen `1'kid0t5 = `1'kid0 + `1'kid1 + `1'kid2 + `1'kid3 + `1'kid4 + `1'kid5
		label var `1'kid0t5 "No. children 0 to 5"

		if "`1'"~="s" & "`1'"~="h" { 	
			rename `1' add_id 
			* keep only one parent id per time frame, rather than one for each child.
			sort add_id wave srefmon
			egen add_id_only = tag(add_id wave srefmon)
			keep if add_id_only==1
			keep add_id wave srefmon `1'kid* `1'yngst
			sort add_id wave srefmon
			save child_tss, replace
			use chpt, clear
			sort add_id wave srefmon
			merge add_id wave srefmon using child_tss
			}

		if "`1'"=="s" {
			rename `1' sfid
			* keep only one sub-family id per time frame, rather than one for each child.
			sort sfid wave srefmon
			egen sfid_only = tag(sfid wave srefmon)
			keep if sfid_only==1
			keep sfid wave srefmon `1'kid* `1'yngst
			sort sfid wave srefmon
			save child_tss, replace
			use chpt, clear
			sort sfid wave srefmon
			merge sfid wave srefmon using child_tss
			}

		if "`1'"=="h" {
			rename `1' hhid
			* keep only one household id per time frame, rather than one for each child.
			sort hhid wave srefmon
			egen hhid_only = tag(hhid wave srefmon)
			keep if hhid_only==1
			keep hhid wave srefmon `1'kid* `1'yngst
			sort hhid wave srefmon
			save child_tss, replace
			use chpt, clear
			sort hhid wave srefmon
			merge hhid wave srefmon using child_tss
			}
		tab _merge
		drop if _merge==2
		drop _merge
		
		recode `1'kid0t5 .=0
		recode `1'kid6t12 .=0
		recode `1'kid13t17 .=0
		recode `1'kid0t17 .=0
		recode `1'kid0 .=0
		recode `1'kid1 .=0
		recode `1'kid2 .=0
		recode `1'kid3 .=0
		recode `1'kid4 .=0
		recode `1'kid5 .=0
		
		compress
		save chpt, replace
	mac shift
	}
end

attach m d s

********************************

if "$p" == "08" | "$p" == "04" | $p==01 | $p==96 {
	keep $ids age spouseid hh_ads fam_ads sfam_ads hhid pfid sfid /*
	*/ mkid* dkid* skid* myngst dyngst syngst famkid rfnkids rfoklt18
}

if $p==93 | $p==92 | $p==91 | $p==90 {
	keep $ids age spouseid hh_ads fam_ads sfam_ads hhid pfid sfid /*
	*/ skid* syngst famkid rfnkids rfoklt18
	}

if $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	keep $ids age spouseid hh_ads fam_ads sfam_ads hhid pfid sfid /*
	*/ skid* syngst famkid rfnkids rfoklt18
	}
aorder
sum
sort $ids
label data "Set C: Household and Family Relationships, $p SIPP ($ver)"

cd "$output"
saveold set_c, replace
capture log close

