*CC Tables MAX

label data "Set E: Childcare, $p SIPP"
notes: For the 1996 SIPP panel, all variables in this subfile all come from TM4 and TM10 for the 2001 SIPP panel, from TM4
notes: 2004 panel, TM4 and TM8
set more off


cd "$tempdata"
use "set_e_test$p", clear
capture log close
cd $log
log using "set_e_max_$p.log", replace

********************************

/*
The raw codebook has the basic method for how the SIPP wrote the variable names.

VARIABLE Definitions 
eckd 				type of child care arrangement

epayhel				anyone help pay for child care?
ewhopa1				government helped pay for child care
ewhopa2				other parent helped pay for child care
ewhopa3				employer helped pay for child care 
ewhopa4				other person helped pay for child care

earrang				number of cc arrangements    (1996 panel only)
ewhothe				place non-relative cared for child
eselfhr				hrs cared for child yourself, while workng/ in school
eselfca				child cared for self 

eparhr1	 1			hours other parent cared for child
ewhsbhr	 3			hours of sibling care (sibling 15+)
esb14hr	 4			hours sibling care(14-)
egranhr	 5			hours of grandparent care
erelhr1	 6			hours of relative care
ehrfam1  7			hours of family day care
edayrhs	 8			hours of day care
enurhrs	 9			hours of nursery care (A-E)
eheadhr	 10			hours of head start care (A-E)
eothehr	 11			hours of non-relative care (A-E)

ehsport	 9			hours in sports (F-J)
ehrles1	 10			hours in lessons (F-J)
eclubhr	 11			hours in clubs (F-J)
ehscho1	 12			hours in after school care (F-J)

ekidhr1	 eselfca=1		hours of self-care
ehrschw	 eschoow=1		hours in school
eccpnum				person number of child
etiamt01 has child (0-14)	time lost
etiamt02 has child (0-14)	unit of time lost
*/


* AORDER to ensure correct values in <eqany> commands
aorder

/*
* SELF CARE recode  This is not necessary because there are no obs in 1996 panel for eselfcaa-eselfcae
*Recode 1996 <eselfca> to match 2001 <eselfca> 
*in 2001 panel this variables is only for children aged 4 and 5
if $p == 96 {
	gen eself1a=eselfcaa if age==4 | age==5
	gen eself1b=eselfcab if age==4 | age==5
	gen eself1c=eselfcac if age==4 | age==5
	gen eself1d=eselfcad if age==4 | age==5
	gen eself1e=eselfcae if age==4 | age==5
	drop eselfcaa eselfcab eselfcac eselfcad eselfcae 
	rename eself1a eselfcaa
	rename eself1b eselfcab
	rename eself1c eselfcac
	rename eself1d eselfcad
	rename eself1e eselfcae
}
*/


*Recode 2001 <eckd12a-e> and <eckd14f-j> to 1996 <eckd11a-e> and <eckd13f-g>
*the 1996 panel does not include the <eckd12a-e> and <eckd14f-j> categories for childcare,
*so we collapse these categories back into similar categories for the 2001 panel
if $p==01 {
	gen eckd_12a=(eckd11a==1 | eckd12a==1)
	replace eckd_12a=. if eckd11a==. & eckd12a==.
	gen eckd_12b=(eckd11b==1 | eckd12b==1)
	replace eckd_12b=. if eckd11b==. & eckd12b==.
	gen eckd_12c=(eckd11c==1 | eckd12c==1)
	replace eckd_12c=. if eckd11c==. & eckd12c==.

	gen eckd_14f=(eckd13f==1 | eckd14f==1)
	replace eckd_14f=. if eckd13f==. & eckd14f==.
	gen eckd_14g=(eckd13g==1 | eckd14g==1)
	replace eckd_14g=. if eckd13g==. & eckd14g==.
	gen eckd_14h=(eckd13h==1 | eckd14h==1)
	replace eckd_14h=. if eckd13h==. & eckd14h==.

	drop eckd11a eckd11b eckd11c eckd12a eckd12b eckd12c eckd12d eckd12e 
	drop eckd13f eckd13g eckd13h  eckd14f eckd14g eckd14h 

	rename eckd_12a eckd11a
	rename eckd_12b eckd11b
	rename eckd_12c eckd11c

	rename eckd_14f eckd13f
	rename eckd_14g eckd13g
	rename eckd_14h eckd13h

}

if "$p" == "04"  {
		gen eckd_12a=(eckd11a==1)
		replace eckd_12a=. if eckd11a==.
		gen eckd_12b=(eckd11b==1)
		replace eckd_12b=. if eckd11b==.
		gen eckd_12c=(eckd11c==1)
		replace eckd_12c=. if eckd11c==.

		gen eckd_14f=(eckd13f==1)
		replace eckd_14f=. if eckd13f==.
		gen eckd_14g=(eckd13g==1)
		replace eckd_14g=. if eckd13g==.
		gen eckd_14h=(eckd13h==1)
		replace eckd_14h=. if eckd13h==.

		drop eckd11a eckd11b eckd11c
		drop eckd13f eckd13g eckd13h 

		rename eckd_12a eckd11a
		rename eckd_12b eckd11b
		rename eckd_12c eckd11c

		rename eckd_14f eckd13f
		rename eckd_14g eckd13g
		rename eckd_14h eckd13h

	}

*RECODE 96/01 to Match 93/92
*This part of the program drops information from 1996 and 2001 panels so that it matches, conceptually, 
*the information in the 1993 panel.  In the 1993 panel we have childcare information only for the 3 youngest children 
*for each parent.  In the 1996 and 2001 panels we have childcare information on the first five children under age 6 for 
*each parent interviewed and for the first five children aged 6-17 for each parent interviewed.  Thus 
*we need to transform the 1996 and 2001 panels' childcare variables into the three youngest children for each 
*parent interviewed.  We do this by recoding information from the 1996 and 2001 panels on children that are not 
*among the three youngest for each parent: we recode this information as missing.


if $p==96 | $p==01 | "$p" == "04" {
	*set trace on 
	set more off
	*this one is for variables with suffixes a-j inclusive
	capture program drop ccdrop1
	program define ccdrop1
	while "`1'"~="" {
		drop `1'd `1'e `1'i `1'j
		if `1'a~=. & `1'b~=. & `1'c~=.  {
			replace (`1'f=.) (`1'g=.) (`1'h=.) 
		}
		if `1'a~=. & `1'b~=. & `1'c==.  {
			replace (`1'g=.) (`1'h=.) 
		}
		if `1'a~=. & `1'b==. & `1'c==.  {
			replace (`1'h=.) 
		}
	mac shift
	}
	end

	*this one is for tamt* variables with suffixes a-j inclusive -- these have no missing values, just 0 values 
	capture program drop ccdrop1a
	program define ccdrop1a
	while "`1'"~="" {
		drop `1'd `1'e `1'i `1'j
		if `1'a>0 & `1'b>0 & `1'c>0  {
			replace (`1'f=.) (`1'g=.) (`1'h=.) 
		}
		if `1'a>0 & `1'b>0 & `1'c==0  {
			replace (`1'g=.) (`1'h=.) 
		}
		if `1'a>0 & `1'b==0 & `1'c==0  {
			replace (`1'h=.) 
		}
	mac shift
	}
	end
	
	*this one is for allvariables with suffixes a-e only
	capture program drop ccdrop2
	program define ccdrop2
	while "`1'"~="" {
		drop `1'd `1'e 
	mac shift
	}
	end
	
	*this one is for allvariables with suffixes f-j only
	capture program drop ccdrop3
	program define ccdrop3
	while "`1'"~="" {
		drop `1'i `1'j 
	mac shift
	}
	end

	ccdrop1 eckd01 eckd02 eckd03 eckd04 eckd05 eckd06 eckd07 eckd08 eckd09 eckd10 eckd11
	if $p==96 {
		ccdrop1 eckd03a eckd04a eckd05a eckd06a eckd07a eckd08a eckd09a eckd10a eckd11a 
	}
	ccdrop1 epaygra epayrel epayfam epayday epayoth epayhel 

	ccdrop1 ewhothe eselfhr eselfca eparhr1 ewhsbhr egranhr erelhr1 eothehr 
	ccdrop1 ehrfam1 edayhrs esb14hr ekidhr1 ehrschw ewhopa1 ewhopa2 ewhopa3 ewhopa4
	ccdrop1a tamtgra tamtrel tamtfam tamtday tamtoth 
	ccdrop2 tamtnur tamtsta epaynur epaysta enurhrs eheadhr
	ccdrop3 tamtspo tamtles tamtclu tamtsch epayspo epayles epayclu epaysch 
	ccdrop3 eckd12 eckd13 eclubhr ehscho1 ehsport ehrles1 
	if $p==96 {
	ccdrop3 eckd12a eckd13a
	}

	set trace off
}



* TIME IN SCHOOL : ehrschw = Hours in school child 4 - 14 (96) 4-5 (01)
egen hr_sch1 = eqany(ehrschwa-ehrschwc)if age>=4 & age<=5, values(1)
label var hr_sch1 "hours child 4-5 in school"
egen hr_sch2 = eqany(ehrschwf-ehrschwh) if age>=6 & age<=14, values(1)
label var hr_sch2 "hours child 6-14 in school"

* RECEIVES HELP WITH CC PAYMENTS
egen help_cc = eqany(epayhela-epayhelh), values(1)
label var help_cc "receives any help paying for cc"
egen govt_help_cc = eqany(ewhopa1a-ewhopa1h), values(1)
label var govt_help_cc "receives govt help paying for cc"

* HOURS LOST 
gen hourslost = etiamt01 if etiamt02==1
replace hourslost = etiamt01*8 if etiamt02==2
replace hourslost = etiamt01*40 if etiamt02==3
replace hourslost = etiamt01*173.2 if etiamt02==4


* MOST USED CC
/*
This program does the following:
(1) Generates a var <cc`1'> with the maximum hours of childcare from all the types of childcare available.
(2) Generate a var <ccmax`1'> with the childcare that the child spent the most time in, based on <cc`1'>.
(3) Generate a var <ccs`1'> with the number of arrangements at the maximum hours.
(4) Generate a var <ccc`1'> with the number of childcare types that the child used per week (month?).

This is run first for young children, then for older children.
*/
capture program drop ccyng
program define ccyng
while "`1'"~="" {
	egen cc`1' = rmax(eparhr1`1' eselfhr`1' ewhsbhr`1' egranhr`1' erelhr1`1' othehr1`1' eothehr2`1' /*
	*/ ehrfam1`1' edayhrs`1' enurhrs`1' eheadhr`1' esb14hr`1' ekidhr1`1')
	recode cc`1' .=0
	gen ccmax`1' = 0 if age>=0 & age<6
	replace ccmax`1' = 1 if (eparhr1`1'>=cc`1' & eparhr1`1'~=.) | (eselfhr`1'>=cc`1' & eselfhr`1'~=.)
	replace ccmax`1' = 2 if (ewhsbhr`1'>=cc`1' & ewhsbhr`1'~=.) | (egranhr`1'>=cc`1' & egranhr`1'~=.) /*
	*/ | (erelhr1`1'>=cc`1' & erelhr1`1'~=.)
	replace ccmax`1' = 3 if (othehr1`1'>=cc`1' & othehr1`1'~=.) | (ehrfam1`1'>=cc`1' & ehrfam1`1'~=.)
	replace ccmax`1' = 4 if (eothehr2`1'>=cc`1' & eothehr2`1'~=.)
	replace ccmax`1' = 5 if (edayhrs`1'>=cc`1' & edayhrs`1'~=.) | (enurhrs`1'>=cc`1' & enurhrs`1'~=.) /*
	*/ | (eheadhr`1'>=cc`1' & eheadhr`1'~=.)
	replace ccmax`1' = 6 if (esb14hr`1'>=cc`1' & esb14hr`1'~=.) | (ekidhr1`1'>=cc`1' & ekidhr1`1'~=.)
	label define ccmax 1 "par" 2 "rel" 3 "fam" 4 "nan" 5 "for" 6 "self", modify
	label values ccmax`1' ccmax
	
	gen byte cc_1`1' = eparhr1`1'>=cc`1' if eparhr1`1'~=.
	gen byte cc_2`1' = eselfhr`1'>=cc`1' if eselfhr`1'~=.
	gen byte cc_3`1' = ewhsbhr`1'>=cc`1' if ewhsbhr`1'~=.
	gen byte cc_4`1' = egranhr`1'>=cc`1' if egranhr`1'~=.
	gen byte cc_5`1' = erelhr1`1'>=cc`1' if erelhr1`1'~=.
	gen byte cc_6`1' = othehr1`1'>=cc`1' if othehr1`1'~=.
	gen byte cc_7`1' = eothehr2`1'>=cc`1' if eothehr2`1'~=.
	gen byte cc_8`1' = ehrfam1`1'>=cc`1' if ehrfam1`1'~=.
	gen byte cc_9`1' = edayhrs`1'>=cc`1' if edayhrs`1'~=.
	gen byte cc_10`1' = enurhrs`1'>=cc`1' if enurhrs`1'~=.
	gen byte cc_11`1' = eheadhr`1'>=cc`1' if eheadhr`1'~=.
	gen byte cc_12`1' = esb14hr`1'>=cc`1' if esb14hr`1'~=.
	gen byte cc_13`1' = ekidhr1`1'>=cc`1' if ekidhr1`1'~=.
	egen ccs`1' = rsum(cc_1`1'-cc_13`1')
	label var ccs`1' "Type of cc w/ max hrs"
	egen ccc`1' = robs(cc_1`1'-cc_13`1')
	label var ccc`1' "Number of cc types (child `1')"
	drop cc_*
	tab ccs`1' if ccs`1'~=0, m
	tab ccc`1' if ccc`1'~=0, m
		
	mac shift
} 
end

capture program drop ccold
program define ccold
while "`1'"~="" {
	egen cc`1' = rmax(eparhr1`1' eselfhr`1' ewhsbhr`1' egranhr`1' erelhr1`1' othehr1`1' eothehr2`1' /*
	*/ ehrfam1`1' edayhrs`1' ehsport`1' ehrles1`1' eclubhr`1' ehscho1`1' esb14hr`1' ekidhr1`1')
	recode cc`1' .=0
	gen ccmax`1' = 0 if age>=6 & age<17
	replace ccmax`1' = 1 if (eparhr1`1'>=cc`1' & eparhr1`1'~=.) | (eselfhr`1'>=cc`1' & eselfhr`1'~=.)
	replace ccmax`1' = 2 if (ewhsbhr`1'>=cc`1' & ewhsbhr`1'~=.) | (egranhr`1'>=cc`1' & egranhr`1'~=.) /*
	*/ | (erelhr1`1'>=cc`1' & erelhr1`1'~=.)
	replace ccmax`1' = 3 if (othehr1`1'>=cc`1' & othehr1`1'~=.) | (ehrfam1`1'>=cc`1' & ehrfam1`1'~=.)
	replace ccmax`1' = 4 if (eothehr2`1'>=cc`1' & eothehr2`1'~=.)
	replace ccmax`1' = 5 if (edayhrs`1'>=cc`1' & edayhrs`1'~=.) | (ehsport`1'>=cc`1' & ehsport`1'~=.) /*
	*/ | (ehrles1`1'>=cc`1' & ehrles1`1'~=.) | (eclubhr`1'>=cc`1' & eclubhr`1'~=.) | (ehscho1`1'>=cc`1' & ehscho1`1'~=.)
	replace ccmax`1' = 6 if (esb14hr`1'>=cc`1' & esb14hr`1'~=.) | (ekidhr1`1'>=cc`1' & ekidhr1`1'~=.)
	label define ccmax 1 "par" 2 "rel" 3 "fam" 4 "nan" 5 "for" 6 "self", modify
	label values ccmax`1' ccmax
	
	gen byte cc_1`1' = eparhr1`1'>=cc`1' if eparhr1`1'~=.
	gen byte cc_2`1' = eselfhr`1'>=cc`1' if eselfhr`1'~=.
	gen byte cc_3`1' = ewhsbhr`1'>=cc`1' if ewhsbhr`1'~=.
	gen byte cc_4`1' = egranhr`1'>=cc`1' if egranhr`1'~=.
	gen byte cc_5`1' = erelhr1`1'>=cc`1' if erelhr1`1'~=.
	gen byte cc_6`1' = othehr1`1'>=cc`1' if othehr1`1'~=.
	gen byte cc_7`1' = eothehr2`1'>=cc`1' if eothehr2`1'~=.
	gen byte cc_8`1' = ehrfam1`1'>=cc`1' if ehrfam1`1'~=.
	gen byte cc_9`1' = edayhrs`1'>=cc`1' if edayhrs`1'~=.
	gen byte cc_10`1' = ehsport`1'>=cc`1' if ehsport`1'~=.
	gen byte cc_11`1' = ehrles1`1'>=cc`1' if ehrles1`1'~=.
	gen byte cc_12`1' = eclubhr`1'>=cc`1' if eclubhr`1'~=.
	gen byte cc_13`1' = ehscho1`1'>=cc`1' if ehscho1`1'~=.
	gen byte cc_14`1' = esb14hr`1'>=cc`1' if esb14hr`1'~=.
	gen byte cc_15`1' = ekidhr1`1'>=cc`1' if ekidhr1`1'~=.
	egen ccs`1' = rsum(cc_1`1'-cc_15`1')
	label var ccs`1' "Type of cc w/ max hrs"
	egen ccc`1' = robs(cc_1`1'-cc_15`1')
	label var ccc`1' "Number of cc types (child `1')"
	drop cc_*
	tab ccs`1' if ccs`1'~=0, m
	tab ccc`1' if ccc`1'~=0, m
		
	mac shift
} 
end


* Recreate "other" category. Family day care (non-relative in their home or other place)
*gen othehr1a = non-relative hrs cc if type==11 & place is _  or _ 
gen othehr1a = eothehra if eckd11a==1 & (ewhothea==2 | ewhothea==3)
gen othehr1b = eothehrb if eckd11b==1 & (ewhotheb==2 | ewhotheb==3)
gen othehr1c = eothehrc if eckd11c==1 & (ewhothec==2 | ewhothec==3)


gen othehr1f = eothehrf if eckd13f==1 & (ewhothef==2 | ewhothef==3)
gen othehr1g = eothehrg if eckd13g==1 & (ewhotheg==2 | ewhotheg==3)
gen othehr1h = eothehrh if eckd13h==1 & (ewhotheh==2 | ewhotheh==3)


*place==1
gen eothehr2a = eothehra if eckd11a==1 & ewhothea==1
gen eothehr2b = eothehrb if eckd11b==1 & ewhotheb==1
gen eothehr2c = eothehrc if eckd11c==1 & ewhothec==1


*nanny day care (non-relative ni child's home)
gen eothehr2f = eothehrf if eckd13f==1 & ewhothef==1
gen eothehr2g = eothehrg if eckd13g==1 & ewhotheg==1
gen eothehr2h = eothehrh if eckd13h==1 & ewhotheh==1


ccyng a b c 
ccold f g h 


drop eday* egran* ehead* ehrfam* ehrles* ehrschw*  ehscho* /*
*/ ehsport*  ekidhr* enur*  eothe* epar* erelhr* esb14* 

***************************
* CHILD-CENTERED ANALYSIS *
***************************
*Note: child care is still attached to the parent, not the child
capture program drop yng
program define yng
while "`1'"~="" {
	if $p==96 {
		gen ccuniv`1' = (eckd03`1'==1 | eckd03`1'==2) | (eckd03a`1'==1 | eckd03a`1'==2)
		}
	if $p==01 | "$p" == "04" {
		gen ccuniv`1' = (eckd03`1'==1 | eckd03`1'==2)
		}
		
	* PARENTAL CARE 
	* Includes either parent or parent at work and caring for child
	gen byte `1'_care_par = (eckd01`1'==1 | eckd02`1'==1 ) & ccuniv`1'==1 & ccmax`1'==1
	label var `1'_care_par "child `1' in parental care"
	drop eckd01`1' eckd02`1'


	* FAMILY MEMBER CARE
	* Includes siblings over age 15, grandparents, and other relatives
	if $p==96 {
		gen byte `1'_care_rel = (eckd03`1'==1 | eckd05`1'==1 | eckd06`1'==1 | eckd03a`1'==1 | /*
		*/ eckd05a`1'==1 | eckd06a`1'==1 ) & ccuniv`1'==1 & ccmax`1'==2
	}
	if $p==01 | "$p" == "04" {
		gen byte `1'_care_rel = (eckd03`1'==1 | eckd05`1'==1 | eckd06`1'==1) & ccuniv`1'==1 & ccmax`1'==2
	}	
	gen byte `1'_paid_rel = (epaygra`1'==1 | epayrel`1'==1) & ccuniv`1'==1 & ccmax`1'==2
	gen `1'_amt_rel = (tamtgra`1' + tamtrel`1') if ccuniv`1'==1 & ccmax`1'==2
	label var `1'_care_rel "child `1' in relative care"
	label var `1'_paid_rel "Child `1' paid for relative care"
	label var `1'_amt_rel "Child `1' amount paid for relative care"
	drop eckd03`1' eckd05`1' eckd06`1'
		
	* FAMILY/INFORMAL DAYCARE 
	* Includes family daycare and informal care (non-relative, not in child's home)
	if $p==96 {
		gen `1'_care_fam = (((eckd11`1'==1 | eckd11a`1'==1) & (ewhothe`1'==2 | ewhothe`1'==3)) | /*
		*/ (eckd07`1'==1 | eckd07a`1'==1)) & ccuniv`1'==1 & ccmax`1'==3
	}
		
	if $p==01 | "$p" == "04" {
		gen `1'_care_fam = ((eckd11`1'==1 & (ewhothe`1'==2 | ewhothe`1'==3)) | eckd07`1'==1  /*
		*/ ) & ccuniv`1'==1 & ccmax`1'==3
	}
	label var `1'_care_fam "Child `1' in family/informal daycare"
	gen byte `1'_paid_fam = ((epayoth`1'==1 & (ewhothe`1'==2 | ewhothe`1'==3)) | epayfam`1'==1) & ccuniv`1'==1 & ccmax`1'==3
	label var `1'_paid_fam "Child `1' paid for family care"
	gen `1'_amt_fam = tamtoth`1' if (epayoth`1'==1 & (ewhothe`1'==2 | ewhothe`1'==3)) & ccuniv`1'==1 & ccmax`1'==3
	replace `1'_amt_fam = (`1'_amt_fam + tamtfam`1') if ccuniv`1'==1 & ccmax`1'==3
	label var `1'_amt_fam "Child `1' amount paid for family care"
	drop eckd07`1'


	* NANNY/SITTER CARE 
	* Care by a non-relative in child's home
	if $p==96 {
		gen `1'_care_nan = (eckd11`1'==1 | eckd11a`1'==1) & ewhothe`1'==1 & ccuniv`1'==1 & ccmax`1'==4	
	}
	if $p==01 | "$p" == "04" {
		gen `1'_care_nan = eckd11`1'==1 & ewhothe`1'==1 & ccuniv`1'==1 & ccmax`1'==4
	}
	label var `1'_care_nan "Child `1' in nanny care"
	gen byte `1'_paid_nan = epayoth`1'==1 & ewhothe`1'==1 & ccuniv`1'==1 & ccmax`1'==4
	label var `1'_paid_nan "Child `1' paid for nanny care"
	gen `1'_amt_nan = tamtoth`1' if epayoth`1'==1 & ewhothe`1'==1 & ccuniv`1'==1 & ccmax`1'==4
	label var `1'_amt_nan "Child `1' amount paid for nanny care"
	drop eckd11`1'


	* FORMAL DAYCARE/PROGRAMS
	* For young children, includes daycare, nursery school, and Head Start.
	if $p==96 {
		gen `1'_care_for = (eckd08`1'==1 | eckd09`1'==1 | eckd10`1'==1| eckd08a`1'==1 | /*
		*/ eckd09a`1'==1 | eckd10a`1'==1) & ccuniv`1'==1 & ccmax`1'==5	
	}
	if $p==01 | "$p" == "04" {
		gen `1'_care_for = (eckd08`1'==1 | eckd09`1'==1 | eckd10`1'==1) & ccuniv`1'==1 & ccmax`1'==5
	}
	label var `1'_care_for "Child `1' in formal care"
	gen byte `1'_paid_for = (epayday`1'==1 | epaynur`1'==1 | epaysta`1'==1) & ccuniv`1'==1 & ccmax`1'==5
	label var `1'_paid_for "Child `1' paid for formal care"
	gen `1'_amt_for = (tamtday`1' + tamtnur`1' + tamtsta`1') if ccuniv`1'==1 & ccmax`1'==5
	label var `1'_amt_for "Child `1' amount paid for formal care"
	drop eckd08`1' eckd09`1' eckd10`1'


	* CHILD CARES FOR SELF OR CARED FOR BY YOUNG SIBLING 
	*Note: there are no obs for eselfc* for 1996 panel and only 88 "yes's" for selfc* in the 2001 panel
	if $p==96 {
		gen `1'_care_self = (eckd04`1'==1 | eselfca`1'==1 | eckd04a`1'==1) & ccuniv`1'==1 & ccmax`1'==6
	}
	if $p==01 | "$p" == "04" {
		gen `1'_care_self = (eckd04`1'==1 | eselfca`1'==1) & ccuniv`1'==1 & ccmax`1'==6
	}
	label var `1'_care_sel "child `1' self care or care by sib under 15"
	drop eckd04`1'


	mac shift
}
end

capture program drop old
program define old
while "`1'"~="" {
	if $p==96 {
		gen ccuniv`1' = (eckd03`1'==1 | eckd03`1'==2) | (eckd03a`1'==1 | eckd03a`1'==2)
		}
	if $p==01 | "$p" == "04" {
		gen ccuniv`1' = (eckd03`1'==1 | eckd03`1'==2)
		}
	* PARENTAL CARE 
	* Includes either parent or parent at work and caring for child
	gen byte `1'_care_par = (eckd01`1'==1 | eckd02`1'==1) & ccuniv`1'==1 & ccmax`1'==1
	label var `1'_care_par "child `1' in parental care"
	drop eckd01`1' eckd02`1'

	* FAMILY MEMBER CARE
	* Includes siblings over age 15, grandparents, and other relatives
	if $p==96 {
		gen byte `1'_care_rel = (eckd03`1'==1 | eckd05`1'==1 | eckd06`1'==1 | eckd03a`1'==1 | /*
		*/ eckd05a`1'==1 | eckd06a`1'==1) & ccuniv`1'==1 & ccmax`1'==2	
	}
	if $p==01 | "$p" == "04" {
		gen byte `1'_care_rel = (eckd03`1'==1 | eckd05`1'==1 | eckd06`1'==1) & ccuniv`1'==1 & ccmax`1'==2
	}
	label var `1'_care_rel "child `1' in relative care"
	gen byte `1'_paid_rel = (epaygra`1'==1 | epayrel`1'==1) & ccuniv`1'==1 & ccmax`1'==2
	label var `1'_paid_rel "Child `1' paid for relative care"
	gen `1'_amt_rel = (tamtgra`1' + tamtrel`1') if ccuniv`1'==1 & ccmax`1'==2
	label var `1'_amt_rel "Child `1' amount paid for relative care"
	drop eckd03`1' eckd05`1' eckd06`1' 
	if $p==96 {
		drop eckd03a`1' eckd05a`1' eckd06a`1'
	}

	* FAMILY/INFORMAL DAYCARE 
	* Includes family daycare and informal care (non-relative, not in child's home)
	if $p==96 {
		gen `1'_care_fam = (((eckd13`1'==1 | eckd13a`1'==1 ) & (ewhothe`1'==2 | ewhothe`1'==3)) | eckd07`1'==1 | eckd07a`1'==1) & ccuniv`1'==1	 & ccmax`1'==3
	}
	if $p==01 | "$p" == "04" {
		gen `1'_care_fam = ((eckd13`1'==1 & (ewhothe`1'==2 | ewhothe`1'==3)) | eckd07`1'==1) & ccuniv`1'==1 & ccmax`1'==3
	}
	label var `1'_care_fam "Child `1' in family/informal daycare"
	gen byte `1'_paid_fam = ((epayoth`1'==1 & (ewhothe`1'==2 | ewhothe`1'==3)) | epayfam`1'==1) & ccuniv`1'==1 & ccmax`1'==3
	label var `1'_paid_fam "Child `1' paid for family care"
	gen `1'_amt_fam = tamtoth`1' if (epayoth`1'==1 & (ewhothe`1'==2 | ewhothe`1'==3)) & ccuniv`1'==1 & ccmax`1'==3
	replace `1'_amt_fam = `1'_amt_fam + tamtfam`1' if ccuniv`1'==1
	label var `1'_amt_fam "Child `1' amount paid for family care"
	drop eckd07`1'  
	if $p==96 {
		drop eckd07a`1'
	}

	* NANNY/SITTER CARE 
	* Care by a non-relative in child's home
	if $p==96 {
		gen `1'_care_nan = (eckd13`1'==1 | eckd13a`1'==1) & ewhothe`1'==1 & ccuniv`1'==1 & ccmax`1'==4	
	}
	if $p==01 | "$p" == "04" {
		gen `1'_care_nan = eckd13`1'==1 & ewhothe`1'==1 & ccuniv`1'==1 & ccmax`1'==4
	}
	label var `1'_care_nan "Child `1' in nanny care"
	gen byte `1'_paid_nan = epayoth`1'==1 & ewhothe`1'==1 & ccuniv`1'==1 & ccmax`1'==4
	label var `1'_paid_nan "Child `1' paid for nanny care"
	gen `1'_amt_nan = tamtoth`1' if epayoth`1'==1 & ewhothe`1'==1 & ccuniv`1'==1 & ccmax`1'==4
	label var `1'_amt_nan "Child `1' amount paid for nanny care"
	drop eckd13`1' 
	if $p==96 {
		drop eckd13a`1'
	}
	
	* FORMAL DAYCARE/PROGRAMS 
	* For older children, includes daycare, sports, lessons, clubs, after-school care.
	if $p==96 {
		gen `1'_care_for = (eckd08`1'==1 | eckd09`1'==1 | eckd10`1'==1 | eckd11`1'==1 | eckd12`1' ==1 /*
		*/ | eckd08a`1'==1 | eckd09a`1'==1 | eckd10a`1'==1 | eckd11a`1'==1 | eckd12a`1'==1) & ccuniv`1'==1 & ccmax`1'==5
	}
	if $p==01 | "$p" == "04" {
		gen `1'_care_for = (eckd08`1'==1 | eckd09`1'==1 | eckd10`1'==1 | eckd11`1'==1 | eckd12`1'==1) & ccuniv`1'==1 & ccmax`1'==5
	} 
	label var `1'_care_nan "Child `1' in formal care"
	gen byte `1'_paid_for = (epayday`1'==1 | epayspo`1'==1 | epayles`1'==1 | epayclu`1'==1 | epaysch`1'==1) & ccuniv`1'==1 & ccmax`1'==5
	label var `1'_paid_for "Child `1' paid for formal care"
	gen `1'_amt_for = tamtday`1' + tamtspo`1' + tamtles`1' + tamtclu`1' + tamtsch`1' if ccuniv`1'==1 & ccmax`1'==5
	label var `1'_amt_for "Child `1' amount paid for formal care"
	drop eckd08`1' eckd09`1' eckd10`1' eckd11`1' eckd12`1' 
	if $p==96 {
		drop eckd08a`1' eckd09a`1' eckd10a`1' eckd11a`1' eckd12a`1'
	}

	* CHILD CARES FOR SELF OR CARED FOR BY YOUNG SIBLING 
	if $p==96 {
		gen `1'_care_self = (eckd04`1'==1 | eselfca`1'==1 | eckd04a`1'==1) & ccuniv`1'==1 & ccmax`1'==6
	}
	if $p==01 | "$p" == "04" {
		gen `1'_care_self = (eckd04`1'==1 | eselfca`1'==1) & ccuniv`1'==1 & ccmax`1'==6
	}
	label var `1'_care_sel "child `1' self care or care by sib under 15"
	drop eckd04`1'
	if $p==96 {
		drop eckd04a`1'
	}
	
	mac shift
}
end

yng a b c 
old f g h 

keep id wave cc*  *_* hourslost eccpnum* 

aorder

****************************
* PARENT-CENTERED ANALYSIS *
****************************
*Note: Tabulates child care types and costs for each parent across children

*Generate (cc) universes for each parent from the universes from each child
egen ccuniv1 = eqany(ccuniva ccunivb ccunivc), values(1)
egen ccuniv2 = eqany(ccunivf ccunivg ccunivh), values(1)


/* PARENTAL CARE */
* Includes either parent or parent at work and caring for child
egen care_par1 = eqany(a_care_par b_care_par c_care_par ), values(1)
replace care_par1 = . if ccuniv1~=1
label var care_par1 "yng child in parental care"
egen care_par2 = eqany(f_care_par g_care_par h_care_par ), values(1)
replace care_par2 =. if ccuniv2~=1
label var care_par2 "old child in parental care"


/* FAMILY MEMBER CARE */
* Includes siblings over age 15, grandparents, and other relatives
egen care_rel1 = eqany(a_care_rel b_care_rel c_care_rel ), values(1)
replace care_rel1 = . if ccuniv1~=1
label var care_rel1 "yng child in relative care"
egen care_rel2 = eqany(f_care_rel g_care_rel h_care_rel ), values(1)
replace care_rel2 =. if ccuniv2~=1
label var care_rel2 "old child in relative care"
egen paid_rel1 = eqany(a_paid_rel b_paid_rel c_paid_rel ), values(1)
replace paid_rel1 = . if ccuniv1~=1
label var paid_rel1 "Paid for relative care"
egen paid_rel2 = eqany(f_paid_rel g_paid_rel h_paid_rel ), values(1)
replace paid_rel2 =. if ccuniv2~=1
label var paid_rel2 "Paid for relative care"
egen amt_rel1 = rmean(a_amt_rel b_amt_rel c_amt_rel )
replace amt_rel1 = . if ccuniv1~=1
label var amt_rel1 "Avg amount paid for relative care"
egen amt_rel2 = rmean(f_amt_rel g_amt_rel h_amt_rel )
replace amt_rel2 =. if ccuniv2~=1
label var amt_rel2 "Avg amount paid for relative care"
egen tot_rel1 = rsum(a_amt_rel b_amt_rel c_amt_rel )
replace tot_rel1 = . if ccuniv1~=1
label var tot_rel1 "Total amount paid for relative care"
egen tot_rel2 = rsum(f_amt_rel g_amt_rel h_amt_rel )
replace tot_rel2 =. if ccuniv2~=1
label var tot_rel2 "Total amount paid for relative care"

/* FAMILY/INFORMAL DAYCARE */
* Includes family daycare and informal care (non-relative, not in child's home)
egen care_fam1 = eqany(a_care_fam b_care_fam c_care_fam ), values(1)
replace care_fam1 = . if ccuniv1~=1
label var care_fam1 "yng child in family care"
egen care_fam2 = eqany(f_care_fam g_care_fam h_care_fam ), values(1)
replace care_fam2 =. if ccuniv2~=1
label var care_fam2 "old child in family care"
egen paid_fam1 = eqany(a_paid_fam b_paid_fam c_paid_fam ), values(1)
replace paid_fam1 = . if ccuniv1~=1
label var paid_fam1 "Paid for family care"
egen paid_fam2 = eqany(f_paid_fam g_paid_fam h_paid_fam ), values(1)
replace paid_fam2 =. if ccuniv2~=1
label var paid_fam2 "Paid for family care"
egen amt_fam1 = rmean(a_amt_fam b_amt_fam c_amt_fam )
replace amt_fam1 = . if ccuniv1~=1
label var amt_fam1 "Avg amount paid for family care"
egen amt_fam2 = rmean(f_amt_fam g_amt_fam h_amt_fam )
replace amt_fam2 =. if ccuniv2~=1
label var amt_fam2 "Avg amount paid for family care"
egen tot_fam1 = rsum(a_amt_fam b_amt_fam c_amt_fam )
replace tot_fam1 = . if ccuniv1~=1
label var tot_fam1 "Total amount paid for family care"
egen tot_fam2 = rsum(f_amt_fam g_amt_fam h_amt_fam )
replace tot_fam2 =. if ccuniv2~=1
label var tot_fam2 "Total amount paid for family care"

/* NANNY/SITTER CARE */
* Care by a non-relative in child's home

egen care_nan1 = eqany(a_care_nan b_care_nan c_care_nan ), values(1)
replace care_nan1 = . if ccuniv1~=1
label var care_nan1 "yng child in nanny care"
egen care_nan2 = eqany(f_care_nan g_care_nan h_care_nan ), values(1)
replace care_nan2 =. if ccuniv2~=1
label var care_nan2 "old child in nanny care"
egen paid_nan1 = eqany(a_paid_nan b_paid_nan c_paid_nan ), values(1)
replace paid_nan1 = . if ccuniv1~=1
label var paid_nan1 "Paid for nanny care"
egen paid_nan2 = eqany(f_paid_nan g_paid_nan h_paid_nan ), values(1)
replace paid_nan2 =. if ccuniv2~=1
label var paid_nan2 "Paid for nanny care"
egen amt_nan1 = rmean(a_amt_nan b_amt_nan c_amt_nan )
replace amt_nan1 = . if ccuniv1~=1
label var amt_nan1 "Avg amount paid for nanny care"
egen amt_nan2 = rmean(f_amt_nan g_amt_nan h_amt_nan )
replace amt_nan2 =. if ccuniv2~=1
label var amt_nan2 "Avg amount paid for nanny care"
egen tot_nan1 = rsum(a_amt_nan b_amt_nan c_amt_nan )
replace tot_nan1 = . if ccuniv1~=1
label var tot_nan1 "Total amount paid for nanny care"
egen tot_nan2 = rsum(f_amt_nan g_amt_nan h_amt_nan )
replace tot_nan2 =. if ccuniv2~=1
label var tot_nan2 "Total amount paid for nanny care"

/* FORMAL DAYCARE/PROGRAMS */
* For young children, includes daycare, nursery school, and Head Start.
* For older children, includes daycare, sports, lessons, clubs, after-school care.
egen care_for1 = eqany(a_care_for b_care_for c_care_for ), values(1)
replace care_for1 = . if ccuniv1~=1
label var care_for1 "yng child in formal care"
egen care_for2 = eqany(f_care_for g_care_for h_care_for ), values(1)
replace care_for2 =. if ccuniv2~=1
label var care_for2 "old child in formal care"
egen paid_for1 = eqany(a_paid_for b_paid_for c_paid_for ), values(1)
replace paid_for1 = . if ccuniv1~=1
label var paid_for1 "Paid for formal care"
egen paid_for2 = eqany(f_paid_for g_paid_for h_paid_for ), values(1)
replace paid_for2 =. if ccuniv2~=1
label var paid_for2 "Paid for formal care"
egen amt_for1 = rmean(a_amt_for b_amt_for c_amt_for )
replace amt_for1 = . if ccuniv1~=1
label var amt_for1 "Avg amount paid for formal care"
egen amt_for2 = rmean(f_amt_for g_amt_for h_amt_for )
replace amt_for2 =. if ccuniv2~=1
label var amt_for2 "Avg amount paid for formal care"
egen tot_for1 = rsum(a_amt_for b_amt_for c_amt_for )
replace tot_for1 = . if ccuniv1~=1
label var tot_for1 "Total amount paid for formal care"
egen tot_for2 = rsum(f_amt_for g_amt_for h_amt_for )
replace tot_for2 =. if ccuniv2~=1
label var tot_for2 "Total amount paid for formal care"

/* CHILD CARES FOR SELF OR CARED FOR BY YOUNG SIBLING */

egen care_sel1 = eqany(a_care_sel b_care_sel c_care_sel), values(1)
replace care_sel1 = . if ccuniv1~=1
label var care_sel1 "yng child in self care"
egen care_sel2 = eqany(f_care_sel g_care_sel h_care_sel), values(1)
replace care_sel2 =. if ccuniv2~=1
label var care_sel2 "old child in self care"

*********************

compress

aorder

bysort wave: summarize

sort id wave
label data "Set E Max: Childcare, $p SIPP ($ver)"
cd "$output"
saveold set_e_noedij_max, replace
capture log close

/*
log using "c:\_files\programs\sipp\SIPP clean\codebook$ver.log", append
desc
sum
codebook, notes header
log close
*/



