*CC Tables MAX

label data "Set E: Childcare, $p SIPP"
notes: For the 1992, 1993 SIPP panels, all variables in this subfile all come from TM4 and TM10 for the 2001 SIPP panel, from TM4
set more off

global p = "92"
use "C:\_Files\data\SIPP\sipp$p\set_e_$p", clear
log using "c:\_files\programs\sipp\SIPP clean\set_e_max_$p.log", replace

********************************

/*
The raw codebook has the basic method for how the SIPP wrote the variable names.

VARIABLE Definitions 
eckd 				type of child care arrangement
epay				whether or not paid for childcare arrangement
tamt				amount spent on childcare for that type of childcare for that child


earrang				number of cc arrangements    (1996 panel only)
ewhothe				place non-relative cared for child
eselfhr				hrs cared for child yourself, while workng/ in school
eselfca				child cared for self 

eparhr1	 1			hours other parent cared for child
ewhsbhr	 3			hours of sibling care (sibling 15+)
esb14hr	 4			hours sibling care(14-)
egranhr	 5			hours of grandparent care
erelhr1	 6			hours of relative care
ehrfam1  7			hours of family day care
edayrhs	 8			hours of day care
enurhrs	 9			hours of nursery care (A-E)
eheadhr	 10			hours of head start care (A-E)
eothehr	 11			hours of non-relative care (A-E)
ehscho1	 12			hours in after school care (F-J)

ekidhr1	 eselfca=1		hours of self-care
eccpnum				person number of child
*/


* AORDER to ensure correct values in <eqany> commands
aorder



* Recreate "other" category. Family day care (non-relative in their home or other place)
*gen othehr1a = non-relative hrs cc if type==11 & place is _  or _ 
gen othehr1a = eothehra if eckd11a==1 & (ewhothea==2 | ewhothea==3)
gen othehr1b = eothehrb if eckd11b==1 & (ewhotheb==2 | ewhotheb==3)
gen othehr1c = eothehrc if eckd11c==1 & (ewhothec==2 | ewhothec==3)

gen othehr1f = eothehrf if eckd11f==1 & (ewhothef==2 | ewhothef==3)
gen othehr1g = eothehrg if eckd11g==1 & (ewhotheg==2 | ewhotheg==3)
gen othehr1h = eothehrh if eckd11h==1 & (ewhotheh==2 | ewhotheh==3)

*place==1
gen eothehr2a = eothehra if eckd11a==1 & ewhothea==1
gen eothehr2b = eothehrb if eckd11b==1 & ewhotheb==1
gen eothehr2c = eothehrc if eckd11c==1 & ewhothec==1

*nanny day care (non-relative ni child's home)
gen eothehr2f = eothehrf if eckd11f==1 & ewhothef==1
gen eothehr2g = eothehrg if eckd11g==1 & ewhotheg==1
gen eothehr2h = eothehrh if eckd11h==1 & ewhotheh==1



***************************
* CHILD-CENTERED ANALYSIS *
***************************
*Note: child care is still attached to the parent, not the child
capture program drop yng
program define yng
while "`1'"~="" {
	set more off

	*gen ccuniv`1' = (eckd03`1'==1 | eckd03`1'==0) 

	* PARENTAL CARE 
	* Includes either parent or parent at work and caring for child
	gen byte `1'_care_par = (eckd01`1'==1 | eckd02`1'==1 ) & ccuniv`1'==1 
	label var `1'_care_par "child `1' in parental care"
	drop eckd01`1' eckd02`1'


	* RELATIVE CARE
	* Includes siblings (any age), grandparents, and other relatives	
	gen byte `1'_care_rel = (eckd03`1'==1 | eckd05`1'==1 | eckd06`1'==1) & ccuniv`1'==1 
	gen byte `1'_paid_rel = (epaygra`1'==1 | epayrel`1'==1) & ccuniv`1'==1 	
	gen `1'_amt_rel = tamtgra`1' if ccuniv`1'==1 
	replace `1'_amt_rel = tamtrel`1' if `1'_amt_rel==.
	label var `1'_care_rel "child `1' in relative care"
	label var `1'_paid_rel "Child `1' paid for relative care"
	label var `1'_amt_rel "Child `1' amount paid for relative care"
	*drop eckd03`1' eckd05`1' eckd06`1'
		
	* FAMILY/INFORMAL DAYCARE 
	* Includes family daycare and informal care (non-relative, not in child's home)
	gen `1'_care_fam = (((eckd11`1'==1) & (ewhothe`1'==2 | ewhothe`1'==3)) & ccuniv`1'==1 )
	label var `1'_care_fam "Child `1' in family/informal daycare"
	gen byte `1'_paid_fam = (epayoth`1'==1 & (ewhothe`1'==2 | ewhothe`1'==3)) & ccuniv`1'==1 
	label var `1'_paid_fam "Child `1' paid for family care"
	gen `1'_amt_fam = tamtoth`1' if (epayoth`1'==1 & (ewhothe`1'==2 | ewhothe`1'==3)) & ccuniv`1'==1 
	replace `1'_amt_fam = (`1'_amt_fam ) if ccuniv`1'==1 
	label var `1'_amt_fam "Child `1' amount paid for family care"


	* NANNY/SITTER CARE 
	* Care by a non-relative in child's home
	gen `1'_care_nan = eckd11`1'==1 & ewhothe`1'==1 & ccuniv`1'==1
	label var `1'_care_nan "Child `1' in nanny care"
	gen byte `1'_paid_nan = epayoth`1'==1 & ewhothe`1'==1 & ccuniv`1'==1 
	label var `1'_paid_nan "Child `1' paid for nanny care"
	gen `1'_amt_nan = tamtoth`1' if epayoth`1'==1 & ewhothe`1'==1 & ccuniv`1'==1 
	label var `1'_amt_nan "Child `1' amount paid for nanny care"
	drop eckd11`1'


	* FORMAL DAYCARE/PROGRAMS 
	* For young children, includes daycare, nursery school, 
	gen `1'_care_for  = (eckd08`1'==1 | eckd09`1'==1) & ccuniv`1'==1 
	label var `1'_care_for "Child `1' in formal care"
	gen byte `1'_paid_for = (epayday`1'==1 | epaynur`1'==1) & ccuniv`1'==1 
	label var `1'_paid_for "Child `1' paid for formal care"
	gen `1'_amt_for = tamtday`1'  if ccuniv`1'==1
	replace `1'_amt_for = tamtnur`1' if `1'_amt_for ==.
	label var `1'_amt_for "Child `1' amount paid for formal care"
	*drop eckd08`1' eckd09`1' 
	*sum eckd09`1' eckd08`1' eckd10`1' if ccuniv`1'==1

	*SELF CARE
	* Care by self 
	gen `1'_care_sel = (eckd14`1'==1) & ccuniv`1'==1
	label var `1'_care_sel "Child `1' in self care"
	drop eckd14`1' 
	
	*sum `1'_paid_for `1'_amt_for  `1'_paid_rel `1'_amt_rel `1'_amt_nan `1'_amt_fam `1'_paid_nan `1'_paid_fam
	mac shift
}
end

yng a b c f g h

keep id wave cc*  *_*  eccpnum*  epppnum*   

aorder

****************************
* PARENT-CENTERED ANALYSIS *
****************************
*Note: Tabulates child care types and costs for each parent across children

*Generate (cc) universes for each parent from the universes from each child
egen ccuniv1 = eqany(ccuniva ccunivb ccunivc), values(1)
egen ccuniv2 = eqany(ccunivf ccunivg ccunivh), values(1)


/* PARENTAL CARE */
* Includes either parent or parent at work and caring for child
egen care_par1 = eqany(a_care_par b_care_par c_care_par ), values(1)
replace care_par1 = . if ccuniv1~=1
label var care_par1 "yng child in parental care"
egen care_par2 = eqany(f_care_par g_care_par h_care_par ), values(1)
replace care_par2 =. if ccuniv2~=1
label var care_par2 "old child in parental care"


/* RELATIVE CARE */
* Includes siblings over age 15, grandparents, and other relatives
egen care_rel1 = eqany(a_care_rel b_care_rel c_care_rel ), values(1)
replace care_rel1 = . if ccuniv1~=1
label var care_rel1 "yng child in relative care"
egen care_rel2 = eqany(f_care_rel g_care_rel h_care_rel ), values(1)
replace care_rel2 =. if ccuniv2~=1
label var care_rel2 "old child in relative care"
egen paid_rel1 = eqany(a_paid_rel b_paid_rel c_paid_rel ), values(1)
replace paid_rel1 = . if ccuniv1~=1
label var paid_rel1 "Paid for relative care"
egen paid_rel2 = eqany(f_paid_rel g_paid_rel h_paid_rel ), values(1)
replace paid_rel2 =. if ccuniv2~=1
label var paid_rel2 "Paid for relative care"
egen amt_rel1 = rmean(a_amt_rel b_amt_rel c_amt_rel )
replace amt_rel1 = . if ccuniv1~=1
label var amt_rel1 "Avg amount paid for relative care"
egen amt_rel2 = rmean(f_amt_rel g_amt_rel h_amt_rel )
replace amt_rel2 =. if ccuniv2~=1
label var amt_rel2 "Avg amount paid for relative care"
egen tot_rel1 = rsum(a_amt_rel b_amt_rel c_amt_rel )
replace tot_rel1 = . if ccuniv1~=1
label var tot_rel1 "Total amount paid for relative care"
egen tot_rel2 = rsum(f_amt_rel g_amt_rel h_amt_rel )
replace tot_rel2 =. if ccuniv2~=1
label var tot_rel2 "Total amount paid for relative care"

/* FAMILY/INFORMAL DAYCARE */
* Includes family daycare and informal care (non-relative, not in child's home)
egen care_fam1 = eqany(a_care_fam b_care_fam c_care_fam ), values(1)
replace care_fam1 = . if ccuniv1~=1
label var care_fam1 "yng child in family care"
egen care_fam2 = eqany(f_care_fam g_care_fam h_care_fam ), values(1)
replace care_fam2 =. if ccuniv2~=1
label var care_fam2 "old child in family care"
egen paid_fam1 = eqany(a_paid_fam b_paid_fam c_paid_fam ), values(1)


replace paid_fam1 = . if ccuniv1~=1
label var paid_fam1 "Paid for family care"
egen paid_fam2 = eqany(f_paid_fam g_paid_fam h_paid_fam ), values(1)
replace paid_fam2 =. if ccuniv2~=1
label var paid_fam2 "Paid for family care"
egen amt_fam1 = rmean(a_amt_fam b_amt_fam c_amt_fam )
replace amt_fam1 = . if ccuniv1~=1
label var amt_fam1 "Avg amount paid for family care"
egen amt_fam2 = rmean(f_amt_fam g_amt_fam h_amt_fam )
replace amt_fam2 =. if ccuniv2~=1
label var amt_fam2 "Avg amount paid for family care"
egen tot_fam1 = rsum(a_amt_fam b_amt_fam c_amt_fam )
replace tot_fam1 = . if ccuniv1~=1
label var tot_fam1 "Total amount paid for family care"
egen tot_fam2 = rsum(f_amt_fam g_amt_fam h_amt_fam )
replace tot_fam2 =. if ccuniv2~=1
label var tot_fam2 "Total amount paid for family care"

/* NANNY/SITTER CARE */
* Care by a non-relative in child's home

egen care_nan1 = eqany(a_care_nan b_care_nan c_care_nan ), values(1)
replace care_nan1 = . if ccuniv1~=1
label var care_nan1 "yng child in nanny care"
egen care_nan2 = eqany(f_care_nan g_care_nan h_care_nan ), values(1)
replace care_nan2 =. if ccuniv2~=1
label var care_nan2 "old child in nanny care"
egen paid_nan1 = eqany(a_paid_nan b_paid_nan c_paid_nan ), values(1)
replace paid_nan1 = . if ccuniv1~=1
label var paid_nan1 "Paid for nanny care"
egen paid_nan2 = eqany(f_paid_nan g_paid_nan h_paid_nan ), values(1)
replace paid_nan2 =. if ccuniv2~=1
label var paid_nan2 "Paid for nanny care"
egen amt_nan1 = rmean(a_amt_nan b_amt_nan c_amt_nan )
replace amt_nan1 = . if ccuniv1~=1
label var amt_nan1 "Avg amount paid for nanny care"
egen amt_nan2 = rmean(f_amt_nan g_amt_nan h_amt_nan )
replace amt_nan2 =. if ccuniv2~=1
label var amt_nan2 "Avg amount paid for nanny care"
egen tot_nan1 = rsum(a_amt_nan b_amt_nan c_amt_nan )
replace tot_nan1 = . if ccuniv1~=1
label var tot_nan1 "Total amount paid for nanny care"
egen tot_nan2 = rsum(f_amt_nan g_amt_nan h_amt_nan )
replace tot_nan2 =. if ccuniv2~=1
label var tot_nan2 "Total amount paid for nanny care"

/* FORMAL DAYCARE/PROGRAMS */
* For young children, includes daycare, nursery school, and Head Start.
* For older children, includes daycare, sports, lessons, clubs, after-school care.
egen care_for1 = eqany(a_care_for b_care_for c_care_for), values(1)
replace care_for1 = . if ccuniv1~=1
label var care_for1 "yng child in formal care"
egen care_for2 = eqany(f_care_for g_care_for h_care_for ), values(1)
replace care_for2 =. if ccuniv2~=1
label var care_for2 "old child in formal care"
egen paid_for1 = eqany(a_paid_for b_paid_for c_paid_for ), values(1)
replace paid_for1 = . if ccuniv1~=1
label var paid_for1 "Paid for formal care"
egen paid_for2 = eqany(f_paid_for g_paid_for h_paid_for ), values(1)
replace paid_for2 =. if ccuniv2~=1
label var paid_for2 "Paid for formal care"
egen amt_for1 = rmean(a_amt_for b_amt_for c_amt_for )
replace amt_for1 = . if ccuniv1~=1
label var amt_for1 "Avg amount paid for formal care"
egen amt_for2 = rmean(f_amt_for g_amt_for h_amt_for )
replace amt_for2 =. if ccuniv2~=1
label var amt_for2 "Avg amount paid for formal care"
egen tot_for1 = rsum(a_amt_for b_amt_for c_amt_for )
replace tot_for1 = . if ccuniv1~=1
label var tot_for1 "Total amount paid for formal care"
egen tot_for2 = rsum(f_amt_for g_amt_for h_amt_for )
replace tot_for2 =. if ccuniv2~=1
label var tot_for2 "Total amount paid for formal care"

/* CHILD CARES FOR SELF OR CARED FOR BY YOUNG SIBLING   */
* Includes 
egen care_sel1 = eqany(a_care_sel b_care_sel c_care_sel ), values(1)
replace care_sel1 = . if ccuniv1~=1
label var care_sel1 "yng child in parental care"
egen care_sel2 = eqany(f_care_sel g_care_sel h_care_sel ), values(1)
replace care_sel2 =. if ccuniv2~=1
label var care_sel2 "old child in parental care"

*********************

*compress

*aorder

*bysort wave: summarize

sort id wave
label data "Set E Max: Childcare, $p SIPP ($ver)"
saveold "c:\_files\data\sipp\sipp$p\set_e_noedij", replace
capture log close

/*
log using "c:\_files\programs\sipp\SIPP clean\codebook$ver.log", append
desc
sum
codebook, notes header
log close
*/



