/* Please do not attempt to run this program without reading the accompanying documentation*/

version 8.0
set more off
prog drop _all

/*
File: clean g (health insurance coverage).do
Date: July, 2005
Desc: Clean-file to create Set G
Note: See acknowledgments and copyright notice in new_master.do
*/

/* 
This program is to be run embedded within new_master.do.
It cleans the variables necessary for Set G and generates a codebook.
*/

cd "$tempdata"
if "$p" == "04" | "$p" == "08" use test, clear

notes: All variables are monthly except where noted.
notes: All variables come from the longitudinal panel except where noted.
notes: See Crosswalk for more information on consistent names

*sum

********************************
* recode all -1 to missing values
mvdecode _all, mv(-1)

* Recode (1,2) vars into (0,1) dummies
/* ssi_c: in panel 96 and 01, "0" is "not covered". In earlier panels, "0" is "not in universe". As a result,there is notable discrepancy 
in ssi_c means between 96, 01 panel and other panels. The discrepancy is from original SIPP data and we are not able to change it.*/ 

if $p>=84 & $p<=93 {
	* To make vars consistent w/ 96/01 coding
        /* Note:recode _r "not applicable" to missing values---consistent with 96/01. If one is interested 
        in knowing the statistics of these variables among the universe, he/she should recode missing values back to 0. 
        Otherwise, he/she will obtain statistics among those who were asked these questions*/
        recode fs_r (0=.)
	recode pubhou_r (0=.)
	recode lowrent_r (0=.)
	recode utilpay_r (0=.)
	recode enrgy_r (0=.)
	recode socseca_r (0=.) 
	recode socseck_r (0=.) 
	recode vets_r (0=.) 
	recode tanf_r (0=.) 
	recode genasst_r (0=.) 
	recode fostkid_r (0=.) 
	recode othwelf_r (0=.) 
	recode wic_r (0=.) 
	recode stateui_r (0=.) 
	recode supui_r (0=.) (2=0)
	recode othui_r (0=.) 

	if $p!=91 & $p!=90 & $p>=90 recode ssi_c (2 = 1) (3 = 1) /*see notes above*/
	recode ssi_r (0=.)
	recode ssi_r (2=0) 
	label define ss 0 "no recipiency this month" 1 "Yes, recipiency this month"
	label values ssi_r ss
	replace wic_a=wic_a/100
	notes: wic_a for pre-96 panels have been changed into dollars to conform with later panels. 
	}

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	recode ccare_r (2=0)
	recode ssi_c (2=0)
	recode ssia_r (2=0)
	recode ssik_r (2=0)
	recode statessi_r (2=0)
	recode sect8_r (2=1)
	note sect8_r: section 8 variable measures if lived in setion 8 OR other government program  
}

recode ercvafdc (2=0)
label define a 0 "no" 1 "yes"
label values ercvafdc a
recode socseca_c (2=0)
label define b 0 "not covered" 1 "covered"
label values socseca_c b
recode vets_c (2=0)
label define c 0 "not covered" 1 "covered"
label values vets_c c
recode tanf_c (2=0)
label define d 0 "not covered" 1 "covered"
label values tanf_c d
recode genasst_c (2=0)
label define e 0 "not covered" 1 "covered"
label values genasst_c e
recode fostkid_c (2=0)
label define f 0 "not covered" 1 "covered"
label values fostkid_c f
recode othwelf_c (2=0)
label define g 0 "not covered" 1 "covered"
label values othwelf_c g
recode wic_c (2=0)
label define h 0 "not covered" 1 "covered"
label values wic_c h
recode fs_c (2=0)
label define i 0 "not covered" 1 "covered"
label values fs_c i
recode fs_r (2=0) 
label define j 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values fs_r j
recode pubhou_r (2=0)
label define k 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values pubhou_r k
recode lowrent_r (2=0)
label define l 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values lowrent_r l
recode utilpay_r (2=0)
label define m 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values utilpay_r m
recode enrgy_r (2=0)
label define n 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values enrgy_r n
recode socseca_r (2=0)
label define o 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values socseca_r o
recode socseck_r (2=0)
label define p 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values socseck_r p
recode vets_r (2=0)
label define r 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values vets_r r
recode tanf_r (2=0) 
label define s 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values tanf_r s
recode genasst_r (2=0) 
label define t 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values genasst_r t
recode fostkid_r (2=0)
label define u 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values fostkid_r u
recode othwelf_r (2=0)
label define v 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values othwelf_r v
recode wic_r (2=0)
label define w 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values wic_r w
recode stateui_r (2=0)
label define x 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values stateui_r x
if ($p>=84 & $p<=93) | $p==96 | $p==01 {
recode othui_r (2=0)
label define y 0 "no recipiency this month" 1 "Yes, recipiency this month"
label values othui_r y
}


* Unemployment Insurance
if "$p" == "04" | "$p" == "08" {
	recode supui_r (2=0)
	label define supui 0 "no recipiency this month" 1 "Yes, recipiency this month"
	label values supui_r supui
	gen byte ui_r = max(stateui_r, supui_r)
	recode supui_a (.=0)
	gen ui_a = stateui_a + supui_a
}
if $p==96 | $p==01 {
	recode stateui_a (.=0)
	recode othui_a (.=0)
	gen byte ui_r = max(stateui_r, othui_r)
	gen ui_a = stateui_a + othui_a
	}
if $p>=84 & $p<=93 {
	gen byte ui_r = max(stateui_r, supui_r, othui_r)
	recode supui_a (.=0)
	gen ui_a = stateui_a + supui_a + othui_a
	}
label var ui_r "Unemployment Ins. Receipient"
label var ui_a "Unemployment Ins. Amount"

* Public housing
if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	gen byte hsg_r = max(sect8_r,pubhou_r,lowrent_r)
	}
if $p>=84 & $p<=93 {
	gen byte hsg_r = max(pubhou_r,lowrent_r)
	}
label var hsg_r "Housing Asst. Receipient"

* Welfare
gen byte welfare_r = max(tanf_r, genasst_r, othwelf_r)
label var welfare_r "Welfare Receipient (tanf_r, genasst_r, othwelf_r)"

gen byte welfare_c = max(tanf_c,genasst_c,othwelf_c)
label var welfare_c "Welfare Coverage (tanf_c, genasst_c, othwelf_c)"

recode tanf_a (.=0) (min/0 = 0)
recode genasst_a (.=0) (min/0 = 0)
recode othwelf_a (.=0) (min/0 = 0)
gen byte welfare_a = tanf_a + genasst_a + othwelf_a
label var welfare_a "Welfare Amount (tanf_a, genasst_a, othwelf_a)"

********************************************
compress
aorder
sum

drop rot

sort $ids
cd "$output"
label data "Set G: Transfers, $p SIPP ($ver)"
saveold set_g, replace

capture log close

