/* Please do not attempt to run this program without reading the accompanying documentation*/

version 8.0
set more off
prog drop _all

/*
File: clean h (health insurance coverage).do
Date: May 2012
Desc: Clean-file to create Set H
Note: See acknowledgments and copyright notice in new_master.do
*/

/* 
This program is to be run embedded within new_master.do.
It cleans the variables necessary for Set H and generates a codebook.

NOTE: This program uses variables from Set A and Set C.

*/

cd "$tempdata"
if "$p" == "04" | "$p" == "08" use test, clear


notes: All variables are monthly except where noted.
notes: All variables come from the longitudinal panel except where noted.
notes: See Crosswalk for more information on consistent names

******************************

* Merge vars from Set A and Set C

sort id wave srefmon
save test2, replace

cd "$output"
use id wave srefmon epppnum month using set_a
cd "$tempdata"
sort id wave srefmon
merge id wave srefmon using test2
tab _merge
drop _merge
sort id wave srefmon
save test2, replace

cd "$output"
use id wave srefmon pfid using set_c
cd "$tempdata"
sort id wave srefmon
merge id wave srefmon using test2
tab _merge
drop _merge

*******************************
if $p==92 | $p==93 | $p==91 | $p==90 | ($p<=89 & $p>=84) {
	replace year=year+1900

	* To make vars consistent w/ 96/01 coding
	recode ehimth (0=2)
	recode ehicost (0=-1)
	recode hiownc (0=-1) (2=0)
	recode hi_otc (0=-1) (2=0)
	recode rmedcode (0=-1)
	recode rchampm (0=-1)
	recode ecrmth (0=-1)
	recode ecdmth (0=-1)
	
	recode ehiothr (0=.) (2=1) (3=1) (4=1) (5=1) (6=1) (7=1) (8=0)
	}
	
label define yesno 0 "No" 1 "Yes"
label values ehiothr yesno
recode ehimth   (2=0)

notes ehimth: SIPP var <hiind> in 92/93 and <ehimth> in 96/01.
notes ehicost: SIPP var <hipay> in 92/93 and <ehicost> in 96/01.
notes rmedcode: SIPP var <medcode> in 92/93 and <rmedcode> in 96/01.
notes ecrmth: SIPP var <careco> in 92/93 and <ecrmth> in 96/01.
notes ecdmth: SIPP var <caidco> in 92/93 and <ecdmth> in 96/01.
notes rchampm: SIPP var <champ> in 92/93 and <rchampm> in 96/01.

* recode all -1 to missing values
mvdecode _all, mv(-1)

sum

*Recode HI vars into dummy variables: yes=1, no=0

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	recode ehiyngkd (2=0)
	recode ehioldkd (2=0)
	recode ehirsn01 (2=0)
	recode ehirsn02 (2=0)
	recode ehirsn03 (2=0)
	recode ehirsn04 (2=0)
	recode ehirsn05 (2=0)
	recode ehirsn06 (2=0)
	recode ehirsn07 (2=0)
	recode ehirsn08 (2=0)
	recode ehirsn09 (2=0)
	recode ehirsn10 (2=0)
	recode ehirsn11 (2=0)
	recode ehirsn12 (2=0)
	recode ehispse  (2=0)
	recode rchampm 	(2=0)
	recode enonhh   (2=0)
	recode ehiothr  (2=0)
	
	gen hisrc = ehemply
}
        
notes hisrc: 1996 and 2000 panels are different from earlier panels.

*****************************
* Health Insurance Variables*
*****************************

/*
NOTE: renamed hiind as ehmith in 92/93
NOTE: 92/93 uses <hiind> while 96/01 uses <ehimth> (see "pull h")

D HIIND 1 682

Did this person have health insurance coverage this month? Includes CHAMPUS, CHAMPVA, and military coverage. Excludes Medicaid, 
Medicare and plans paying benefit only for accidents or specific diseases. Range=(0:2)
U All persons, no age limitation 
V 0 .Not applicable 
V 1 .Yes 
V 2 .No 

D EHIMTH 2 2116
T HI: Private health insurance coverage in this month. Was ... covered by a health insurance plan 
other than medicare, medicaid? This is a monthly variable. Its value is subject to change between months.
U All persons
V 1 .Yes, covered
V 2 .No, not covered
*/

*Health insurance coverage:
gen byte himth = ehimth==1 | ecdmth==1 | ecrmth==1 
label var himth "Has ANY Health Ins. this month" 

*Private Health insurance coverage: 
gen byte privhimth=ehimth==1 
label var privhimth "Has private health ins. this month" 

*Medicare coverage
gen byte medcarmth = ecrmth==1 
label var medcarmth "Has Medicare this month"

*Medicaid coverage
gen byte medcaidmth = ecdmth==1 
label var medcaidmth "Has Medicaid this month"

*Military coverage
gen byte milmth = rchampm==1 
label var milmth "Has Military coverage this month"

drop ehimth ecrmth ecdmth rchampm

*************************
*Employer based coverage*
*************************

* Note: 
if $p==01 | "$p" == "04" | "$p" == "08" {
	gen ehemply1 = ehemply if ehiowner==1
	gen ehemply2 = ehemply if ehiowner==2
	gen ehemply3 = ehemply if ehiowner==3
	replace ehemply2 = . if enonhh==0
	gen hiemp=ehemply if  ehemply1~=. |  ehemply2~=. |  ehemply3~=.
	drop ehemply ehemply1 ehemply2 ehemply3
	rename hiemp ehemply
	}

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	gen  byte ephi_t = ehemply==1 | ehemply==2 | ehemply==3
	}

if $p==92 | $p==93 | $p==91 | $p==90 | ($p<=89 & $p>=84) {
	gen  byte ephi_t = hiempl==1 
	}

label var ephi_t "Has employer provided coverage this month"
notes: <ephi> includes present and past employer for all panels; union provided for 96 and 01 only.

********************
*Coverage ownership*
********************
*(Note: Universe is ehimth==1)

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	gen byte own_cov= ehiowner==1 & ehiowner>=1 & ehiowner<=3
	gen byte oth_cov = ehiowner==2 & ehiowner>=1 & ehiowner<=3
	gen byte both_cov =ehiowner==3 & ehiowner>=1 & ehiowner<=3
	replace own_cov=. if (both_cov~=1 & own_cov~=1 & oth_cov~=1)
	replace oth_cov=. if (both_cov~=1 & own_cov~=1 & oth_cov~=1)
 	replace both_cov=. if (both_cov~=1 & own_cov~=1 & oth_cov~=1)
	}

if $p==92 | $p==93 | $p==91 |$p==90 | ($p<=89 & $p>=84) {
	rename hiownc own_cov
	rename hi_otc oth_cov
	gen both_cov = own_cov==1 & oth_cov==1
	replace own_cov=. if (oth_cov~=1 & own_cov~=1 & both_cov~=1)
	replace oth_cov=. if (oth_cov~=1 & own_cov~=1 & both_cov~=1)
	replace both_cov=. if (oth_cov~=1 & own_cov~=1 & both_cov~=1)
	gen own_covt=own_cov 
	replace own_covt=0 if both_cov==1
	gen oth_covt=oth_cov
	replace oth_covt=0 if both_cov==1
	sum own_cov* oth_cov* 
	replace own_cov=own_covt
	replace oth_cov=oth_covt
	drop oth_covt own_covt
	sum own_cov oth_cov both_cov
	}
label var own_cov "Covered by own plan"
label define own 1 "Own plan" 0 "Not own plan"
label values own_cov own

label var oth_cov "Covered by someone else's plan"
label define oth 1 "Other's plan" 0 "Not other's"
label values oth_cov oth

label var both_cov "Covered by own and else's plan"
label define bth 1 "Both own/other's plan" 0 "Not both"
label values both_cov bth

* Generate own versus other coverage
gen byte ownboth = own_cov==1 | both_cov==1 /* if own_cov!=.*/
gen byte othboth = oth_cov==1 | both_cov==1 /* if oth_cov!=.*/
label var ownboth "HI through self or both self & other"
label var othboth "HI through other or both self & other"

*************************************
*Employer-provided health insurance *
*************************************

*Clean ephi so that it only includes those who have hi coverage in their own name
gen byte re_ephi = 0 
replace re_ephi = 1 if ephi_t==1 & ownboth==1
rename re_ephi ephi
label var ephi "Had Emplyr-provided HI this month"

*****************************
*Reason not covered by insurance
*******************************

/* this part of the program is incomplete */

cd "$output"
save set_h, replace
cd "$tempdata"

cd "$output"
use set_h, clear
cd "$tempdata"

*************************************************
*Employer-provided coverage for family members
/* 
Generate a dataset of dependents and prepare to merge
back onto full dataset.

Do this twice, once for rcuow58a and once for rcuow58b.

This is not available pre-96
*/
if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	sort epppnum pfid wave srefmon
        cd "$tempdata"
	save set_h_fordep, replace
	cd "$tempdata"

	keep id wave srefmon rcuow58a himth epppnum othboth pfid year month
	rename id dep_id

	* Keep only possible dependents
	* (A) Have coverage through someone else
	keep if himth==1 
	keep if rcuow58a~=. & rcuow58a~=0  
	keep if othboth==1
	* (B) Don't identify self as source of HI
	destring epppnum, replace
	drop if rcuow58a==epppnum

	* identify provider as person num to merge back onto full dataset
	rename epppnum dep_epppnum
	rename rcuow58a epppnum

	sort epppnum pfid wave srefmon
	save test3, replace

	cd "$tempdata"
	use set_h_fordep, clear
	cd "$tempdata"
	keep id wave srefmon rcuow58b himth epppnum othboth pfid year month
	rename id dep_id

	* Keep only possible dependents
	* (A) Have coverage through someone else
	keep if himth==1 
	keep if rcuow58b~=. & rcuow58b~=0  
	keep if othboth==1
	* (B) Don't identify self as source of HI
	destring epppnum, replace
	drop if rcuow58b==epppnum

	* identify provider as person num to merge back onto full dataset
	rename epppnum dep_epppnum
	rename rcuow58b epppnum

	* Merge two subsets together
	sort epppnum pfid year month
	append using test3
      
	* rename vars for dependents 
	label var dep_id "ID of dependent"
	rename himth dep_himth
	label var dep_himth "HI Dependent"

	sort epppnum pfid wave srefmon
	compress
	save test4, replace
	sum 	

	* Determine who has coverage from an employer through either fam coverage or self.
	* Identify if are provider or dependent	
	cd "$tempdata"
	use set_h_fordep, clear
	cd "$tempdata"
	destring epppnum, replace

	sort epppnum pfid wave srefmon
	merge epppnum pfid wave srefmon using test4
	tab _merge
	drop _merge
	sum
        
       	* dependent if has hi from employer in someone else's name
	gen byte dep_ephi = dep_himth==1 & ephi_t==1
	
	label var dep_ephi "Provider's dependent-has coverage from someone w/ EPHI"
	
	sort pfid epppnum wave srefmon
	egen provcov = sum(dep_ephi), by(pfid epppnum wave srefmon)
	recode provcov 1/max = 1
	label var provcov "Dependent HI coverage from someone's employer"
	sum provcov
	
        
	
	}
	
*dep_ephi is actually not available for 90, 91, 92 and 93 panels

/*if $p==92 | $p==93 | $p==91 | $p==90 {
	gen byte dep_ephi = oth_cov==1 & ephi_t==1
	}
*/	


compress	

*****************************

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
        drop year month rot
        aorder
        label data "Set H2: HI Coverage--dependent info added, $p SIPP ($ver)"
        notes: h2 has all the observations, including dependents, providers and all other people not in the provider-dependent relationship
	
	cd "$output"
	saveold set_h2, replace
	cd "$tempdata"


	/*
	Merge dependent information back onto full dataset using
	the provider's person number to generate tables for providers. 
	This file will have one observation per person per month for
	those who are not providers, and one observations per provider 
	per dependent per month for providers.
	*/

	use test4, clear
	rename dep_id id

	/* 
	Keep one obs per person. There are multiple observations per person if 
	a person cites more than one other person as their health insurance 
	provider.
	*/

	sort id wave srefmon
	egen idx=tag(id wave srefmon)
	tab idx
	keep if idx==1
	drop idx

	sort id wave srefmon
	save test5, replace
	
	cd "$output"
	use set_h2, clear
	cd "$tempdata"

	*****************************
	
	sort id wave srefmon
	merge id wave srefmon using test5
	tab _merge
	drop _merge
	recode dep_himth (.=0) 

	gen byte anyemphi=(ephi==1 | dep_himth==1)
	label var anyemphi "EPHI from any source"
	
	drop dep_ephi dep_epppnum dep_himth

	}
	
/*
********************************************
* Example code to create yearly coverage variables
********************************************
* NOTE: You need to merge year into dataset to run the following code.

egen cnt = count(srefmon), by(id year)

sort id year
egen hiyr = max(himth), by(id year)
label var hiyr "Had any hlth ins. anytime this year"  

egen hlthyr_ = sum(himth) , by(id year)
gen byte hiayr = hlthyr_ ==cnt 
drop hlthyr_
label var hiayr "Had any hlth ins. all this year" 
*/
**************************************************************

if $p==92 | $p==93 | $p==91 | $p==90 | ($p<=89 & $p>=84) { 
   drop hiempl pfid year month rot epppnum
   }
   
if $p==93 {
	drop tst1 tst2
	}

drop ephi_t
compress
aorder

cd "$output"
use set_h, clear

sort $ids
label data "Set H: Health Insurance Coverage, $p SIPP ($ver)"

cd "$output"
saveold set_h, replace

desc
sum

capture log close

