/*
File: clean_i_workschedules.do
Date: July, 2005
Desc: This program recodes variables pulled from the extracted SIPP data to create Set I.
Note: See instructions, acknowledgments, and copyright notice in master.do
*/

/* Please do not attempt to run this program without reading the accompanying documentation*/

version 8.0
set more off
prog drop _all

cd "$tempdata"
if "$p" == "04"  | "$p" == "08" use test, clear

notes: For the 2008 SIPP panel, all variables in this subfile come from T5
notes: For the 2004 SIPP panel, all variables in this subfile come from T4
notes: For the 2001 SIPP panel, all variables in this subfile come from T4
notes: For the 1996 SIPP panel, all variables in this subfile all come from TM4 and TM10
notes: For the 1993 SIPP panel, all variables in this subfile come from T9a
notes: For the 1992 SIPP panel, all variables in this subfile come from T9a


* recode all -1 to missing values
mvdecode _all, mv(-1)

recode ewshrs1 ewshrs2 (0=.)
recode ewsjob1 ewsjob2 (0=.)
recode ewsmnr1 ewsmnr2 (0=.)
recode ewsbeg1 ewsbeg2 (0=.)
recode ewsbegm1 ewsbegm2 (0=.)
recode ewsend1 ewsend2 (0=.)

if "$p" == "08" | "$p" == "04" | $p==01 | $p==96 {
	recode ewshmwk1 (2=0)
	recode ewshmwk2 (2=0)
	label var ewshmwk1 "Worked only at home in job 1"
	label var ewshmwk2 "Worked only at home in job 2"
	}
	
*note:seems no info available for pre-93
if $p==93 {
	gen byte ewshmwk1= max(ewsdy11,ewsdy12,ewsdy13,ewsdy14,ewsdy15,ewsdy16,ewsdy17)
	gen byte ewshmwk2= max(ewsdy21,ewsdy22,ewsdy23,ewsdy24,ewsdy25,ewsdy26,ewsdy27)
	label var ewshmwk1 "Worked only at home in job 1"
	label var ewshmwk2 "Worked only at home in job 2"
	}



*puts times in military time
*1 pm =1300, 12:30pm = 1230, 6am = 600, 12am=2400=0, etc. 
if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	* SIPP goes from 1 until 12:59 in civilian
	gen timebeg1 = ewsbeg1 if ewsbeg1>=0 & ewsbeg1<=1200 & ewsbegm1==1
	replace timebeg1 = ewsbeg1-1200 if ewsbeg1>=1200
	replace timebeg1 = ewsbeg1+1200 if ewsbegm1==2
	replace timebeg1=timebeg1-1200 if timebeg1>=2400 /*change those who should have belonged to afternoons back*/
	replace timebeg1 = 1200 if ewsbegm1==3
	replace timebeg1 = 0 if ewsbegm1==4 /*make timebeg1=0 instead of =2400 to avoid having both 2400 and 0 for midnight*/
	
	
	gen timebeg2 = ewsbeg2 if ewsbeg2>=0 & ewsbeg2<=1200 & ewsbegm2==1
	replace timebeg2 = ewsbeg2-1200 if ewsbeg2>=1200
	replace timebeg2 = ewsbeg2+1200 if ewsbegm2==2
	replace timebeg2=timebeg2-1200 if timebeg2>=2400
	replace timebeg2 = 1200 if ewsbegm2==3
	replace timebeg2 = 0 if ewsbegm2==4
	
	gen timeend1 = ewsend1 if ewsend1>=0 & ewsend1<=1200 & ewsendm1==1
	replace timeend1 = ewsend1-1200 if ewsend1>=1200
	replace timeend1 = ewsend1+1200 if ewsendm1==2
	replace timeend1=timeend1-1200 if timeend1>=2400
	replace timeend1 = 1200 if ewsendm1==3
	replace timeend1 = 0 if ewsendm1==4
	
	gen timeend2 = ewsend2 if ewsend2>=0 & ewsend2<=1200 & ewsendm2==1
	replace timeend2 = ewsend2-1200 if ewsend2>=1200
	replace timeend2 = ewsend2+1200 if ewsendm2==2
	replace timeend2=timeend2-1200 if timeend2>=2400
	replace timeend2 = 1200 if ewsendm2==3
	replace timeend2 = 0 if ewsendm2==4

	recode ewsempct ewsend1 ewsend2 ewsendm1 ewsendm2 (0=.)
	
	}
	
if $p>=90 & $p<=93 {

	gen timebeg1 = ewsbeg1 if ewsbeg1>=0 & ewsbeg1<=1200 & ewsbegm1==1
	replace timebeg1 = ewsbeg1-1200 if ewsbeg1>=1200
	replace timebeg1 = ewsbeg1+1200 if ewsbegm1==2
	replace timebeg1=timebeg1-1200 if timebeg1>=2400 /*change those who should have belonged to afternoons back*/
	
	
	gen timebeg2 = ewsbeg2 if ewsbeg2>=0 & ewsbeg2<=1200 & ewsbegm2==1
	replace timebeg2 = ewsbeg2-1200 if ewsbeg2>=1200
	replace timebeg2 = ewsbeg2+1200 if ewsbegm2==2
	replace timebeg2=timebeg2-1200 if timebeg2>=2400
	
	
	gen timeend1 = ewsend1 if ewsend1>=0 & ewsend1<=1200 & ewsendm1==1
	replace timeend1 = ewsend1-1200 if ewsend1>=1200
	replace timeend1 = ewsend1+1200 if ewsendm1==2
	replace timeend1=timeend1-1200 if timeend1>=2400
		
	gen timeend2 = ewsend2 if ewsend2>=0 & ewsend2<=1200 & ewsendm2==1
	replace timeend2 = ewsend2-1200 if ewsend2>=1200
	replace timeend2 = ewsend2+1200 if ewsendm2==2
	replace timeend2=timeend2-1200 if timeend2>=2400
	
	recode ewsempct ewsendm1 ewsendm2 (0=.)

	}
	
label var timebeg1 "Time began job 1"
label var timebeg2 "Time began job 2"
label var timeend1 "Time ended job 1"
label var timeend2 "Time ended job 2"	

	
*generate #of days worked
if $p>=90 & $p<=92 {
	gen ewsdys1 = ewsday11 + ewsday12 + ewsday13 + ewsday14 + ewsday15 + ewsday16 + ewsday17 
	gen ewsdys2 = ewsday21 + ewsday22 + ewsday23 + ewsday24 + ewsday25 + ewsday26 + ewsday27 
	}
if $p==93 {
	gen ewsdys1 = max(ewsday11, ewsdy11) + max(ewsday12,ewsdy12) + max(ewsday13, /*
	*/ ewsdy13) + max(ewsday14, ewsdy14) + max(ewsday15, ewsdy15) + max(ewsday16, /*
	*/ ewsdy16) + max(ewsday17, ewsdy17)
	gen ewsdys2 = max(ewsday21, ewsdy21) + max(ewsday22, ewsdy22) + max(ewsday23, /*
	*/ ewsdy23) + max(ewsday24, ewsdy24) + max(ewsday25, ewsdy25) + max(ewsday26, /*
	*/ ewsdy26) + max(ewsday27, ewsdy27)
	}

if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {

	* these variables recreate the number of days worked per week.  They should match the variables ewsdys1 and ewsdys2 

	gen ewsdys1check = max(ewsday11, ewsdy11) + max(ewsday12,ewsdy12) + max(ewsday13, /*
	*/ ewsdy13) + max(ewsday14, ewsdy14) + max(ewsday15, ewsdy15) + max(ewsday16, /*
	*/ ewsdy16) + max(ewsday17, ewsdy17)
	gen ewsdys2check = max(ewsday21, ewsdy21) + max(ewsday22, ewsdy22) + max(ewsday23, /*
	*/ ewsdy23) + max(ewsday24, ewsdy24) + max(ewsday25, ewsdy25) + max(ewsday26, /*
	*/ ewsdy26) + max(ewsday27, ewsdy27)
	}
label var ewsdys1 "number of days worked per week at job1"
label var ewsdys2 "number of days worked per week at job2"

*Below was completely updated and modified. 

gen byte wrkjob2 = ewsdys2!=0 & ewsdys2!=.
gen byte wrkjob1 = ewsdys1!=0 & ewsdys1!=.
label var wrkjob1 "Worked at job 1"
label var wrkjob2 "Worked at job 2"

gen byte stdhr1 = ((timebeg1>=700 & timebeg1!=.) & (timeend1!=. & timeend1<=1800) & ewsday17==0 & ewsday11==0 & (ewsdys1>0 & ewsdys1!=.))
gen byte stdhr2 = ((timebeg2>=700 & timebeg2!=.) & (timeend2<=1800 & timeend2!=.) & ewsday27==0 & ewsday21==0 & (ewsdys2>0 & ewsdys2!=.))

label var stdhr1 "Worked only standard hours in job 1"
label var stdhr2 "Worked only standard hours in job 2"
notes: standard hours is starting at or after 7am and ending before or at 6pm; no weekends

gen byte nstdhr1 = (((timebeg1<700 & timebeg1!=.) | (timeend1>1800 & timeend1!=.) | (ewsday17==1) | (ewsday11==1)) & ewsdys1!=. & ewsdys1>0)
gen byte nstdhr2 = (((timebeg2<700 & timebeg2!=.) | (timeend2>1800 & timeend1!=.) | (ewsday27==1) | (ewsday21==1)) & ewsdys2!=. & ewsdys2>0)

label var nstdhr1 "Worked any nonstandard hours in job 1"
label var nstdhr2 "Worked any nonstandard hours in job 2"
notes: Non-standard hours is working any hour 7am or before, after 6pm, or weekends

gen byte weekends = max(ewsday11, ewsday17, ewsday21, ewsday27)
gen byte evenings = (timeend1>1800 & timeend1!=.) | (timeend2>1800 & timeend2!=.) 
gen byte nights = ((timeend1<timebeg1 | timebeg1<500 | timeend1>2300) & timebeg1!=.& timeend1!=.) | ((timeend2<timebeg2 | timebeg2<500 | timeend2>2300) & timebeg2!=.& timeend2!=.)   

label var weekends "Worked any weekends, any job"
label var evenings "Worked any evenings (sometime between after 6 to midnight), any job"
label var nights "Worked any nights (sometime after 11 PM but before 5 AM), any job"

gen byte stdhrs = ((stdhr1==1 | stdhr2==1) & nstdhr1!=1 & nstdhr2!=1)
notes stdhrs: Had at least one job working standard hours and no jobs working non-standard hours. 
notes stdhrs: <stdhours> and <nstdhrs> are mutually exclusive.

gen byte nstdhrs = ((nstdhr1==1 | nstdhr2==1) & stdhr1!=1 & stdhr2!=1)
notes nstdhrs: <stdhours> and <nstdhrs> are mutually exclusive.
notes nstdhrs: Had any job working any nonstandard hours.

label var stdhrs "Worked standard hours only, any jobs"
label var nstdhrs "Worked any non-standard hours, any job"


if "$p" == "04" | $p==01 | $p==96 | $p==93  | "$p" == "08" {
	gen byte hstdhr1 = stdhr1==1 & ewshmwk1==1
	gen byte hstdhr2 = stdhr2==1 & ewshmwk2==1
	
	label var hstdhr1 "standard hours in home job 1"
	label var hstdhr2 "standard hours in home job 2"

	gen byte hnstdhr1 = nstdhr1==1 & ewshmwk1==1
	gen byte hnstdhr2 = nstdhr2==1 & ewshmwk2==1

	label var hnstdhr1 "non-standard hours in home job 1"
	label var hnstdhr2 "non-standard hours in home job 2"

	gen byte hstdhrs = ((hstdhr1==1 | hstdhr2==1) & hnstdhr1!=1 & hnstdhr2!=1)
	gen byte hnstdhrs = (hnstdhr1==1 | hnstdhr2==1) & hstdhr1!=1 & hstdhr2!=1
	
	label var hstdhrs "Worked standard hours at home, any job"
	label var hnstdhrs "Worked non-standard hours at home, any job"

	gen byte nstddays = max(ewsday11,ewsday21,ewsdy11,ewsdy21)+max(ewsday17,ewsday27,ewsdy17,ewsdy27 ) + /*
	*/ max(max(ewsday12,ewsdy12) * ((timebeg1<700 | timeend1>1800)& ewsdys1!=0), max(ewsday22,ewsdy22) * ((timebeg2<700 | timeend2>1800)&ewsdys2!=0)) + /*
	*/ max(max(ewsday13,ewsdy13) * ((timebeg1<700 | timeend1>1800)& ewsdys1!=0), max(ewsday23,ewsdy23) * ((timebeg2<700 | timeend2>1800)&ewsdys2!=0)) + /*
	*/ max(max(ewsday14,ewsdy14) * ((timebeg1<700 | timeend1>1800)& ewsdys1!=0), max(ewsday24,ewsdy24) * ((timebeg2<700 | timeend2>1800)&ewsdys2!=0)) + /*
	*/ max(max(ewsday15,ewsdy15) * ((timebeg1<700 | timeend1>1800)& ewsdys1!=0), max(ewsday25,ewsdy25) * ((timebeg2<700 | timeend2>1800)&ewsdys2!=0)) + /*
	*/ max(max(ewsday16,ewsdy16) * ((timebeg1<700 | timeend1>1800)& ewsdys1!=0), max(ewsday26,ewsdy26) * ((timebeg2<700 | timeend2>1800)&ewsdys2!=0))

	gen byte stddays = max(ewsday11,ewsday21,ewsdy11,ewsdy21)+max(ewsday12,ewsday22,ewsdy12,ewsdy22) + /*
		*/ max(ewsday13,ewsday23,ewsdy13,ewsdy23)+max(ewsday14,ewsday24,ewsdy14,ewsdy24) + /*
		*/ max(ewsday15,ewsday25,ewsdy15,ewsdy25)+max(ewsday16,ewsday26,ewsdy16,ewsdy26) + /*
		*/ max(ewsday17,ewsday27,ewsdy17,ewsdy27) - nstddays

	gen byte dayswrkd = stddays+nstddays
	}

if $p==92 | $p==91 | $p==90 {
	gen byte nstddays = max(ewsday11,ewsday21)+max(ewsday17,ewsday27) + /*
	*/ max(ewsday12 * ((timebeg1<700 | timeend1>1800)&ewsdys1!=0), ewsday22 * ((timebeg2<700 | timeend2>1800)&ewsdys2!=0)) + /*
	*/ max(ewsday13 * ((timebeg1<700 | timeend1>1800)&ewsdys1!=0), ewsday23 * ((timebeg2<700 | timeend2>1800)&ewsdys2!=0)) + /*
	*/ max(ewsday14 * ((timebeg1<700 | timeend1>1800)&ewsdys1!=0), ewsday24 * ((timebeg2<700 | timeend2>1800)&ewsdys2!=0)) + /*
	*/ max(ewsday15 * ((timebeg1<700 | timeend1>1800)&ewsdys1!=0), ewsday25 * ((timebeg2<700 | timeend2>1800)&ewsdys2!=0)) + /*
	*/ max(ewsday16 * ((timebeg1<700 | timeend1>1800)&ewsdys1!=0), ewsday26 * ((timebeg2<700 | timeend2>1800)&ewsdys2!=0))

	gen byte stddays = max(ewsday11,ewsday21)+max(ewsday12,ewsday22) + /*
		*/ max(ewsday13,ewsday23)+max(ewsday14,ewsday24) + /*
		*/ max(ewsday15,ewsday25)+max(ewsday16,ewsday26) + /*
		*/ max(ewsday17,ewsday27) - nstddays

	gen byte dayswrkd = stddays+nstddays
	}
label var nstddays "No. days worked non-standard hours either at home or other jobs"
label var stddays "No. days worked only standard hours"
label var dayswrkd "Total number of days worked per week"


*******************************************


if $p==96 | $p==01 | "$p" == "04" | "$p" == "08" {
	keep $idw age stddays nstddays dayswrkd hstdhr* hnstdhr* weekends evenings nights wrkjob* ewshrs1 ewshrs2 /*
	*/ std* nstd* timebeg* timeend* ewsmnr* ewsbeg* ewsend* ewsjob1 ewsjob2 ewshmwk1 ewshmwk2 ewsdys* ewsempct
        }       
        
if $p==92 | $p==91 | $p==90 | $p==93 {  
        drop ewsday* 
        }
if $p==93 {
        drop ewsdy1* ewsdy2* 
        }
aorder
sum
sort $idw
label data "Set I: Work Schedules, $p SIPP ($ver)"

cd "$output"
saveold set_i, replace
capture log close

