/* Please do not attempt to run this program without reading the accompanying documentation*/

version 8.0
set more off
prog drop _all

/*
File: clean J (leave).do
Date: May 2012
Desc: Clean-file to create Set J
Note: See acknowledgments and copyright notice in new_master.do
*/

/* 
This program is to be run embedded within new_master.do.
It cleans the variables necessary for Set J and generates a codebook.

*/

notes: All variables are monthly except where noted.
notes: See Crosswalk for more information on consistent names
notes: For the 1996,2001,2004,2008 SIPP panels, all variables in this subfile all come from TM1 and TM2

cd "$tempdata"
use test, clear

********************************
sort $idw
save test, replace

cd "$output"
use $idw year using set_a.dta, clear
cd "$tempdata"
sort $idw
merge $idw using test
tab _merge
keep if _merge==3
drop _merge

* recode all -1 to missing values
mvdecode _all, mv(-1)

if $p>=84 & $p<=93 {
	recode eyrsince 0=.
	}
	
if "$p" == "04" | "$p" == "08" {
	gen elstwrkm = .
	notes elstwrkm: not available in 20$p panel
	gen eprvjbmn = .
	notes eprvjbmn: not available in 20$p panel
	gen efrmrmn = .
	notes efrmrmn: not available in 20$p panel
	gen byte eyrsince = .
	replace eyrsince = 1 if tmakmnyr>=1953 & tmakmnyr<=2004
}
recode eyrsince 2=0
recode tmakmnyr 0=.
recode tlstwrky 0=.
recode efbrthmo 0=.

recode efrmrmn 0=.
recode elstwrkm 0=.
recode tfbrthyr 0=.
recode tfrmryr 0=.

if $p>=84 & $p<=93 {
	recode tfbrthyr -3=.
	recode tmakmnyr -3=.
	}

if $p==96 {
	recode tmomchl 5/max=5
	}
	
label define yesno 1 "yes" 0 "no"


/*
The SIPP only asks leave questions for the first child, born
between 1980 and 1996 in the 1996 panel, or 1990 and 2001 in 
the 2001 panel. The questions have a complicated skip pattern.

If worked during first pregnancy, asked a series of questions:
- How many hours worked
- When stopped working, during preg.
	- If stopped, why (ebtsit**)
- Why stopped working post-birth (eafbst**), regardless of whether stopped during preg.

If worked for pay after child born, asked more questions:
- When back to work?
- Hours?
 
If had worked during preg and went back to work: 
- Same hours?
- Same employer?
- Same skills/pay?
- Still with that employer?
	- If not, when left them?
*/

if $p==96 | $p==01 | "$p" == "08" {
	if $p==96 {
		gen byte smp_fh = tfbrthyr>=1980
		}
	if $p==01 {
		gen byte smp_fh = tfbrthyr>=1990
	}
	if "$p" == "08" {
		gen byte smp_fh = year - tfbrthyr <= 21
	}

	label var smp_fh "Sample for fertility questions"
	
	
	        recode eafbwkft 2=0
		recode eafbwkse 2=0
		recode eafbwrk 2=0
		recode ebfbctwk 2=0
		recode ebfbpgft 2=0
		recode ebfbstop 2=0
		recode ebfbwkpr 2=0
		recode emomlivh 2=0
		recode eoff6mtn 2=0
		recode eothtime 2=0
		recode ewrk35hr 2=0
        
	
	rename ebfbctwk smp_w
	label var smp_w "Worked prior to first preg"
	label values smp_w yesno

	rename ebfbwkpr smp_wkp
	label var smp_wkp "Worked during first preg"
	label values smp_wkp yesno

	rename ebfbpgft smp_wftp
	label var smp_wftp "Worked ft during first preg--at least 35 hours/week"
	label values smp_wftp yesno

	rename ebfbstop smp_swp
	label var smp_swp "Stopped working when preg"
	label values smp_swp yesno

	rename eafbwrk smp_wkb
	label var smp_wkb "Worked after first birth"
	label values smp_wkb yesno

	rename eafbwkft smp_wftb
	label var smp_wftb "Worked ft after first birth"
	label values smp_wftb yesno

	gen byte workpb = smp_wkp==1 & smp_wkb==1 if smp_fh==1
	replace workpb=. if smp_wkb==. | smp_wkp==.
	label var workpb "Worked during & after first birth"
	label values workpb yesno

	gen byte workpyok = (eafbwkpy==1 | eafbwkpy==2) if workpb==1
	label var workpyok "Pay same or better after birth"
	label values workpyok yesno

	gen byte workskok = (eafbwkps==1 | eafbwkps==2) if workpb==1
	label var workskok "Job skill level same or better after birth"
	label values workskok yesno

	gen byte workok = (eafbwkpy==1 | eafbwkpy==2) & (eafbwkps==1 | eafbwkps==2) if workpb==1
	label var workok "Both Pay & skills same or better after birth"
	label values workok yesno

	renpfix ebtsit0 ebtsit
	renpfix eafbst0 eafbst
	
	capture program drop rcde 
	program define rcde 
	local i = 1
	while `i'<=15 {
		recode ebtsit`i' 2=0
		recode eafbst`i' 2=0
		local i = `i'+1
		}
	end
	
	rcde	
	
	label define stoprsn 1 "quit" 2 "let go" 3 "paid maternity" 4 "unpaid maternity" /*
	*/ 5 "paid sick" 6 "unpaid sick" 7 "disability" 8 "paid vacation" 9 "unpaid vacation" /*
	*/ 10 "other paid" 11 "other unpaid" 12 "never stopped wkg" 13 "self employed" /*
	*/ 14 "employer out of business" 15 "other reason" 0 "did not answer"
	
	label define stoprsn2 1 "quit" 2 "let go" 3 "paid maternity" 4 "unpaid maternity" /*
	*/ 5 "paid sick" 6 "unpaid sick" 7 "disability" 8 "paid vacation" 9 "unpaid vacation" /*
	*/ 10 "other paid" 11 "other unpaid" 12 "never stopped wkg" 13 "self employed" /*
	*/ 14 "employer out of business" 15 "other reason" 0 "did not answer or one answer only"

	aorder
	capture program drop stoprsn
	program define stoprsn
	/* Program generates one var (from 15) for why stopped working and 
	a var for those who answer one or more reasons.*/
		gen `1' = 0 if `2'1~=.
		gen `3' = 0 if `2'1~=.
		
		replace `1' = 1 if `2'1==1
		
		local i = 2
		while `i'<=15 {
			replace `3' = `i' if `2'`i'==1 & `1'~=0 & `3'==0 
			replace `1' = `i' if `2'`i'==1 & `1'==0
			local i = `i'+1
			}
		label values `1' stoprsn
		label values `3' stoprsn2
	end

	compress

	stoprsn stopprg ebtsit dualprg
	stoprsn stopbrth eafbst dualbrth
	
	label var stopprg "First reason stopped working at pregnancy"
	label var dualprg "Second reason stopped working at pregnancy"
	label var stopbrth "First reason stopped working after birth of child"
	label var dualbrth "Second reason stopped working after birth of child"
	notes stopprg: reasons were coded in order of importance based on CEPR's analysis
	notes dualprg: reasons were coded in order of importance based on CEPR's analysis
	notes stopbrth: reasons were coded in order of importance based on CEPR's analysis
	notes dualbrth: reasons were coded in order of importance based on CEPR's analysis
        
        
	if $p==96 {
		gen plvdur = ragfbrth-ragestop if ragestop~=. & ragfbrth~=.
		label var plvdur "Duration of pregnancy leave"
		notes plvdur: should match 01 RNMSTOP

		gen mlvdur = ragertwk-ragfbrth if ragfbrth~=. & ragertwk~=.
		label var mlvdur "Duration of non-work after child born"
		notes mlvdur: should match 01 RNMRETWK 

		gen empdur = ragelvem-ragertwk if ragelvem~=. & ragertwk~=. & eafbwkem==1 
		label var empdur "How long stayed with emp, if returned to same emp."

		gen empdur2 = ragelvem-ragfbrth if ragelvem~=. & ragfbrth~=. & eafbwkem==1 
		label var empdur2 "Number of mnths after birth left post birth employer"
		notes empdur2: should match 01 RNMLEVEM
		}

	*********************
	* Caring leaves
	compress
	
	* Breaks are asked of adults age 21 to 64 who worked at least 6 straight months at some point.
	* tmakmnyr~=0 & tmakmnyr~=.
	gen numbreak = eoff6mtn==1
	recode ecntothr .=0
	replace numbreak = numbreak + ecntothr
	recode numbreak 4/max = 4
	label var numbreak "Number of 6 mo.+ job breaks"
	tab numbreak, m

	gen ft_n = ewrk35hr==1
	label var ft_n "Worked ft all years"

	gen brk = tnowrkto - tnowrkfr
	replace brk = . if brk <0
	label var brk "Length of most recent caring labor break"

	gen brk_yrs = year - tnowrkto
	sum brk_yrs
	recode brk_yrs min/0 = .
	label var brk_yrs "Years since most recent caring labor break"

	gen byte brk_ch = enwresn==1 if numbreak~=0
	label var brk_ch "Most recent break for childcare"

	gen byte brk_eld = enwresn==2 if numbreak~=0
	label var brk_eld "Most recent break for elderly family"

	gen byte brk_dis = enwresn==3 if numbreak~=0
	label var brk_dis "Most recent break for disabled family"
	
	drop ebtsit* eafbst*
	
	}

gen agepreg = tfbrthyr - (year - age)
label var agepreg "Mother's age at first pregnancy"

gen agefkid = age-agepreg
label var agefkid "Age of mother's oldest child"

* Experience
count if tmakmnyr>year & (tmakmnyr~=. & tmakmnyr~=0)
* should be zero?
replace tmakmnyr = year if tmakmnyr>year & (tmakmnyr~=. & tmakmnyr~=0)

gen myrs_exp = year - tmakmnyr if (tmakmnyr~=. & tmakmnyr~=0)
replace myrs_exp = . if (tmakmnyr==. | tmakmnyr==0)
label var myrs_exp "Maximum years of experience"

gen byte stable_n = eyrsince==1
label var stable_n "Stable emp. all years (6 mo or more)"

if $p==01 | $p==96 {
	recode eyrsinc2 .=0
	count if myrs_exp<eyrsinc2
	replace eyrsinc2 = myrs_exp if myrs_exp<eyrsinc2
	gen yrs_exp = myrs_exp - eyrsinc2
	label var yrs_exp "Yrs exp, minus yrs not wk min. 6 mos"

	recode ewrk35hr 2=0 .=0
	tab ewrk35hr, m 
	* Should be zero/1, no missing
	gen yrs_ftexp = yrs_exp*ewrk35hr
	label var yrs_ftexp "Yrs ft exp, minus yrs not wk min. 6 mos"
}

if "$p"=="04"  | "$p" == "08" {
	recode etimeoff .=0
	* convert to annual
	replace etimeoff = etimeoff / 12
	count if myrs_exp<etimeoff
	replace etimeoff = myrs_exp if myrs_exp<etimeoff
	gen yrs_exp = myrs_exp - etimeoff
	label var yrs_exp "Yrs exp, minus yrs not wk min. 6 mos"

	recode ewrk35hr 2=0 .=0
	tab ewrk35hr, m 
	* Should be zero/1, no missing
	gen yrs_ftexp = yrs_exp*ewrk35hr
	label var yrs_ftexp "Yrs ft exp, minus yrs not wk min. 6 mos"
}

if $p==93 | $p==92 | $p==91 | $p==90 | ($p<=89 & $p>=84) {
	* In 93 panel, have "how many years worked at least 6 mos."
	gen yrs_exp = myrs_exp if eyrsince==1
	replace yrs_exp = eyrsinc3 if eyrsince==0
	label var yrs_exp "Yrs exp, minus yrs not wk min. 6 mos"
}

	
*********************


compress

aorder

sum
sort $idw
label data "Set J: Leaves, $p SIPP ($ver)"

cd "$output"
saveold set_j, replace
cd "$tempdata"
capture log close

************************
