/* 
This program generates three tenure variables of interest:

matjob -- Months at job during panel
matjobt -- total months at job pre- and during panel
tenure -- categorical tenure var using matjobt

It requires the following variables:
	hasjob
	eyear
	emonth
	syear
	smonth
	year
	month
	id
	wave

It requires the following program in the directory labeled $programs:
idx.do
	
*/


cd $programs
do idx.do
cd $tempdata

sort id wave job
egen idjob = group(id job)

* generate counters for months to ease computations
*if $p<=93 & $p>=90 {
*	gen eyear = 0
*	}
sum year month syear smonth eyear emonth
gen actdate = ym(year,month)
label var actdate "Actual date in STATA counter (480 is Jan. 2000)"
* negative start dates are no good
replace actdate = actdate + 2000 if actdate~=.
replace actdate = actdate + 2000 if actdate~=.

* generate end dates for 1993 panel 
gen sdate = ym(syear,smonth)
label var sdate "Job start date in STATA counter (480 is Jan. 2000)"
gen edate = ym(eyear,emonth)
label var edate "Job end date in STATA counter (480 is Jan. 2000)"
if $p==96 | $p==01 {
	gen edate = ym(eyear,emonth)
	label var edate "Job end date in STATA counter (480 is Jan. 2000)"
	sum edate
	}
sum actdate sdate
if $p==96 {
	* Jobs reported ending in Mar 2000, but the data only through Feb 2000
	recode sdate 482=481
	recode edate 482=481
	}
if $p==01 {
	* Jobs reported ending in Jan 2004, but the data only through Dec 2003
	recode sdate 528=527
	recode edate 528=527
	}
replace sdate = sdate + 2000 if sdate~=.
replace edate = edate + 2000 if edate~=.
sum actdate sdate 
drop syear smonth eyear emonth

* fix hasjob
* assume that end dates are correct (cross tabs on earnings indicate they are likely to be)
replace hasjob = 0 if edate<actdate & edate~=.
replace idjob = . if edate<actdate & edate~=.
recode hasjob .=0

* generate unique job spells
sort idx idjob actdate
spell, by(idjob) cond(hasjob==1) censor(cl cr)
label var _seq "Number of months at job during panel"
label var _spell "Job spell during panel"
label var _end "Month job ends"

* generate total months at job, assign to all person-months.
egen matjob = max(_seq), by(idjob)
label var matjob "months at job during panel"
sum matjob [aw=wpfinwgt], detail 
tab matjob, m /* note that there is a seaming problem */
tab matjob hasjob, m 

* gen variable w/ end dates for panel calculations
sort idx wave month
gen end_ = actdate if _seq==matjob
egen end = max(end_), by(idx)
label var end "last month w/ job in panel"

* do above by job spell
sort idjob wave month
egen end2 = max(end_), by(idjob)
label var end2 "last month w/ job"

gen matjobt = (end2 + 1) - sdate
label var matjobt "total months at job, pre- and during sipp"


* Tenure
gen tenure = 1 if matjobt<=24 & matjobt~=.
replace tenure = 2 if matjobt>24 & matjobt<=48
replace tenure = 3 if matjobt>48 & matjobt<=72
replace tenure = 4 if matjobt>72 & matjobt<=96
replace tenure = 5 if matjobt>96 & matjobt~=.
label define tenure 1 "2 yrs or less" 2 "from 2 to 4 yrs" 3 "from 4 to 6 yrs" 4 "from 6 to 8 yrs" 5 "more than 8 yrs", modify
label values tenure tenure
label var tenure "Total time at job"




