
/* Please do not attempt to run this program without reading the accompanying documentation. */

version 8.0
set more off
prog drop _all
capture log close
clear

cd "$log"
log using set_b$p, replace

/*
File: pull b (demographics).do
Date: May 2012
Desc: Pull-file to create Set B
Note: See acknowledgements and copyright notice in new_master.do.
*/

/*

This program is to be run embedded within new_master.do.

The programs below pull the variables necessary for Set B from the 
SIPP Longitudinal, Core, and Topical Modules and merge them into 
one dataset that is by person-month.

Note that Topical Module data is appended to all observations, not
only that for the wave in which the data was gathered since the 
information on citizenship and cohabitation are only asked once
panel. 

Note that we delete any individual who appears in a Core or Topical 
Module file, but who is not on the Longitudinal file, as recommended by 
U.S. Census Bureau staff.

For the 1990-1993 panels, in order to reshape the Longitudinal 
files by person-month, we need to do three separate steps. 
(1) Pull all Longitudinal vars that appear once per panel and 
create a dataset that is by <id>.
(2) Pull all Longitudinal vars that appear once per wave and 
create a dataset that is by <id wave>.
(3) Pull all Longitudinal vars that appear once per month and 
create a dataset that is by <id mnth>. Generate calendar month
and wave from the month counter in this file. (The variable 
<mnth> goes from 1 to 36 in the 1993 panel and thus must be
converted into calendar months for merging.)
Then, we merge the three files together into one person-month 
file, along with variables from the Core and Topical Module
files.

Note that there is an error in the 1993 panel whereby 
there are individuals in the longitudinal file that show up 
without data. These are deleted. 
       
*/

macro list


capture program drop loop08
program define loop08
	
	global bvarlist "$ids rot esex erace eorigin tage ems edisabl renroll eenrlm eeducate tmetro tfipsst"

	forvalues i=1/8 {
		if `i' == 1 {
			use $bvarlist using $c`i', clear
		}
		if `i' > 1 {
			append using $c`i', keep($bvarlist)
		}
	}

	sort id rot
	cd "$tempdata"
	save test, replace

	cd "$cleandata"
	use id rot ecitiznt enatcitt erelat* using sipp08t2, clear
	sort id rot
	cd "$tempdata"
	merge id rot using test
	tab _merge
	drop _merge
        
	* give uniform names, as necessary
	rename esex sex
	rename erace race
	rename eorigin ethnic
	rename tage age
	rename ems ms
	rename edisabl disabled
	rename renroll ststat
	rename eenrlm student
	rename tmetro metro
	rename tfipsst sipp_st

	save test, replace
end

capture program drop loop04
program define loop04
	
	global bvarlist "$ids rot esex erace eorigin tage ems edisabl renroll eenrlm eeducate tmetro tfipsst"

	forvalues i=1/12 {
		if `i' == 1 {
			use $bvarlist using $c`i', clear
		}
		if `i' > 1 {
			append using $c`i', keep($bvarlist)
		}
	}

	sort id rot
	cd "$tempdata"
	save test, replace

	cd "$cleandata"
	use id rot ecitiznt enatcitt erelat* using sipp04t2, clear
	sort id rot
	cd "$tempdata"
	merge id rot using test
	tab _merge
  drop _merge
        
	* give uniform names, as necessary
	rename esex sex
	rename erace race
	rename eorigin ethnic
	rename tage age
	rename ems ms
	rename edisabl disabled
	rename renroll ststat
	rename eenrlm student
	rename tmetro metro
	rename tfipsst sipp_st

	save test, replace
end


capture program drop loop01
program define loop01
        local i=1
        use $ids rot esex erace eorigin tage ems edisabl renroll eenrlm eeducate /*
        */ tmetro tmsa tfipsst using $c`i', clear
        sort $ids
	cd "$tempdata"
        save test, replace
        local i = `i'+1
        while `i'>1 & `i'<10 {
                use $ids rot esex erace eorigin tage ems edisabl renroll eenrlm eeducate /*
                */ tmetro tmsa tfipsst using $c`i', clear
                sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
        } 
        sort id rot
	save test, replace

	cd "$cleandata"
	use id rot tcitiznt erelat* using sipp01t2, clear
	cd "$tempdata"
	sort id rot 
	merge id rot using test
	tab _merge
        drop _merge
        
        * give uniform names, as necessary
        rename esex sex
        rename erace race
        rename eorigin ethnic
        rename tage age
        rename ems ms
        rename edisabl disabled
        rename renroll ststat
        rename eenrlm student
        rename tmetro metro
        rename tmsa msa
        rename tfipsst sipp_st
        
        save test, replace
end

capture program drop loop96
program define loop96
        local i=1
        use $ids rot esex erace eorigin tage ems edisabl renroll eenrlm eeducate /*
        */ tmetro tmsa tfipsst using $f`i', clear
        sort id rot
        save test, replace
        local i = `i'+1
        while `i'>1 & `i'<13 {
                use $ids rot esex erace eorigin tage ems edisabl renroll eenrlm eeducate /*
                */ tmetro tmsa tfipsst using $f`i', clear
                sort id rot
                append using test
                sort id rot
                save test, replace
                local i=`i'+1
        } 
	order id rot
    sort id rot, stable
	ds
	save test, replace
	cd "$tempdata"
    save test, replace
    
	cd "$cleandata"
	use id rot rcitiznt erelat* using sipp96t2, clear
	cd "$tempdata"
		order id rot
        sort id rot, stable
        merge id rot using test
        tab _merge
        drop _merge
        
        * give uniform names, as necessary
        rename esex sex
        rename erace race
        rename eorigin ethnic
        rename tage age
        rename ems ms
        rename edisabl disabled
        rename renroll ststat
        rename eenrlm student
        rename tmetro metro
        rename tmsa msa
        rename tfipsst sipp_st
        sort id rot
        save test, replace
end

capture program drop loop93
program define loop93
        local p = $p
        * Longitudinal data: create two files 1) by id wave; 3) by id wave month
        * id
	cd "$cleandata"
	use id rot sex race ethnicty using sipp93l1, clear
	cd "$tempdata"
        count if id==""
        drop if id==""
        sort id rot
        save testi, replace
        
	* id wave
        cd "$cleandata"
	use id rot att_sch* higrade* grd_cmp* geo_ste* using sipp93l1, clear
        cd "$tempdata"
	sort id
        reshape long att_sch higrade grd_cmp geo_ste, i(id) j(wave)
        count if id==""
        drop if id==""
        sort id wave
        save testw, replace
        
	* id month
	cd "$cleandata"
	use id rot age* ms* enrl_m* using sipp93l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix ms_ ms
        renpfix ms0 ms
        renpfix enrl_m0 enrl_m
        count if id==""
        drop if id==""
        sort id
        reshape long age ms enrl_m, i(id) j(mnth)
        
	cd "$programs"
        do monthwave93.do
	cd "$tempdata"
        
        count if id==""
        drop if id==""
        sort id wave month
        save testm, replace
                
        * Core data     
        local i=1
	cd "$cleandata"
	use $ids rot month hmetro hmsa disab using sipp93w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<10 {
        	cd "$cleandata"
		use $ids rot month hmetro hmsa disab using sipp93w`i', clear
                cd "$tempdata"
		sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
        } 
        sort id rot
        save test, replace

        use testi, clear
        merge id rot using test
        tab _merge
        rename _merge mtst
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge miw
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge miwm
        sort id wave month
        
        save test, replace
        
        * Topical module data (append to all observations)
        sort id rot
        save test, replace
        
	cd "$cleandata"
	use id rot tm8732 tm8734 tm8400 tm8408 tm8416 tm8422 tm8430 using sipp93t2, clear
	cd "$tempdata"
        sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm
        
        * give uniform names, as necessary
        rename ethnicty ethnic
        rename att_sch ststat
        rename enrl_m student
        rename geo_ste sipp_st
        rename hmetro metro
        rename hmsa msa
        rename disab disabled
	recode disab 0=-1
	recode ststat 0=-1

        drop if mtst~=3
        drop mtst*
        compress
        save test, replace
        erase testi.dta

        erase testw.dta
        erase testm.dta
end

capture program drop loop92
program define loop92
        local p = $p
        * Longitudinal data: create two files 1) by id wave; 3) by id wave month
        * id
	cd "$cleandata"
	use id rot sex race ethnicty using sipp92l1, clear
        cd "$tempdata"
	sort id rot
        save testi, replace
        
	* id wave
        cd "$cleandata"
	use id rot att_sc* higrad* grd_cm* geo_st* using sipp92l1, clear
        cd "$tempdata"
	renpfix att_sc0 att_sc
        renpfix att_sc att_sch
        renpfix higrad0 higrad
        renpfix higrad higrade
        renpfix grd_cm0 grd_cm
        renpfix grd_cm grd_cmp
        renpfix geo_st0 geo_st
        renpfix geo_st geo_ste
        sort id
        reshape long att_sch higrade grd_cmp geo_ste, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace
        
	* id month
	cd "$cleandata"        
	use id rot age* ms* enrl_m* using sipp92l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix ms_ ms
        renpfix ms0 ms
        renpfix enrl_m0 enrl_m
        sort id
        reshape long age ms enrl_m, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
        do monthwave92.do
	cd "$tempdata"
        
        sort id wave month
        save testm, replace
                
        * Core data     
        local i=1
	cd "$cleandata"
	use $ids rot month hmetro hmsa disab using sipp92w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<10 {
		cd "$cleandata"
		use $ids rot month hmetro hmsa disab using sipp92w`i', clear
		cd "$tempdata"
                sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
        } 
	cd "$tempdata"
        sort id rot
        save test, replace

        use testi, clear
        merge id rot using test
        tab _merge
        rename _merge mtst
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge miw
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge miwm
        sort id wave month
        cd "$tempdata"
        save test, replace
        
        * Topical module data (append to all observations)
        sort id rot
	cd "$tempdata"
        save test, replace
        
	cd "$cleandata"
	use id rot tm8732 tm8734 tm8400 tm8408 tm8416 tm8422 tm8430 using sipp92t2, clear
	cd "$tempdata"
        sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm
        
        * give uniform names, as necessary
        rename ethnicty ethnic
        rename att_sch ststat
        rename enrl_m student
        rename geo_ste sipp_st
        rename hmetro metro
        rename hmsa msa
        rename disab disabled
       	recode disab 0=-1
	recode ststat 0=-1


        drop if mtst~=3
        drop mtst*
        compress
        save test, replace
        erase testi.dta
        erase testw.dta
        erase testm.dta

end

capture program drop loop91
program define loop91
        local p = $p
        * Longitudinal data: create two files 1) by id wave; 3) by id wave month
        * id
	cd "$cleandata"
	use id rot sex race ethnicty using sipp91l1, clear
        cd "$tempdata"
	sort id rot
        save testi, replace
        
	* id wave
        cd "$cleandata"
	use id rot att_sch* higrad* grd_cmp* geo_st* using sipp91l1, clear
	cd "$tempdata"
        sort id
        reshape long att_sch higrade grd_cmp geo_ste, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace
        
	* id month
        cd "$cleandata"
	use id rot age* ms* enrl_m* using sipp91l1, clear
        cd "$tempdata"
	renpfix age_ age
        renpfix age0 age
        renpfix ms_ ms
        renpfix ms0 ms
        renpfix enrl_m0 enrl_m
        sort id
        reshape long age ms enrl_m, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
        do monthwave91.do
	cd "$tempdata"
        
        sort id wave month
        save testm, replace
                
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids rot month hmetro hmsa disab using sipp91w`i', clear
        cd "$tempdata"
	sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<9 {
        	cd "$cleandata"
		use $ids rot month hmetro hmsa disab using sipp91w`i', clear
                cd "$tempdata"
		sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
        } 
        sort id rot
        save test, replace

        use testi, clear
        merge id rot using test
        tab _merge
        rename _merge mtst
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge miw
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge miwm
        sort id wave month
        
        save test, replace
        
        * Topical module data (append to all observations)
        sort id rot
        save test, replace
        
	cd "$cleandata"
        use id rot tm8732 tm8734 tm8400 tm8408 tm8416 tm8422 tm8430 using sipp91t2, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm
        
        * give uniform names, as necessary
        rename ethnicty ethnic
        rename att_sch ststat
        rename enrl_m student
        rename geo_ste sipp_st
        rename hmetro metro
        rename hmsa msa
        rename disab disabled
       	recode disab 0=-1
	recode ststat 0=-1


        drop if mtst~=3
        drop mtst*
        compress
        save test, replace
        erase testi.dta
        erase testw.dta
        erase testm.dta

end

capture program drop loop90
program define loop90
        local p = $p
        * Longitudinal data: create two files 1) by id wave; 3) by id wave month
        * id
	cd "$cleandata"
        use id rot sex race ethnicty using sipp90l1, clear
        cd "$tempdata"
	sort id rot
        save testi, replace
        
	* id wave
        cd "$cleandata"
	use id rot att_sch* higrad* grd_cmp* geo_st* using sipp90l1, clear
	cd "$tempdata"
        sort id
        reshape long att_sch higrade grd_cmp geo_ste, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace
        
	* id month
        cd "$cleandata"
	use id rot age* ms* enrl_m* using sipp90l1, clear
        cd "$tempdata"
	renpfix age_ age
        renpfix age0 age
        renpfix ms_ ms
        renpfix ms0 ms
        renpfix enrl_m0 enrl_m
        sort id
        reshape long age ms enrl_m, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
        do monthwave90.do
	cd "$tempdata"
        
        sort id wave month
        save testm, replace
                
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids rot month hmetro hmsa disab using sipp90w`i', clear
        cd "$tempdata"
	sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<9 {
        	cd "$cleandata"
		use $ids rot month hmetro hmsa disab using sipp90w`i', clear
                cd "$tempdata"
		sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
        } 
        sort id rot
        save test, replace

        use testi, clear
        merge id rot using test
        tab _merge
        rename _merge mtst
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge miw
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge miwm
        sort id wave month
        
        save test, replace
        
        * Topical module data (append to all observations)
        sort id rot
        save test, replace
        
	cd "$cleandata"
        use id rot tm8732 tm8734 tm8400 tm8408 tm8416 tm8422 tm8430 using sipp90t2, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm
        
        * give uniform names, as necessary
        rename ethnicty ethnic
        rename att_sch ststat
        rename enrl_m student
        rename geo_ste sipp_st
        rename hmetro metro
        rename hmsa msa
        rename disab disabled
       	recode disab 0=-1
	recode ststat 0=-1


        drop if mtst~=3
        drop mtst*
        compress
        save test, replace
        erase testi.dta
        erase testw.dta
        erase testm.dta

end

capture program drop loop89
program define loop89
        local p = $p
        * Longitudinal data: create two files 1) by id wave; 3) by id wave month
        * id
	* disab is only available once during the panel, so include here without reshaping
	cd "$cleandata"
        use id rot sex race ethnicty disab using sipp89l1, clear
        cd "$tempdata"
	sort id rot
        save testi, replace
        
	* id wave
        cd "$cleandata"
	use id rot att_sch* higrad* grd_cmp* state_* using sipp89l1, clear
	cd "$tempdata"
        sort id
        reshape long att_sch higrade grd_cmp state_, i(id) j(wave)
	ren state_ geo_ste
        sort id wave
        drop if wave==10
        save testw, replace
        
	* id month
        cd "$cleandata"
	*use id rot age* ms* enrl_m* using sipp89l1, clear
	use id rot age* ms* using sipp89l1, clear
        cd "$tempdata"
	renpfix age_ age
        renpfix age0 age
        renpfix ms_ ms
        renpfix ms0 ms
        sort id
        *reshape long age ms enrl_m, i(id) j(mnth)
        reshape long age ms, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
        do monthwave89.do
	cd "$tempdata"
        
        sort id wave month
        save testm, replace
                
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids rot month h_metro h_msa using sipp89w`i', clear
        cd "$tempdata"
	sort $ids
        save test, replace
	* I think disab is sc1388 or sc1386 or something along those lines, but I'm not sure so I'm removing it
        local i=`i'+1
        while `i'>=2 & `i'<10 {
		capture confirm file "$c`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $c`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
		}
                local i=`i'+1
/*		capture confirm file "$t`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $t`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			local i=`i'+1
		}*/
        } 
        sort id rot
        save test, replace

        use testi, clear
        merge id rot using test
        tab _merge
        rename _merge mtst
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge miw
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge miwm
        sort id wave month
        
        save test, replace
        
        * Topical module data (append to all observations)
        sort id rot
        save test, replace
        
	* Citizenship data
	cd "$cleandata"
	* corresponding topical module names from 90+
        *use id rot tm8732 tm8734 using sipp90t2, clear
        use id rot tm8172 tm8174 using sipp89rt8, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm1
	sort id rot
	save test, replace

	* Education Data
	cd "$cleandata"
	* corresponding topical module names from 90+
        *use id rot tm8900 tm8908 tm8916 tm8922 tm8930 using sipp90t2, clear
        use id rot tm8002 tm8024 tm8022 tm8028 tm8034 using sipp89rt3, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm2
        
        * give uniform names, as necessary
        rename ethnicty ethnic
        rename att_sch ststat
	gen student = .
        *rename enrl_m student
        rename geo_ste sipp_st
        rename h_metro metro
        rename h_msa msa
        rename disab disabled
       	recode disab 0=-1
	recode ststat 0=-1


        drop if mtst~=3
        drop mtst*
        compress
        save test, replace
        erase testi.dta
        erase testw.dta
        erase testm.dta

end

capture program drop loop88
program define loop88
        local p = $p
        * Longitudinal data: create two files 1) by id wave; 3) by id wave month
        * id
	* disab is only available once during the panel, so include here without reshaping
	cd "$cleandata"
        use id rot sex race ethnicty disab using sipp88l1, clear
        cd "$tempdata"
	sort id rot
        save testi, replace
        
	* id wave
        cd "$cleandata"
	use id rot att_sch* higrad* grd_cmp* using sipp88l1, clear
	cd "$tempdata"
        sort id
        reshape long att_sch higrade grd_cmp, i(id) j(wave)
	*ren state_ geo_ste
        sort id wave
        drop if wave==10
        save testw, replace
        
	* id month
        cd "$cleandata"
	*use id rot age* ms* enrl_m* using sipp88l1, clear
	use id rot age* ms* using sipp88l1, clear
        cd "$tempdata"
	renpfix age_ age
        renpfix age0 age
        renpfix ms_ ms
        renpfix ms0 ms
        sort id
        *reshape long age ms enrl_m, i(id) j(mnth)
        reshape long age ms, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
        do monthwave88.do
	cd "$tempdata"
        
        sort id wave month
        save testm, replace
                
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids rot month state h_metro h_msa using sipp88w`i', clear
	ren state geo_ste
        cd "$tempdata"
	sort $ids
        save test, replace
	* I think disab is sc1388 or sc1386 or something along those lines, but I'm not sure so I'm removing it
        local i=`i'+1
        while `i'>=2 & `i'<10 {
		capture confirm file "$c`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month state h_metro h_msa using $c`i', clear
			ren state geo_ste
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
		}
                local i=`i'+1
/*		capture confirm file "$t`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $t`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			local i=`i'+1
		}*/
        } 
        sort id rot
        save test, replace

        use testi, clear
        merge id rot using test
        tab _merge
        rename _merge mtst
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge miw
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge miwm
        sort id wave month
        
        save test, replace
        
        * Topical module data (append to all observations)
        sort id rot
        save test, replace
        /*
	* Citizenship data
	cd "$cleandata"
	* corresponding topical module names from 90+
        *use id rot tm8732 tm8734 using sipp90t2, clear
        use id rot tm8172 tm8174 using sipp88rt8, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm1
	sort id rot
	save test, replace
	*/
	* Education Data
	cd "$cleandata"
	* corresponding topical module names from 90+
        *use id rot tm8800 tm8808 tm8816 tm8822 tm8830 using sipp90t2, clear
	use id rot tm8732 tm8734 tm8400 tm8408 tm8416 tm8422 tm8430 using sipp88rt2, clear
        *use id rot tm8002 tm8024 tm8022 tm8028 tm8034 using sipp88rt3, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm1
        
        * give uniform names, as necessary
        rename ethnicty ethnic
        rename att_sch ststat
	gen student = .
        *rename enrl_m student
        rename geo_ste sipp_st
        rename h_metro metro
        rename h_msa msa
        rename disab disabled
       	recode disab 0=-1
	recode ststat 0=-1


        drop if mtst~=3
        drop mtst*
        compress
        save test, replace
        erase testi.dta
        erase testw.dta
        erase testm.dta

end

capture program drop loop87
program define loop87
        local p = $p
        * Longitudinal data: create two files 1) by id wave; 3) by id wave month
        * id
	* disab is only available once during the panel, so include here without reshaping
	cd "$cleandata"
        use id rot sex race ethnicty disab using sipp87l1, clear
        cd "$tempdata"
	sort id rot
        save testi, replace
        
	* id wave
        cd "$cleandata"
	use id rot att_sch* higrad* grd_cmp* state_* using sipp87l1, clear
	cd "$tempdata"
        sort id
        reshape long att_sch higrade grd_cmp state_, i(id) j(wave)
	ren state_ geo_ste
        sort id wave
        drop if wave==10
        save testw, replace
        
	* id month
        cd "$cleandata"
	*use id rot age* ms* enrl_m* using sipp87l1, clear
	use id rot age* ms* using sipp87l1, clear
        cd "$tempdata"
	renpfix age_ age
        renpfix age0 age
        renpfix ms_ ms
        renpfix ms0 ms
        sort id
        *reshape long age ms enrl_m, i(id) j(mnth)
        reshape long age ms, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
        do monthwave87.do
	cd "$tempdata"
        
        sort id wave month
        save testm, replace
                
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids rot month h_metro h_msa using sipp87w`i', clear
        cd "$tempdata"
	sort $ids
        save test, replace
	* I think disab is sc1388 or sc1386 or something along those lines, but I'm not sure so I'm removing it
        local i=`i'+1
        while `i'>=2 & `i'<10 {
		capture confirm file "$c`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $c`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
		}
                local i=`i'+1
/*		capture confirm file "$t`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $t`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			local i=`i'+1
		}*/
        } 
        sort id rot
        save test, replace

        use testi, clear
        merge id rot using test
        tab _merge
        rename _merge mtst
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge miw
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge miwm
        sort id wave month
        
        save test, replace
        
        * Topical module data (append to all observations)
        sort id rot
        save test, replace

/*
	* Citizenship data
	cd "$cleandata"
	* corresponding topical module names from 90+
        *use id rot tm8732 tm8734 using sipp90t2, clear
        use id rot tm8172 tm8174 using sipp87rt8, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm1
	sort id rot
	save test, replace
*/

	* Education Data
	cd "$cleandata"
	* corresponding topical module names from 90+
        use id rot tm8732 tm8734 tm8400 tm8408 tm8416 tm8422 tm8430 using sipp87rt2, clear
        *use id rot tm8700 tm8708 tm8716 tm8722 tm8730 using sipp90t2, clear
        *use id rot tm8002 tm8024 tm8022 tm8028 tm8034 using sipp87rt3, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm2
        
        * give uniform names, as necessary
        rename ethnicty ethnic
        rename att_sch ststat
	gen student = .
        *rename enrl_m student
        rename geo_ste sipp_st
        rename h_metro metro
        rename h_msa msa
        rename disab disabled
       	recode disab 0=-1
	recode ststat 0=-1


        drop if mtst~=3
        drop mtst*
        compress
        save test, replace
        erase testi.dta
        erase testw.dta
        erase testm.dta

end

capture program drop loop86
program define loop86
        local p = $p
        * Longitudinal data: create two files 1) by id wave; 3) by id wave month
        * id
	* disab is only available once during the panel, so include here without reshaping
	cd "$cleandata"
        use id rot sex race ethnicty disab using sipp86l1, clear
        cd "$tempdata"
	sort id rot
        save testi, replace
        
	* id wave
        cd "$cleandata"
	use id rot att_sch* higrad* grd_cmp* state_* using sipp86l1, clear
	cd "$tempdata"
        sort id
        reshape long att_sch higrade grd_cmp state_, i(id) j(wave)
	ren state_ geo_ste
        sort id wave
        drop if wave==10
        save testw, replace
        
	* id month
        cd "$cleandata"
	*use id rot age* ms* enrl_m* using sipp86l1, clear
	use id rot age* ms* using sipp86l1, clear
        cd "$tempdata"
	renpfix age_ age
        renpfix age0 age
        renpfix ms_ ms
        renpfix ms0 ms
        sort id
        *reshape long age ms enrl_m, i(id) j(mnth)
        reshape long age ms, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
        do monthwave86.do
	cd "$tempdata"
        
        sort id wave month
        save testm, replace
                
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids rot month h_metro h_msa using sipp86w`i', clear
        cd "$tempdata"
	sort $ids
        save test, replace
	* I think disab is sc1388 or sc1386 or something along those lines, but I'm not sure so I'm removing it
        local i=`i'+1
        while `i'>=2 & `i'<10 {
		capture confirm file "$c`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $c`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
		}
		local i=`i'+1
/*		capture confirm file "$t`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $t`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			local i=`i'+1
		}*/
        } 
        sort id rot
        save test, replace

        use testi, clear
        merge id rot using test
        tab _merge
        rename _merge mtst
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge miw
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge miwm
        sort id wave month
        
        save test, replace
        
        * Topical module data (append to all observations)
        sort id rot
        save test, replace
        
	* Citizenship data
	/*
	cd "$cleandata"
	* corresponding topical module names from 90+
        use id rot tm8732 tm8734 using sipp86rt2, clear
        *use id rot tm8172 tm8174 using sipp86rt5, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm1
	sort id rot
	save test, replace
	*/

	* Education Data
	cd "$cleandata"
	* corresponding topical module names from 90+
        use id rot tm8732 tm8734 tm8400 tm8408 tm8416 tm8422 tm8430 using sipp86rt2, clear
        *use id rot tm8600 tm8608 tm8616 tm8622 tm8630 using sipp86rt2, clear
        *use id rot tm8002 tm8024 tm8022 tm8028 tm8034 using sipp86rt2, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm2
        
        * give uniform names, as necessary
        rename ethnicty ethnic
        rename att_sch ststat
	gen student = .
        *rename enrl_m student
        rename geo_ste sipp_st
        rename h_metro metro
        rename h_msa msa
        rename disab disabled
       	recode disab 0=-1
	recode ststat 0=-1


        drop if mtst~=3
        drop mtst*
        compress
        save test, replace
        erase testi.dta
        erase testw.dta
        erase testm.dta

end

capture program drop loop85
program define loop85
        local p = $p
        * Longitudinal data: create two files 1) by id wave; 3) by id wave month
        * id
	* disab is only available once during the panel, so include here without reshaping
	cd "$cleandata"
        use id rot sex race ethnicty disab using sipp85l1, clear
        cd "$tempdata"
	sort id rot
        save testi, replace
        
	* id wave
        cd "$cleandata"
	use id rot att_sch* higrad* grd_cmp* state_* using sipp85l1, clear
	cd "$tempdata"
        sort id
        reshape long att_sch higrade grd_cmp state_, i(id) j(wave)
	ren state_ geo_ste
        sort id wave
        drop if wave==10
        save testw, replace
        
	* id month
        cd "$cleandata"
	*use id rot age* ms* enrl_m* using sipp85l1, clear
	use id rot age* ms* using sipp85l1, clear
        cd "$tempdata"
	renpfix age_ age
        renpfix age0 age
        renpfix ms_ ms
        renpfix ms0 ms
        sort id
        *reshape long age ms enrl_m, i(id) j(mnth)
        reshape long age ms, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
        do monthwave85.do
	cd "$tempdata"
        
        sort id wave month
        save testm, replace
                
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids rot month h_metro h_msa using sipp85w`i', clear
        cd "$tempdata"
	sort $ids
        save test, replace
	* I think disab is sc1388 or sc1386 or something along those lines, but I'm not sure so I'm removing it
        local i=`i'+1
        while `i'>=2 & `i'<10 {
		capture confirm file "$c`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $c`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
		}
		local i=`i'+1
/*		capture confirm file "$t`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $t`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			local i=`i'+1
		}*/
        } 
        sort id rot
        save test, replace

        use testi, clear
        merge id rot using test
        tab _merge
        rename _merge mtst
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge miw
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge miwm
        sort id wave month
        
        save test, replace
        
        * Topical module data (append to all observations)
        sort id rot
        save test, replace
        
	* Citizenship data
	cd "$cleandata"
	* corresponding topical module names from 90+
        *use id rot tm8732 tm8734 using sipp90t2, clear
        use id rot tm8172 tm8174 using sipp85rt4, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm1
	sort id rot
	save test, replace

	* Education Data
	cd "$cleandata"
	* corresponding topical module names from 90+
        *use id rot tm8500 tm8508 tm8516 tm8522 tm8530 using sipp90t2, clear
        use id rot tm8002 tm8024 tm8022 tm8028 tm8034 using sipp85w6, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm2
        
        * give uniform names, as necessary
        rename ethnicty ethnic
        rename att_sch ststat
	gen student = .
        *rename enrl_m student
        rename geo_ste sipp_st
        rename h_metro metro
        rename h_msa msa
        rename disab disabled
       	recode disab 0=-1
	recode ststat 0=-1


        drop if mtst~=3
        drop mtst*
        compress
        save test, replace
        erase testi.dta
        erase testw.dta
        erase testm.dta

end


capture program drop loop84
program define loop84
        local p = $p
        * Longitudinal data: create two files 1) by id wave; 3) by id wave month
        * id
	* disab is only available once during the panel, so include here without reshaping
	cd "$cleandata"
        use id rot sex race ethnicty disab using sipp84l1, clear
        cd "$tempdata"
	sort id rot
        save testi, replace
        
	* id wave
        cd "$cleandata"
	use id rot att_sch* higrad* grd_cmp* state_* using sipp84l1, clear
	cd "$tempdata"
        sort id
        reshape long att_sch higrade grd_cmp state_, i(id) j(wave)
	ren state_ geo_ste
        sort id wave
        drop if wave==10
        save testw, replace
        
	* id month
        cd "$cleandata"
	*use id rot age* ms* enrl_m* using sipp84l1, clear
	use id rot age* ms* using sipp84l1, clear
        cd "$tempdata"
	renpfix age_ age
        renpfix age0 age
        renpfix ms_ ms
        renpfix ms0 ms
        sort id
        *reshape long age ms enrl_m, i(id) j(mnth)
        reshape long age ms, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
        do monthwave84.do
	cd "$tempdata"
        
        sort id wave month
        save testm, replace
                
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids rot month h_metro h_msa using sipp84w`i', clear
        cd "$tempdata"
	sort $ids
        save test, replace
	* I think disab is sc1388 or sc1386 or something along those lines, but I'm not sure so I'm removing it
        local i=`i'+1
        while `i'>=2 & `i'<10 {
		capture confirm file "$c`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $c`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			local i=`i'+1
		}
/*		capture confirm file "$t`i'.dta"
		if !_rc {
			cd "$cleandata"
			use $ids rot month h_metro h_msa using $t`i', clear
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			local i=`i'+1
		}*/
        } 
        sort id rot
        save test, replace

        use testi, clear
        merge id rot using test
        tab _merge
        rename _merge mtst
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge miw
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge miwm
        sort id wave month
        
        save test, replace
        
        * Topical module data (append to all observations)
        sort id rot
        save test, replace
        
	* Citizenship data
	cd "$cleandata"
	* corresponding topical module names from 90+
        *use id rot tm8732 tm8734 using sipp90t2, clear
        use id rot tm8172 tm8174 using sipp84rt8, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm1
	sort id rot
	save test, replace

	* Education Data
	cd "$cleandata"
	* corresponding topical module names from 90+
        *use id rot tm8400 tm8408 tm8416 tm8422 tm8430 using sipp90t2, clear
        use id rot tm8002 tm8024 tm8022 tm8028 tm8034 using sipp84rt3, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm2
        
        * give uniform names, as necessary
        rename ethnicty ethnic
        rename att_sch ststat
	gen student = .
        *rename enrl_m student
        rename geo_ste sipp_st
        rename h_metro metro
        rename h_msa msa
        rename disab disabled
       	recode disab 0=-1
	recode ststat 0=-1


        drop if mtst~=3
        drop mtst*
        compress
        save test, replace
        erase testi.dta
        erase testw.dta
        erase testm.dta

end


loop$p
compress
