
/* Please do not attempt to run this program without reading the accompanying documentation*/

version 8.0
set more off
prog drop _all
capture log close
clear

cd "$log"
log using set_c$p.log, replace

/*
File: pull c (hhfam).do
Date: July, 2005
Desc: Pull-file to creat Set C
Note: See acknowledgements and copyright notice in new_master.do.
*/

/*

This program is to be run embedded within new_master.do.

The programs below pull the variables necessary for Set A from the 
SIPP Longitudinal, Core, and Topical Modules and merge them into 
one dataset that is by person-month.

Note that we delete any individual who appears in a Core or Topical 
Module file, but who is not on the Longitudinal file, as recommended by 
U.S. Census Bureau staff.
	
For the 1990-1993 panels, in order to reshape the Longitudinal 
files by person-month, we need to do three separate steps. 
(1) Pull all Longitudinal vars that appear once per panel and 
create a dataset that is by <id>.
(2) Pull all Longitudinal vars that appear once per wave and 
create a dataset that is by <id wave>.
(3) Pull all Longitudinal vars that appear once per month and 
create a dataset that is by <id mnth>. Generate calendar month
and wave from the month counter in this file. (The variable 
<mnth> goes from 1 to 36 in the 1993 panel and thus must be
converted into calendar months for merging.)
Then, we merge the three files together into one person-month 
file, along with variables from the Core and Topical Module
files.

Note that there is an error in the 1993 panel whereby 
there are individuals in the longitudinal file that show up 
without data. These are deleted. 

*/

cd "$tempdata"
* need to pull from each wave and merge

capture program drop loop08
program define loop08

	global cvarlist "$ids esex ssuid eentaid epnmom epndad epnguard tage shhadid rfid rfid2 rsid ehhnumpp efnp esfnp rfoklt18 rfnkids epppnum epnspous"

	forvalues i=1/8 {
		if `i' == 1 {
			use $cvarlist using $c`i', clear
		}
		if `i' > 1 {
			append using $c`i', keep($cvarlist)
		}
	}

	rename tage age
	cd "$tempdata"
	save test, replace
end



capture program drop loop04
program define loop04

	global cvarlist "$ids esex ssuid eentaid epnmom epndad epnguard tage shhadid rfid rfid2 rsid ehhnumpp efnp esfnp rfoklt18 rfnkids epppnum epnspous"

	forvalues i=1/12 {
		if `i' == 1 {
			use $cvarlist using $c`i', clear
		}
		if `i' > 1 {
			append using $c`i', keep($cvarlist)
		}
	}

	rename tage age
	cd "$tempdata"
	save test, replace
end

capture program drop loop01
program define loop01
        local i=1
        use $ids esex ssuid eentaid epnmom epndad epnguard tage shhadid /*
*/ 	rfid rfid2 rsid ehhnumpp efnp esfnp rfoklt18 rfnkids epppnum /*
*/	epnspous using $c`i', clear
        sort $ids
        save test, replace
        local i = `i'+1
        while `i'>1 & `i'<10 {
                use $ids esex ssuid eentaid epnmom epndad epnguard tage /*
*/		shhadid rfid rfid2 rsid ehhnumpp efnp esfnp rfoklt18 /*
*/		rfnkids epppnum epnspous using $c`i', clear
                sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
        } 
rename tage age
save test, replace
end

capture program drop loop96
program define loop96

* Need to run on computer with large memory capacity.
set mem 2g 
        local i=1
        use $ids esex ssuid eentaid epnmom epndad epnguard tage /*
*/	shhadid rfid rfid2 rsid ehhnumpp efnp esfnp rfoklt18 rfnkids /*
*/	epppnum epnspous using $f`i', clear
        sort $ids
        save test, replace
        local i = `i'+1
        while `i'>1 & `i'<13 {
                use $ids esex ssuid eentaid epnmom epndad epnguard tage /*
*/		shhadid rfid rfid2 rsid ehhnumpp efnp esfnp rfoklt18 /*
*/		rfnkids epppnum epnspous using $f`i', clear
                sort $ids
                append using test
                sort $ids
                
                save test, replace
                local i=`i'+1
	} 
rename tage age
save test, replace
end

capture program drop loop93
program define loop93
        
        *Longitudinal data
        *id
	cd "$cleandata"
        use id sex pp_id pp_entry using sipp93l1, clear
        cd "$tempdata"
	count if id==""
        drop if id==""
        sort id
        save testi, replace
     
     	*id wave
	cd "$cleandata"
	use id u_pngd* entid_g* using sipp93l1, clear
	cd "$tempdata"
	sort id 
	reshape long u_pngd entid_g, i(id) j(wave)
	count if id==""
        drop if id==""
	
	sort id wave
	drop if wave==10
	save testw, replace

	*id month
	cd "$cleandata"
	use $idr age* hh_add* famnum* pnpt* pnsp* ent_pt* using sipp93l1, clear
	cd "$tempdata"
	renpfix age_ age
	renpfix age0 age
	renpfix hh_add0 hh_add
	renpfix famnum0 famnum
	renpfix pnpt_ pnpt
	renpfix pnpt0 pnpt
	renpfix pnsp_ pnsp
	renpfix pnsp0 pnsp
	renpfix ent_pt0 ent_pt
        count if id==""
        drop if id==""
	sort id
	reshape long age hh_add famnum pnpt pnsp ent_pt, i(id) j(mnth)
	drop if mnth>=37 & mnth<=40
	
	cd "$programs"
	do monthwave93.do
	cd "$tempdata"
	
	sort id wave month
	save testm, replace


        *Core data
        local i=1
        use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
        sort $ids
        save test, replace
        local i=`i' +1
        while `i'>=2 & `i'<10 {
                use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
                sort $ids
                append using test
                sort $ids
                save test, replace
                tab wave
                local i=`i'+1
        }       

        use testi, clear
        merge id using test
        tab _merge
        rename _merge mtst1
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge mtst2
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge mtst3

        rename sex esex
        rename pp_id ssuid
        rename pp_entry eentaid
        rename hh_add shhadid
        rename famnum rsid
        rename fid rfid
        rename fid2 rfid2
        rename hnp ehhnumpp
        rename fnp efnp
        rename snp esfnp
        rename foklt18 rfoklt18
        rename fnkids rfnkids
	rename pnsp epnspous

        drop if mtst3~=3
        drop mtst*

        save test, replace
        tab wave
        erase testi.dta
        erase testw.dta
        erase testm.dta
end

capture program drop loop92
program define loop92
        
        *Longitudinal data: create 3 files 1)by id; 2) by id wave; 3) by id wave month
        *id
	cd "$cleandata"
        use id sex pp_id pp_entry using sipp92l1, clear 
	cd "$tempdata"

        sort id
        save testi, replace

        *id wave
	cd "$cleandata"
        use id u_pngd* ent_gd* using sipp92l1, clear
	cd "$tempdata"
        renpfix u_pngd0 u_pngd
        renpfix ent_gd entid_g
	renpfix entid_g0 entid_g
	
        sort id 
        reshape long u_pngd entid_g, i(id) j(wave)

        sort id wave
        drop if wave==10
        save testw, replace

        *id month
	cd "$cleandata"
        use $idr age* hh_add* famnum* pnpt* pnsp* ent_pt* using sipp92l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix hh_add0 hh_add
        renpfix famnum0 famnum
        renpfix pnpt_ pnpt
        renpfix pnpt0 pnpt
        renpfix pnsp_ pnsp
        renpfix pnsp0 pnsp
        renpfix ent_pt0 ent_pt
	
	sort id
        reshape long age hh_add famnum pnpt pnsp ent_pt, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40

	cd "$programs"
        do monthwave92.do
	cd "$tempdata"
	
        sort id wave month
        save testm, replace

        *Core data
        local i=1
        use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
        sort $ids 
        save test, replace
        local i= `i'+1
        while `i'>=2 & `i'<10 {
                use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear 
                sort $ids
                append using test
                sort $ids
                save test, replace
                tab wave
                local i=`i'+1
        	}
        use testi, clear
        merge id using test
        tab _merge
        rename _merge mtst1
        sort id wave

        merge id wave using testw
        tab _merge
        rename _merge mtst2
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge mtst3

        rename sex esex
        rename pp_id ssuid
        rename pp_entry eentaid
        rename hh_add shhadid
        rename famnum rsid
        rename fid rfid
        rename fid2 rfid2
        rename hnp ehhnumpp
        rename fnp efnp
        rename snp esfnp
        rename foklt18 rfoklt18
        rename fnkids rfnkids
        rename pnsp epnspous

        drop if mtst3~=3
   	drop mtst*

        save test, replace
        tab wave

        erase testi.dta
        erase testw.dta
        erase testm.dta
end     

capture program drop loop91
program define loop91
        
        *Longitudinal data: create 3 files 1)by id; 2) by id wave; 3) by id wave month
        *id
	cd "$cleandata"
        use id sex pp_id pp_entry using sipp91l1, clear 
        cd "$tempdata"
	sort id
        save testi, replace

        *id wave
        cd "$cleandata"
	use id u_pngd* entid_g* using sipp91l1, clear
        cd "$tempdata"
	sort id 
        reshape long u_pngd entid_g, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace


        *id month
        cd "$cleandata"
	use $idr pnpt* age* hh_add* famnum* pnsp* ent_pt* using sipp91l1, clear
        cd "$tempdata"
	renpfix hh_add0 hh_add
        renpfix famnum0 famnum
        renpfix pnpt_ pnpt
        renpfix pnpt0 pnpt
        renpfix age_ age
        renpfix age0 age
        renpfix pnsp_ pnsp
        renpfix pnsp0 pnsp
        renpfix ent_pt0 ent_pt
        
	sort id
        reshape long pnpt age hh_add famnum pnsp ent_pt, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40

	cd "$programs"
        do monthwave91.do
	cd "$tempdata"	
	
        sort id wave month
        save testm, replace

        *Core data
        local i=1
        use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
        sort $ids 
        save test, replace
        local i= `i'+1
        while `i'>=2 & `i'<9 {
                use $ids rot pnum month fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear 
                sort $ids
                append using test
                sort $ids
                save test, replace
                tab wave
                local i=`i'+1
        	}
        use testi, clear
        merge id using test
        tab _merge
        rename _merge mtst1
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge mtst2
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge mtst3

        rename sex esex
        rename pp_id ssuid
        rename pp_entry eentaid
        rename hh_add shhadid
        rename famnum rsid
        rename fid rfid
        rename fid2 rfid2
        rename hnp ehhnumpp
        rename fnp efnp
        rename snp esfnp
        rename foklt18 rfoklt18
        rename fnkids rfnkids
	rename pnsp epnspous

        drop if mtst3~=3
   	drop mtst*

        save test, replace
        tab wave

      	erase testi.dta
        erase testw.dta
        erase testm.dta
end    

capture program drop loop90
program define loop90
        
        *Longitudinal data: create 3 files 1)by id; 2) by id wave; 3) by id wave month
        *id
	cd "$cleandata"
        use id sex pp_id pp_entry using sipp90l1, clear 
        cd "$tempdata"
	sort id
        save testi, replace

        *id wave
        cd "$cleandata"
	use id u_pngd* using sipp90l1, clear
        cd "$tempdata"
	*renpfix u_pngd0 u_pngd
        sort id 
        reshape long u_pngd, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace

        *id month
	cd "$cleandata"
        use $idr pnpt* age* hh_add* famnum* pnsp* ent_pt* using sipp90l1, clear
        cd "$tempdata"
	renpfix hh_add0 hh_add
        renpfix famnum0 famnum
        renpfix pnpt_ pnpt
        renpfix pnpt0 pnpt
        renpfix age_ age
        renpfix age0 age
        renpfix pnsp_ pnsp
        renpfix pnsp0 pnsp
      	renpfix ent_pt0 ent_pt
	sort id
        reshape long pnpt age hh_add famnum pnsp ent_pt, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
	do monthwave92.do
        cd "$tempdata"
	
	sort id wave month
        save testm, replace

        *Core data
        local i=1
        use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
        sort $ids 
        save test, replace
        local i= `i'+1
        while `i'>=2 & `i'<9 {
                use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear 
                sort $ids
                append using test
                sort $ids
                save test, replace
                tab wave
                local i=`i'+1
        	}
        use testi, clear
        merge id using test
        tab _merge
        rename _merge mtst1
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge mtst2
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge mtst3

        rename sex esex
        rename pp_id ssuid
        rename pp_entry eentaid
        rename hh_add shhadid
        rename famnum rsid
        rename fid rfid
        rename fid2 rfid2
        rename hnp ehhnumpp
        rename fnp efnp
        rename snp esfnp
        rename foklt18 rfoklt18
        rename fnkids rfnkids
	rename pnsp epnspous

        drop if mtst3~=3
   	drop mtst*

        save test, replace
        tab wave

        erase testi.dta
        erase testw.dta
        erase testm.dta
end

capture program drop loop89
program define loop89
        
        *Longitudinal data: create 3 files 1)by id; 2) by id wave; 3) by id wave month
        *id
	cd "$cleandata"
        use id sex pp_id pp_entry using sipp89l1, clear 
        cd "$tempdata"
	sort id
        save testi, replace

        *id wave
        cd "$cleandata"
	use id u_pngd* using sipp89l1, clear
        cd "$tempdata"
	*renpfix u_pngd0 u_pngd
        sort id 
        reshape long u_pngd, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace

        *id month
	cd "$cleandata"
        use $idr pnpt* age* hh_add* famnum* pnsp* ent_pt* using sipp89l1, clear
        cd "$tempdata"
	renpfix hh_add0 hh_add
        renpfix famnum0 famnum
        renpfix pnpt_ pnpt
        renpfix pnpt0 pnpt
        renpfix age_ age
        renpfix age0 age
        renpfix pnsp_ pnsp
        renpfix pnsp0 pnsp
      	renpfix ent_pt0 ent_pt
	sort id
        reshape long pnpt age hh_add famnum pnsp ent_pt, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
	do monthwave89.do
        cd "$tempdata"
	
	sort id wave month
        save testm, replace

        *Core data
        local i=1
        *use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
        use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear
        sort $ids 
        save test, replace
        local i= `i'+1
        while `i'>=2 & `i'<10 {
                use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear 
                sort $ids
                append using test
                sort $ids
                save test, replace
                tab wave
                local i=`i'+1
        	}
        use testi, clear
        merge id using test
        tab _merge
        rename _merge mtst1
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge mtst2
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge mtst3

        rename sex esex
        rename pp_id ssuid
        rename pp_entry eentaid
        rename hh_add shhadid
        rename famnum rsid
        rename f_numbr rfid
	gen rfid2 = .
        *rename fid2 rfid2
        rename h_size ehhnumpp
        rename fnumper efnp
        rename snumper esfnp
        rename foklt18 rfoklt18
        rename fownkid rfnkids
	rename pnsp epnspous

        drop if mtst3~=3
   	drop mtst*

        save test, replace
        tab wave

        erase testi.dta
        erase testw.dta
        erase testm.dta
end

capture program drop loop88
program define loop88
        
        *Longitudinal data: create 3 files 1)by id; 2) by id wave; 3) by id wave month
        *id
	cd "$cleandata"
        use id sex pp_id pp_entry using sipp88l1, clear 
        cd "$tempdata"
	sort id
        save testi, replace

        *id wave
        cd "$cleandata"
	use id u_pngd* using sipp88l1, clear
        cd "$tempdata"
	*renpfix u_pngd0 u_pngd
        sort id 
        reshape long u_pngd, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace

        *id month
	cd "$cleandata"
        use $idr pnpt* age* hh_add* famnum* pnsp* ent_pt* using sipp88l1, clear
        cd "$tempdata"
	renpfix hh_add0 hh_add
        renpfix famnum0 famnum
        renpfix pnpt_ pnpt
        renpfix pnpt0 pnpt
        renpfix age_ age
        renpfix age0 age
        renpfix pnsp_ pnsp
        renpfix pnsp0 pnsp
      	renpfix ent_pt0 ent_pt
	sort id
        reshape long pnpt age hh_add famnum pnsp ent_pt, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
	do monthwave88.do
        cd "$tempdata"
	
	sort id wave month
        save testm, replace

        *Core data
        local i=1
        *use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
        use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear
        sort $ids 
        save test, replace
        local i= `i'+1
        while `i'>=2 & `i'<10 {
		capture confirm file "$c`i'.dta"
		if !_rc {
			use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear 
			sort $ids
			append using test
			sort $ids
			save test, replace
			tab wave
			}
                local i=`i'+1
        	}
        use testi, clear
        merge id using test
        tab _merge
        rename _merge mtst1
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge mtst2
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge mtst3

        rename sex esex
        rename pp_id ssuid
        rename pp_entry eentaid
        rename hh_add shhadid
        rename famnum rsid
        rename f_numbr rfid
	gen rfid2 = .
        *rename fid2 rfid2
        rename h_size ehhnumpp
        rename fnumper efnp
        rename snumper esfnp
        rename foklt18 rfoklt18
        rename fownkid rfnkids
	rename pnsp epnspous

        drop if mtst3~=3
   	drop mtst*

        save test, replace
        tab wave

        erase testi.dta
        erase testw.dta
        erase testm.dta
end

capture program drop loop87
program define loop87
        
        *Longitudinal data: create 3 files 1)by id; 2) by id wave; 3) by id wave month
        *id
	cd "$cleandata"
        use id sex pp_id pp_entry using sipp87l1, clear 
        cd "$tempdata"
	sort id
        save testi, replace

        *id wave
        cd "$cleandata"
	use id u_pngd* using sipp87l1, clear
        cd "$tempdata"
	*renpfix u_pngd0 u_pngd
        sort id 
        reshape long u_pngd, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace

        *id month
	cd "$cleandata"
        use $idr pnpt* age* hh_add* famnum* pnsp* ent_pt* using sipp87l1, clear
        cd "$tempdata"
	renpfix hh_add0 hh_add
        renpfix famnum0 famnum
        renpfix pnpt_ pnpt
        renpfix pnpt0 pnpt
        renpfix age_ age
        renpfix age0 age
        renpfix pnsp_ pnsp
        renpfix pnsp0 pnsp
      	renpfix ent_pt0 ent_pt
	sort id
        reshape long pnpt age hh_add famnum pnsp ent_pt, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
	do monthwave87.do
        cd "$tempdata"
	
	sort id wave month
        save testm, replace

        *Core data
        local i=1
        *use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
        use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear
        sort $ids 
        save test, replace
        local i= `i'+1
        while `i'>=2 & `i'<10 {
		capture confirm file "$c`i'.dta"
		if !_rc {
			use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear 
			sort $ids
			append using test
			sort $ids
			save test, replace
			tab wave
			}
                local i=`i'+1
        	}
        use testi, clear
        merge id using test
        tab _merge
        rename _merge mtst1
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge mtst2
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge mtst3

        rename sex esex
        rename pp_id ssuid
        rename pp_entry eentaid
        rename hh_add shhadid
        rename famnum rsid
        rename f_numbr rfid
	gen rfid2 = .
        *rename fid2 rfid2
        rename h_size ehhnumpp
        rename fnumper efnp
        rename snumper esfnp
        rename foklt18 rfoklt18
        rename fownkid rfnkids
	rename pnsp epnspous

        drop if mtst3~=3
   	drop mtst*

        save test, replace
        tab wave

        erase testi.dta
        erase testw.dta
        erase testm.dta
end

capture program drop loop86
program define loop86
        
        *Longitudinal data: create 3 files 1)by id; 2) by id wave; 3) by id wave month
        *id
	cd "$cleandata"
        use id sex pp_id pp_entry using sipp86l1, clear 
        cd "$tempdata"
	sort id
        save testi, replace

        *id wave
        cd "$cleandata"
	use id u_pngd* using sipp86l1, clear
        cd "$tempdata"
	*renpfix u_pngd0 u_pngd
        sort id 
        reshape long u_pngd, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace

        *id month
	cd "$cleandata"
        use $idr pnpt* age* hh_add* famnum* pnsp* ent_pt* using sipp86l1, clear
        cd "$tempdata"
	renpfix hh_add0 hh_add
        renpfix famnum0 famnum
        renpfix pnpt_ pnpt
        renpfix pnpt0 pnpt
        renpfix age_ age
        renpfix age0 age
        renpfix pnsp_ pnsp
        renpfix pnsp0 pnsp
      	renpfix ent_pt0 ent_pt
	sort id
        reshape long pnpt age hh_add famnum pnsp ent_pt, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
	do monthwave86.do
        cd "$tempdata"
	
	sort id wave month
        save testm, replace

        *Core data
        local i=1
        *use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
        use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear
        sort $ids 
        save test, replace
        local i= `i'+1
        while `i'>=2 & `i'<10 {
		capture confirm file "$c`i'.dta"
		if !_rc {
			use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear 
			sort $ids
			append using test
			sort $ids
			save test, replace
			tab wave
			}
                local i=`i'+1
        	}
        use testi, clear
        merge id using test
        tab _merge
        rename _merge mtst1
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge mtst2
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge mtst3

        rename sex esex
        rename pp_id ssuid
        rename pp_entry eentaid
        rename hh_add shhadid
        rename famnum rsid
        rename f_numbr rfid
	gen rfid2 = .
        *rename fid2 rfid2
        rename h_size ehhnumpp
        rename fnumper efnp
        rename snumper esfnp
        rename foklt18 rfoklt18
        rename fownkid rfnkids
	rename pnsp epnspous

        drop if mtst3~=3
   	drop mtst*

        save test, replace
        tab wave

        erase testi.dta
        erase testw.dta
        erase testm.dta
end

capture program drop loop85
program define loop85
        
        *Longitudinal data: create 3 files 1)by id; 2) by id wave; 3) by id wave month
        *id
	cd "$cleandata"
        use id sex pp_id pp_entry using sipp85l1, clear 
        cd "$tempdata"
	sort id
        save testi, replace

        *id wave
        cd "$cleandata"
	use id u_pngd* using sipp85l1, clear
        cd "$tempdata"
	*renpfix u_pngd0 u_pngd
        sort id 
        reshape long u_pngd, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace

        *id month
	cd "$cleandata"
        use $idr pnpt* age* hh_add* famnum* pnsp* ent_pt* using sipp85l1, clear
        cd "$tempdata"
	renpfix hh_add0 hh_add
        renpfix famnum0 famnum
        renpfix pnpt_ pnpt
        renpfix pnpt0 pnpt
        renpfix age_ age
        renpfix age0 age
        renpfix pnsp_ pnsp
        renpfix pnsp0 pnsp
      	renpfix ent_pt0 ent_pt
	sort id
        reshape long pnpt age hh_add famnum pnsp ent_pt, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
	do monthwave85.do
        cd "$tempdata"
	
	sort id wave month
        save testm, replace

        *Core data
        local i=1
        *use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
        use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear
        sort $ids 
        save test, replace
        local i= `i'+1
        while `i'>=2 & `i'<10 {
		capture confirm file "$c`i'.dta"
		if !_rc {
			use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear 
			sort $ids
			append using test
			sort $ids
			save test, replace
			tab wave
			}
		local i=`i'+1
        	}
        use testi, clear
        merge id using test
        tab _merge
        rename _merge mtst1
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge mtst2
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge mtst3

        rename sex esex
        rename pp_id ssuid
        rename pp_entry eentaid
        rename hh_add shhadid
        rename famnum rsid
        rename f_numbr rfid
	gen rfid2 = .
        *rename fid2 rfid2
        rename h_size ehhnumpp
        rename fnumper efnp
        rename snumper esfnp
        rename foklt18 rfoklt18
        rename fownkid rfnkids
	rename pnsp epnspous

        drop if mtst3~=3
   	drop mtst*

        save test, replace
        tab wave

        erase testi.dta
        erase testw.dta
        erase testm.dta
end

capture program drop loop84
program define loop84
        
        *Longitudinal data: create 3 files 1)by id; 2) by id wave; 3) by id wave month
        *id
	cd "$cleandata"
        use id sex pp_id pp_entry using sipp84l1, clear 
        cd "$tempdata"
	sort id
        save testi, replace

        *id wave
        cd "$cleandata"
	use id u_pngd* using sipp84l1, clear
        cd "$tempdata"
	*renpfix u_pngd0 u_pngd
        sort id 
        reshape long u_pngd, i(id) j(wave)
        sort id wave
        drop if wave==10
        save testw, replace

        *id month
	cd "$cleandata"
        use $idr pnpt* age* hh_add* famnum* pnsp* ent_pt* using sipp84l1, clear
        cd "$tempdata"
	renpfix hh_add0 hh_add
        renpfix famnum0 famnum
        renpfix pnpt_ pnpt
        renpfix pnpt0 pnpt
        renpfix age_ age
        renpfix age0 age
        renpfix pnsp_ pnsp
        renpfix pnsp0 pnsp
      	renpfix ent_pt0 ent_pt
	sort id
        reshape long pnpt age hh_add famnum pnsp ent_pt, i(id) j(mnth)
        drop if mnth>=37 & mnth<=40
        
	cd "$programs"
	do monthwave84.do
        cd "$tempdata"
	
	sort id wave month
        save testm, replace

        *Core data
        local i=1
        *use $ids rot month pnum fid fid2 hnp fnp snp foklt18 fnkids using $c`i', clear
        use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear
        sort $ids 
        save test, replace
        local i= `i'+1
        while `i'>=2 & `i'<10 {
                use $ids rot month pnum f_numbr h_size fnumper snumper foklt18 fownkid using $c`i', clear 
                sort $ids
                append using test
                sort $ids
                save test, replace
                tab wave
                local i=`i'+1
        	}
        use testi, clear
        merge id using test
        tab _merge
        rename _merge mtst1
        sort id wave
        merge id wave using testw
        tab _merge
        rename _merge mtst2
        sort id wave month
        merge id wave month using testm
        tab _merge
        rename _merge mtst3

        rename sex esex
        rename pp_id ssuid
        rename pp_entry eentaid
        rename hh_add shhadid
        rename famnum rsid
        rename f_numbr rfid
	gen rfid2 = .
        *rename fid2 rfid2
        rename h_size ehhnumpp
        rename fnumper efnp
        rename snumper esfnp
        rename foklt18 rfoklt18
        rename fownkid rfnkids
	rename pnsp epnspous

        drop if mtst3~=3
   	drop mtst*

        save test, replace
        tab wave

        erase testi.dta
        erase testw.dta
        erase testm.dta
end

loop$p
compress
