
/* Please do not attempt to run this program without reading the accompanying documentation*/

version 8.0
set more off
prog drop _all
capture log close
clear

/*
File: pull d (id and weights).do
Date: May 2012
Desc: Pull-file to create Set D
Note: See acknowledgements and copyright notice in new_master.do.
*/

cd "$log"
log using set_d$p_new.log, replace

/*

This program is to be run embedded within new_master.do.


The programs below pull the variables necessary for Set D from the 
SIPP Longitudinal, Core, and Topical Modules and merge them into 
one dataset that is by person-month.

Note that we delete any individual who appears in a Core or Topical 
Module file, but who is not on the Longitudinal file, as recommended by 
U.S. Census Bureau staff.
        
For the 1990-1993 panels, in order to reshape the Longitudinal 
files by person-month, we need to do three separate steps. 
(1) Pull all Longitudinal vars that appear once per panel and 
create a dataset that is by <id>.
(2) Pull all Longitudinal vars that appear once per wave and 
create a dataset that is by <id wave>.
(3) Pull all Longitudinal vars that appear once per month and 
create a dataset that is by <id mnth>. Generate calendar month
and wave from the month counter in this file. (The variable 
<mnth> goes from 1 to 36 in the 1993 panel and thus must be
converted into calendar months for merging.)
Then, we merge the three files together into one person-month 
file, along with variables from the Core and Topical Module
files.

Note that there is an error in the 1993 panel whereby 
there are individuals in the longitudinal file that show up 
without data. These are deleted. 

*/

macro list
cd "$tempdata"
************* pull employment

* need to pull from each wave and merge


capture program drop loop08
program define loop08

	global dvarlist "$ids rot rhcalyr tage ejobcntr rmesr rmwkwjb rwksperm eclwrk* eunion* epayhr* ejbhrs* tpmsum* tpyrate* ejbind* tjbocc* tempall* tempsiz* eeno* estlemp* tsjdate* tejdate* ersend* apmsum* apyrate* tbmsum* tmlmsum abmsum* rwkesr*"

	forvalues i=1/8 {
		if `i' == 1 {
			use $dvarlist using $c`i', clear
		}
		if `i' > 1 {
			append using $c`i', keep($dvarlist)
		}
	}

	rename rmesr esr
	rename rwksperm wksper
	renpfix ejbhrs hours
	renpfix tpyrate rate
	renpfix tpmsum earn
	renpfix ejbind ind3
	renpfix tjbocc occ3
	renpfix eclwrk class
	renpfix eunion union
	renpfix eeno job
	renpfix epayhr hrly
	renpfix tbmsum selfinc
	rename tmlmsum mooninc
	rename tage age
	rename rhcalyr year

	cd "$tempdata"
	save test, replace
end



capture program drop loop04
program define loop04

	global dvarlist "$ids rot rhcalyr tage ejobcntr rmesr rmwkwjb rwksperm eclwrk* eunion* epayhr* ejbhrs* tpmsum* tpyrate* ejbind* tjbocc* tempall* tempsiz* eeno* estlemp* tsjdate* tejdate* ersend* apmsum* apyrate* tbmsum* tmlmsum abmsum* rwkesr*"

	forvalues i=1/12 {
		if `i' == 1 {
			use $dvarlist using $c`i', clear
		}
		if `i' > 1 {
			append using $c`i', keep($dvarlist)
		}
	}

	rename rmesr esr
	rename rwksperm wksper
	renpfix ejbhrs hours
	renpfix tpyrate rate
	renpfix tpmsum earn
	renpfix ejbind ind3
	renpfix tjbocc occ3
	renpfix eclwrk class
	renpfix eunion union
	renpfix eeno job
	renpfix epayhr hrly
	renpfix tbmsum selfinc
	rename tmlmsum mooninc
	rename tage age
	rename rhcalyr year

	cd "$tempdata"
	save test, replace
end

capture program drop loop01
program define loop01
        local i=1
        use $ids rot rhcalyr tage ejobcntr rmesr rmwkwjb rwksperm eclwrk* eunion* epayhr* /*
        */ ejbhrs* tpmsum* tpyrate* ejbind* tjbocc* tempall* tempsiz* eeno* estlemp* tsjdate* /*
        */ tejdate* ersend* apmsum* apyrate* tbmsum* tmlmsum abmsum* rwkesr* /*
        */ using $c`i', clear
        sort $ids
        save test, replace
        local i = `i'+1
        while `i'>1 & `i'<10 {
        	use $ids rot rhcalyr tage ejobcntr rmesr rmwkwjb rwksperm eclwrk* eunion* epayhr* /*
        	*/ ejbhrs* tpmsum* tpyrate* ejbind* tjbocc* tempall* tempsiz* eeno* estlemp* /*
        	*/ tsjdate* tejdate* ersend* apmsum* apyrate* tbmsum* tmlmsum abmsum* rwkesr* /*
        	*/ using $c`i', clear
        	sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
        
        * give uniform names, as necessary
        rename rmesr esr
        rename rwksperm wksper
        renpfix ejbhrs hours
        renpfix tpyrate rate
        renpfix tpmsum earn
        renpfix ejbind ind3
        renpfix tjbocc occ3
        renpfix eclwrk class
        renpfix eunion union
        renpfix eeno job
        renpfix epayhr hrly
        renpfix tbmsum selfinc
        rename tmlmsum mooninc
        rename tage age
        rename rhcalyr year
        } 
save test, replace
end


capture program drop loop96
program define loop96
        local i=1
        use $ids rot rhcalyr tage ejobcntr rmesr rmwkwjb rwksperm eclwrk* eunion* epayhr* /*
        */ ejbhrs* tpmsum* tpyrate* ejbind* tjbocc* tempall* tempsiz* eeno* estlemp* tsjdate* /*
        */ tejdate* ersend* apmsum* apyrate* tbmsum* tmlmsum abmsum* rwkesr* /*
        */ using $f`i', clear
        sort $ids
        save test, replace
        local i = `i'+1
        while `i'>1 & `i'<13 {
        	use $ids rot rhcalyr tage ejobcntr rmesr rmwkwjb rwksperm eclwrk* eunion* epayhr* /*
        	*/ ejbhrs* tpmsum* tpyrate* ejbind* tjbocc* tempall* tempsiz* eeno* estlemp* /*
        	*/ tsjdate* tejdate* ersend* apmsum* apyrate* tbmsum* tmlmsum abmsum* rwkesr* /*
        	*/ using $f`i', clear
                sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
        
        * give uniform names, as necessary
        rename rmesr esr
        rename rwksperm wksper
        renpfix ejbhrs hours
        renpfix tpyrate rate
        renpfix tpmsum earn
        renpfix ejbind ind3
        renpfix tjbocc occ3
        renpfix eclwrk class
        renpfix eunion union
        renpfix eeno job
        renpfix epayhr hrly
        renpfix tbmsum selfinc
        rename tmlmsum mooninc
        rename tage age
	rename rhcalyr year
        } 
save test, replace
end


capture program drop loop93
program define loop93
        local p = $p
        * Longitudinal data
        * id month L1
        cd "$cleandata"
	use id rot age* esr* mthjbw* wksper* jobid* clswk* using sipp93l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix esr_ esr
        renpfix esr0 esr
        renpfix mthjbw0 mthjbw
        renpfix mthjbw rmwkwjb
        renpfix wksper0 wksper
        renpfix jobid10 job1_
	renpfix jobid20 job2_
	renpfix jobid1 job1_
	renpfix jobid2 job2_
	renpfix clswk10 class1_
	renpfix clswk20 class2_
        renpfix clswk1 class1_
        renpfix clswk2 class2_
     
        reshape long age esr rmwkwjb wksper job1_ job2_ class1_ class2_, i(id) j(mnth)
	ren job1_ job1
	ren job2_ job2
	ren class1_ class1
	ren class2_ class2
        gen month2 = mnth
        
	cd "$programs"
	do monthwave93.do
	cd "$tempdata"
	
        count if id==""
        drop if id==""
        sort id wave month
        save testm1, replace
        
        * id month L2
	cd "$cleandata"
        use id rot occ* ind* ernam* wshrs* hrrat* se_am* using sipp93l2, clear
	cd "$tempdata"
        renpfix occ1_0 occ31
        renpfix occ1_ occ31
        renpfix ind1_0 ind31
        renpfix ind1_ ind31
        renpfix occ2_0 occ32
        renpfix occ2_ occ32
        renpfix ind2_0 ind32
        renpfix ind2_ ind32
        renpfix ernam10 earn1_
        renpfix ernam20 earn2_
        renpfix ernam1 earn1_
        renpfix ernam2 earn2_
        renpfix wshrs10 hours1_
        renpfix wshrs20 hours2_
        renpfix wshrs1 hours1_
        renpfix wshrs2 hours2_
        renpfix hrrat10 rate1_
        renpfix hrrat20 rate2_
        renpfix hrrat1 rate1_
        renpfix hrrat2 rate2_
        renpfix se_am10 selfinc1_
        renpfix se_am1 selfinc1_
        renpfix se_am20 selfinc2_
        renpfix se_am2 selfinc2_


        reshape long earn1_ earn2_ rate1_ rate2_ hours1_ hours2_ occ31 occ32 ind31 ind32 selfinc1_ selfinc2_, i(id) j(mnth)
	ren earn1_ earn1
	ren earn2_ earn2
	ren rate1_ rate1
	ren rate2_ rate2
	ren hours1_ hours1
	ren hours2_ hours2
	ren selfinc1_ selfinc1
	ren selfinc2_ selfinc2
        gen month2 = mnth
        
	cd "$programs"
	do monthwave93.do
	cd "$tempdata"        
	
	count if id==""
        drop if id==""
        sort id wave month
        save testm2, replace
        
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
        */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
        */ wesr1 wesr2 wesr3 wesr4 wesr5 /*
        */ using sipp`p'w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<10 {
		cd "$cleandata"
                use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
                */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
		*/ wesr1 wesr2 wesr3 wesr4 wesr5 /*
                */ using sipp`p'w`i', clear
                cd "$tempdata"
		sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
		} 

	sort id wave month
        save test, replace
	

	use testm1, clear
        merge id wave month using test
        tab _merge
        rename _merge m1tst
        
        sort id wave month
        merge id wave month using testm2
        tab _merge
        rename _merge m2tst
        
        * Topical module data (append to all observations)
        * Data on job start dates.
        sort id rot
        save test, replace
        
	cd "$cleandata"
        use id rot tm8214 tm8218 tm8220 using sipp93t1, clear
        cd "$tempdata"
	sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm
        
        * give uniform names, as necessary
        rename ws12003 estlemp1
        rename ws12016 smonth1
        rename ws12020 emonth1
        rename ws12024 ersend1
        rename ws12026 hrly1
        rename ws12044 union1
        rename ws22103 estlemp2
        rename ws22116 smonth2
        rename ws22120 emonth2
        rename ws22124 ersend2
        rename ws22126 hrly2
        rename ws22144 union2
        rename iws12028 apyrate1
        rename iws22128 apyrate2
        rename ws1calc apmsum1
        rename ws2calc apmsum2
		rename wesr1 rwkesr1
        rename wesr2 rwkesr2
		rename wesr3 rwkesr3
		rename wesr4 rwkesr4
		rename wesr5 rwkesr5
        replace year = year+1900

        drop if m1tst~=3
        drop m1tst m2tst
        compress
        save test, replace       
end


capture program drop loop92
program define loop92
        local p = $p
        
        * Longitudinal data
        * id month L1
	cd "$cleandata"
		use id rot age* esr* mthjbw* wksper* using sipp92l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix esr_ esr
        renpfix esr0 esr
        renpfix mthjbw0 mthjbw
        renpfix mthjbw rmwkwjb
        renpfix wksper0 wksper
       
        reshape long age esr rmwkwjb wksper, i(id) j(mnth)
        gen month2 = mnth
        
	cd "$programs"
	do monthwave92.do
	cd "$tempdata"
        
	sort id wave month
        save testm1, replace
        
        * id month L2
	cd "$cleandata"
		di `p'
        use id rot jobid* clswk* occ* ind* ernam* wshrs* hrrat* se_am* /*
        */ using sipp92l2, clear
		di `p'
	cd "$tempdata"
        renpfix jobid10 job1_
	renpfix jobid20 job2_
	renpfix jobid1 job1_
	renpfix jobid2 job2_
	renpfix clswk10 class1_
	renpfix clswk20 class2_
        renpfix clswk1 class1_
        renpfix clswk2 class2_
        renpfix occ1_0 occ31
        renpfix occ1_ occ31
        renpfix ind1_0 ind31
        renpfix ind1_ ind31
        renpfix occ2_0 occ32
        renpfix occ2_ occ32
        renpfix ind2_0 ind32
        renpfix ind2_ ind32
        renpfix ernam10 earn1_
        renpfix ernam20 earn2_
        renpfix ernam1 earn1_
        renpfix ernam2 earn2_
        renpfix wshrs10 hours1_
        renpfix wshrs20 hours2_
        renpfix wshrs1 hours1_
        renpfix wshrs2 hours2_
        renpfix hrrat10 rate1_
        renpfix hrrat20 rate2_
        renpfix hrrat1 rate1_
        renpfix hrrat2 rate2_
        renpfix se_am10 selfinc1_
        renpfix se_am1 selfinc1_
        renpfix se_am20 selfinc2_
        renpfix se_am2 selfinc2_


        reshape long job1_ job2_ class1_ class2_ earn1_ earn2_ rate1_ rate2_ hours1_ hours2_ occ31 occ32 ind31 ind32 selfinc1_ selfinc2_, i(id) j(mnth)
	ren job1_ job1
	ren job2_ job2
	ren class1_ class1
	ren class2_ class2
	ren earn1_ earn1
	ren earn2_ earn2
	ren rate1_ rate1
	ren rate2_ rate2
	ren hours1_ hours1
	ren hours2_ hours2
	ren selfinc1_ selfinc1
	ren selfinc2_ selfinc2
        gen month2 = mnth
        
	cd "$programs"
	do monthwave92.do
	cd "$tempdata"
	
        sort id wave month
        save testm2, replace
        
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
        */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
        */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<10 {
		cd "$cleandata"
                use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
                */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
                */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
		cd "$tempdata"
                sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
		} 
        
	sort id wave month
        save test, replace
        
        use testm1, clear
        merge id wave month using test
        tab _merge
        rename _merge m1tst
        sort id wave month
        merge id wave month using testm2
        tab _merge
        rename _merge m2tst
        
        * Topical module data (append to all observations)
        * Data on job start dates.
        sort id rot
        save test, replace
        
	cd "$cleandata"
        use id rot tm8214 tm8218 tm8220 using sipp92t1, clear
	cd "$tempdata"
        sort id rot
        merge id rot using test
        tab _merge
        rename _merge mtm
        save test, replace
                
        
        * give uniform names, as necessary
        rename ws12003 estlemp1
        rename ws12016 smonth1
        rename ws12020 emonth1
        rename ws12024 ersend1
        rename ws12026 hrly1
        rename ws12044 union1
        rename ws22103 estlemp2
        rename ws22116 smonth2
        rename ws22120 emonth2
        rename ws22124 ersend2
        rename ws22126 hrly2
        rename ws22144 union2
        rename iws12028 apyrate1
        rename iws22128 apyrate2
        rename ws1calc apmsum1
        rename ws2calc apmsum2
		rename wesr1 rwkesr1
        rename wesr2 rwkesr2
		rename wesr3 rwkesr3
		rename wesr4 rwkesr4
		rename wesr5 rwkesr5
        replace year = year+1900


        drop if m1tst~=3
        drop m1tst m2tst
        compress
        save test, replace
end

capture program drop loop91
program define loop91
        local p = $p
        * Longitudinal data
        * id month L1
        cd "$cleandata"
	use id rot age* esr* mthjbw* wksper* jobid* clswk* using sipp91l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix esr_ esr
        renpfix esr0 esr
        renpfix mthjbw0 mthjbw
        renpfix mthjbw rmwkwjb
        renpfix wksper0 wksper
        renpfix jobid10 job1_
	renpfix jobid20 job2_
	renpfix jobid1 job1_
	renpfix jobid2 job2_
	renpfix clswk10 class1_
	renpfix clswk20 class2_
        renpfix clswk1 class1_
        renpfix clswk2 class2_
        reshape long job1_ job2_ class1_ class2_ age esr rmwkwjb wksper, i(id) j(mnth)
        
	ren job1_ job1
	ren job2_ job2
	ren class1_ class1
	ren class2_ class2
	
        gen month2 = mnth
        
	cd "$programs"
	do monthwave91.do
	cd "$tempdata"
       
        sort id wave month
        save testm1, replace
        
        * id month L2   
        cd "$cleandata"
	use id rot occ* ind* ernam* wshrs* hrrat* se_am* using sipp91l2, clear
        cd "$tempdata"
	
        renpfix occ1_0 occ31
        renpfix occ1_ occ31
        renpfix ind1_0 ind31
        renpfix ind1_ ind31
        renpfix occ2_0 occ32
        renpfix occ2_ occ32
        renpfix ind2_0 ind32
        renpfix ind2_ ind32
        renpfix ernam10 earn1_
        renpfix ernam20 earn2_
        renpfix ernam1 earn1_
        renpfix ernam2 earn2_
        renpfix wshrs10 hours1_
        renpfix wshrs20 hours2_
        renpfix wshrs1 hours1_
        renpfix wshrs2 hours2_
        renpfix hrrat10 rate1_
        renpfix hrrat20 rate2_
        renpfix hrrat1 rate1_
        renpfix hrrat2 rate2_
        renpfix se_am10 selfinc1_
        renpfix se_am1 selfinc1_
        renpfix se_am20 selfinc2_
        renpfix se_am2 selfinc2_

        reshape long earn1_ earn2_ rate1_ rate2_ hours1_ hours2_ occ31 occ32 ind31 ind32 selfinc1_ selfinc2_, i(id) j(mnth)
	ren earn1_ earn1
	ren earn2_ earn2
	ren rate1_ rate1
	ren rate2_ rate2
	ren hours1_ hours1
	ren hours2_ hours2
	ren selfinc1_ selfinc1
	ren selfinc2_ selfinc2
        gen month2 = mnth
        
	cd "$programs"
	do monthwave91.do
	cd "$tempdata"
	
        sort id wave month
        save testm2, replace
        
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
        */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
        */ wesr1 wesr2 wesr3 wesr4 wesr5 /*
        */ using sipp`p'w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<9 {
		cd "$cleandata"
                use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
                */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
                */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
		cd "$tempdata"
                sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
		} 
	sort id wave month
	save test, replace
	
        use testm1, clear
        merge id wave month using test
        tab _merge
        rename _merge m1tst
        sort id wave month
        merge id wave month using testm2
        tab _merge
        rename _merge m2tst
        
        * Topical module data (append to all observations)
        * Data on start dates
        sort id wave
        save test, replace
       
        cd "$cleandata"
	use id wave tm8214 tm8218 tm8220 using sipp91t2, clear
        cd "$tempdata"
	sort id wave
        merge id wave using test
        tab _merge
        rename _merge mtm
        save test, replace
        
        * give uniform names, as necessary
        rename ws12003 estlemp1
        rename ws12016 smonth1
        rename ws12020 emonth1
        rename ws12024 ersend1
        rename ws12026 hrly1
        rename ws12044 union1
        rename ws22103 estlemp2
        rename ws22116 smonth2
        rename ws22120 emonth2
        rename ws22124 ersend2
        rename ws22126 hrly2
        rename ws22144 union2
        rename iws12028 apyrate1
        rename iws22128 apyrate2
        rename ws1calc apmsum1
        rename ws2calc apmsum2
		rename wesr1 rwkesr1
        rename wesr2 rwkesr2
		rename wesr3 rwkesr3
		rename wesr4 rwkesr4
		rename wesr5 rwkesr5
        replace year = year+1900


        drop if m1tst~=3
        drop m1tst m2tst
        compress
        save test, replace        
end

capture program drop loop90
program define loop90
        local p = $p
        * Longitudinal data
        * id month L1
	cd "$cleandata"
        use id rot occ* ind* age* esr* mthjbw* wksper* jobid* clswk* using sipp90l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix esr_ esr
        renpfix esr0 esr
        renpfix mthjbw0 mthjbw
        renpfix mthjbw rmwkwjb
        renpfix wksper0 wksper
        renpfix jobid10 job1_
	renpfix jobid20 job2_
	renpfix jobid1 job1_
	renpfix jobid2 job2_
	renpfix clswk10 class1_
	renpfix clswk20 class2_
        renpfix clswk1 class1_
        renpfix clswk2 class2_
        renpfix occ1_0 occ31
        renpfix occ1_ occ31
        renpfix ind1_0 ind31
        renpfix ind1_ ind31
        renpfix occ2_0 occ32
        renpfix occ2_ occ32
        renpfix ind2_0 ind32
        renpfix ind2_ ind32
        reshape long job1_ job2_ occ31 occ32 ind31 ind32 class1_ class2_ age esr rmwkwjb wksper, i(id) j(mnth)
        
	ren job1_ job1
	ren job2_ job2
	ren class1_ class1
	ren class2_ class2
	
        gen month2 = mnth
        
	cd "$programs"
	do monthwave90.do
        cd "$tempdata"
	
	sort id wave month
        save testm1, replace
        
        * id month L2
	cd "$cleandata"   
        use id rot ernam* wshrs* hrrat* se_am* using sipp90l2, clear
        cd "$tempdata"
	
        renpfix ernam10 earn1_
        renpfix ernam20 earn2_
        renpfix ernam1 earn1_
        renpfix ernam2 earn2_
        renpfix wshrs10 hours1_
        renpfix wshrs20 hours2_
        renpfix wshrs1 hours1_
        renpfix wshrs2 hours2_
        renpfix hrrat10 rate1_
        renpfix hrrat20 rate2_
        renpfix hrrat1 rate1_
        renpfix hrrat2 rate2_
        renpfix se_am10 selfinc1_
        renpfix se_am1 selfinc1_
        renpfix se_am20 selfinc2_
        renpfix se_am2 selfinc2_
        reshape long earn1_ earn2_ rate1_ rate2_ hours1_ hours2_ selfinc1_ selfinc2_, i(id) j(mnth)
	ren earn1_ earn1
	ren earn2_ earn2
	ren rate1_ rate1
	ren rate2_ rate2
	ren hours1_ hours1
	ren hours2_ hours2
	ren selfinc1_ selfinc1
	ren selfinc2_ selfinc2
        gen month2 = mnth
        
	cd "$programs"
	do monthwave90.do
	cd "$tempdata"        
	
	sort id wave month
        save testm2, replace
        
        * Core data     
        local i=1
	cd "$cleandata"
        use $ids month year intvw njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
        */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
        */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<9 {
		cd "$cleandata"
                use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
                */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
                */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
		cd "$tempdata"
                sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
		} 


        sort id wave month
        save test, replace
        
        use testm1, clear
        merge id wave month using test
        tab _merge
        rename _merge m1tst
        sort id wave month
        merge id wave month using testm2
        tab _merge
        rename _merge m2tst
        
        * Topical module data (append to all observations)
        * Data on start dates
        sort id wave
        save test, replace
        
	cd "$cleandata"
        use id wave tm8214 tm8218 tm8220 using sipp90t2, clear
	cd "$tempdata"
        sort id wave
        merge id wave using test
        tab _merge
        rename _merge mtm
        save test, replace
        
        * give uniform names, as necessary
        rename ws12003 estlemp1
        rename ws12016 smonth1
        rename ws12020 emonth1
        rename ws12024 ersend1
        rename ws12026 hrly1
        rename ws12044 union1
        rename ws22103 estlemp2
        rename ws22116 smonth2
        rename ws22120 emonth2
        rename ws22124 ersend2
        rename ws22126 hrly2
        rename ws22144 union2
        rename iws12028 apyrate1
        rename iws22128 apyrate2
        rename ws1calc apmsum1
        rename ws2calc apmsum2
		rename wesr1 rwkesr1
        rename wesr2 rwkesr2
		rename wesr3 rwkesr3
		rename wesr4 rwkesr4
		rename wesr5 rwkesr5
        replace year = year+1900


        drop if m1tst~=3
        drop m1tst m2tst
        compress
        save test, replace
end

capture program drop loop89
program define loop89
        local p = $p
        * Longitudinal data
        * id month L1
	cd "$cleandata"
	*use sipp89l1
        *use id rot occ* ind* age* esr* mthjbw* wksper* jobid* clswk* using sipp90l1, clear
        use id rot ws*_oc* ws*_in* age* esr* wksjb* wksper* jobid* clswk* using sipp89l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix esr_ esr
        renpfix esr0 esr
        renpfix wksjb_0 rmwkwjb
        renpfix wksjb_ rmwkwjb
        renpfix wksper0 wksper
        renpfix jobid10 job1_
        renpfix jobid1 job1_
        renpfix jobid20 job2_
	renpfix jobid2 job2_
	*renpfix jobid job1
	renpfix clswk10 class1_
	renpfix clswk1 class1_
	renpfix clswk20 class2_
	renpfix clswk2 class2_
        *renpfix clswk class
        renpfix ws1_oc0 occ31
        renpfix ws1_oc occ31
        renpfix ws1_in0 ind31
        renpfix ws1_in ind31
        renpfix ws2_oc0 occ32
        renpfix ws2_oc occ32
        renpfix ws2_in0 ind32
        renpfix ws2_in ind32
        reshape long job1_ job2_ occ31 occ32 ind31 ind32 class1_ class2_ age esr rmwkwjb wksper, i(id) j(mnth)
	
	ren job1_ job1
	ren job2_ job2
	ren class1_ class1
	ren class2_ class2
        
        gen month2 = mnth
        
	cd "$programs"
	do monthwave89.do
        cd "$tempdata"
	
	sort id wave month
        save testm1, replace
        
        * id month L2
	cd "$cleandata"
	* use id rot ernam* wshrs* hrrat* se_am* using sipp90l2, clear
        use id rot ws*_am* w2*24* w2*28* se*_am* using sipp89l1, clear
        cd "$tempdata"
	
	renpfix ws1_am0 earn1
	renpfix ws1_am earn1
	renpfix ws2_am0 earn2
	renpfix ws2_am earn2
        *renpfix ernam10 earn1
        *renpfix ernam20 earn2
        *renpfix ernam earn
	renpfix w2024_0 hours1
	renpfix w2024_ hours1
	renpfix w2124_0 hours2
	renpfix w2124_ hours2
        *renpfix wshrs10 hours1
        *renpfix wshrs20 hours2
        *renpfix wshrs hours
	renpfix w2028_0 rate1
	renpfix w2028_ rate1
	renpfix w2128_0 rate2
	renpfix w2128_ rate2	
        *renpfix hrrat10 rate1
        *renpfix hrrat20 rate2
        *renpfix hrrat rate
        renpfix se1_am0 selfinc1
        renpfix se1_am selfinc1
        renpfix se2_am0 selfinc2
        renpfix se2_am selfinc2
        *renpfix se_am20 se_am2
        *renpfix se_am selfinc


        reshape long earn1 earn2 rate1 rate2 hours1 hours2 selfinc1 selfinc2, i(id) j(mnth)
        gen month2 = mnth
        
	cd "$programs"
	do monthwave89.do
	cd "$tempdata"        
	
	sort id wave month
        save testm2, replace
        
        * Core data     
        local i=1
	cd "$cleandata"
/*
        use $ids month year pp_intvw ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
        */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
        */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
	*/
        use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
        */ ws2_2016 ws2_2020 sc1174 ws2_2026 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
        */ wkwjob* using sipp`p'w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<9 {
		cd "$cleandata"
/*
                use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
                */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
                */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
*/
                use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
                */ ws2_2016 ws2_2020 sc1174 ws2_2026 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
                */ wkwjob* using sipp`p'w`i', clear
		cd "$tempdata"
                sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
		} 


	*gen ws1calc = (ws1cal01==1|ws1cal02==1|ws1cal03==1|ws1cal04==1)
	*gen ws2calc = (ws2cal01==1|ws2cal02==1|ws2cal03==1|ws2cal04==1)
        sort id wave month
        save test, replace
        
        use testm1, clear
        merge id wave month using test
        tab _merge
        rename _merge m1tst
        sort id wave month
        merge id wave month using testm2
        tab _merge
        rename _merge m2tst
	
        * Topical module data (append to all observations)
        * Data on start dates
        sort id wave month
        save test, replace
        
	cd "$cleandata"
        *use id wave tm8214 tm8218 tm8220 using sipp89t2, clear
        use id wave month ws1_2002 ws2_2002 using sipp89w3, clear
	cd "$tempdata"
        sort id wave month
        merge id wave month using test
        tab _merge
	drop _merge
	sort id wave month
        save test, replace
	cd "$cleandata"
        use id wave tm8262 using sipp89rt3, clear
	cd "$tempdata"
        sort id wave
        merge id wave using test
        tab _merge
        rename _merge mtm
        save test, replace
        
        * give uniform names, as necessary
        *rename ws12003 estlemp1
        *rename ws12016 smonth1
	ren ws1_2016 smonth1
        *rename ws12020 emonth1
	ren ws1_2020 emonth1
        *rename ws12024 ersend1
	ren sc1098 ersend1
        *rename ws12026 hrly1
	ren ws1_2026 hrly1
        *rename ws12044 union1
        *rename ws22103 estlemp2
        *rename ws22116 smonth2
	ren ws2_2016 smonth2
        *rename ws22120 emonth2
	ren ws2_2020 emonth2
        *rename ws22124 ersend2
	ren sc1174 ersend2
        *rename ws22126 hrly2
	ren ws2_2026 hrly2
        *rename ws22144 union2
        *rename iws12028 apyrate1
	ren ws1imp05 apyrate1
        *rename iws22128 apyrate2
	ren ws2imp05 apyrate2
        *rename ws1calc apmsum1
	ren ws1cal0 apmsum1
        *rename ws2calc apmsum2
	ren ws2cal0 apmsum2
	*rename wesr1 rwkesr1
	gen rwkesr1 = .
	replace rwkesr1 = wkwjob01 if srefmon == 1
	replace rwkesr1 = wkwjob05 if srefmon == 2
	replace rwkesr1 = wkwjob09 if srefmon == 3
	replace rwkesr1 = wkwjob13 if srefmon == 4
	replace rwkesr1 = wkwjob17 if srefmon == 5
        *rename wesr2 rwkesr2
	gen rwkesr2 = .
	replace rwkesr2 = wkwjob02 if srefmon == 1
	replace rwkesr2 = wkwjob06 if srefmon == 2
	replace rwkesr2 = wkwjob10 if srefmon == 3
	replace rwkesr2 = wkwjob14 if srefmon == 4
	replace rwkesr2 = wkwjob18 if srefmon == 5
	*rename wesr3 rwkesr3
	gen rwkesr3 = .
	replace rwkesr3 = wkwjob03 if srefmon == 1
	replace rwkesr3 = wkwjob07 if srefmon == 2
	replace rwkesr3 = wkwjob11 if srefmon == 3
	replace rwkesr3 = wkwjob15 if srefmon == 4
	*rename wesr4 rwkesr4
	gen rwkesr4 = .
	replace rwkesr4 = wkwjob04 if srefmon == 1
	replace rwkesr4 = wkwjob08 if srefmon == 2
	replace rwkesr4 = wkwjob12 if srefmon == 3
	replace rwkesr4 = wkwjob16 if srefmon == 4
	*rename wesr5 rwkesr5
	gen rwkesr5 = .
	replace rwkesr5 = wkwjob05 if srefmon == 1
	replace rwkesr5 = wkwjob09 if srefmon == 2
	replace rwkesr5 = wkwjob13 if srefmon == 3
	replace rwkesr5 = wkwjob17 if srefmon == 4
	ren pp_intvw intvw
	ren sc1716 njobs
	ren ws1_2002 tm8214
	gen tm8218 = smonth1
	ren tm8262 tm8220
        replace year = year+1900


        drop if m1tst~=3
        drop m1tst m2tst
        compress
        save test, replace
end

capture program drop loop88
program define loop88
        local p = $p
        * Longitudinal data
        * id month L1
	cd "$cleandata"
	*use sipp88l1
        *use id rot occ* ind* age* esr* mthjbw* wksper* jobid* clswk* using sipp90l1, clear
        use id rot occ* ind* age* esr* mthjbw* wksper* jobid* clswk* using sipp88l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix esr_ esr
        renpfix esr0 esr
        renpfix mthjbw0 rmwkwjb
        renpfix mthjbw rmwkwjb
        renpfix wksper0 wksper
        renpfix jobid10 job1_
        renpfix jobid1 job1_
        renpfix jobid20 job2_
	renpfix jobid2 job2_
	*renpfix jobid job1
	renpfix clswk10 class1_
	renpfix clswk1 class1_
	renpfix clswk20 class2_
	renpfix clswk2 class2_
        *renpfix clswk class
        renpfix occ1_0 occ31
        renpfix occ1_ occ31
        renpfix ind1_0 ind31
        renpfix ind1_ ind31
        renpfix occ2_0 occ32
        renpfix occ2_ occ32
        renpfix ind2_0 ind32
        renpfix ind2_ ind32
        reshape long job1_ job2_ occ31 occ32 ind31 ind32 class1_ class2_ age esr rmwkwjb wksper, i(id) j(mnth)
	
	ren job1_ job1
	ren job2_ job2
	ren class1_ class1
	ren class2_ class2
        
        gen month2 = mnth
        
	cd "$programs"
	do monthwave88.do
        cd "$tempdata"
	
	sort id wave month
        save testm1, replace
        
        * id month L2
	cd "$cleandata"
	* use id rot ernam* wshrs* hrrat* se_am* using sipp90l2, clear
        *use id rot ws*_am* w2*24* w2*28* se*_am* using sipp88l1, clear
	use id rot ernam* wshrs* hrrat* se_am* using sipp88l1, clear
        cd "$tempdata"
	
	*renpfix ws1_am0 earn1
	*renpfix ws1_am earn1
	*renpfix ws2_am0 earn2
	*renpfix ws2_am earn2
        renpfix ernam10 earn1
        renpfix ernam20 earn2
        renpfix ernam earn
	*renpfix w2024_0 hours1
	*renpfix w2024_ hours1
	*renpfix w2124_0 hours2
	*renpfix w2124_ hours2
        renpfix wshrs10 hours1
        renpfix wshrs20 hours2
        renpfix wshrs hours
	*renpfix w2028_0 rate1
	*renpfix w2028_ rate1
	*renpfix w2128_0 rate2
	*renpfix w2128_ rate2	
        renpfix hrrat10 rate1
        renpfix hrrat20 rate2
        renpfix hrrat rate
        *renpfix se1_am0 selfinc1
        *renpfix se1_am selfinc1
        *renpfix se2_am0 selfinc2
        *renpfix se2_am selfinc2
	renpfix se_am10 se_am1
        renpfix se_am20 se_am2
        renpfix se_am selfinc


        reshape long earn1 earn2 rate1 rate2 hours1 hours2 selfinc1 selfinc2, i(id) j(mnth)
        gen month2 = mnth
        
	cd "$programs"
	do monthwave88.do
	cd "$tempdata"        
	
	sort id wave month
        save testm2, replace
        
        * Core data     
        local i=1
	cd "$cleandata"
/*
        use $ids month year pp_intvw ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
        */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
        */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
	*/
        use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
        */ ws2_2116 ws2_2120 sc1174 ws2_2126 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
        */ wkwjob* using sipp`p'w`i', clear
	ren ws2_2116 ws2_2016
	ren ws2_2120 ws2_2020
	ren ws2_2126 ws2_2026
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<9 {
		cd "$cleandata"
		capture confirm file "$c`i'.dta"
		if !_rc {
			use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
			*/ ws2_2116 ws2_2120 sc1174 ws2_2126 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
			*/ wkwjob* using sipp`p'w`i', clear
			ren ws2_2116 ws2_2016
			ren ws2_2120 ws2_2020
			ren ws2_2126 ws2_2026
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			}
                local i=`i'+1
		} 
		
	cd "$tempdata"
	*gen ws1calc = (ws1cal01==1|ws1cal02==1|ws1cal03==1|ws1cal04==1)
	*gen ws2calc = (ws2cal01==1|ws2cal02==1|ws2cal03==1|ws2cal04==1)
        sort id wave month
        save test, replace
        
        use testm1, clear
        merge id wave month using test
        tab _merge
        rename _merge m1tst
        sort id wave month
        merge id wave month using testm2
        tab _merge
        rename _merge m2tst
	
        * Topical module data (append to all observations)
        * Data on start dates
        sort id wave month
        save test, replace
        
	cd "$cleandata"
	use id wave tm8214 tm8218 tm8220 using sipp88rt2, clear
        *use id wave tm8214 tm8218 tm8220 using sipp88t2, clear
        *use id wave month ws1_2002 ws2_2002 using sipp88w3, clear
	cd "$tempdata"
        sort id wave
        merge id wave using test
        tab _merge
	ren _merge mtm
	sort id wave month
        save test, replace
	/*
	cd "$cleandata"
        use id wave tm8262 using sipp88rt3, clear
	cd "$tempdata"
        sort id wave
        merge id wave using test
        tab _merge
        rename _merge mtm
        save test, replace
	*/
        
        * give uniform names, as necessary
        *rename ws12003 estlemp1
        *rename ws12016 smonth1
	ren ws1_2016 smonth1
        *rename ws12020 emonth1
	ren ws1_2020 emonth1
        *rename ws12024 ersend1
	ren sc1098 ersend1
        *rename ws12026 hrly1
	ren ws1_2026 hrly1
        *rename ws12044 union1
        *rename ws22103 estlemp2
        *rename ws22116 smonth2
	ren ws2_2016 smonth2
        *rename ws22120 emonth2
	ren ws2_2020 emonth2
        *rename ws22124 ersend2
	ren sc1174 ersend2
        *rename ws22126 hrly2
	ren ws2_2026 hrly2
        *rename ws22144 union2
        *rename iws12028 apyrate1
	ren ws1imp05 apyrate1
        *rename iws22128 apyrate2
	ren ws2imp05 apyrate2
        *rename ws1calc apmsum1
	ren ws1cal0 apmsum1
        *rename ws2calc apmsum2
	ren ws2cal0 apmsum2
	*rename wesr1 rwkesr1
	gen rwkesr1 = .
	replace rwkesr1 = wkwjob01 if srefmon == 1
	replace rwkesr1 = wkwjob05 if srefmon == 2
	replace rwkesr1 = wkwjob09 if srefmon == 3
	replace rwkesr1 = wkwjob13 if srefmon == 4
	replace rwkesr1 = wkwjob17 if srefmon == 5
        *rename wesr2 rwkesr2
	gen rwkesr2 = .
	replace rwkesr2 = wkwjob02 if srefmon == 1
	replace rwkesr2 = wkwjob06 if srefmon == 2
	replace rwkesr2 = wkwjob10 if srefmon == 3
	replace rwkesr2 = wkwjob14 if srefmon == 4
	replace rwkesr2 = wkwjob18 if srefmon == 5
	*rename wesr3 rwkesr3
	gen rwkesr3 = .
	replace rwkesr3 = wkwjob03 if srefmon == 1
	replace rwkesr3 = wkwjob07 if srefmon == 2
	replace rwkesr3 = wkwjob11 if srefmon == 3
	replace rwkesr3 = wkwjob15 if srefmon == 4
	*rename wesr4 rwkesr4
	gen rwkesr4 = .
	replace rwkesr4 = wkwjob04 if srefmon == 1
	replace rwkesr4 = wkwjob08 if srefmon == 2
	replace rwkesr4 = wkwjob12 if srefmon == 3
	replace rwkesr4 = wkwjob16 if srefmon == 4
	*rename wesr5 rwkesr5
	gen rwkesr5 = .
	replace rwkesr5 = wkwjob05 if srefmon == 1
	replace rwkesr5 = wkwjob09 if srefmon == 2
	replace rwkesr5 = wkwjob13 if srefmon == 3
	replace rwkesr5 = wkwjob17 if srefmon == 4
	ren pp_intvw intvw
	ren sc1716 njobs
	*ren ws1_2002 tm8214
	*gen tm8218 = smonth1
	*ren tm8262 tm8220
        replace year = year+1900


        drop if m1tst~=3
        drop m1tst m2tst
        compress
        save test, replace
end

capture program drop loop87
program define loop87
        local p = $p
        * Longitudinal data
        * id month L1
	cd "$cleandata"
	*use sipp87l1
        *use id rot occ* ind* age* esr* mthjbw* wksper* jobid* clswk* using sipp90l1, clear
        use id rot ws*_oc* ws*_in* age* esr* wksjb* wksper* ws*_ei* ws*_cl* using sipp87l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix esr_ esr
        renpfix esr0 esr
        renpfix wksjb_0 rmwkwjb
        renpfix wksjb_ rmwkwjb
        renpfix wksper0 wksper
        renpfix ws1_ei0 job1_
        renpfix ws1_ei job1_
        renpfix ws2_ei0 job2_
        renpfix ws2_ei job2_
	*renpfix jobid job1
        renpfix ws1_cl0 class1_
        renpfix ws1_cl class1_
        renpfix ws2_cl0 class2_
        renpfix ws2_cl class2_
        *renpfix clswk class
        renpfix ws1_oc0 occ31
        renpfix ws1_oc occ31
        renpfix ws1_in0 ind31
        renpfix ws1_in ind31
        renpfix ws2_oc0 occ32
        renpfix ws2_oc occ32
        renpfix ws2_in0 ind32
        renpfix ws2_in ind32
        reshape long job1_ job2_ occ31 occ32 ind31 ind32 class1_ class2_ age esr rmwkwjb wksper, i(id) j(mnth)
	
	ren job1_ job1
	ren job2_ job2
	ren class1_ class1
	ren class2_ class2
        
        gen month2 = mnth
        
	cd "$programs"
	do monthwave87.do
        cd "$tempdata"
	
	sort id wave month
        save testm1, replace
        
        * id month L2
	cd "$cleandata"
	* use id rot ernam* wshrs* hrrat* se_am* using sipp90l2, clear
        use id rot ws*_am* w2*24* w2*28* se*_am* using sipp87l1, clear
        cd "$tempdata"
	
	renpfix ws1_am0 earn1
	renpfix ws1_am earn1
	renpfix ws2_am0 earn2
	renpfix ws2_am earn2
        *renpfix ernam10 earn1
        *renpfix ernam20 earn2
        *renpfix ernam earn
	renpfix w2024_0 hours1
	renpfix w2024_ hours1
	renpfix w2124_0 hours2
	renpfix w2124_ hours2
        *renpfix wshrs10 hours1
        *renpfix wshrs20 hours2
        *renpfix wshrs hours
	renpfix w2028_0 rate1
	renpfix w2028_ rate1
	renpfix w2128_0 rate2
	renpfix w2128_ rate2	
        *renpfix hrrat10 rate1
        *renpfix hrrat20 rate2
        *renpfix hrrat rate
        renpfix se1_am0 selfinc1
        renpfix se1_am selfinc1
        renpfix se2_am0 selfinc2
        renpfix se2_am selfinc2
        *renpfix se_am20 se_am2
        *renpfix se_am selfinc


        reshape long earn1 earn2 rate1 rate2 hours1 hours2 selfinc1 selfinc2, i(id) j(mnth)
        gen month2 = mnth
        
	cd "$programs"
	do monthwave87.do
	cd "$tempdata"        
	
	sort id wave month
        save testm2, replace
        
        * Core data     
        local i=1
	cd "$cleandata"
/*
        use $ids month year pp_intvw ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
        */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
        */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
	*/
        use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
        */ ws2_2016 ws2_2020 sc1174 ws2_2026 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
        */ wkwjob* using sipp`p'w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<9 {
		cd "$cleandata"
		capture confirm file "$c`i'.dta"
		if !_rc {
			use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
			*/ ws2_2116 ws2_2120 sc1174 ws2_2126 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
			*/ wkwjob* using sipp`p'w`i', clear
			ren ws2_2116 ws2_2016
			ren ws2_2120 ws2_2020
			ren ws2_2126 ws2_2026
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			}
                local i=`i'+1
		} 


	*gen ws1calc = (ws1cal01==1|ws1cal02==1|ws1cal03==1|ws1cal04==1)
	*gen ws2calc = (ws2cal01==1|ws2cal02==1|ws2cal03==1|ws2cal04==1)
	cd "$tempdata"
        sort id wave month
        save test, replace
        
        use testm1, clear
        merge id wave month using test
        tab _merge
        rename _merge m1tst
        sort id wave month
        merge id wave month using testm2
        tab _merge
        rename _merge m2tst
	
        * Topical module data (append to all observations)
        * Data on start dates
        sort id wave month
        save test, replace
        
	cd "$cleandata"
        use id wave tm8214 tm8218 tm8220 using sipp87rt2, clear
        *use id wave month ws1_2002 ws2_2002 using sipp87w3, clear
	cd "$tempdata"
        sort id wave
        merge id wave using test
        tab _merge
	ren _merge mtm
	sort id wave month
        save test, replace
        /* use id wave tm8262 using sipp87rt2, clear */
	/* cd "$tempdata" */
        /* sort id wave */
        /* merge id wave using test */
        /* tab _merge */
        /* rename _merge mtm */
        /* save test, replace */
        
        * give uniform names, as necessary
        *rename ws12003 estlemp1
        *rename ws12016 smonth1
	ren ws1_2016 smonth1
        *rename ws12020 emonth1
	ren ws1_2020 emonth1
        *rename ws12024 ersend1
	ren sc1098 ersend1
        *rename ws12026 hrly1
	ren ws1_2026 hrly1
        *rename ws12044 union1
        *rename ws22103 estlemp2
        *rename ws22116 smonth2
	ren ws2_2016 smonth2
        *rename ws22120 emonth2
	ren ws2_2020 emonth2
        *rename ws22124 ersend2
	ren sc1174 ersend2
        *rename ws22126 hrly2
	ren ws2_2026 hrly2
        *rename ws22144 union2
        *rename iws12028 apyrate1
	ren ws1imp05 apyrate1
        *rename iws22128 apyrate2
	ren ws2imp05 apyrate2
        *rename ws1calc apmsum1
	ren ws1cal0 apmsum1
        *rename ws2calc apmsum2
	ren ws2cal0 apmsum2
	*rename wesr1 rwkesr1
	gen rwkesr1 = .
	replace rwkesr1 = wkwjob01 if srefmon == 1
	replace rwkesr1 = wkwjob05 if srefmon == 2
	replace rwkesr1 = wkwjob09 if srefmon == 3
	replace rwkesr1 = wkwjob13 if srefmon == 4
	replace rwkesr1 = wkwjob17 if srefmon == 5
        *rename wesr2 rwkesr2
	gen rwkesr2 = .
	replace rwkesr2 = wkwjob02 if srefmon == 1
	replace rwkesr2 = wkwjob06 if srefmon == 2
	replace rwkesr2 = wkwjob10 if srefmon == 3
	replace rwkesr2 = wkwjob14 if srefmon == 4
	replace rwkesr2 = wkwjob18 if srefmon == 5
	*rename wesr3 rwkesr3
	gen rwkesr3 = .
	replace rwkesr3 = wkwjob03 if srefmon == 1
	replace rwkesr3 = wkwjob07 if srefmon == 2
	replace rwkesr3 = wkwjob11 if srefmon == 3
	replace rwkesr3 = wkwjob15 if srefmon == 4
	*rename wesr4 rwkesr4
	gen rwkesr4 = .
	replace rwkesr4 = wkwjob04 if srefmon == 1
	replace rwkesr4 = wkwjob08 if srefmon == 2
	replace rwkesr4 = wkwjob12 if srefmon == 3
	replace rwkesr4 = wkwjob16 if srefmon == 4
	*rename wesr5 rwkesr5
	gen rwkesr5 = .
	replace rwkesr5 = wkwjob05 if srefmon == 1
	replace rwkesr5 = wkwjob09 if srefmon == 2
	replace rwkesr5 = wkwjob13 if srefmon == 3
	replace rwkesr5 = wkwjob17 if srefmon == 4
	ren pp_intvw intvw
	ren sc1716 njobs
	*ren ws1_2002 tm8214
	*gen tm8218 = smonth1
	*ren tm8262 tm8220
        replace year = year+1900


        drop if m1tst~=3
        drop m1tst m2tst
        compress
        save test, replace
end

capture program drop loop86
program define loop86
        local p = $p
        * Longitudinal data
        * id month L1
	cd "$cleandata"
	*use sipp86l1
        *use id rot occ* ind* age* esr* mthjbw* wksper* jobid* clswk* using sipp90l1, clear
        use id rot ws*_oc* ws*_in* age* esr* wksjb* wksper* ws*_ei* ws*_cl* using sipp86l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix esr_ esr
        renpfix esr0 esr
        renpfix wksjb_0 rmwkwjb
        renpfix wksjb_ rmwkwjb
        renpfix wksper0 wksper
        renpfix ws1_ei0 job1_
        renpfix ws1_ei job1_
        renpfix ws2_ei0 job2_
        renpfix ws2_ei job2_
	*renpfix jobid job1
        renpfix ws1_cl0 class1_
        renpfix ws1_cl class1_
        renpfix ws2_cl0 class2_
        renpfix ws2_cl class2_
        *renpfix clswk class
        renpfix ws1_oc0 occ31
        renpfix ws1_oc occ31
        renpfix ws1_in0 ind31
        renpfix ws1_in ind31
        renpfix ws2_oc0 occ32
        renpfix ws2_oc occ32
        renpfix ws2_in0 ind32
        renpfix ws2_in ind32
        reshape long job1_ job2_ occ31 occ32 ind31 ind32 class1_ class2_ age esr rmwkwjb wksper, i(id) j(mnth)
	
	ren job1_ job1
	ren job2_ job2
	ren class1_ class1
	ren class2_ class2
        
        gen month2 = mnth
        
	cd "$programs"
	do monthwave86.do
        cd "$tempdata"
	
	sort id wave month
        save testm1, replace
        
        * id month L2
	cd "$cleandata"
	* use id rot ernam* wshrs* hrrat* se_am* using sipp90l2, clear
        use id rot ws*_am* w2*24* w2*28* se*_am* using sipp86l1, clear
        cd "$tempdata"
	
	renpfix ws1_am0 earn1
	renpfix ws1_am earn1
	renpfix ws2_am0 earn2
	renpfix ws2_am earn2
        *renpfix ernam10 earn1
        *renpfix ernam20 earn2
        *renpfix ernam earn
	renpfix w2024_0 hours1
	renpfix w2024_ hours1
	renpfix w2124_0 hours2
	renpfix w2124_ hours2
        *renpfix wshrs10 hours1
        *renpfix wshrs20 hours2
        *renpfix wshrs hours
	renpfix w2028_0 rate1
	renpfix w2028_ rate1
	renpfix w2128_0 rate2
	renpfix w2128_ rate2	
        *renpfix hrrat10 rate1
        *renpfix hrrat20 rate2
        *renpfix hrrat rate
        renpfix se1_am0 selfinc1
        renpfix se1_am selfinc1
        renpfix se2_am0 selfinc2
        renpfix se2_am selfinc2
        *renpfix se_am20 se_am2
        *renpfix se_am selfinc


        reshape long earn1 earn2 rate1 rate2 hours1 hours2 selfinc1 selfinc2, i(id) j(mnth)
        gen month2 = mnth
        
	cd "$programs"
	do monthwave86.do
	cd "$tempdata"        
	
	sort id wave month
        save testm2, replace
        
        * Core data     
        local i=1
	cd "$cleandata"
/*
        use $ids month year pp_intvw ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
        */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
        */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
	*/
        use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
        */ ws2_2016 ws2_2020 sc1174 ws2_2026 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
        */ wkwjob* using sipp`p'w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<9 {
		cd "$cleandata"
/*
                use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
                */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
                */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
*/
		capture confirm file "$c`i'.dta"
		if !_rc {
			use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
			*/ ws2_2116 ws2_2120 sc1174 ws2_2126 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
			*/ wkwjob* using sipp`p'w`i', clear
			ren ws2_2116 ws2_2016
			ren ws2_2120 ws2_2020
			ren ws2_2126 ws2_2026
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			}
                local i=`i'+1
		} 

	*gen ws1calc = (ws1cal01==1|ws1cal02==1|ws1cal03==1|ws1cal04==1)
	*gen ws2calc = (ws2cal01==1|ws2cal02==1|ws2cal03==1|ws2cal04==1)
        sort id wave month
	cd "$tempdata"
        save test, replace
        
        use testm2, clear
        merge id wave month using test
        tab _merge
        rename _merge m1tst
        sort id wave month
        merge id wave month using testm1
        tab _merge
        rename _merge m2tst
	
        * Topical module data (append to all observations)
        * Data on start dates
        sort id wave month
        save test, replace
        
	cd "$cleandata"
        use id wave tm8214 tm8218 tm8220 using sipp86rt2, clear
        *use id wave month ws1_2002 ws2_2002 using sipp86w3, clear
	cd "$tempdata"
        sort id wave
        merge id wave using test
        tab _merge
	drop _merge
	sort id wave month
        save test, replace
	cd "$cleandata"
        use id wave tm8262 using sipp86rt2, clear
	cd "$tempdata"
        sort id wave
        merge id wave using test
        tab _merge
        rename _merge mtm
        save test, replace
        
        * give uniform names, as necessary
        *rename ws12003 estlemp1
        *rename ws12016 smonth1
	ren ws1_2016 smonth1
        *rename ws12020 emonth1
	ren ws1_2020 emonth1
        *rename ws12024 ersend1
	ren sc1098 ersend1
        *rename ws12026 hrly1
	ren ws1_2026 hrly1
        *rename ws12044 union1
        *rename ws22103 estlemp2
        *rename ws22116 smonth2
	ren ws2_2016 smonth2
        *rename ws22120 emonth2
	ren ws2_2020 emonth2
        *rename ws22124 ersend2
	ren sc1174 ersend2
        *rename ws22126 hrly2
	ren ws2_2026 hrly2
        *rename ws22144 union2
        *rename iws12028 apyrate1
	ren ws1imp05 apyrate1
        *rename iws22128 apyrate2
	ren ws2imp05 apyrate2
        *rename ws1calc apmsum1
	ren ws1cal0 apmsum1
        *rename ws2calc apmsum2
	ren ws2cal0 apmsum2
	*rename wesr1 rwkesr1
	gen rwkesr1 = .
	replace rwkesr1 = wkwjob01 if srefmon == 1
	replace rwkesr1 = wkwjob05 if srefmon == 2
	replace rwkesr1 = wkwjob09 if srefmon == 3
	replace rwkesr1 = wkwjob13 if srefmon == 4
	replace rwkesr1 = wkwjob17 if srefmon == 5
        *rename wesr2 rwkesr2
	gen rwkesr2 = .
	replace rwkesr2 = wkwjob02 if srefmon == 1
	replace rwkesr2 = wkwjob06 if srefmon == 2
	replace rwkesr2 = wkwjob10 if srefmon == 3
	replace rwkesr2 = wkwjob14 if srefmon == 4
	replace rwkesr2 = wkwjob18 if srefmon == 5
	*rename wesr3 rwkesr3
	gen rwkesr3 = .
	replace rwkesr3 = wkwjob03 if srefmon == 1
	replace rwkesr3 = wkwjob07 if srefmon == 2
	replace rwkesr3 = wkwjob11 if srefmon == 3
	replace rwkesr3 = wkwjob15 if srefmon == 4
	*rename wesr4 rwkesr4
	gen rwkesr4 = .
	replace rwkesr4 = wkwjob04 if srefmon == 1
	replace rwkesr4 = wkwjob08 if srefmon == 2
	replace rwkesr4 = wkwjob12 if srefmon == 3
	replace rwkesr4 = wkwjob16 if srefmon == 4
	*rename wesr5 rwkesr5
	gen rwkesr5 = .
	replace rwkesr5 = wkwjob05 if srefmon == 1
	replace rwkesr5 = wkwjob09 if srefmon == 2
	replace rwkesr5 = wkwjob13 if srefmon == 3
	replace rwkesr5 = wkwjob17 if srefmon == 4
	ren pp_intvw intvw
	ren sc1716 njobs
	*ren ws1_2002 tm8214
	*gen tm8218 = smonth1
	*ren tm8262 tm8220
        replace year = year+1900


        drop if m1tst~=3
        drop m1tst m2tst
        compress
        save test, replace
end

capture program drop loop85
program define loop85
        local p = $p
        * Longitudinal data
        * id month L1
	cd "$cleandata"
	*use sipp85l1
        *use id rot occ* ind* age* esr* mthjbw* wksper* jobid* clswk* using sipp90l1, clear
        use id rot ws*_oc* ws*_in* age* esr* mthjbw* wksper* ws*_ei* ws*_cl* using sipp85l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix esr_ esr
        renpfix esr0 esr
        renpfix mthjbw0 rmwkwjb
        renpfix mthjbw rmwkwjb
        renpfix wksper0 wksper
        renpfix ws1_ei0 job1_
        renpfix ws1_ei job1_
        renpfix ws2_ei0 job2_
        renpfix ws2_ei job2_
	*renpfix jobid job1
        renpfix ws1_cl0 class1_
        renpfix ws1_cl class1_
        renpfix ws2_cl0 class2_
        renpfix ws2_cl class2_
        *renpfix clswk class
        renpfix ws1_oc0 occ31
        renpfix ws1_oc occ31
        renpfix ws1_in0 ind31
        renpfix ws1_in ind31
        renpfix ws2_oc0 occ32
        renpfix ws2_oc occ32
        renpfix ws2_in0 ind32
        renpfix ws2_in ind32
        reshape long job1_ job2_ occ31 occ32 ind31 ind32 class1_ class2_ age esr rmwkwjb wksper, i(id) j(mnth)
	
	ren job1_ job1
	ren job2_ job2
	ren class1_ class1
	ren class2_ class2
        
        gen month2 = mnth
        
	cd "$programs"
	do monthwave85.do
        cd "$tempdata"
	
	sort id wave month
        save testm1, replace
        
        * id month L2
	cd "$cleandata"
	* use id rot ernam* wshrs* hrrat* se_am* using sipp90l2, clear
        use id rot ws*_am* ws*_hr*  ws*_ra* se*_am* using sipp85l1, clear
        cd "$tempdata"
	
	renpfix ws1_am0 earn1
	renpfix ws1_am earn1
	renpfix ws2_am0 earn2
	renpfix ws2_am earn2
        *renpfix ernam10 earn1
        *renpfix ernam20 earn2
        *renpfix ernam earn
	renpfix ws1_hr0 hours1
	renpfix ws1_hr hours1
	renpfix ws2_hr0 hours2
	renpfix ws2_hr hours2
        *renpfix wshrs10 hours1
        *renpfix wshrs20 hours2
        *renpfix wshrs hours
	renpfix ws1_ra0 rate1
	renpfix ws1_ra rate1
	renpfix ws2_ra0 rate2
	renpfix ws2_ra rate2	
        *renpfix hrrat10 rate1
        *renpfix hrrat20 rate2
        *renpfix hrrat rate
        renpfix se1_am0 selfinc1
        renpfix se1_am selfinc1
        renpfix se2_am0 selfinc2
        renpfix se2_am selfinc2
        *renpfix se_am20 se_am2
        *renpfix se_am selfinc


        reshape long earn1 earn2 rate1 rate2 hours1 hours2 selfinc1 selfinc2, i(id) j(mnth)
        gen month2 = mnth
        
	cd "$programs"
	do monthwave85.do
	cd "$tempdata"        
	
	sort id wave month
        save testm2, replace
        
        * Core data     
        local i=1
	cd "$cleandata"
/*
        use $ids month year pp_intvw ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
        */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
        */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
	*/
        use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
        */ ws2_2016 ws2_2020 sc1174 ws2_2026 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
        */ wkwjob* using sipp`p'w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<8 {
		cd "$cleandata"
/*
                use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
                */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
                */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
*/
		
		capture confirm file "$c`i'.dta"
		if !_rc {
			use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
			*/ ws2_2116 ws2_2120 sc1174 ws2_2126 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
			*/ wkwjob* using sipp`p'w`i', clear
			ren ws2_2116 ws2_2016
			ren ws2_2120 ws2_2020
			ren ws2_2126 ws2_2026
			cd "$tempdata"
			sort $ids
			append using test
			sort $ids
			save test, replace
			}
                local i=`i'+1
		} 
	cd "$cleandata"
/*
                use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
                */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
                */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
*/
		
	capture confirm file "$c`i'.dta"
	if !_rc {
		use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
		*/ ws2_2016 ws2_2020 sc1174 ws2_2026 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
		*/ wkwjob* using sipp`p'w`i', clear
		cd "$tempdata"
		sort $ids
		append using test
		sort $ids
		save test, replace
		} 

	*gen ws1calc = (ws1cal01==1|ws1cal02==1|ws1cal03==1|ws1cal04==1)
	*gen ws2calc = (ws2cal01==1|ws2cal02==1|ws2cal03==1|ws2cal04==1)
        sort id wave month
        save test, replace
        
        use testm1, clear
        merge id wave month using test
        tab _merge
        rename _merge m1tst
        sort id wave month
        merge id wave month using testm2
        tab _merge
        rename _merge m2tst
	
        * Topical module data (append to all observations)
        * Data on start dates
        sort id wave month
        save test, replace
        
	cd "$cleandata"
        *use id wave tm8214 tm8218 tm8220 using sipp85t2, clear
        use id wave month ws1_2002 ws2_2102 using sipp85w3, clear
	ren ws2_2102 ws2_2002
	cd "$tempdata"
        sort id wave month
        merge id wave month using test
        tab _merge
	drop _merge
	sort id wave month
        save test, replace
	cd "$cleandata"
        use id wave tm8262 using sipp85rt3, clear
	cd "$tempdata"
        sort id wave
        merge id wave using test
        tab _merge
        rename _merge mtm
        save test, replace
        
        * give uniform names, as necessary
        *rename ws12003 estlemp1
        *rename ws12016 smonth1
	ren ws1_2016 smonth1
        *rename ws12020 emonth1
	ren ws1_2020 emonth1
        *rename ws12024 ersend1
	ren sc1098 ersend1
        *rename ws12026 hrly1
	ren ws1_2026 hrly1
        *rename ws12044 union1
        *rename ws22103 estlemp2
        *rename ws22116 smonth2
	ren ws2_2016 smonth2
        *rename ws22120 emonth2
	ren ws2_2020 emonth2
        *rename ws22124 ersend2
	ren sc1174 ersend2
        *rename ws22126 hrly2
	ren ws2_2026 hrly2
        *rename ws22144 union2
        *rename iws12028 apyrate1
	ren ws1imp05 apyrate1
        *rename iws22128 apyrate2
	ren ws2imp05 apyrate2
        *rename ws1calc apmsum1
	ren ws1cal0 apmsum1
        *rename ws2calc apmsum2
	ren ws2cal0 apmsum2
	*rename wesr1 rwkesr1
	gen rwkesr1 = .
	replace rwkesr1 = wkwjob01 if srefmon == 1
	replace rwkesr1 = wkwjob05 if srefmon == 2
	replace rwkesr1 = wkwjob09 if srefmon == 3
	replace rwkesr1 = wkwjob13 if srefmon == 4
	replace rwkesr1 = wkwjob17 if srefmon == 5
        *rename wesr2 rwkesr2
	gen rwkesr2 = .
	replace rwkesr2 = wkwjob02 if srefmon == 1
	replace rwkesr2 = wkwjob06 if srefmon == 2
	replace rwkesr2 = wkwjob10 if srefmon == 3
	replace rwkesr2 = wkwjob14 if srefmon == 4
	replace rwkesr2 = wkwjob18 if srefmon == 5
	*rename wesr3 rwkesr3
	gen rwkesr3 = .
	replace rwkesr3 = wkwjob03 if srefmon == 1
	replace rwkesr3 = wkwjob07 if srefmon == 2
	replace rwkesr3 = wkwjob11 if srefmon == 3
	replace rwkesr3 = wkwjob15 if srefmon == 4
	*rename wesr4 rwkesr4
	gen rwkesr4 = .
	replace rwkesr4 = wkwjob04 if srefmon == 1
	replace rwkesr4 = wkwjob08 if srefmon == 2
	replace rwkesr4 = wkwjob12 if srefmon == 3
	replace rwkesr4 = wkwjob16 if srefmon == 4
	*rename wesr5 rwkesr5
	gen rwkesr5 = .
	replace rwkesr5 = wkwjob05 if srefmon == 1
	replace rwkesr5 = wkwjob09 if srefmon == 2
	replace rwkesr5 = wkwjob13 if srefmon == 3
	replace rwkesr5 = wkwjob17 if srefmon == 4
	ren pp_intvw intvw
	ren sc1716 njobs
	ren ws1_2002 tm8214
	gen tm8218 = smonth1
	ren tm8262 tm8220
        replace year = year+1900


        drop if m1tst~=3
        drop m1tst m2tst
        compress
        save test, replace
end

capture program drop loop84
program define loop84
        local p = $p
        * Longitudinal data
        * id month L1
	cd "$cleandata"
	*use sipp84l1
        *use id rot occ* ind* age* esr* mthjbw* wksper* jobid* clswk* using sipp90l1, clear
        use id rot ws*_oc* ws*_in* age* esr* wksjb* wksper* jobid* clswk* using sipp84l1, clear
	cd "$tempdata"
        renpfix age_ age
        renpfix age0 age
        renpfix esr_ esr
        renpfix esr0 esr
        renpfix wksjb_0 rmwkwjb
        renpfix wksjb_ rmwkwjb
        renpfix wksper0 wksper
        renpfix jobid10 job1_
        renpfix jobid1 job1_
        renpfix jobid20 job2_
	renpfix jobid2 job2_
	*renpfix jobid job1
	renpfix clswk10 class1_
	renpfix clswk1 class1_
	renpfix clswk20 class2_
	renpfix clswk2 class2_
        *renpfix clswk class
        renpfix ws1_oc0 occ31
        renpfix ws1_oc occ31
        renpfix ws1_in0 ind31
        renpfix ws1_in ind31
        renpfix ws2_oc0 occ32
        renpfix ws2_oc occ32
        renpfix ws2_in0 ind32
        renpfix ws2_in ind32
        reshape long job1_ job2_ occ31 occ32 ind31 ind32 class1_ class2_ age esr rmwkwjb wksper, i(id) j(mnth)
	
	ren job1_ job1
	ren job2_ job2
	ren class1_ class1
	ren class2_ class2
        
        gen month2 = mnth
        
	cd "$programs"
	do monthwave84.do
        cd "$tempdata"
	
	sort id wave month
        save testm1, replace
        
        * id month L2
	cd "$cleandata"
	* use id rot ernam* wshrs* hrrat* se_am* using sipp90l2, clear
        use id rot ws*_am* w2*24* w2*28* se*_am* using sipp84l1, clear
        cd "$tempdata"
	
	renpfix ws1_am0 earn1
	renpfix ws1_am earn1
	renpfix ws2_am0 earn2
	renpfix ws2_am earn2
        *renpfix ernam10 earn1
        *renpfix ernam20 earn2
        *renpfix ernam earn
	renpfix w2024_0 hours1
	renpfix w2024_ hours1
	renpfix w2124_0 hours2
	renpfix w2124_ hours2
        *renpfix wshrs10 hours1
        *renpfix wshrs20 hours2
        *renpfix wshrs hours
	renpfix w2028_0 rate1
	renpfix w2028_ rate1
	renpfix w2128_0 rate2
	renpfix w2128_ rate2	
        *renpfix hrrat10 rate1
        *renpfix hrrat20 rate2
        *renpfix hrrat rate
        renpfix se1_am0 selfinc1
        renpfix se1_am selfinc1
        renpfix se2_am0 selfinc2
        renpfix se2_am selfinc2
        *renpfix se_am20 se_am2
        *renpfix se_am selfinc


        reshape long earn1 earn2 rate1 rate2 hours1 hours2 selfinc1 selfinc2, i(id) j(mnth)
        gen month2 = mnth
        
	cd "$programs"
	do monthwave84.do
	cd "$tempdata"        
	
	sort id wave month
        save testm2, replace
        
        * Core data     
        local i=1
	cd "$cleandata"
/*
        use $ids month year pp_intvw ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
        */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
        */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
	*/
        use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
        */ ws2_2016 ws2_2020 sc1174 ws2_2026 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
        */ wkwjob* using sipp`p'w`i', clear
	cd "$tempdata"
        sort $ids
        save test, replace
        local i=`i'+1
        while `i'>=2 & `i'<9 {
		cd "$cleandata"
/*
                use $ids month year njobs ws12003 ws12016 ws12020 ws12024 ws12026 ws12044 /*
                */ ws22103 ws22116 ws22120 ws22124 ws22126 ws22144 ws1calc ws2calc iws12028 iws22128 /*
                */ wesr1 wesr2 wesr3 wesr4 wesr5 using sipp`p'w`i', clear
*/
                use $ids month year sc1716 pp_intvw ws1_2016 ws1_2020 sc1098 ws1_2026 /*
                */ ws2_2016 ws2_2020 sc1174 ws2_2026 ws1cal* ws2cal* ws1imp05 ws2imp05 /*
                */ wkwjob* using sipp`p'w`i', clear
		cd "$tempdata"
                sort $ids
                append using test
                sort $ids
                save test, replace
                local i=`i'+1
		} 


	*gen ws1calc = (ws1cal01==1|ws1cal02==1|ws1cal03==1|ws1cal04==1)
	*gen ws2calc = (ws2cal01==1|ws2cal02==1|ws2cal03==1|ws2cal04==1)
        sort id wave month
        save test, replace
        
        use testm1, clear
        merge id wave month using test
        tab _merge
        rename _merge m1tst
        sort id wave month
        merge id wave month using testm2
        tab _merge
        rename _merge m2tst
	
        * Topical module data (append to all observations)
        * Data on start dates
        sort id wave month
        save test, replace
        
	cd "$cleandata"
        *use id wave tm8214 tm8218 tm8220 using sipp84t2, clear
        use id wave month ws1_2002 ws2_2002 using sipp84w3, clear
	cd "$tempdata"
        sort id wave month
        merge id wave month using test
        tab _merge
	drop _merge
	sort id wave month
        save test, replace
	cd "$cleandata"
        use id wave tm8262 using sipp84rt3, clear
	cd "$tempdata"
        sort id wave
        merge id wave using test
        tab _merge
        rename _merge mtm
        save test, replace
        
        * give uniform names, as necessary
        *rename ws12003 estlemp1
        *rename ws12016 smonth1
	ren ws1_2016 smonth1
        *rename ws12020 emonth1
	ren ws1_2020 emonth1
        *rename ws12024 ersend1
	ren sc1098 ersend1
        *rename ws12026 hrly1
	ren ws1_2026 hrly1
        *rename ws12044 union1
        *rename ws22103 estlemp2
        *rename ws22116 smonth2
	ren ws2_2016 smonth2
        *rename ws22120 emonth2
	ren ws2_2020 emonth2
        *rename ws22124 ersend2
	ren sc1174 ersend2
        *rename ws22126 hrly2
	ren ws2_2026 hrly2
        *rename ws22144 union2
        *rename iws12028 apyrate1
	ren ws1imp05 apyrate1
        *rename iws22128 apyrate2
	ren ws2imp05 apyrate2
        *rename ws1calc apmsum1
	ren ws1cal0 apmsum1
        *rename ws2calc apmsum2
	ren ws2cal0 apmsum2
	*rename wesr1 rwkesr1
	gen rwkesr1 = .
	replace rwkesr1 = wkwjob01 if srefmon == 1
	replace rwkesr1 = wkwjob05 if srefmon == 2
	replace rwkesr1 = wkwjob09 if srefmon == 3
	replace rwkesr1 = wkwjob13 if srefmon == 4
	replace rwkesr1 = wkwjob17 if srefmon == 5
        *rename wesr2 rwkesr2
	gen rwkesr2 = .
	replace rwkesr2 = wkwjob02 if srefmon == 1
	replace rwkesr2 = wkwjob06 if srefmon == 2
	replace rwkesr2 = wkwjob10 if srefmon == 3
	replace rwkesr2 = wkwjob14 if srefmon == 4
	replace rwkesr2 = wkwjob18 if srefmon == 5
	*rename wesr3 rwkesr3
	gen rwkesr3 = .
	replace rwkesr3 = wkwjob03 if srefmon == 1
	replace rwkesr3 = wkwjob07 if srefmon == 2
	replace rwkesr3 = wkwjob11 if srefmon == 3
	replace rwkesr3 = wkwjob15 if srefmon == 4
	*rename wesr4 rwkesr4
	gen rwkesr4 = .
	replace rwkesr4 = wkwjob04 if srefmon == 1
	replace rwkesr4 = wkwjob08 if srefmon == 2
	replace rwkesr4 = wkwjob12 if srefmon == 3
	replace rwkesr4 = wkwjob16 if srefmon == 4
	*rename wesr5 rwkesr5
	gen rwkesr5 = .
	replace rwkesr5 = wkwjob05 if srefmon == 1
	replace rwkesr5 = wkwjob09 if srefmon == 2
	replace rwkesr5 = wkwjob13 if srefmon == 3
	replace rwkesr5 = wkwjob17 if srefmon == 4
	ren pp_intvw intvw
	ren sc1716 njobs
	ren ws1_2002 tm8214
	gen tm8218 = smonth1
	ren tm8262 tm8220
        replace year = year+1900


        drop if m1tst~=3
        drop m1tst m2tst
        compress
        save test, replace
end

loop$p
compress
