
/* Please do not attempt to run this program without reading the accompanying documentation*/

version 8.0
set more off
prog drop _all
capture log close
clear

cd "$log"
log using set_g$p.log, replace
cd "$tempdata"

/*
File: pull k (surveyed wealth).do
Date: Oct. 2018
Desc: Pull-file to create Set K Wealth
Note: See acknowledgements and copyright notice in new_master.do.
*/

/*

This program is to be run embedded within new_master.do.

The programs below pull the variables necessary for Set A from the 
SIPP Longitudinal, Core, and Topical Modules and merge them into 
one dataset that is by person-month.

Note that we delete any individual who appears in a Core or Topical 
Module file, but who is not on the Longitudinal file, as recommended by 
U.S. Census Bureau staff.
	
For the 1990-1993 panels, in order to reshape the Longitudinal 
files by person-month, we need to do three separate steps. 
(1) Pull all Longitudinal vars that appear once per panel and 
create a dataset that is by <id>.
(2) Pull all Longitudinal vars that appear once per wave and 
create a dataset that is by <id wave>.
(3) Pull all Longitudinal vars that appear once per month and 
create a dataset that is by <id mnth>. Generate calendar month
and wave from the month counter in this file. (The variable 
<mnth> goes from 1 to 36 in the 1993 panel and thus must be
converted into calendar months for merging.)
Then, we merge the three files together into one person-month 
file, along with variables from the Core and Topical Module
files.

Note that there is an error in the 1993 panel whereby 
there are individuals in the longitudinal file that show up 
without data. These are deleted. 

*/


* need to pull from each wave and merge


capture program drop loop08
program define loop08

	global gvarlist "$ids rot tage east1* east2* east3* east4* easet* ejnt* tjarnt* eownrnt* toarnt* tmthrnt* trnd* eprop* tothprop* eckjt* tckjtint* eckoast* tckoint* esvjt* tsvjtint* esvoast* tsvoint* emdjt* tmdjtint* emdoast* tmdoint* ecdjt* tcdjtint* ecdoast* tcdoint* ebdjt* tbdjtint* ebdoast* tbdoint* egvjt* tgvjtint* egvoast* tgvoint* emanychk* esanychk* tintinc* tmjntdiv* tmowndiv* emothdiv* tsjntdiv* tsowndiv* esothdiv* tmjadiv* tmownadv* tsjadiv* tdivinc* emrtjnt* emrtown* tmijnt* tmiown* tjaclr* toaclr*"

	forvalues i=1/16 {
		if `i' == 1 use $gvarlist using $c`i', clear
		if `i' > 1 append using $c`i', keep($gvarlist)
	}

	sort id wave rot
	cd "$tempdata"
	save test, replace
	
	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo taljdab taljdal taljdao ealil ealich talicha ealidb ealidl ealido talidab talidal talidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1year ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot rhhstk thhore thhotast thhira thhthrif thhdebt thhscdbt rhhuscbt toaeq tiajta tiaita timja timia tsmjv tsmjmav tsmiv tsmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp08t4
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
        ren rhhstk thhstk
        ren rhhuscbt thhuscbt
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo taljdab taljdal taljdao ealil ealich talicha ealidb ealidl ealido talidab talidal talidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1year ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot thhstk thhore thhotast thhira thhthrif thhdebt thhscdbt thhuscbt toaeq tiajta tiaita timja timia tsmjv tsmjmav tsmiv tsmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp08t7
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo taljdab taljdal taljdao ealil ealich talicha ealidb ealidl ealido talidab talidal talidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1year ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot thhstk thhore thhotast thhira thhthrif thhdebt thhscdbt thhuscbt toaeq tiajta tiaita timja timia tsmjv tsmjmav tsmiv tsmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp08t10
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	rename tage age
	rename east1a usgovbndsyn
	rename east1b irayn
	rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn
	rename ejntrnt jntrntincyn
	rename tjarnt jntrntinc
	rename tjaclr netjntrntinc
	rename eownrnt ownrntincyn
	rename toarnt ownrntinc
	rename toaclr netownrntinc
	rename emrtjnt jntmortyn
	rename emrtown ownmortyn
	rename tmijnt jntmortamt
	rename tmiown ownmortamt
	rename trndup1 ownroyamt
	rename trndup2 ownfinamt
	rename tothprop totothpropinc
	rename eckjt jntchkacctyn
	rename tckjtint jntchkacctamt
	rename eckoast ownchkacctyn
	rename tckoint ownchkacctamt
	rename esvjt jntsavacctyn
	rename tsvjtint jntsavacctamt
	rename esvoast ownsavacctyn
	rename tsvoint ownsavacctamt
	rename emdjt jntmmdacctyn
	rename tmdjtint jntmmdacctamt
	rename emdoast ownmmdacctyn
	rename tmdoint ownmmdacctamt
	rename ecdjt jntcdyn
	rename tcdjtint jntcdamt
	rename ecdoast owncdyn
	rename tcdoint owncdamt
	rename ebdjt jntbndyn
	rename tbdjtint jntbndamt
	rename ebdoast ownbndyn
	rename tbdoint ownbndamt
	rename egvjt jntgovsecyn
	rename tgvjtint jntgovsecamt
	rename egvoast owngovsecyn
	rename tgvoint owngovsecamt
	rename tintinc totintinc
	rename emanychk jntmfdivyn
	rename tmjntdiv jntmfdivamt
	rename tmowndiv ownmfdivamt
	rename emothdiv jntmargdivyn
	rename tmjadiv jntmargdivamt
	rename tmownadv ownmargdivamt
	rename esanychk jntstkdivyn
	rename tsjntdiv jntstkdivamt
	rename tsowndiv ownstkdivamt
	rename esothdiv jntmargstkdivyn
	rename tsjadiv jntmargstkdivamt

	compress
	sort id wave rot
	cd "$tempdata"
	save test, replace
end



capture program drop loop04
program define loop04

	global gvarlist "$ids rot tage east1* east2* east3* east4* easet* ejnt* tjarnt* eownrnt* toarnt* tmthrnt* trnd* eprop* tothprop* eckjt* tckjtint* eckoast* tckoint* esvjt* tsvjtint* esvoast* tsvoint* emdjt* tmdjtint* emdoast* tmdoint* ecdjt* tcdjtint* ecdoast* tcdoint* ebdjt* tbdjtint* ebdoast* tbdoint* egvjt* tgvjtint* egvoast* tgvoint* emanychk* esanychk* tintinc* tmjntdiv* tmowndiv* emothdiv* tsjntdiv* tsowndiv* esothdiv* tmjadiv* tmownadv* tsjadiv* tdivinc* emrtjnt* emrtown* tmijnt* tmiown* tjaclr* toaclr*"

	forvalues i=1/12 {
		if `i' == 1 use $gvarlist using $c`i', clear
		if `i' > 1 append using $c`i', keep($gvarlist)
	}

	sort id wave rot
	cd "$tempdata"
	save test, replace
	
	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo ealjdab ealjdal ealjdao ealil ealich talicha ealidb ealidl ealido ealidab ealidal ealidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1year ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot rhhstk thhore thhotast thhira thhthrif thhdebt thhscdbt rhhuscbt eoaeq tiajta tiaita timja timia esmjv esmjmav esmiv esmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp04t3
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo ealjdab ealjdal ealjdao ealil ealich talicha ealidb ealidl ealido ealidab ealidal ealidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1year ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot rhhstk thhore thhotast thhira thhthrif thhdebt thhscdbt rhhuscbt eoaeq tiajta tiaita timja timia esmjv esmjmav esmiv esmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp04t6
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

** make names consistent with SIPP08 dataset
        ren rhhstk thhstk
        ren rhhuscbt thhuscbt
	rename ealjdab taljdab
	rename ealjdal taljdal
	rename ealjdao taljdao
	rename ealidab talidab
	rename ealidal talidal
	rename ealidao talidao
	rename eoaeq toaeq
	rename esmjv tsmjv
	rename esmjmav tsmjmav
	rename esmiv tsmiv
	rename esmimav tsmimav

	rename tage age
	rename east1a usgovbndsyn
	rename east1b irayn
	rename east1c retyn
	rename east2a intchkactyn
	rename east2b svactyn
	rename east2c mmactyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn
	rename ejntrnt jntrntincyn
	rename tjarnt jntrntinc
	rename tjaclr netjntrntinc
	rename eownrnt ownrntincyn
	rename toarnt ownrntinc
	rename toaclr netownrntinc
	rename emrtjnt jntmortyn
	rename emrtown ownmortyn
	rename tmijnt jntmortamt
	rename tmiown ownmortamt
	rename trndup1 ownroyamt
	rename trndup2 ownfinamt
	rename tothprop totothpropinc
	rename eckjt jntchkacctyn
	rename tckjtint jntchkacctamt
	rename eckoast ownchkacctyn
	rename tckoint ownchkacctamt
	rename esvjt jntsavacctyn
	rename tsvjtint jntsavacctamt
	rename esvoast ownsavacctyn
	rename tsvoint ownsavacctamt
	rename emdjt jntmmdacctyn
	rename tmdjtint jntmmdacctamt
	rename emdoast ownmmdacctyn
	rename tmdoint ownmmdacctamt
	rename ecdjt jntcdyn
	rename tcdjtint jntcdamt
	rename ecdoast owncdyn
	rename tcdoint owncdamt
	rename ebdjt jntbndyn
	rename tbdjtint jntbndamt
	rename ebdoast ownbndyn
	rename tbdoint ownbndamt
	rename egvjt jntgovsecyn
	rename tgvjtint jntgovsecamt
	rename egvoast owngovsecyn
	rename tgvoint owngovsecamt
	rename tintinc totintinc
	rename emanychk jntmfdivyn
	rename tmjntdiv jntmfdivamt
	rename tmowndiv ownmfdivamt
	rename emothdiv jntmargdivyn
	rename tmjadiv jntmargdivamt
	rename tmownadv ownmargdivamt
	rename esanychk jntstkdivyn
	rename tsjntdiv jntstkdivamt
	rename tsowndiv ownstkdivamt
	rename esothdiv jntmargstkdivyn
	rename tsjadiv jntmargstkdivamt

	compress
	sort id wave rot
	cd "$tempdata"
	save test, replace
end

capture program drop loop01
program define loop01
	local i=1
	
	global gvarlist "$ids rot tage east1* east2* east3* east4* easet* ejnt* tjarnt* eownrnt* toarnt* tmthrnt* trnd* eprop* tothprop* eckjt* tckjtint* eckoast* tckoint* esvjt* tsvjtint* esvoast* tsvoint* emdjt* tmdjtint* emdoast* tmdoint* ecdjt* tcdjtint* ecdoast* tcdoint* ebdjt* tbdjtint* ebdoast* tbdoint* egvjt* tgvjtint* egvoast* tgvoint* emanychk* esanychk* tintinc* tmjntdiv* tmowndiv* emothdiv* tsjntdiv* tsowndiv* esothdiv* tmjadiv* tmownadv* tsjadiv* tdivinc* emrtjnt* emrtown* tmijnt* tmiown* tjaclr* toaclr*"

	forvalues i=1/9 {
		if `i' == 1 use $gvarlist using $c`i', clear
		if `i' > 1 append using $c`i', keep($gvarlist)
	}

	sort id wave rot
	cd "$tempdata"
	save test, replace
	
	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo ealjdab ealjdal ealjdao ealil ealich talicha ealidb ealidl ealido ealidab ealidal ealidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1year ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot rhhstk thhore thhotast thhira thhthrif thhdebt thhscdbt rhhuscbt eoaeq tiajta tiaita timja timia esmjv esmjmav esmiv esmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp01t3
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo ealjdab ealjdal ealjdao ealil ealich talicha ealidb ealidl ealido ealidab ealidal ealidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1year ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot rhhstk thhore thhotast thhira thhthrif thhdebt thhscdbt rhhuscbt eoaeq tiajta tiaita timja timia esmjv esmjmav esmiv esmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp01t6
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo ealjdab ealjdal ealjdao ealil ealich talicha ealidb ealidl ealido ealidab ealidal ealidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1year ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot rhhstk thhore thhotast thhira thhthrif thhdebt thhscdbt rhhuscbt eoaeq tiajta tiaita timja timia esmjv esmjmav esmiv esmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp01t9
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

** make names consistent with SIPP08 dataset
        ren rhhstk thhstk
        ren rhhuscbt thhuscbt
	rename ealjdab taljdab
	rename ealjdal taljdal
	rename ealjdao taljdao
	rename ealidab talidab
	rename ealidal talidal
	rename ealidao talidao
	rename eoaeq toaeq
	rename esmjv tsmjv
	rename esmjmav tsmjmav
	rename esmiv tsmiv
	rename esmimav tsmimav

	rename tage age
	rename east1a usgovbndsyn
	rename east1b irayn
	rename east1c retyn
	rename east2a intchkactyn
	rename east2b svactyn
	rename east2c mmactyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn
	rename ejntrnt jntrntincyn
	rename tjarnt jntrntinc
	rename tjaclr netjntrntinc
	rename eownrnt ownrntincyn
	rename toarnt ownrntinc
	rename toaclr netownrntinc
	rename emrtjnt jntmortyn
	rename emrtown ownmortyn
	rename tmijnt jntmortamt
	rename tmiown ownmortamt
	rename trndup1 ownroyamt
	rename trndup2 ownfinamt
	rename tothprop totothpropinc
	rename eckjt jntchkacctyn
	rename tckjtint jntchkacctamt
	rename eckoast ownchkacctyn
	rename tckoint ownchkacctamt
	rename esvjt jntsavacctyn
	rename tsvjtint jntsavacctamt
	rename esvoast ownsavacctyn
	rename tsvoint ownsavacctamt
	rename emdjt jntmmdacctyn
	rename tmdjtint jntmmdacctamt
	rename emdoast ownmmdacctyn
	rename tmdoint ownmmdacctamt
	rename ecdjt jntcdyn
	rename tcdjtint jntcdamt
	rename ecdoast owncdyn
	rename tcdoint owncdamt
	rename ebdjt jntbndyn
	rename tbdjtint jntbndamt
	rename ebdoast ownbndyn
	rename tbdoint ownbndamt
	rename egvjt jntgovsecyn
	rename tgvjtint jntgovsecamt
	rename egvoast owngovsecyn
	rename tgvoint owngovsecamt
	rename tintinc totintinc
	rename emanychk jntmfdivyn
	rename tmjntdiv jntmfdivamt
	rename tmowndiv ownmfdivamt
	rename emothdiv jntmargdivyn
	rename tmjadiv jntmargdivamt
	rename tmownadv ownmargdivamt
	rename esanychk jntstkdivyn
	rename tsjntdiv jntstkdivamt
	rename tsowndiv ownstkdivamt
	rename esothdiv jntmargstkdivyn
	rename tsjadiv jntmargstkdivamt
	
	sort id wave rot
	save test, replace		
end

capture program drop loop96
program define loop96
	local i=1

	use $ids rot tage east1* east2* east3* east4* easet* ejnt* tjarnt* eownrnt* toarnt* tmthrnt* trnd* eprop* tothprop* eckjt* tckjtint* eckoast* tckoint* esvjt* tsvjtint* esvoast* tsvoint* emdjt* tmdjtint* emdoast* tmdoint* ecdjt* tcdjtint* ecdoast* tcdoint* ebdjt* tbdjtint* ebdoast* tbdoint* egvjt* tgvjtint* egvoast* tgvoint* emanychk* esanychk* tintinc* tmjntdiv* tmowndiv* emothdiv* tsjntdiv* tsowndiv* esothdiv* tmjadiv* tmownadv* tsjadiv* tdivinc* emrtjnt* emrtown* tmijnt* tmiown* tjaclr* toaclr* using $f`i', clear
	sort $ids
	save test, replace
	local i = `i'+1
	while `i'>1 & `i'<13 {
		use $ids rot tage east1* east2* east3* east4* easet* ejnt* tjarnt* eownrnt* toarnt* tmthrnt* trnd* eprop* tothprop* eckjt* tckjtint* eckoast* tckoint* esvjt* tsvjtint* esvoast* tsvoint* emdjt* tmdjtint* emdoast* tmdoint* ecdjt* tcdjtint* ecdoast* tcdoint* ebdjt* tbdjtint* ebdoast* tbdoint* egvjt* tgvjtint* egvoast* tgvoint* emanychk* esanychk* tintinc* tmjntdiv* tmowndiv* emothdiv* tsjntdiv* tsowndiv* esothdiv* tmjadiv* tmownadv* tsjadiv* tdivinc* emrtjnt* emrtown* tmijnt* tmiown* tjaclr* toaclr* using $f`i', clear
		sort $ids
		append using test
		sort $ids
		save test, replace
		local i=`i'+1
		}
	* Extract welfare history from topical module 1
	sort id wave rot
	save test, replace
	
	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo ealjdab ealjdal ealjdao ealil ealich talicha ealidb ealidl ealido ealidab ealidal ealidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot rhhstk thhore thhotast thhira thhdebt thhscdbt rhhuscbt eoaeq tiajta tiaita timja timia esmjv esmjmav esmiv esmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp96t3
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo ealjdab ealjdal ealjdao ealil ealich talicha ealidb ealidl ealido ealidab ealidal ealidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot rhhstk thhore thhotast thhira thhdebt thhscdbt rhhuscbt eoaeq tiajta tiaita timja timia esmjv esmjmav esmiv esmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp96t6
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo ealjdab ealjdal ealjdao ealil ealich talicha ealidb ealidl ealido ealidab ealidal ealidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot rhhstk thhore thhotast thhira thhdebt thhscdbt rhhuscbt eoaeq tiajta tiaita timja timia esmjv esmjmav esmiv esmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp96t9
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot ealr ealry talrb ealjch taljcha ealjdb ealjdl ealjdo ealjdab ealjdal ealjdao ealil ealich talicha ealidb ealidl ealido ealidab ealidal ealidao ealli talliv eallie talliev ehreunv ehbuymo ehbuyyr ehmort enummort tmor1pr tmor1amt emor1yr emor1mo emor1int emor1var tpropval tmhval tmhpr thomeamt tothreva eautonum tcarval1 ta1amt thhtnw thhtwlth thhtheq thhvehcl thhbeq thhintbk thhintot rhhstk thhore thhotast thhira thhdebt thhscdbt rhhuscbt eoaeq tiajta tiaita timja timia esmjv esmjmav esmiv esmimav erjnum erjtyp1 trjmv trjpri trimv tripri trtmv trtpri tvbva1 tvbde1 using sipp96t12
	cd "$tempdata"
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

** make names consistent with SIPP08 dataset
        ren rhhstk thhstk
        ren rhhuscbt thhuscbt
	rename ealjdab taljdab
	rename ealjdal taljdal
	rename ealjdao taljdao
	rename ealidab talidab
	rename ealidal talidal
	rename ealidao talidao
	rename eoaeq toaeq
	rename esmjv tsmjv
	rename esmjmav tsmjmav
	rename esmiv tsmiv
	rename esmimav tsmimav
	
	rename tage age
	rename east1a usgovbndsyn
	rename east1b irayn
	rename east1c retyn
	rename east2a intchkactyn
	rename east2b svactyn
	rename east2c mmactyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn
	rename ejntrnt jntrntincyn
	rename tjarnt jntrntinc
	rename tjaclr netjntrntinc
	rename eownrnt ownrntincyn
	rename toarnt ownrntinc
	rename toaclr netownrntinc
	rename emrtjnt jntmortyn
	rename emrtown ownmortyn
	rename tmijnt jntmortamt
	rename tmiown ownmortamt
	rename trndup1 ownroyamt
	rename trndup2 ownfinamt
	rename tothprop totothpropinc
	rename eckjt jntchkacctyn
	rename tckjtint jntchkacctamt
	rename eckoast ownchkacctyn
	rename tckoint ownchkacctamt
	rename esvjt jntsavacctyn
	rename tsvjtint jntsavacctamt
	rename esvoast ownsavacctyn
	rename tsvoint ownsavacctamt
	rename emdjt jntmmdacctyn
	rename tmdjtint jntmmdacctamt
	rename emdoast ownmmdacctyn
	rename tmdoint ownmmdacctamt
	rename ecdjt jntcdyn
	rename tcdjtint jntcdamt
	rename ecdoast owncdyn
	rename tcdoint owncdamt
	rename ebdjt jntbndyn
	rename tbdjtint jntbndamt
	rename ebdoast ownbndyn
	rename tbdoint ownbndamt
	rename egvjt jntgovsecyn
	rename tgvjtint jntgovsecamt
	rename egvoast owngovsecyn
	rename tgvoint owngovsecamt
	rename tintinc totintinc
	rename emanychk jntmfdivyn
	rename tmjntdiv jntmfdivamt
	rename tmowndiv ownmfdivamt
	rename emothdiv jntmargdivyn
	rename tmjadiv jntmargdivamt
	rename tmownadv ownmargdivamt
	rename esanychk jntstkdivyn
	rename tsjntdiv jntstkdivamt
	rename tsowndiv ownstkdivamt
	rename esothdiv jntmargstkdivyn
	rename tsjadiv jntmargstkdivamt
	
	sort id wave rot
	save test, replace		
end


capture program drop loop93
program define loop93
	* Longitudinal data: create two files 1) by id wave; 2) by id wave month
	* id
	cd "$cleandata"
	use id rot g2s* using sipp93l1, clear
	cd "$tempdata"
	sort id rot

	save testi, replace
		

	* id wave
	cd "$cleandata"
	use id rot ast* using sipp93l1, clear
	cd "$tempdata"

	renpfix ast107 east1a
	renpfix ast103 east2a
	renpfix ast100 east2b
	renpfix ast101 east2c
	renpfix ast102 east2d
	renpfix ast104 east3a
	renpfix ast110 east3b
	renpfix ast106 east3c
	renpfix ast105 east3d
	renpfix ast130 east3e
	renpfix ast120 east4a
	renpfix ast140 east4b
	renpfix ast150 east4c
	*renpfix ast107 astyn7_
	
	
	reshape long east1a east2a east2b east2c east2d east3a east3b east3c east3d east3e east4a east4b east4c, i(id) j(wave)

        *gen east3b = east3a

	rename east1a usgovbndsyn
	*rename east1b irayn
	*rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn

	sort id wave
	save testw, replace
	

	*id month
	cd "$cleandata"
	use id rot age* g2a* using sipp93l1, clear
	cd "$tempdata"
	sort id

	renpfix age_ age
	renpfix age0 age
	renpfix g2a1000 astincamt0_
	renpfix g2a100 astincamt0_
	renpfix g2a1040 astincamt4_
	renpfix g2a104 astincamt4_
	renpfix g2a1100 astincamt11_
	renpfix g2a110 astincamt11_
	renpfix g2a1200 astincamt12_
	renpfix g2a120 astincamt12_
	renpfix g2a1300 astincamt13_
	renpfix g2a130 astincamt13_
	renpfix g2a1400 astincamt14_
	renpfix g2a140 astincamt14_
	sort id
	
	save test1, replace


	
	reshape long age astincamt0_ astincamt4_ astincamt11_ astincamt12_ astincamt13_ astincamt14_, i(id) j(mnth)
		
	cd "$programs"
	do monthwave93.do
	cd "$tempdata"

	sort id wave month
	save testm, replace
	
	* Core data
	local i=1
	cd "$cleandata"
        *use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* o4* j4* ram* sc43* sc44* sc45* sc46* sc47* using sipp93w`i', clear
        use $ids month *prop* rj1* ro1* j1* o1* *rent* r105 using sipp93w`i', clear
	cd "$tempdata"
	sort $ids id wave srefmon
        ren prop totownpropinc
        ren hprop totjntpropinc
        gen jntsavacctyn = (rj10003==1)
        gen jntmmdacctyn = (rj10003==1)
        gen jntcdyn = (rj10003==1)
        gen jntchkacctyn = (rj10003==1)
        gen ownsavacctyn = (ro10003==1)
        gen ownmmdacctyn = (ro10003==1)
        gen owncdyn = (ro10003==1)
        gen ownchkacctyn = (ro10003==1)
        gen jntmfacctyn = (rj10407==1)
        gen jntgovsecyn = (rj10407==1)
        gen jntcrpbndsyn = (rj10407==1)
        gen jntothyn = (rj10407==1)
        gen ownmfacctyn = (ro10407==1)
        gen owngovsecyn = (ro10407==1)
        gen owncrpbndsyn = (ro10407==1)
        gen ownothyn = (ro10407==1)
        gen jntstkdivyn = (rj110==1)
        gen ownstkdivyn = (ro110==1)
        gen jntrntincyn = (rj120==1)
        gen ownrntincyn = (ro120==1)
        ren j10003 jntsavacctamt
        ren o10003 ownsavacctamt
        ren r105 jntgovsecamt
        ren j110 jntstkdivamt
        ren o110 ownstkdivamt
        ren ogrent ownrntinc
        ren onrent netownrntinc
        ren jgrent jntrntinc
        ren jnrent netjntrntinc
        ren j130 jntmortamt
        ren o130 ownmortamt
        drop rj1* ro1* j1* o1* *rent*
	save test, replace
	local i=`i'+1
	while `i'>=2 & `i'<10 {
		cd "$cleandata"
            capture confirm file "$c`i'.dta"
		if !_rc {

                    use $ids month *prop* rj1* ro1* j1* o1* *rent* r105 using sipp93w`i', clear
                    cd "$tempdata"
                    sort $ids id wave srefmon
                    ren prop totownpropinc
                    ren hprop totjntpropinc
                    gen jntsavacctyn = (rj10003==1)
                    gen jntmmdacctyn = (rj10003==1)
                    gen jntcdyn = (rj10003==1)
                    gen jntchkacctyn = (rj10003==1)
                    gen ownsavacctyn = (ro10003==1)
                    gen ownmmdacctyn = (ro10003==1)
                    gen owncdyn = (ro10003==1)
                    gen ownchkacctyn = (ro10003==1)
                    gen jntmfacctyn = (rj10407==1)
                    gen jntgovsecyn = (rj10407==1)
                    gen jntcrpbndsyn = (rj10407==1)
                    gen jntothyn = (rj10407==1)
                    gen ownmfacctyn = (ro10407==1)
                    gen owngovsecyn = (ro10407==1)
                    gen owncrpbndsyn = (ro10407==1)
                    gen ownothyn = (ro10407==1)
                    gen jntstkdivyn = (rj110==1)
                    gen ownstkdivyn = (ro110==1)
                    gen jntrntincyn = (rj120==1)
                    gen ownrntincyn = (ro120==1)
                    ren j10003 jntsavacctamt
                    ren o10003 ownsavacctamt
                    ren r105 jntgovsecamt
                    ren j110 jntstkdivamt
                    ren o110 ownstkdivamt
                    ren ogrent ownrntinc
                    ren onrent netownrntinc
                    ren jgrent jntrntinc
                    ren jnrent netjntrntinc
                    ren j130 jntmortamt
                    ren o130 ownmortamt
                    drop rj1* ro1* j1* o1* *rent*
                    append using test
                    sort $ids
                    save test, replace
                    }
		local i=`i'+1
	} 

        cd "$tempdata"
	sort id wave month
	merge id wave month using testm
	tab _merge
	rename _merge m1tst
	
	sort id rot
	merge id rot using testi
	tab _merge
	rename _merge mtst

	sort id wave
	merge id wave using testw
	tab _merge
	rename _merge miw

	sort id wave rot
	save test, replace
	
	*Note:for 1990 panel, tm8078 is in topical module 2 instead of 1 as in panel 92 and 93
	cd "$cleandata"
	use id wave rot sc4314 sc4322 sc4414 sc4422 using sipp93t4
	cd "$tempdata"
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm823_3 is a coding error from my generation code
	use id wave rot tm8204 tm8206 tm8208 tm8232 tm8233 tm8260 tm8262 tm8264 tm8308 tm8310 tm8666 tm8716 tm8730 tm8754 tm8788 tm8790 tm8044 tm8034 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp93t4
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        *gen talicha = .
        *gen ealich = .
        ren tm8233 talicha
        gen ealich = (talicha~=0)
        ren tm8308 ealli
        ren tm8310 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        **ren tm8600 ehbuyyr
        ren tm8666 tothreva
        ren tm8790 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8044 toaeq
        ren tm8034 tsmjv
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
        drop tm*
	sort id wave rot
        merge id wave rot using test
	tab _merge
        drop _merge
        cd "$tempdata"
        sort id wave rot
	save test, replace


	cd "$cleandata"
	use id wave rot hh_mortg hh_theq hh_vehcl hh_beq hh_intbk hh_intot hh_stk hh_ore hh_otast hh_ira hh_twlth hh_scdbt hh_usdbt hh_debt hh_tnw atsum* tm4314 tm4322 tm4414 tm4422 using sipp93t7
	cd "$tempdata"
        ren hh_theq thhtheq
        ren hh_vehcl thhvehcl
        ren hh_beq thhbeq
        ren hh_intbk thhintbk
        ren hh_intot thhintot
        ren hh_stk thhstk
        ren hh_ore thhore
        ren hh_otast thhotast
        ren hh_ira thhira
        gen thhthrif = .
        ren hh_twlth thhtwlth
        ren hh_debt thhdebt
        ren hh_scdbt thhscdbt
        ren hh_usdbt thhuscbt
        ren hh_tnw thhtnw
        ren tm4314 tiajta
        ren tm4322 tiaita
        ren tm4414 timja
        ren tm4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm8200 - tm8232 are joint debt held by household
* tm8234 - tm8256 are individual debt
* non-interest may be coded in hh_asum*
        use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8232 tm8233 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8260 tm8262 tm8264 tm8308 ///
	tm8309 tm8540 tm8542 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8630 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarvl1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp93t7
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8216 ealjdl
        ren tm8218 taljdal
        ren tm8222 taljdao
        ren tm8220 ealjdo
        *gen talicha = .
        *gen ealich = .
        ren tm8233 talicha
        gen ealich = (talicha~=0)
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8240 ealidl
        ren tm8242 talidal
        ren tm8246 talidao
        ren tm8244 ealido
        ren tm8308 ealli
        ren tm8309 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        *ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        *ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarvl1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
	sort id wave rot
	merge id wave rot using test
	tab _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	
	drop if m1tst~=3
	drop m1tst 
	compress
	save test, replace
	erase testm.dta
	*drop tst1
	drop mtst
	drop miw
	
	compress
	sort id wave rot
	drop _merge
	save test, replace
end


	
capture program drop loop92
program define loop92
	* Longitudinal data: create two files 1) by id wave; 2) by id wave month
	* id
	cd "$cleandata"
	use id rot g2s* using sipp92l1, clear
	cd "$tempdata"
	sort id rot

	save testi, replace
		

	* id wave
	cd "$cleandata"
	use id rot ast* using sipp92l1, clear
	cd "$tempdata"
	
	renpfix ast1070 east1a
	renpfix ast107 east1a
	renpfix ast1030 east2a
	renpfix ast103 east2a
	renpfix ast1000 east2b
	renpfix ast100 east2b
	renpfix ast1010 east2c
	renpfix ast101 east2c
	renpfix ast1020 east2d
	renpfix ast102 east2d
	renpfix ast1040 east3a
	renpfix ast104 east3a
	renpfix ast1100 east3b
	renpfix ast110 east3b
	renpfix ast1060 east3c
	renpfix ast106 east3c
	renpfix ast1050 east3d
	renpfix ast105 east3d
	renpfix ast1300 east3e
	renpfix ast130 east3e
	renpfix ast1200 east4a
	renpfix ast120 east4a
	renpfix ast1400 east4b
	renpfix ast140 east4b
	renpfix ast1500 east4c
	renpfix ast150 east4c
	*renpfix ast107 astyn7_
	
	
	reshape long east1a east2a east2b east2c east2d east3a east3b east3c east3d east3e east4a east4b east4c, i(id) j(wave)

        *gen east3b = east3a

	rename east1a usgovbndsyn
	*rename east1b irayn
	*rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn

	sort id wave
	save testw, replace
	

	*id month
	cd "$cleandata"
	use id rot age* g2a* using sipp92l1, clear
	cd "$tempdata"
	sort id

	renpfix age_ age
	renpfix age0 age
	renpfix g2a1000 astincamt0_
	renpfix g2a100 astincamt0_
	renpfix g2a1040 astincamt4_
	renpfix g2a104 astincamt4_
	renpfix g2a1100 astincamt11_
	renpfix g2a110 astincamt11_
	renpfix g2a1200 astincamt12_
	renpfix g2a120 astincamt12_
	renpfix g2a1300 astincamt13_
	renpfix g2a130 astincamt13_
	renpfix g2a1400 astincamt14_
	renpfix g2a140 astincamt14_
	sort id
	
	save test1, replace


	
	reshape long age astincamt0_ astincamt4_ astincamt11_ astincamt12_ astincamt13_ astincamt14_, i(id) j(mnth)
		
	cd "$programs"
	do monthwave92.do
	cd "$tempdata"

	sort id wave month
	save testm, replace
	
	* Core data
	local i=1
	cd "$cleandata"
        *use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* o4* j4* ram* sc43* sc44* sc45* sc46* sc47* using sipp92w`i', clear
        use $ids month *prop* rj1* ro1* j1* o1* *rent* r105 using sipp92w`i', clear
	cd "$tempdata"
	sort $ids id wave srefmon
        ren prop totownpropinc
        ren hprop totjntpropinc
        gen jntsavacctyn = (rj10003==1)
        gen jntmmdacctyn = (rj10003==1)
        gen jntcdyn = (rj10003==1)
        gen jntchkacctyn = (rj10003==1)
        gen ownsavacctyn = (ro10003==1)
        gen ownmmdacctyn = (ro10003==1)
        gen owncdyn = (ro10003==1)
        gen ownchkacctyn = (ro10003==1)
        gen jntmfacctyn = (rj10407==1)
        gen jntgovsecyn = (rj10407==1)
        gen jntcrpbndsyn = (rj10407==1)
        gen jntothyn = (rj10407==1)
        gen ownmfacctyn = (ro10407==1)
        gen owngovsecyn = (ro10407==1)
        gen owncrpbndsyn = (ro10407==1)
        gen ownothyn = (ro10407==1)
        gen jntstkdivyn = (rj110==1)
        gen ownstkdivyn = (ro110==1)
        gen jntrntincyn = (rj120==1)
        gen ownrntincyn = (ro120==1)
        ren j10003 jntsavacctamt
        ren o10003 ownsavacctamt
        ren r105 jntgovsecamt
        ren j110 jntstkdivamt
        ren o110 ownstkdivamt
        ren ogrent ownrntinc
        ren onrent netownrntinc
        ren jgrent jntrntinc
        ren jnrent netjntrntinc
        ren j130 jntmortamt
        ren o130 ownmortamt
        drop rj1* ro1* j1* o1* *rent*
	save test, replace
	local i=`i'+1
	while `i'>=2 & `i'<10 {
		cd "$cleandata"
            capture confirm file "$c`i'.dta"
		if !_rc {

                    use $ids month *prop* rj1* ro1* j1* o1* *rent* r105 using sipp92w`i', clear
                    cd "$tempdata"
                    sort $ids id wave srefmon
                    ren prop totownpropinc
                    ren hprop totjntpropinc
                    gen jntsavacctyn = (rj10003==1)
                    gen jntmmdacctyn = (rj10003==1)
                    gen jntcdyn = (rj10003==1)
                    gen jntchkacctyn = (rj10003==1)
                    gen ownsavacctyn = (ro10003==1)
                    gen ownmmdacctyn = (ro10003==1)
                    gen owncdyn = (ro10003==1)
                    gen ownchkacctyn = (ro10003==1)
                    gen jntmfacctyn = (rj10407==1)
                    gen jntgovsecyn = (rj10407==1)
                    gen jntcrpbndsyn = (rj10407==1)
                    gen jntothyn = (rj10407==1)
                    gen ownmfacctyn = (ro10407==1)
                    gen owngovsecyn = (ro10407==1)
                    gen owncrpbndsyn = (ro10407==1)
                    gen ownothyn = (ro10407==1)
                    gen jntstkdivyn = (rj110==1)
                    gen ownstkdivyn = (ro110==1)
                    gen jntrntincyn = (rj120==1)
                    gen ownrntincyn = (ro120==1)
                    ren j10003 jntsavacctamt
                    ren o10003 ownsavacctamt
                    ren r105 jntgovsecamt
                    ren j110 jntstkdivamt
                    ren o110 ownstkdivamt
                    ren ogrent ownrntinc
                    ren onrent netownrntinc
                    ren jgrent jntrntinc
                    ren jnrent netjntrntinc
                    ren j130 jntmortamt
                    ren o130 ownmortamt
                    drop rj1* ro1* j1* o1* *rent*
                    append using test
                    sort $ids
                    save test, replace
                    }
		local i=`i'+1
	} 

        cd "$tempdata"
	sort id wave month
	merge id wave month using testm
	tab _merge
	rename _merge m1tst
	
	sort id rot
	merge id rot using testi
	tab _merge
	rename _merge mtst

	sort id wave
	merge id wave using testw
	tab _merge
	rename _merge miw

	sort id wave rot
	save test, replace
	
	*Note:for 1990 panel, tm8078 is in topical module 2 instead of 1 as in panel 92 and 93
	cd "$cleandata"
	use id wave rot hh_mortg hh_theq hh_vehcl hh_beq hh_intbk hh_intot hh_stk hh_ore hh_otast hh_ira hh_twlth hh_scdbt hh_usdbt hh_debt hh_tnw atsum* tm4314 tm4322 tm4414 tm4422 using sipp92t4
	cd "$tempdata"
        ren hh_theq thhtheq
        ren hh_vehcl thhvehcl
        ren hh_beq thhbeq
        ren hh_intbk thhintbk
        ren hh_intot thhintot
        ren hh_stk thhstk
        ren hh_ore thhore
        ren hh_otast thhotast
        ren hh_ira thhira
        gen thhthrif = .
        ren hh_twlth thhtwlth
        ren hh_debt thhdebt
        ren hh_scdbt thhscdbt
        ren hh_usdbt thhuscbt
        ren hh_tnw thhtnw
        ren tm4314 tiajta
        ren tm4322 tiaita
        ren tm4414 timja
        ren tm4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm8200 - tm8232 are joint debt held by household
* tm8234 - tm8256 are individual debt
* non-interest may be coded in hh_asum*
        use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8232 tm8233 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8260 tm8262 tm8264 tm8308 ///
	tm8309 tm8540 tm8542 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8630 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarva1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp92t4
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8216 ealjdl
        ren tm8218 taljdal
        ren tm8222 taljdao
        ren tm8220 ealjdo
        *gen talicha = .
        *gen ealich = .
        ren tm8233 talicha
        gen ealich = (talicha~=0)
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8240 ealidl
        ren tm8242 talidal
        ren tm8246 talidao
        ren tm8244 ealido
        ren tm8308 ealli
        ren tm8309 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        *ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        *ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarva1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot sc4314 sc4322 sc4414 sc4422 using sipp92t7
	cd "$tempdata"
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm823_3 is a coding error from my generation code
	use id wave rot tm8204 tm8206 tm8208 tm8232 tm8233 tm8260 tm8262 tm8264 tm8308 tm8310 tm8666 tm8716 tm8730 tm8754 tm8788 tm8790 tm8044 tm8034 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp92t7
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        *gen talicha = .
        *gen ealich = .
        ren tm8233 talicha
        gen ealich = (talicha~=0)
        ren tm8308 ealli
        ren tm8310 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        **ren tm8600 ehbuyyr
        ren tm8666 tothreva
        ren tm8790 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8044 toaeq
        ren tm8034 tsmjv
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
        drop tm*
	sort id wave rot
        merge id wave rot using test
	tab _merge
        cd "$tempdata"
        sort id wave rot
	save test, replace
	
	drop if m1tst~=3
	drop m1tst 
	compress
	save test, replace
	erase testm.dta
	*drop tst1
	drop mtst
	drop miw

compress
sort id wave rot
drop _merge
	
save test, replace

end
	

capture program drop loop91
program define loop91
	* Longitudinal data: create two files 1) by id wave; 2) by id wave month
	* id
	cd "$cleandata"
	use id rot g2s* using sipp91l1, clear
	cd "$tempdata"
	sort id rot

	save testi, replace
		

	* id wave
	cd "$cleandata"
	use id rot ast* using sipp91l1, clear
	cd "$tempdata"

	renpfix ast107 east1a
	renpfix ast103 east2a
	renpfix ast100 east2b
	renpfix ast101 east2c
	renpfix ast102 east2d
	renpfix ast104 east3a
	renpfix ast110 east3b
	renpfix ast106 east3c
	renpfix ast105 east3d
	renpfix ast130 east3e
	renpfix ast120 east4a
	renpfix ast140 east4b
	renpfix ast150 east4c
	*renpfix ast107 astyn7_
	
	
	reshape long east1a east2a east2b east2c east2d east3a east3b east3c east3d east3e east4a east4b east4c, i(id) j(wave)

        *gen east3b = east3a

	rename east1a usgovbndsyn
	*rename east1b irayn
	*rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn

	sort id wave
	save testw, replace
	

	*id month
	cd "$cleandata"
	use id rot age* g2a* using sipp91l1, clear
	cd "$tempdata"
	sort id

	renpfix age_ age
	renpfix age0 age
	renpfix g2a1000 astincamt0_
	renpfix g2a100 astincamt0_
	renpfix g2a1040 astincamt4_
	renpfix g2a104 astincamt4_
	renpfix g2a1100 astincamt11_
	renpfix g2a110 astincamt11_
	renpfix g2a1200 astincamt12_
	renpfix g2a120 astincamt12_
	renpfix g2a1300 astincamt13_
	renpfix g2a130 astincamt13_
	renpfix g2a1400 astincamt14_
	renpfix g2a140 astincamt14_
	sort id
	
	save test1, replace


	
	reshape long age astincamt0_ astincamt4_ astincamt11_ astincamt12_ astincamt13_ astincamt14_, i(id) j(mnth)
		
	cd "$programs"
	do monthwave91.do
	cd "$tempdata"

	sort id wave month
	save testm, replace
	
	* Core data
	local i=1
	cd "$cleandata"
        *use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* o4* j4* ram* sc43* sc44* sc45* sc46* sc47* using sipp91w`i', clear
        use $ids month *prop* rj1* ro1* j1* o1* *rent* r105 using sipp91w`i', clear
	cd "$tempdata"
	sort $ids id wave srefmon
        ren prop totownpropinc
        ren hprop totjntpropinc
        gen jntsavacctyn = (rj10003==1)
        gen jntmmdacctyn = (rj10003==1)
        gen jntcdyn = (rj10003==1)
        gen jntchkacctyn = (rj10003==1)
        gen ownsavacctyn = (ro10003==1)
        gen ownmmdacctyn = (ro10003==1)
        gen owncdyn = (ro10003==1)
        gen ownchkacctyn = (ro10003==1)
        gen jntmfacctyn = (rj10407==1)
        gen jntgovsecyn = (rj10407==1)
        gen jntcrpbndsyn = (rj10407==1)
        gen jntothyn = (rj10407==1)
        gen ownmfacctyn = (ro10407==1)
        gen owngovsecyn = (ro10407==1)
        gen owncrpbndsyn = (ro10407==1)
        gen ownothyn = (ro10407==1)
        gen jntstkdivyn = (rj110==1)
        gen ownstkdivyn = (ro110==1)
        gen jntrntincyn = (rj120==1)
        gen ownrntincyn = (ro120==1)
        ren j10003 jntsavacctamt
        ren o10003 ownsavacctamt
        ren r105 jntgovsecamt
        ren j110 jntstkdivamt
        ren o110 ownstkdivamt
        ren ogrent ownrntinc
        ren onrent netownrntinc
        ren jgrent jntrntinc
        ren jnrent netjntrntinc
        ren j130 jntmortamt
        ren o130 ownmortamt
        drop rj1* ro1* j1* o1* *rent*
	save test, replace
	local i=`i'+1
	while `i'>=2 & `i'<10 {
		cd "$cleandata"
            capture confirm file "$c`i'.dta"
		if !_rc {

                    use $ids month *prop* rj1* ro1* j1* o1* *rent* r105 using sipp91w`i', clear
                    cd "$tempdata"
                    sort $ids id wave srefmon
                    ren prop totownpropinc
                    ren hprop totjntpropinc
                    gen jntsavacctyn = (rj10003==1)
                    gen jntmmdacctyn = (rj10003==1)
                    gen jntcdyn = (rj10003==1)
                    gen jntchkacctyn = (rj10003==1)
                    gen ownsavacctyn = (ro10003==1)
                    gen ownmmdacctyn = (ro10003==1)
                    gen owncdyn = (ro10003==1)
                    gen ownchkacctyn = (ro10003==1)
                    gen jntmfacctyn = (rj10407==1)
                    gen jntgovsecyn = (rj10407==1)
                    gen jntcrpbndsyn = (rj10407==1)
                    gen jntothyn = (rj10407==1)
                    gen ownmfacctyn = (ro10407==1)
                    gen owngovsecyn = (ro10407==1)
                    gen owncrpbndsyn = (ro10407==1)
                    gen ownothyn = (ro10407==1)
                    gen jntstkdivyn = (rj110==1)
                    gen ownstkdivyn = (ro110==1)
                    gen jntrntincyn = (rj120==1)
                    gen ownrntincyn = (ro120==1)
                    ren j10003 jntsavacctamt
                    ren o10003 ownsavacctamt
                    ren r105 jntgovsecamt
                    ren j110 jntstkdivamt
                    ren o110 ownstkdivamt
                    ren ogrent ownrntinc
                    ren onrent netownrntinc
                    ren jgrent jntrntinc
                    ren jnrent netjntrntinc
                    ren j130 jntmortamt
                    ren o130 ownmortamt
                    drop rj1* ro1* j1* o1* *rent*
                    append using test
                    sort $ids
                    save test, replace
                    }
		local i=`i'+1
	} 

        cd "$tempdata"
	sort id wave month
	merge id wave month using testm
	tab _merge
	rename _merge m1tst
	
	sort id rot
	merge id rot using testi
	tab _merge
	rename _merge mtst

	sort id wave
	merge id wave using testw
	tab _merge
	rename _merge miw

	sort id wave rot
	save test, replace
	
	cd "$cleandata"
	use id wave rot sc4314 sc4322 sc4414 sc4422 using sipp91t4
	cd "$tempdata"
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm823_3 is a coding error from my generation code
	use id wave rot tm8204 tm8206 tm8208 tm8232 tm8233 tm8260 tm8262 tm8264 tm8308 tm8310 tm8666 tm8716 tm8730 tm8754 tm8788 tm8790 tm8044 tm8034 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp91t4
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        *gen talicha = .
        *gen ealich = .
        ren tm8233 talicha
        gen ealich = (talicha~=0)
        ren tm8308 ealli
        ren tm8310 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        **ren tm8600 ehbuyyr
        ren tm8666 tothreva
        ren tm8790 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8044 toaeq
        ren tm8034 tsmjv
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
        drop tm*
	sort id wave rot
        merge id wave rot using test
	tab _merge
	drop _merge
        cd "$tempdata"
        sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot hh_mortg hh_theq hh_vehcl hh_beq hh_intbk hh_intot hh_stk hh_ore hh_otast hh_ira hh_twlth hh_scdbt hh_usdbt hh_debt hh_tnw atsum* tm4314 tm4322 tm4414 tm4422 using sipp91t7
	cd "$tempdata"
        ren hh_theq thhtheq
        ren hh_vehcl thhvehcl
        ren hh_beq thhbeq
        ren hh_intbk thhintbk
        ren hh_intot thhintot
        ren hh_stk thhstk
        ren hh_ore thhore
        ren hh_otast thhotast
        ren hh_ira thhira
        gen thhthrif = .
        ren hh_twlth thhtwlth
        ren hh_debt thhdebt
        ren hh_scdbt thhscdbt
        ren hh_usdbt thhuscbt
        ren hh_tnw thhtnw
        ren tm4314 tiajta
        ren tm4322 tiaita
        ren tm4414 timja
        ren tm4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm823_3 is a coding error from my generation code
	use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8232 tm8233 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8260 tm8262 tm8264 tm8308 ///
	tm8309 tm8540 tm8542 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8630 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarvl1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp91t7
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8216 ealjdl
        ren tm8218 taljdal
        ren tm8222 taljdao
        ren tm8220 ealjdo
        *gen talicha = .
        *gen ealich = .
        ren tm8233 talicha
        gen ealich = (talicha~=0)
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8240 ealidl
        ren tm8242 talidal
        ren tm8246 talidao
        ren tm8244 ealido
        ren tm8308 ealli
        ren tm8309 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        **ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        *ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarvl1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
        *ren tm8544 mortpay1
        ren tm8576 mortlen1
        *ren tm8604 housprice
        ren tm8754 veh1debtyn
        ren tm8788 veh1val
        *ren tm8602 housbuildyr
        drop tm*
	sort id wave rot
	merge id wave rot using test
	tab _merge
        cd "$tempdata"
        sort id wave rot
	save test, replace
	
	drop if m1tst~=3
	drop m1tst 
	compress
	save test, replace
	erase testm.dta
	*drop tst1
	drop mtst
	drop miw

compress
sort id wave rot
drop _merge
save test, replace
	

end

capture program drop loop90
program define loop90
	* Longitudinal data: create two files 1) by id wave; 2) by id wave month
	* id
	cd "$cleandata"
	use id rot g2s* using sipp90l1, clear
	cd "$tempdata"
	sort id rot

	save testi, replace
		

	* id wave
	cd "$cleandata"
	use id rot ast* using sipp90l1, clear
	cd "$tempdata"

	renpfix ast107 east1a
	renpfix ast103 east2a
	renpfix ast100 east2b
	renpfix ast101 east2c
	renpfix ast102 east2d
	renpfix ast104 east3a
	renpfix ast110 east3b
	renpfix ast106 east3c
	renpfix ast105 east3d
	renpfix ast130 east3e
	renpfix ast120 east4a
	renpfix ast140 east4b
	renpfix ast150 east4c
	*renpfix ast107 astyn7_
	
	
	reshape long east1a east2a east2b east2c east2d east3a east3b east3c east3d east3e east4a east4b east4c, i(id) j(wave)

        *gen east3b = east3a

	rename east1a usgovbndsyn
	*rename east1b irayn
	*rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn

	sort id wave
	save testw, replace
	

	*id month
	cd "$cleandata"
	use id rot age* g2a* using sipp90l1, clear
	cd "$tempdata"
	sort id

	renpfix age_ age
	renpfix age0 age
	renpfix g2a1000 astincamt0_
	renpfix g2a100 astincamt0_
	renpfix g2a1040 astincamt4_
	renpfix g2a104 astincamt4_
	renpfix g2a1100 astincamt11_
	renpfix g2a110 astincamt11_
	renpfix g2a1200 astincamt12_
	renpfix g2a120 astincamt12_
	renpfix g2a1300 astincamt13_
	renpfix g2a130 astincamt13_
	renpfix g2a1400 astincamt14_
	renpfix g2a140 astincamt14_
	sort id
	
	save test1, replace


	
	reshape long age astincamt0_ astincamt4_ astincamt11_ astincamt12_ astincamt13_ astincamt14_, i(id) j(mnth)
		
	cd "$programs"
	do monthwave90.do
	cd "$tempdata"

	sort id wave month
	save testm, replace
	
	* Core data
	local i=1
	cd "$cleandata"
        *use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* o4* j4* ram* sc43* sc44* sc45* sc46* sc47* using sipp90w`i', clear
        use $ids month *prop* rj1* ro1* j1* o1* *rent* r105 using sipp90w`i', clear
	cd "$tempdata"
	sort $ids id wave srefmon
        ren prop totownpropinc
        ren hprop totjntpropinc
        gen jntsavacctyn = (rj10003==1)
        gen jntmmdacctyn = (rj10003==1)
        gen jntcdyn = (rj10003==1)
        gen jntchkacctyn = (rj10003==1)
        gen ownsavacctyn = (ro10003==1)
        gen ownmmdacctyn = (ro10003==1)
        gen owncdyn = (ro10003==1)
        gen ownchkacctyn = (ro10003==1)
        gen jntmfacctyn = (rj10407==1)
        gen jntgovsecyn = (rj10407==1)
        gen jntcrpbndsyn = (rj10407==1)
        gen jntothyn = (rj10407==1)
        gen ownmfacctyn = (ro10407==1)
        gen owngovsecyn = (ro10407==1)
        gen owncrpbndsyn = (ro10407==1)
        gen ownothyn = (ro10407==1)
        gen jntstkdivyn = (rj110==1)
        gen ownstkdivyn = (ro110==1)
        gen jntrntincyn = (rj120==1)
        gen ownrntincyn = (ro120==1)
        ren j10003 jntsavacctamt
        ren o10003 ownsavacctamt
        ren r105 jntgovsecamt
        ren j110 jntstkdivamt
        ren o110 ownstkdivamt
        ren ogrent ownrntinc
        ren onrent netownrntinc
        ren jgrent jntrntinc
        ren jnrent netjntrntinc
        ren j130 jntmortamt
        ren o130 ownmortamt
        drop rj1* ro1* j1* o1* *rent*
	save test, replace
	local i=`i'+1
	while `i'>=2 & `i'<10 {
		cd "$cleandata"
            capture confirm file "$c`i'.dta"
		if !_rc {

                    use $ids month *prop* rj1* ro1* j1* o1* *rent* r105 using sipp90w`i', clear
                    cd "$tempdata"
                    sort $ids id wave srefmon
                    ren prop totownpropinc
                    ren hprop totjntpropinc
                    gen jntsavacctyn = (rj10003==1)
                    gen jntmmdacctyn = (rj10003==1)
                    gen jntcdyn = (rj10003==1)
                    gen jntchkacctyn = (rj10003==1)
                    gen ownsavacctyn = (ro10003==1)
                    gen ownmmdacctyn = (ro10003==1)
                    gen owncdyn = (ro10003==1)
                    gen ownchkacctyn = (ro10003==1)
                    gen jntmfacctyn = (rj10407==1)
                    gen jntgovsecyn = (rj10407==1)
                    gen jntcrpbndsyn = (rj10407==1)
                    gen jntothyn = (rj10407==1)
                    gen ownmfacctyn = (ro10407==1)
                    gen owngovsecyn = (ro10407==1)
                    gen owncrpbndsyn = (ro10407==1)
                    gen ownothyn = (ro10407==1)
                    gen jntstkdivyn = (rj110==1)
                    gen ownstkdivyn = (ro110==1)
                    gen jntrntincyn = (rj120==1)
                    gen ownrntincyn = (ro120==1)
                    ren j10003 jntsavacctamt
                    ren o10003 ownsavacctamt
                    ren r105 jntgovsecamt
                    ren j110 jntstkdivamt
                    ren o110 ownstkdivamt
                    ren ogrent ownrntinc
                    ren onrent netownrntinc
                    ren jgrent jntrntinc
                    ren jnrent netjntrntinc
                    ren j130 jntmortamt
                    ren o130 ownmortamt
                    drop rj1* ro1* j1* o1* *rent*
                    append using test
                    sort $ids
                    save test, replace
                    }
		local i=`i'+1
	} 

        cd "$tempdata"
	sort id wave month
	merge id wave month using testm
	tab _merge
	rename _merge m1tst
	
	sort id rot
	merge id rot using testi
	tab _merge
	rename _merge mtst

	sort id wave
	merge id wave using testw
	tab _merge
	rename _merge miw

	sort id wave rot
	save test, replace
	
	*Note:for 1990 panel, tm8078 is in topical module 2 instead of 1 as in panel 92 and 93
	cd "$cleandata"
	use id wave rot hh_mortg hh_theq hh_vehcl hh_beq hh_intbk hh_intot hh_stk hh_ore hh_otast hh_ira hh_twlth hh_scdbt hh_usdbt hh_debt hh_tnw hh_ats* sc4314 sc4322 sc4414 sc4422 using sipp90t4
	cd "$tempdata"
        ren hh_theq thhtheq
        ren hh_vehcl thhvehcl
        ren hh_beq thhbeq
        ren hh_intbk thhintbk
        ren hh_intot thhintot
        ren hh_stk thhstk
        ren hh_ore thhore
        ren hh_otast thhotast
        ren hh_ira thhira
        gen thhthrif = .
        ren hh_twlth thhtwlth
        ren hh_debt thhdebt
        ren hh_scdbt thhscdbt
        ren hh_usdbt thhuscbt
        ren hh_tnw thhtnw
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm8200 - tm8232 are joint debt held by household
* tm8234 - tm8256 are individual debt
* non-interest may be coded in hh_asum*
        use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8232 tm8233 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8260 tm8262 tm8264 tm8308 ///
	tm8309 tm8540 tm8542 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8630 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarva1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp90t4
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8216 ealjdl
        ren tm8218 taljdal
        ren tm8222 taljdao
        ren tm8220 ealjdo
        *gen talicha = .
        *gen ealich = .
        ren tm8233 talicha
        gen ealich = (talicha~=0)
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8240 ealidl
        ren tm8242 talidal
        ren tm8246 talidao
        ren tm8244 ealido
        ren tm8308 ealli
        ren tm8309 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        *ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        *ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarva1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot sc4314 sc4322 sc4414 sc4422 using sipp90t7
	cd "$tempdata"
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm823_3 is a coding error from my generation code
	use id wave rot tm8204 tm8206 tm8208 tm8232 tm8233 tm8260 tm8262 tm8264 tm8308 tm8310 tm8666 tm8716 tm8730 tm8754 tm8788 tm8790 tm8044 tm8034 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp90t7
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        *gen talicha = .
        *gen ealich = .
        ren tm8233 talicha
        gen ealich = (talicha~=0)
        ren tm8308 ealli
        ren tm8310 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        **ren tm8600 ehbuyyr
        ren tm8666 tothreva
        ren tm8790 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8044 toaeq
        ren tm8034 tsmjv
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
        drop tm*
	sort id wave rot
        merge id wave rot using test
	tab _merge
        cd "$tempdata"
        sort id wave rot
	save test, replace
	
	drop if m1tst~=3
	drop m1tst 
	compress
	save test, replace
	erase testm.dta
	*drop tst1
	drop mtst
	drop miw

compress

drop _merge
sort id wave rot	
save test, replace

end


capture program drop loop89
program define loop89
	* Longitudinal data: create two files 1) by id wave; 2) by id wave month
	* id
	cd "$cleandata"
	use id rot g2s* using sipp89l1, clear
	cd "$tempdata"
	sort id rot

	save testi, replace
		

	* id wave
	cd "$cleandata"
	use id rot ast* using sipp89l1, clear
	cd "$tempdata"

	renpfix ast107 east1a
	renpfix ast103 east2a
	renpfix ast100 east2b
	renpfix ast101 east2c
	renpfix ast102 east2d
	renpfix ast104 east3a
	renpfix ast110 east3b
	renpfix ast106 east3c
	renpfix ast105 east3d
	renpfix ast130 east3e
	renpfix ast120 east4a
	renpfix ast140 east4b
	renpfix ast150 east4c
	*renpfix ast107 astyn7_
	
	
	reshape long east1a east2a east2b east2c east2d east3a east3b east3c east3d east3e east4a east4b east4c, i(id) j(wave)

        *gen east3b = east3a

	rename east1a usgovbndsyn
	*rename east1b irayn
	*rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn

	sort id wave
	save testw, replace
	

	*id month
	cd "$cleandata"
	use id rot age* g2a* using sipp89l1, clear
	cd "$tempdata"
	sort id

	renpfix age_ age
	renpfix age0 age
	renpfix g2a1000 astincamt0_
	renpfix g2a100 astincamt0_
	renpfix g2a1040 astincamt4_
	renpfix g2a104 astincamt4_
	renpfix g2a1100 astincamt11_
	renpfix g2a110 astincamt11_
	renpfix g2a1200 astincamt12_
	renpfix g2a120 astincamt12_
	renpfix g2a1300 astincamt13_
	renpfix g2a130 astincamt13_
	renpfix g2a1400 astincamt14_
	renpfix g2a140 astincamt14_
	sort id
	
	save test1, replace


	
	reshape long age astincamt0_ astincamt4_ astincamt11_ astincamt12_ astincamt13_ astincamt14_, i(id) j(mnth)
		
	cd "$programs"
	do monthwave89.do
	cd "$tempdata"

	sort id wave month
	save testm, replace
	
	* Core data
	local i=1
	cd "$cleandata"
        *use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* o4* j4* ram* sc43* sc44* sc45* sc46* sc47* using sipp89w`i', clear
        use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp89w`i', clear
	cd "$tempdata"
	sort $ids id wave srefmon
        ren pp_prop totownpropinc
        ren h_prop totjntpropinc
        drop sc16*
        gen jntsavacctyn = (j100yn==1)
        gen jntmmdacctyn = (j100yn==1)
        gen jntcdyn = (j100yn==1)
        gen jntchkacctyn = (j100yn==1)
        gen ownsavacctyn = (o100yn==1)
        gen ownmmdacctyn = (o100yn==1)
        gen owncdyn = (o100yn==1)
        gen ownchkacctyn = (o100yn==1)
        gen jntmfacctyn = (j104yn==1)
        gen jntgovsecyn = (j104yn==1)
        gen jntcrpbndsyn = (j104yn==1)
        gen jntothyn = (j104yn==1)
        gen ownmfacctyn = (o104yn==1)
        gen owngovsecyn = (o104yn==1)
        gen owncrpbndsyn = (o104yn==1)
        gen ownothyn = (o104yn==1)
        gen jntstkdivyn = (j110ryn==1)
        gen ownstkdivyn = (o110ryn==1)
        gen jntrntincyn = (j120yn==1)
        gen ownrntincyn = (o120yn==1)
        drop j1* o1*
        ren jmtgnyn jntmortyn
        ren omtgnyn ownmortyn
        ren jmortyn jntpaymortyn
        ren omortyn ownpaymortyn
        *ren jmam130 jntmortamt
        *ren omam130 ownmortamt
        ren sc4312 jntsavacctamt
        ren sc4412 jntgovsecamt
        ren sc4508 jntstkdivamt
        ren sc4604 jntrntinc
        ren sc4606 netjntrntinc
        ren sc4712 jntmortamt
        ren sc4716 ownmortamt
        drop sc4*
	save test, replace
	local i=`i'+1
	while `i'>=2 & `i'<9 {
		cd "$cleandata"
            capture confirm file "$c`i'.dta"
		if !_rc {

                    use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp89w`i', clear
                    cd "$tempdata"
                    sort $ids id wave srefmon
                    ren pp_prop totownpropinc
                    ren h_prop totjntpropinc
                    drop sc16*
                    gen jntsavacctyn = (j100yn==1)
                    gen jntmmdacctyn = (j100yn==1)
                    gen jntcdyn = (j100yn==1)
                    gen jntchkacctyn = (j100yn==1)
                    gen ownsavacctyn = (o100yn==1)
                    gen ownmmdacctyn = (o100yn==1)
                    gen owncdyn = (o100yn==1)
                    gen ownchkacctyn = (o100yn==1)
                    gen jntmfacctyn = (j104yn==1)
                    gen jntgovsecyn = (j104yn==1)
                    gen jntcrpbndsyn = (j104yn==1)
                    gen jntothyn = (j104yn==1)
                    gen ownmfacctyn = (o104yn==1)
                    gen owngovsecyn = (o104yn==1)
                    gen owncrpbndsyn = (o104yn==1)
                    gen ownothyn = (o104yn==1)
                    gen jntstkdivyn = (j110ryn==1)
                    gen ownstkdivyn = (o110ryn==1)
                    gen jntrntincyn = (j120yn==1)
                    gen ownrntincyn = (o120yn==1)
                    drop j1* o1*
                             ren jmtgnyn jntmortyn
                    ren omtgnyn ownmortyn
                    ren jmortyn jntpaymortyn
                    ren omortyn ownpaymortyn
                    *ren jmam130 jntmortamt
                    *ren omam130 ownmortamt
                    ren sc4312 jntsavacctamt
                    ren sc4412 jntgovsecamt
                    ren sc4508 jntstkdivamt
                    ren sc4604 jntrntinc
                    ren sc4606 netjntrntinc
                    ren sc4712 jntmortamt
                    ren sc4716 ownmortamt
                    drop sc4*
                    append using test
                    sort $ids
                    save test, replace
                    }
		local i=`i'+1
	} 

        cd "$tempdata"
	sort id wave month
	merge id wave month using testm
	tab _merge
	rename _merge m1tst
	
	sort id rot
	merge id rot using testi
	tab _merge
	rename _merge mtst

	sort id wave
	merge id wave using testw
	tab _merge
	rename _merge miw
	
	drop if m1tst~=3
	drop m1tst 
	compress
	save test, replace
	erase testm.dta
	*drop tst1
	drop mtst
	drop miw


compress

drop _merge
sort id wave rot	
save test, replace

end

capture program drop loop88
program define loop88
	* Longitudinal data: create two files 1) by id wave; 2) by id wave month
	* id
	cd "$cleandata"
	use id rot g2s* using sipp88l1, clear
	cd "$tempdata"
	sort id rot

	save testi, replace
		

	* id wave
	cd "$cleandata"
	use id rot ast* using sipp88l1, clear
	cd "$tempdata"

	renpfix ast107 east1a
	renpfix ast103 east2a
	renpfix ast100 east2b
	renpfix ast101 east2c
	renpfix ast102 east2d
	renpfix ast104 east3a
	renpfix ast110 east3b
	renpfix ast106 east3c
	renpfix ast105 east3d
	renpfix ast130 east3e
	renpfix ast120 east4a
	renpfix ast140 east4b
	renpfix ast150 east4c
	*renpfix ast107 astyn7_
	
	
	reshape long east1a east2a east2b east2c east2d east3a east3b east3c east3d east3e east4a east4b east4c, i(id) j(wave)

        *gen east3b = east3a

	rename east1a usgovbndsyn
	*rename east1b irayn
	*rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn

	sort id wave
	save testw, replace
	

	*id month
	cd "$cleandata"
	use id rot age* g2a* using sipp88l1, clear
	cd "$tempdata"
	sort id

	renpfix age_ age
	renpfix age0 age
	renpfix g2a1000 astincamt0_
	renpfix g2a100 astincamt0_
	renpfix g2a1040 astincamt4_
	renpfix g2a104 astincamt4_
	renpfix g2a1100 astincamt11_
	renpfix g2a110 astincamt11_
	renpfix g2a1200 astincamt12_
	renpfix g2a120 astincamt12_
	renpfix g2a1300 astincamt13_
	renpfix g2a130 astincamt13_
	renpfix g2a1400 astincamt14_
	renpfix g2a140 astincamt14_
	sort id
	
	save test1, replace


	
	reshape long age astincamt0_ astincamt4_ astincamt11_ astincamt12_ astincamt13_ astincamt14_, i(id) j(mnth)
		
	cd "$programs"
	do monthwave88.do
	cd "$tempdata"

	sort id wave month
	save testm, replace
	
	* Core data
	local i=1
	cd "$cleandata"
        *use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* o4* j4* ram* sc43* sc44* sc45* sc46* sc47* using sipp88w`i', clear
        use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp88w`i', clear
	cd "$tempdata"
	sort $ids id wave srefmon
        ren pp_prop totownpropinc
        ren h_prop totjntpropinc
        drop sc16*
        gen jntsavacctyn = (j100yn==1)
        gen jntmmdacctyn = (j100yn==1)
        gen jntcdyn = (j100yn==1)
        gen jntchkacctyn = (j100yn==1)
        gen ownsavacctyn = (o100yn==1)
        gen ownmmdacctyn = (o100yn==1)
        gen owncdyn = (o100yn==1)
        gen ownchkacctyn = (o100yn==1)
        gen jntmfacctyn = (j104yn==1)
        gen jntgovsecyn = (j104yn==1)
        gen jntcrpbndsyn = (j104yn==1)
        gen jntothyn = (j104yn==1)
        gen ownmfacctyn = (o104yn==1)
        gen owngovsecyn = (o104yn==1)
        gen owncrpbndsyn = (o104yn==1)
        gen ownothyn = (o104yn==1)
        gen jntstkdivyn = (j110ryn==1)
        gen ownstkdivyn = (o110ryn==1)
        gen jntrntincyn = (j120yn==1)
        gen ownrntincyn = (o120yn==1)
        drop j1* o1*
        ren jmtgnyn jntmortyn
        ren omtgnyn ownmortyn
        ren jmortyn jntpaymortyn
        ren omortyn ownpaymortyn
        *ren jmam130 jntmortamt
        *ren omam130 ownmortamt
        ren sc4312 jntsavacctamt
        ren sc4412 jntgovsecamt
        ren sc4508 jntstkdivamt
        ren sc4604 jntrntinc
        ren sc4606 netjntrntinc
        ren sc4712 jntmortamt
        ren sc4716 ownmortamt
        drop sc4*
	save test, replace
	local i=`i'+1
	while `i'>=2 & `i'<9 {
		cd "$cleandata"
            capture confirm file "$c`i'.dta"
		if !_rc {

                    use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp88w`i', clear
                    cd "$tempdata"
                    sort $ids id wave srefmon
                    ren pp_prop totownpropinc
                    ren h_prop totjntpropinc
                    drop sc16*
                    gen jntsavacctyn = (j100yn==1)
                    gen jntmmdacctyn = (j100yn==1)
                    gen jntcdyn = (j100yn==1)
                    gen jntchkacctyn = (j100yn==1)
                    gen ownsavacctyn = (o100yn==1)
                    gen ownmmdacctyn = (o100yn==1)
                    gen owncdyn = (o100yn==1)
                    gen ownchkacctyn = (o100yn==1)
                    gen jntmfacctyn = (j104yn==1)
                    gen jntgovsecyn = (j104yn==1)
                    gen jntcrpbndsyn = (j104yn==1)
                    gen jntothyn = (j104yn==1)
                    gen ownmfacctyn = (o104yn==1)
                    gen owngovsecyn = (o104yn==1)
                    gen owncrpbndsyn = (o104yn==1)
                    gen ownothyn = (o104yn==1)
                    gen jntstkdivyn = (j110ryn==1)
                    gen ownstkdivyn = (o110ryn==1)
                    gen jntrntincyn = (j120yn==1)
                    gen ownrntincyn = (o120yn==1)
                    drop j1* o1*
                             ren jmtgnyn jntmortyn
                    ren omtgnyn ownmortyn
                    ren jmortyn jntpaymortyn
                    ren omortyn ownpaymortyn
                    *ren jmam130 jntmortamt
                    *ren omam130 ownmortamt
                    ren sc4312 jntsavacctamt
                    ren sc4412 jntgovsecamt
                    ren sc4508 jntstkdivamt
                    ren sc4604 jntrntinc
                    ren sc4606 netjntrntinc
                    ren sc4712 jntmortamt
                    ren sc4716 ownmortamt
                    drop sc4*
                    append using test
                    sort $ids
                    save test, replace
                    }
		local i=`i'+1
	} 

        cd "$tempdata"
	sort id wave month
	merge id wave month using testm
	tab _merge
	rename _merge m1tst
	
	sort id rot
	merge id rot using testi
	tab _merge
	rename _merge mtst

	sort id wave
	merge id wave using testw
	tab _merge
	rename _merge miw

	sort id wave rot
	save test, replace
	
	*Note:for 1990 panel, tm8078 is in topical module 2 instead of 1 as in panel 92 and 93
	cd "$cleandata"
	use id wave rot sc4314 sc4322 sc4414 sc4422 using sipp88w4
	cd "$tempdata"
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm823_3 is a coding error from my generation code
	use id wave rot tm8204 tm8206 tm8208 tm8232 tm8233 tm8260 tm8262 tm8264 tm8308 tm8310 tm8666 tm8716 tm8730 tm8754 tm8788 tm8790 tm8044 tm8034 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp88rt4
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        *gen talicha = .
        *gen ealich = .
        ren tm8233 talicha
        gen ealich = (talicha~=0)
        ren tm8308 ealli
        ren tm8310 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        **ren tm8600 ehbuyyr
        ren tm8666 tothreva
        ren tm8790 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8044 toaeq
        ren tm8034 tsmjv
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
        drop tm*
	sort id wave rot
	merge id wave rot using test
	tab _merge
        cd "$tempdata"
        sort id wave rot
	save test, replace

compress

drop _merge
sort id wave rot	
save test, replace

end


capture program drop loop87
program define loop87
	* Longitudinal data: create two files 1) by id wave; 2) by id wave month
	* id
	cd "$cleandata"
	use id rot g2s* using sipp87l1, clear
	cd "$tempdata"
	sort id rot

	save testi, replace
		

	* id wave
	cd "$cleandata"
	use id rot ast* using sipp87l1, clear
	cd "$tempdata"

	renpfix ast107 east1a
	renpfix ast103 east2a
	renpfix ast100 east2b
	renpfix ast101 east2c
	renpfix ast102 east2d
	renpfix ast104 east3a
	renpfix ast110 east3b
	renpfix ast106 east3c
	renpfix ast105 east3d
	renpfix ast130 east3e
	renpfix ast120 east4a
	renpfix ast140 east4b
	renpfix ast150 east4c
	*renpfix ast107 astyn7_
	
	
	reshape long east1a east2a east2b east2c east2d east3a east3b east3c east3d east3e east4a east4b east4c, i(id) j(wave)

        *gen east3b = east3a

	rename east1a usgovbndsyn
	*rename east1b irayn
	*rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn

	sort id wave
	save testw, replace
	

	*id month
	cd "$cleandata"
	use id rot age* g2a* using sipp87l1, clear
	cd "$tempdata"
	sort id

	renpfix age_ age
	renpfix age0 age
	renpfix g2a1000 astincamt0_
	renpfix g2a100 astincamt0_
	renpfix g2a1040 astincamt4_
	renpfix g2a104 astincamt4_
	renpfix g2a1100 astincamt11_
	renpfix g2a110 astincamt11_
	renpfix g2a1200 astincamt12_
	renpfix g2a120 astincamt12_
	renpfix g2a1300 astincamt13_
	renpfix g2a130 astincamt13_
	renpfix g2a1400 astincamt14_
	renpfix g2a140 astincamt14_
	sort id
	
	save test1, replace


	
	reshape long age astincamt0_ astincamt4_ astincamt11_ astincamt12_ astincamt13_ astincamt14_, i(id) j(mnth)
		
	cd "$programs"
	do monthwave87.do
	cd "$tempdata"

	sort id wave month
	save testm, replace
	
	* Core data
	local i=1
	cd "$cleandata"
        *use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* o4* j4* ram* sc43* sc44* sc45* sc46* sc47* using sipp87w`i', clear
        use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp87w`i', clear
	cd "$tempdata"
	sort $ids id wave srefmon
        ren pp_prop totownpropinc
        ren h_prop totjntpropinc
        drop sc16*
        gen jntsavacctyn = (j100yn==1)
        gen jntmmdacctyn = (j100yn==1)
        gen jntcdyn = (j100yn==1)
        gen jntchkacctyn = (j100yn==1)
        gen ownsavacctyn = (o100yn==1)
        gen ownmmdacctyn = (o100yn==1)
        gen owncdyn = (o100yn==1)
        gen ownchkacctyn = (o100yn==1)
        gen jntmfacctyn = (j104yn==1)
        gen jntgovsecyn = (j104yn==1)
        gen jntcrpbndsyn = (j104yn==1)
        gen jntothyn = (j104yn==1)
        gen ownmfacctyn = (o104yn==1)
        gen owngovsecyn = (o104yn==1)
        gen owncrpbndsyn = (o104yn==1)
        gen ownothyn = (o104yn==1)
        gen jntstkdivyn = (j110ryn==1)
        gen ownstkdivyn = (o110ryn==1)
        gen jntrntincyn = (j120yn==1)
        gen ownrntincyn = (o120yn==1)
        drop j1* o1*
        ren jmtgnyn jntmortyn
        ren omtgnyn ownmortyn
        ren jmortyn jntpaymortyn
        ren omortyn ownpaymortyn
        *ren jmam130 jntmortamt
        *ren omam130 ownmortamt
        ren sc4312 jntsavacctamt
        ren sc4412 jntgovsecamt
        ren sc4508 jntstkdivamt
        ren sc4604 jntrntinc
        ren sc4606 netjntrntinc
        ren sc4712 jntmortamt
        ren sc4716 ownmortamt
        drop sc4*
	save test, replace
	local i=`i'+1
	while `i'>=2 & `i'<9 {
		cd "$cleandata"
            capture confirm file "$c`i'.dta"
		if !_rc {

                    use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp87w`i', clear
                    cd "$tempdata"
                    sort $ids id wave srefmon
                    ren pp_prop totownpropinc
                    ren h_prop totjntpropinc
                    drop sc16*
                    gen jntsavacctyn = (j100yn==1)
                    gen jntmmdacctyn = (j100yn==1)
                    gen jntcdyn = (j100yn==1)
                    gen jntchkacctyn = (j100yn==1)
                    gen ownsavacctyn = (o100yn==1)
                    gen ownmmdacctyn = (o100yn==1)
                    gen owncdyn = (o100yn==1)
                    gen ownchkacctyn = (o100yn==1)
                    gen jntmfacctyn = (j104yn==1)
                    gen jntgovsecyn = (j104yn==1)
                    gen jntcrpbndsyn = (j104yn==1)
                    gen jntothyn = (j104yn==1)
                    gen ownmfacctyn = (o104yn==1)
                    gen owngovsecyn = (o104yn==1)
                    gen owncrpbndsyn = (o104yn==1)
                    gen ownothyn = (o104yn==1)
                    gen jntstkdivyn = (j110ryn==1)
                    gen ownstkdivyn = (o110ryn==1)
                    gen jntrntincyn = (j120yn==1)
                    gen ownrntincyn = (o120yn==1)
                    drop j1* o1*
                             ren jmtgnyn jntmortyn
                    ren omtgnyn ownmortyn
                    ren jmortyn jntpaymortyn
                    ren omortyn ownpaymortyn
                    *ren jmam130 jntmortamt
                    *ren omam130 ownmortamt
                    ren sc4312 jntsavacctamt
                    ren sc4412 jntgovsecamt
                    ren sc4508 jntstkdivamt
                    ren sc4604 jntrntinc
                    ren sc4606 netjntrntinc
                    ren sc4712 jntmortamt
                    ren sc4716 ownmortamt
                    drop sc4*
                    append using test
                    sort $ids
                    save test, replace
                    }
		local i=`i'+1
	} 

        cd "$tempdata"
	sort id wave month
	merge id wave month using testm
	tab _merge
	rename _merge m1tst
	
	sort id rot
	merge id rot using testi
	tab _merge
	rename _merge mtst

	sort id wave
	merge id wave using testw
	tab _merge
	rename _merge miw

	sort id wave rot
	save test, replace
	
	*Note:for 1990 panel, tm8078 is in topical module 2 instead of 1 as in panel 92 and 93
	cd "$cleandata"
	use id wave rot hh_mortg hh_theq hh_vehcl hh_beq hh_intbk hh_intot hh_stk hh_ore hh_otast hh_ira hh_twlth hh_scdbt hh_usdbt hh_debt hh_tnw hh_ats* sc4314 sc4322 sc4414 sc4422 using sipp87w4
	cd "$tempdata"
        ren hh_theq thhtheq
        ren hh_vehcl thhvehcl
        ren hh_beq thhbeq
        ren hh_intbk thhintbk
        ren hh_intot thhintot
        ren hh_stk thhstk
        ren hh_ore thhore
        ren hh_otast thhotast
        ren hh_ira thhira
        gen thhthrif = .
        ren hh_twlth thhtwlth
        ren hh_debt thhdebt
        ren hh_scdbt thhscdbt
        ren hh_usdbt thhuscbt
        ren hh_tnw thhtnw
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm8200 - tm8232 are joint debt held by household
* tm8234 - tm8256 are individual debt
* non-interest may be coded in hh_asum*
        use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8232 tm823_3 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8260 tm8262 tm8264 tm8308 ///
	tm8309 tm8540 tm8542 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8630 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarva1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp87rt4
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8216 ealjdl
        ren tm8218 taljdal
        ren tm8222 taljdao
        ren tm8220 ealjdo
        *gen talicha = .
        *gen ealich = .
        ren tm823_3 talicha
        gen ealich = (talicha~=0)
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8240 ealidl
        ren tm8242 talidal
        ren tm8246 talidao
        ren tm8244 ealido
        ren tm8308 ealli
        ren tm8309 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        *ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        *ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarva1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot sc4314 sc4322 sc4414 sc4422 using sipp87w7
	cd "$tempdata"
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm823_3 is a coding error from my generation code
	use id wave rot tm8204 tm8206 tm8208 tm8232 tm8233 tm8260 tm8262 tm8264 tm8308 tm8310 tm8666 tm8716 tm8730 tm8754 tm8788 tm8790 tm8044 tm8034 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp87rt7
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        *gen talicha = .
        *gen ealich = .
        ren tm8233 talicha
        gen ealich = (talicha~=0)
        ren tm8308 ealli
        ren tm8310 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        **ren tm8600 ehbuyyr
        ren tm8666 tothreva
        ren tm8790 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8044 toaeq
        ren tm8034 tsmjv
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
        drop tm*
	sort id wave rot
	merge id wave rot using test
	tab _merge
        cd "$tempdata"
        sort id wave rot
	save test, replace
	
	drop if m1tst~=3
	drop m1tst 
	compress
	save test, replace
	erase testm.dta
	*drop tst1
	drop mtst
	drop miw


compress

drop _merge
sort id wave rot	
save test, replace

end

capture program drop loop86
program define loop86
	* Longitudinal data: create two files 1) by id wave; 2) by id wave month
	* id
	cd "$cleandata"
	use id rot g2s* using sipp86l1, clear
	cd "$tempdata"
	sort id rot

	save testi, replace
		

	* id wave
	cd "$cleandata"
	use id rot ast* using sipp86l1, clear
	cd "$tempdata"

	renpfix ast107 east1a
	renpfix ast103 east2a
	renpfix ast100 east2b
	renpfix ast101 east2c
	renpfix ast102 east2d
	renpfix ast104 east3a
	renpfix ast110 east3b
	renpfix ast106 east3c
	renpfix ast105 east3d
	renpfix ast130 east3e
	renpfix ast120 east4a
	renpfix ast140 east4b
	renpfix ast150 east4c
	*renpfix ast107 astyn7_
	
	
	reshape long east1a east2a east2b east2c east2d east3a east3b east3c east3d east3e east4a east4b east4c, i(id) j(wave)

        *gen east3b = east3a

	rename east1a usgovbndsyn
	*rename east1b irayn
	*rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn

	sort id wave
	save testw, replace
	

	*id month
	cd "$cleandata"
	use id rot age* g2a* using sipp86l1, clear
	cd "$tempdata"
	sort id

	renpfix age_ age
	renpfix age0 age
	renpfix g2a1000 astincamt0_
	renpfix g2a100 astincamt0_
	renpfix g2a1040 astincamt4_
	renpfix g2a104 astincamt4_
	renpfix g2a1100 astincamt11_
	renpfix g2a110 astincamt11_
	renpfix g2a1200 astincamt12_
	renpfix g2a120 astincamt12_
	renpfix g2a1300 astincamt13_
	renpfix g2a130 astincamt13_
	renpfix g2a1400 astincamt14_
	renpfix g2a140 astincamt14_
	sort id
	
	save test1, replace


	
	reshape long age astincamt0_ astincamt4_ astincamt11_ astincamt12_ astincamt13_ astincamt14_, i(id) j(mnth)
		
	cd "$programs"
	do monthwave86.do
	cd "$tempdata"

	sort id wave month
	save testm, replace
	
	* Core data
	local i=1
	cd "$cleandata"
        *use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* o4* j4* ram* sc43* sc44* sc45* sc46* sc47* using sipp86w`i', clear
        use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp86w`i', clear
	cd "$tempdata"
	sort $ids id wave srefmon
        ren pp_prop totownpropinc
        ren h_prop totjntpropinc
        drop sc16*
        gen jntsavacctyn = (j100yn==1)
        gen jntmmdacctyn = (j100yn==1)
        gen jntcdyn = (j100yn==1)
        gen jntchkacctyn = (j100yn==1)
        gen ownsavacctyn = (o100yn==1)
        gen ownmmdacctyn = (o100yn==1)
        gen owncdyn = (o100yn==1)
        gen ownchkacctyn = (o100yn==1)
        gen jntmfacctyn = (j104yn==1)
        gen jntgovsecyn = (j104yn==1)
        gen jntcrpbndsyn = (j104yn==1)
        gen jntothyn = (j104yn==1)
        gen ownmfacctyn = (o104yn==1)
        gen owngovsecyn = (o104yn==1)
        gen owncrpbndsyn = (o104yn==1)
        gen ownothyn = (o104yn==1)
        gen jntstkdivyn = (j110ryn==1)
        gen ownstkdivyn = (o110ryn==1)
        gen jntrntincyn = (j120yn==1)
        gen ownrntincyn = (o120yn==1)
        drop j1* o1*
        ren jmtgnyn jntmortyn
        ren omtgnyn ownmortyn
        ren jmortyn jntpaymortyn
        ren omortyn ownpaymortyn
        *ren jmam130 jntmortamt
        *ren omam130 ownmortamt
        ren sc4312 jntsavacctamt
        ren sc4412 jntgovsecamt
        ren sc4508 jntstkdivamt
        ren sc4604 jntrntinc
        ren sc4606 netjntrntinc
        ren sc4712 jntmortamt
        ren sc4716 ownmortamt
        drop sc4*
	save test, replace
	local i=`i'+1
	while `i'>=2 & `i'<9 {
		cd "$cleandata"
            capture confirm file "$c`i'.dta"
		if !_rc {

                    use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp86w`i', clear
                    cd "$tempdata"
                    sort $ids id wave srefmon
                    ren pp_prop totownpropinc
                    ren h_prop totjntpropinc
                    drop sc16*
                    gen jntsavacctyn = (j100yn==1)
                    gen jntmmdacctyn = (j100yn==1)
                    gen jntcdyn = (j100yn==1)
                    gen jntchkacctyn = (j100yn==1)
                    gen ownsavacctyn = (o100yn==1)
                    gen ownmmdacctyn = (o100yn==1)
                    gen owncdyn = (o100yn==1)
                    gen ownchkacctyn = (o100yn==1)
                    gen jntmfacctyn = (j104yn==1)
                    gen jntgovsecyn = (j104yn==1)
                    gen jntcrpbndsyn = (j104yn==1)
                    gen jntothyn = (j104yn==1)
                    gen ownmfacctyn = (o104yn==1)
                    gen owngovsecyn = (o104yn==1)
                    gen owncrpbndsyn = (o104yn==1)
                    gen ownothyn = (o104yn==1)
                    gen jntstkdivyn = (j110ryn==1)
                    gen ownstkdivyn = (o110ryn==1)
                    gen jntrntincyn = (j120yn==1)
                    gen ownrntincyn = (o120yn==1)
                    drop j1* o1*
                             ren jmtgnyn jntmortyn
                    ren omtgnyn ownmortyn
                    ren jmortyn jntpaymortyn
                    ren omortyn ownpaymortyn
                    *ren jmam130 jntmortamt
                    *ren omam130 ownmortamt
                    ren sc4312 jntsavacctamt
                    ren sc4412 jntgovsecamt
                    ren sc4508 jntstkdivamt
                    ren sc4604 jntrntinc
                    ren sc4606 netjntrntinc
                    ren sc4712 jntmortamt
                    ren sc4716 ownmortamt
                    drop sc4*
                    append using test
                    sort $ids
                    save test, replace
                    }
		local i=`i'+1
	} 

        cd "$tempdata"
	sort id wave month
	merge id wave month using testm
	tab _merge
	rename _merge m1tst
	
	sort id rot
	merge id rot using testi
	tab _merge
	rename _merge mtst

	sort id wave
	merge id wave using testw
	tab _merge
	rename _merge miw

	sort id wave rot
	save test, replace
	
	*Note:for 1990 panel, tm8078 is in topical module 2 instead of 1 as in panel 92 and 93
	cd "$cleandata"
	use id wave rot hh_mortg hh_theq hh_vehcl hh_beq hh_intbk hh_intot hh_stk hh_ore hh_otast hh_ira hh_twlth hh_scdbt hh_usdbt hh_debt hh_tnw hh_ats* sc4314 sc4322 sc4414 sc4422 using sipp86w4
	cd "$tempdata"
        ren hh_theq thhtheq
        ren hh_vehcl thhvehcl
        ren hh_beq thhbeq
        ren hh_intbk thhintbk
        ren hh_intot thhintot
        ren hh_stk thhstk
        ren hh_ore thhore
        ren hh_otast thhotast
        ren hh_ira thhira
        gen thhthrif = .
        ren hh_twlth thhtwlth
        ren hh_debt thhdebt
        ren hh_scdbt thhscdbt
        ren hh_usdbt thhuscbt
        ren hh_tnw thhtnw
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm8200 - tm8232 are joint debt held by household
* tm8234 - tm8256 are individual debt
* non-interest may be coded in hh_asum*
        use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8232 tm823_3 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8260 tm8262 tm8264 tm8308 ///
	tm8309 tm8540 tm8542 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8630 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarva1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp86rt4
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8216 ealjdl
        ren tm8218 taljdal
        ren tm8222 taljdao
        ren tm8220 ealjdo
        *gen talicha = .
        *gen ealich = .
        ren tm823_3 talicha
        gen ealich = (talicha~=0)
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8240 ealidl
        ren tm8242 talidal
        ren tm8246 talidao
        ren tm8244 ealido
        ren tm8308 ealli
        ren tm8309 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        *ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        *ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarva1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot hh_mortg hh_theq hh_vehcl hh_beq hh_intbk hh_intot hh_stk hh_ore hh_otast hh_ira hh_twlth hh_scdbt hh_usdbt hh_debt hh_tnw hh_ats* sc4314 sc4322 sc4414 sc4422 using sipp86w7
	cd "$tempdata"
        ren hh_theq thhtheq
        ren hh_vehcl thhvehcl
        ren hh_beq thhbeq
        ren hh_intbk thhintbk
        ren hh_intot thhintot
        ren hh_stk thhstk
        ren hh_ore thhore
        ren hh_otast thhotast
        ren hh_ira thhira
        gen thhthrif = .
        ren hh_twlth thhtwlth
        ren hh_debt thhdebt
        ren hh_scdbt thhscdbt
        ren hh_usdbt thhuscbt
        ren hh_tnw thhtnw
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm823_3 is a coding error from my generation code
	use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8232 tm823_3 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8260 tm8262 tm8264 tm8308 ///
	tm8309 tm8540 tm8542 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8630 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarva1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp86rt7
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8216 ealjdl
        ren tm8218 taljdal
        ren tm8222 taljdao
        ren tm8220 ealjdo
        *gen talicha = .
        *gen ealich = .
        ren tm823_3 talicha
        gen ealich = (talicha~=0)
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8240 ealidl
        ren tm8242 talidal
        ren tm8246 talidao
        ren tm8244 ealido
        ren tm8308 ealli
        ren tm8309 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        **ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        *ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarva1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
        *ren tm8544 mortpay1
        ren tm8576 mortlen1
        *ren tm8604 housprice
        ren tm8754 veh1debtyn
        ren tm8788 veh1val
        *ren tm8602 housbuildyr
        drop tm*
	sort id wave rot
	merge id wave rot using test
	tab _merge
        cd "$tempdata"
        sort id wave rot
	save test, replace
	
	drop if m1tst~=3
	drop m1tst 
	compress
	save test, replace
	erase testm.dta
	*drop tst1
	drop mtst
	drop miw


compress

drop _merge
sort id wave rot	
save test, replace

end

capture program drop loop85
program define loop85
	* Longitudinal data: create two files 1) by id wave; 2) by id wave month
	* id
	cd "$cleandata"
	use id rot g2s* using sipp85l1, clear
	cd "$tempdata"
	sort id rot

	save testi, replace
		

	* id wave
	cd "$cleandata"
	use id rot ast* using sipp85l1, clear
	cd "$tempdata"

	renpfix ast107 east1a
	renpfix ast103 east2a
	renpfix ast100 east2b
	renpfix ast101 east2c
	renpfix ast102 east2d
	renpfix ast104 east3a
	renpfix ast110 east3b
	renpfix ast106 east3c
	renpfix ast105 east3d
	renpfix ast130 east3e
	renpfix ast120 east4a
	renpfix ast140 east4b
	renpfix ast150 east4c
	*renpfix ast107 astyn7_
	
	
	reshape long east1a east2a east2b east2c east2d east3a east3b east3c east3d east3e east4a east4b east4c, i(id) j(wave)

        *gen east3b = east3a

	rename east1a usgovbndsyn
	*rename east1b irayn
	*rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn

	sort id wave
	save testw, replace
	

	*id month
	cd "$cleandata"
	use id rot age* g2a* using sipp85l1, clear
	cd "$tempdata"
	sort id

	renpfix age_ age
	renpfix age0 age
	renpfix g2a1000 astincamt0_
	renpfix g2a100 astincamt0_
	renpfix g2a1040 astincamt4_
	renpfix g2a104 astincamt4_
	renpfix g2a1100 astincamt11_
	renpfix g2a110 astincamt11_
	renpfix g2a1200 astincamt12_
	renpfix g2a120 astincamt12_
	renpfix g2a1300 astincamt13_
	renpfix g2a130 astincamt13_
	renpfix g2a1400 astincamt14_
	renpfix g2a140 astincamt14_
	sort id
	
	save test1, replace


	
	reshape long age astincamt0_ astincamt4_ astincamt11_ astincamt12_ astincamt13_ astincamt14_, i(id) j(mnth)
		
	cd "$programs"
	do monthwave85.do
	cd "$tempdata"

	sort id wave month
	save testm, replace
	
	* Core data
	local i=1
	cd "$cleandata"
        *use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* o4* j4* ram* sc43* sc44* sc45* sc46* sc47* using sipp85w`i', clear
        use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp85w`i', clear
	cd "$tempdata"
	sort $ids id wave srefmon
        ren pp_prop totownpropinc
        ren h_prop totjntpropinc
        drop sc16*
        gen jntsavacctyn = (j100yn==1)
        gen jntmmdacctyn = (j100yn==1)
        gen jntcdyn = (j100yn==1)
        gen jntchkacctyn = (j100yn==1)
        gen ownsavacctyn = (o100yn==1)
        gen ownmmdacctyn = (o100yn==1)
        gen owncdyn = (o100yn==1)
        gen ownchkacctyn = (o100yn==1)
        gen jntmfacctyn = (j104yn==1)
        gen jntgovsecyn = (j104yn==1)
        gen jntcrpbndsyn = (j104yn==1)
        gen jntothyn = (j104yn==1)
        gen ownmfacctyn = (o104yn==1)
        gen owngovsecyn = (o104yn==1)
        gen owncrpbndsyn = (o104yn==1)
        gen ownothyn = (o104yn==1)
        gen jntstkdivyn = (j110ryn==1)
        gen ownstkdivyn = (o110ryn==1)
        gen jntrntincyn = (j120yn==1)
        gen ownrntincyn = (o120yn==1)
        drop j1* o1*
        ren jmtgnyn jntmortyn
        ren omtgnyn ownmortyn
        ren jmortyn jntpaymortyn
        ren omortyn ownpaymortyn
        *ren jmam130 jntmortamt
        *ren omam130 ownmortamt
        ren sc4312 jntsavacctamt
        ren sc4412 jntgovsecamt
        ren sc4508 jntstkdivamt
        ren sc4604 jntrntinc
        ren sc4606 netjntrntinc
        ren sc4712 jntmortamt
        ren sc4716 ownmortamt
        drop sc4*
	save test, replace
	local i=`i'+1
	while `i'>=2 & `i'<9 {
		cd "$cleandata"
            capture confirm file "$c`i'.dta"
		if !_rc {

                    use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp85w`i', clear
                    cd "$tempdata"
                    sort $ids id wave srefmon
                    ren pp_prop totownpropinc
                    ren h_prop totjntpropinc
                    drop sc16*
                    gen jntsavacctyn = (j100yn==1)
                    gen jntmmdacctyn = (j100yn==1)
                    gen jntcdyn = (j100yn==1)
                    gen jntchkacctyn = (j100yn==1)
                    gen ownsavacctyn = (o100yn==1)
                    gen ownmmdacctyn = (o100yn==1)
                    gen owncdyn = (o100yn==1)
                    gen ownchkacctyn = (o100yn==1)
                    gen jntmfacctyn = (j104yn==1)
                    gen jntgovsecyn = (j104yn==1)
                    gen jntcrpbndsyn = (j104yn==1)
                    gen jntothyn = (j104yn==1)
                    gen ownmfacctyn = (o104yn==1)
                    gen owngovsecyn = (o104yn==1)
                    gen owncrpbndsyn = (o104yn==1)
                    gen ownothyn = (o104yn==1)
                    gen jntstkdivyn = (j110ryn==1)
                    gen ownstkdivyn = (o110ryn==1)
                    gen jntrntincyn = (j120yn==1)
                    gen ownrntincyn = (o120yn==1)
                    drop j1* o1*
                             ren jmtgnyn jntmortyn
                    ren omtgnyn ownmortyn
                    ren jmortyn jntpaymortyn
                    ren omortyn ownpaymortyn
                    *ren jmam130 jntmortamt
                    *ren omam130 ownmortamt
                    ren sc4312 jntsavacctamt
                    ren sc4412 jntgovsecamt
                    ren sc4508 jntstkdivamt
                    ren sc4604 jntrntinc
                    ren sc4606 netjntrntinc
                    ren sc4712 jntmortamt
                    ren sc4716 ownmortamt
                    drop sc4*
                    append using test
                    sort $ids
                    save test, replace
                    }
		local i=`i'+1
	} 

	sort id wave month
	merge id wave month using testm
	tab _merge
	rename _merge m1tst
	
	sort id rot
	merge id rot using testi
	tab _merge
	rename _merge mtst

	sort id wave
	merge id wave using testw
	tab _merge
	rename _merge miw

	sort id wave rot
	save test, replace
	
	*Note:for 1990 panel, tm8078 is in topical module 2 instead of 1 as in panel 92 and 93
	cd "$cleandata"
	use id wave rot hh_mortg hh_theq hh_vehcl hh_beq hh_intbk hh_intot hh_stk hh_ore hh_otast hh_ira hh_twlth hh_scdbt hh_usdbt hh_debt hh_tnw hh_sum* sc4314 sc4322 sc4414 sc4422 using sipp85w3
	cd "$tempdata"
        ren hh_theq thhtheq
        ren hh_vehcl thhvehcl
        ren hh_beq thhbeq
        ren hh_intbk thhintbk
        ren hh_intot thhintot
        ren hh_stk thhstk
        ren hh_ore thhore
        ren hh_otast thhotast
        ren hh_ira thhira
        gen thhthrif = .
        ren hh_twlth thhtwlth
        ren hh_debt thhdebt
        ren hh_scdbt thhscdbt
        ren hh_usdbt thhuscbt
        ren hh_tnw thhtnw
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm8200 - tm8232 are joint debt held by household
* tm8234 - tm8256 are individual debt
* non-interest may be coded in hhasum*
	use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8224 tm8228 tm8230 tm8232 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8248 tm8250 tm8252 tm8254 tm8256 tm8260 tm8262 tm8264 tm8308 ///
	tm8310 tm8540 tm8542 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8630 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarvl1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp85rt3
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8224 ealjdl
        ren tm8228 taljdal
        gen taljdao = tm8218 + tm8222 + tm8232
        gen ealjdo = (tm8216==1|tm8220==1|tm8230==1)
        gen talicha = .
        gen ealich = .
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8248 ealidl
        ren tm8252 talidal
        gen talidao = tm8242 + tm8246 + tm8256
        gen ealido = (tm8240==1|tm8244==1|tm8254==1)
        ren tm8308 ealli
        ren tm8310 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        *ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        *ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarvl1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot hh_mortg hh_theq hh_vehcl hh_beq hh_intbk hh_intot hh_stk hh_ore hh_otast hh_ira hh_twlth hh_scdbt hh_usdbt hh_debt hh_tnw hh_ats* sc4314 sc4322 sc4414 sc4422 using sipp85w7
	cd "$tempdata"
        ren hh_theq thhtheq
        ren hh_vehcl thhvehcl
        ren hh_beq thhbeq
        ren hh_intbk thhintbk
        ren hh_intot thhintot
        ren hh_stk thhstk
        ren hh_ore thhore
        ren hh_otast thhotast
        ren hh_ira thhira
        gen thhthrif = .
        ren hh_twlth thhtwlth
        ren hh_debt thhdebt
        ren hh_scdbt thhscdbt
        ren hh_usdbt thhuscbt
        ren hh_tnw thhtnw
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
	use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8232 tm823_3 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8260 tm8262 tm8264 tm8308 ///
	tm8309 tm8540 tm8542 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8630 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarva1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp85rt7
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8216 ealjdl
        ren tm8218 taljdal
        ren tm8222 taljdao
        ren tm8220 ealjdo
        *gen talicha = .
        *gen ealich = .
        ren tm823_3 talicha
        gen ealich = (talicha~=0)
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8240 ealidl
        ren tm8242 talidal
        ren tm8246 talidao
        ren tm8244 ealido
        ren tm8308 ealli
        ren tm8309 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        **ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        *ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarva1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
        *ren tm8544 mortpay1
        ren tm8576 mortlen1
        *ren tm8604 housprice
        ren tm8754 veh1debtyn
        ren tm8788 veh1val
        *ren tm8602 housbuildyr
        drop tm*
	sort id wave rot
	merge id wave rot using test
	tab _merge
        cd "$tempdata"
        sort id wave rot
	save test, replace
	
	drop if m1tst~=3
	drop m1tst 
	compress
	save test, replace
	erase testm.dta
	*drop tst1
	drop mtst
	drop miw


compress

drop _merge
sort id wave rot	
save test, replace

end

capture program drop loop84
program define loop84
	* Longitudinal data: create two files 1) by id wave; 2) by id wave month
	* id
	cd "$cleandata"
	use id rot g2s* using sipp84l1, clear
	cd "$tempdata"
	sort id rot

	save testi, replace
		

	* id wave
	cd "$cleandata"
	use id rot ast* using sipp84l1, clear
	cd "$tempdata"

	renpfix ast107 east1a
	renpfix ast103 east2a
	renpfix ast100 east2b
	renpfix ast101 east2c
	renpfix ast102 east2d
	renpfix ast104 east3a
	renpfix ast110 east3b
	renpfix ast106 east3c
	renpfix ast105 east3d
	renpfix ast130 east3e
	renpfix ast120 east4a
	renpfix ast140 east4b
	renpfix ast150 east4c
	*renpfix ast107 astyn7_
	
	
	reshape long east1a east2a east2b east2c east2d east3a east3b east3c east3d east3e east4a east4b east4c, i(id) j(wave)

        *gen east3b = east3a

	rename east1a usgovbndsyn
	*rename east1b irayn
	*rename east1c retyn
	rename east2a intchkacctyn
	rename east2b savacctyn
	rename east2c mmacctyn
	rename east2d cdyn
	rename east3a mfyn
	rename east3b stkyn
	rename east3c crpbndsyn
	rename east3d usgovsecyn
	rename east3e mortyn
	rename east4a ownrentyn
	rename east4b royincyn
	rename east4c othfinyn

	sort id wave
	save testw, replace
	

	*id month
	cd "$cleandata"
	use id rot age* g2a* using sipp84l1, clear
	cd "$tempdata"
	sort id

	renpfix age_ age
	renpfix age0 age
	renpfix g2a1000 astincamt0_
	renpfix g2a100 astincamt0_
	renpfix g2a1040 astincamt4_
	renpfix g2a104 astincamt4_
	renpfix g2a1100 astincamt11_
	renpfix g2a110 astincamt11_
	renpfix g2a1200 astincamt12_
	renpfix g2a120 astincamt12_
	renpfix g2a1300 astincamt13_
	renpfix g2a130 astincamt13_
	renpfix g2a1400 astincamt14_
	renpfix g2a140 astincamt14_
	sort id
	
	save test1, replace


	
	reshape long age astincamt0_ astincamt4_ astincamt11_ astincamt12_ astincamt13_ astincamt14_, i(id) j(mnth)
		
	cd "$programs"
	do monthwave84.do
	cd "$tempdata"

	sort id wave month
	save testm, replace
	
	* Core data
	local i=1
	cd "$cleandata"
        *use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* o4* j4* ram* sc43* sc44* sc45* sc46* sc47* using sipp84w`i', clear
        use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp84w`i', clear
	cd "$tempdata"
	sort $ids id wave srefmon
        ren pp_prop totownpropinc
        ren h_prop totjntpropinc
/*
        ren assets01 savacctyn
        ren assets02 mmacctyn
        ren assets03 cdyn
        ren assets04 nowacctyn
        ren assets05 usgovbndsyn
        ren assets06 crpbndsyn
        ren assets07 othfinyn
        ren assets08 stkyn
        ren assets09 ownrentyn
        ren assets10 mortyn
        ren astsou01 savacctyn
        ren astsou02 mmacctyn
        ren astsou03 cdyn
        ren astsou04 nowacctyn
        ren astsou05 usgovbndsyn
        ren astsou06 crpbndsyn
        ren astsou07 othfinyn
        ren astsou08 stkyn
        ren astsou09 ownrentyn
        ren astsou10 mortyn
*/
/*
        ren sc1624 savacctyn
        ren sc1628 mmacctyn
        ren sc1632 intchkacctyn
        ren sc1638 govsecyn
        ren sc1640 crpbndsyn
        ren sc1642 mortyn
        ren sc1646 usgovbndsyn
        ren sc1648 stkyn
        ren sc1650 ownrentyn
        ren sc1652 royincyn
        ren sc1654 othfinyn
*/
        drop sc16*
        gen jntsavacctyn = (j100yn==1)
        gen jntmmdacctyn = (j100yn==1)
        gen jntcdyn = (j100yn==1)
        gen jntchkacctyn = (j100yn==1)
        gen ownsavacctyn = (o100yn==1)
        gen ownmmdacctyn = (o100yn==1)
        gen owncdyn = (o100yn==1)
        gen ownchkacctyn = (o100yn==1)
        gen jntmfacctyn = (j104yn==1)
        gen jntgovsecyn = (j104yn==1)
        gen jntcrpbndsyn = (j104yn==1)
        gen jntothyn = (j104yn==1)
        gen ownmfacctyn = (o104yn==1)
        gen owngovsecyn = (o104yn==1)
        gen owncrpbndsyn = (o104yn==1)
        gen ownothyn = (o104yn==1)
        gen jntstkdivyn = (j110ryn==1)
        gen ownstkdivyn = (o110ryn==1)
        gen jntrntincyn = (j120yn==1)
        gen ownrntincyn = (o120yn==1)
        drop j1* o1*
        ren jmtgnyn jntmortyn
        ren omtgnyn ownmortyn
        ren jmortyn jntpaymortyn
        ren omortyn ownpaymortyn
        *ren jmam130 jntmortamt
        *ren omam130 ownmortamt
        ren sc4312 jntsavacctamt
        ren sc4412 jntgovsecamt
        ren sc4508 jntstkdivamt
        ren sc4604 jntrntinc
        ren sc4606 netjntrntinc
        ren sc4712 jntmortamt
        ren sc4716 ownmortamt
        drop sc4*
	save test, replace
	local i=`i'+1
	while `i'>=2 & `i'<9 {
		cd "$cleandata"
            capture confirm file "$c`i'.dta"
		if !_rc {

                    use $ids month su_totg2* *prop* asset* astsou* sc16* j1* o1* jint* oint* jcal* ocal* odic* jdic* ornt* jrnt* omor* jmor* jmt* omt* jmam* omam* sc43* sc44* sc45* sc46* sc47* using sipp84w`i', clear
                    cd "$tempdata"
                    sort $ids id wave srefmon
                    ren pp_prop totownpropinc
                    ren h_prop totjntpropinc
                    /*
                    ren assets01 savacctyn
                    ren assets02 mmacctyn
                    ren assets03 cdyn
                    ren assets04 nowacctyn
                    ren assets05 usgovbndsyn
                    ren assets06 crpbndsyn
                    ren assets07 othfinyn
                    ren assets08 stkyn
                    ren assets09 ownrentyn
                    ren assets10 mortyn
                    ren astsou01 savacctyn
                    ren astsou02 mmacctyn
                    ren astsou03 cdyn
                    ren astsou04 nowacctyn
                    ren astsou05 usgovbndsyn
                    ren astsou06 crpbndsyn
                    ren astsou07 othfinyn
                    ren astsou08 stkyn
                    ren astsou09 ownrentyn
                    ren astsou10 mortyn
                    */
                    /*
                    ren sc1626 savacctyn
                    ren sc1628 mmacctyn
                    ren sc1632 intchkacctyn
                    ren sc1638 govsecyn
                    ren sc1640 crpbndsyn
                    ren sc1642 mortyn
                    ren sc1646 usgovbndsyn
                    ren sc1648 stkyn
                    ren sc1650 ownrentyn
                    ren sc1652 royincyn
                    ren sc1654 othfinyn
                    */
                    drop sc16*
                    gen jntsavacctyn = (j100yn==1)
                    gen jntmmdacctyn = (j100yn==1)
                    gen jntcdyn = (j100yn==1)
                    gen jntchkacctyn = (j100yn==1)
                    gen ownsavacctyn = (o100yn==1)
                    gen ownmmdacctyn = (o100yn==1)
                    gen owncdyn = (o100yn==1)
                    gen ownchkacctyn = (o100yn==1)
                    gen jntmfacctyn = (j104yn==1)
                    gen jntgovsecyn = (j104yn==1)
                    gen jntcrpbndsyn = (j104yn==1)
                    gen jntothyn = (j104yn==1)
                    gen ownmfacctyn = (o104yn==1)
                    gen owngovsecyn = (o104yn==1)
                    gen owncrpbndsyn = (o104yn==1)
                    gen ownothyn = (o104yn==1)
                    gen jntstkdivyn = (j110ryn==1)
                    gen ownstkdivyn = (o110ryn==1)
                    gen jntrntincyn = (j120yn==1)
                    gen ownrntincyn = (o120yn==1)
                    drop j1* o1*
                             ren jmtgnyn jntmortyn
                    ren omtgnyn ownmortyn
                    ren jmortyn jntpaymortyn
                    ren omortyn ownpaymortyn
                    *ren jmam130 jntmortamt
                    *ren omam130 ownmortamt
                    ren sc4312 jntsavacctamt
                    ren sc4412 jntgovsecamt
                    ren sc4508 jntstkdivamt
                    ren sc4604 jntrntinc
                    ren sc4606 netjntrntinc
                    ren sc4712 jntmortamt
                    ren sc4716 ownmortamt
                    drop sc4*
                    append using test
                    sort $ids
                    save test, replace
                    }
		local i=`i'+1
	} 

	sort id wave month
	merge id wave month using testm
	tab _merge
	rename _merge m1tst
	
	sort id rot
	merge id rot using testi
	tab _merge
	rename _merge mtst

	sort id wave
	merge id wave using testw
	tab _merge
	rename _merge miw

	sort id wave rot
	save test, replace
	
	*Note:for 1990 panel, tm8078 is in topical module 2 instead of 1 as in panel 92 and 93
	cd "$cleandata"
	use id wave rot hhmortg hhtheq hhvehcl hhbeq hhintbk hhintot hhstk hhore hhotast hhira hhtwlth hhscdbt hhusdbt hhdebt hhtnw hhatsum* sc4314 sc4322 sc4414 sc4422 using sipp84w4
	cd "$tempdata"
        ren hhtheq thhtheq
        ren hhvehcl thhvehcl
        ren hhbeq thhbeq
        ren hhintbk thhintbk
        ren hhintot thhintot
        ren hhstk thhstk
        ren hhore thhore
        ren hhotast thhotast
        ren hhira thhira
        gen thhthrif = .
        ren hhtwlth thhtwlth
        ren hhdebt thhdebt
        ren hhscdbt thhscdbt
        ren hhusdbt thhuscbt
        ren hhtnw thhtnw
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
* tm8200 - tm8232 are joint debt held by household
* tm8234 - tm8256 are individual debt
* non-interest may be coded in hhasum*
	use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8224 tm8228 tm8230 tm8232 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8248 tm8250 tm8252 tm8254 tm8256 tm8260 tm8262 tm8264 tm8308 tm8310 ///
	tm8540 tm8542 tm8544 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8600 tm8602 tm8604 tm8610 tm8624 tm8630 tm8638 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarvl1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp84rt4
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8224 ealjdl
        ren tm8228 taljdal
        gen taljdao = tm8218 + tm8222 + tm8232
        gen ealjdo = (tm8216==1|tm8220==1|tm8230==1)
        gen talicha = .
        gen ealich = .
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8248 ealidl
        ren tm8252 talidal
        gen talidao = tm8242 + tm8246 + tm8256
        gen ealido = (tm8240==1|tm8244==1|tm8254==1)
        ren tm8308 ealli
        ren tm8310 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarvl1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace

	cd "$cleandata"
	use id wave rot hhmortg hhtheq hhvehcl hhbeq hhintbk hhintot hhstk hhore hhotast hhira hhtwlth hhscdbt hhusdbt hhdebt hhtnw hhatsum* sc4314 sc4322 sc4414 sc4422 using sipp84w7
	cd "$tempdata"
        ren hhtheq thhtheq
        ren hhvehcl thhvehcl
        ren hhbeq thhbeq
        ren hhintbk thhintbk
        ren hhintot thhintot
        ren hhstk thhstk
        ren hhore thhore
        ren hhotast thhotast
        ren hhira thhira
        gen thhthrif = .
        ren hhtwlth thhtwlth
        ren hhdebt thhdebt
        ren hhscdbt thhscdbt
        ren hhusdbt thhuscbt
        ren hhtnw thhtnw
        ren sc4314 tiajta
        ren sc4322 tiaita
        ren sc4414 timja
        ren sc4422 timia
	sort id wave rot
	merge id wave rot using test
	tab _merge
	drop _merge
	cd "$tempdata"
	sort id wave rot
	save test, replace
	cd "$cleandata"
	use id wave rot tm8200 tm8202 tm8204 tm8206 tm8208 tm8212 tm8214 tm8216 tm8218 tm8220 tm8222 tm8224 tm8228 tm8230 tm8232 tm8234 tm8236 tm8238 tm8240 tm8242 tm8244 tm8246 tm8248 tm8250 tm8252 tm8254 tm8256 tm8260 tm8262 tm8264 tm8308 ///
	tm8310 tm8540 tm8542 tm8564 tm8566 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8630 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarvl1 tm8044 tm8034 tm8040 tm8048 tm8054 tm8068 tm8074 tm8092 tm8098 tm8116 tm8120 using sipp84rt7
	cd "$tempdata"
        ren tm8260 ealr
        ren tm8262 ealry
        ren tm8264 talrb
        ren tm8204 taljcha
        gen ealjch = (taljcha~=0)
        ren tm8212 ealjdb
        ren tm8214 taljdab
        ren tm8224 ealjdl
        ren tm8228 taljdal
        gen taljdao = tm8218 + tm8222 + tm8232
        gen ealjdo = (tm8216==1|tm8220==1|tm8230==1)
        gen talicha = .
        gen ealich = .
        ren tm8234 ealil
        ren tm8236 ealidb
        ren tm8238 talidab
        ren tm8248 ealidl
        ren tm8252 talidal
        gen talidao = tm8242 + tm8246 + tm8256
        gen ealido = (tm8240==1|tm8244==1|tm8254==1)
        ren tm8308 ealli
        ren tm8310 talliv
        gen eallie = .
        gen talliev = .
        gen ehreunv = .
        *ren tm8600 ehbuyyr
        gen ehbuymo = .
        ren tm8540 ehmort
        ren tm8542 enummort
* i think this is supposed to just be tm8564, but the codebook says otherwise
        gen tmor1pr = tm8564 + tm8566
        ren tm8572 tmor1amt
        ren tm8568 emor1yr
        gen emor1mo = .
        ren tm8580 emor1int
        ren tm8584 emor1var
        ren tm8598 tpropval
        ren tm8630 thmval
        ren tm8624 thmpr
        *ren tm8638 thomeamt
        ren tm8666 tothreva
        ren tmcarvl1 tcarval1
        ren tm8716 eautonum
        ren tm8730 ta1year
        ren tm8760 ta1amt
        ren tm8044 toaeq
        ren tm8034 tsmjv
        ren tm8040 tsmjmav
        *ren tm8044 tsmiv
        gen tsmiv = toaeq
        ren tm8048 tsmimav
        ren tm8054 erjnum
        ren tm8068 trjmv
        ren tm8074 trjpri
        ren tm8092 trimv
        ren tm8098 tripri
        ren tm8116 trtmv
        ren tm8120 trtpri
        gen tvba1 = .
        gen tvbde1 = .
        *ren tm8544 mortpay1
        ren tm8576 mortlen1
        *ren tm8604 housprice
        ren tm8754 veh1debtyn
        ren tm8788 veh1val
        *ren tm8602 housbuildyr
/*
	use id wave rot tm8540 tm8542 tm8564 tm8568 tm8572 tm8576 tm8580 tm8584 tm8598 tm8610 tm8624 tm8666 tm8716 tm8730 tm8754 tm8760 tm8788 tmcarvl1 using sipp84rt7
	cd "$tempdata"
        ren tm8540 hasmort
        ren tm8542 nummort
        ren tm8564 tmor1pr
        ren tm8568 emor1yr
        ren tm8572 mortamtinit1
        ren tm8576 mortlen1
        ren tm8580 mortintrate1
        ren tm8584 emor1var
        ren tm8598 housval
        ren tm8610 mobhmmort
        ren tm8624 mobhmmortamt
        ren tm8666 othrealestate
        ren tm8716 numvehicles
        ren tm8730 veh1year
        ren tm8754 veh1debtyn
        ren tm8760 veh1debamt
        ren tm8788 veh1val
        ren tmcarvl1 totcarval
*/
        drop tm*
	sort id wave rot
	merge id wave rot using test
	tab _merge
        cd "$tempdata"
        sort id wave rot
	save test, replace
	
	drop if m1tst~=3
	drop m1tst 
	compress
	save test, replace
	erase testm.dta
	*drop tst1
	drop mtst
	drop miw

compress

drop _merge
sort id wave rot	
save test, replace

end

loop$p
