/* Please do not attemp to run this program without reading the accompanying documentation. */


version 8.0
set more off
prog drop _all
clear

/*
This program runs the top-coding adjustments: lognormal and Pareto. 

Three different sources of monthly employment income are identified in the SIPP public use
files: (1) rate and salary income, (2) self-employed earnings, and (3) other worker
arrangements. Each of these three sources is topcoded separately. For each source, monthly
amounts over $12,500 (one-twelfth of the $150,000 annual benchmark) are topcoded if the total
income from those sources from all 4 months in the wave is greater than $50,000 (one-third of
$150,000).

See SIPP User's Guide, Ch. 10 for information on the 1996 panel and XX for information 
on the 1993 and 1992 panels.
*/


/*
Pull variables from other sets in order to have information to estimate topcodes.
As of summer 2004, we only have Census-supplied topcodes for 1996, so this panel is different.
*/

capture program drop loop01
program define loop01
        local i=1
        use $ids erace eorigin rmhrswk using $c`i', clear
        sort $ids
	cd "$tempdata"
        save tst, replace
        local i = `i'+1
        while `i'>1 & `i'<9 {
                use $ids erace eorigin rmhrswk using $c`i', clear
                sort $ids
		cd "$tempdata"
                append using tst
                sort $ids
		cd "$tempdata"
                save tst, replace
                local i=`i'+1
        }
end

capture program drop loop96
program define loop96
        local i=1
        use $ids erace eorigin rmhrswk using $f`i', clear
        sort $ids
	cd "$tempdata"
        save tst, replace
        local i = `i'+1
        while `i'>1 & `i'<13 {
                use $ids erace eorigin rmhrswk using $f`i', clear
                sort $ids
		cd "$tempdata"
                append using tst
                sort $ids
		cd "$tempdata"
                save tst, replace
                local i=`i'+1
        }
end

if $p==96 {
	loop$p
	cd "$output"
	use $ids rate earn esr rate jobno selfinc mooninc using set_d, clear
	sort $ids
	cd "$tempdata"
	merge $ids using tst
	tab _merge
	drop _merge
	sort $ids
	cd "$tempdata"
	save tst, replace
	}

if "$p" == "08" | "$p" == "04" | $p==92 | $p==93 | $p==01 | $p==91 | $p==90 | $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	cd "$output"
	use $ids rate earn jobno using set_d, clear
	sort $ids
	cd "$tempdata"
	save tst, replace
}

cd "$output"
use $ids age year month wpfinwgt using set_a, clear
sort $ids
cd "$tempdata"
merge $ids using tst
tab _merge
drop _merge
sort $ids
cd "$tempdata"
save tst, replace

cd "$output"
use $ids female age race using set_b, clear
sort $ids
cd "$tempdata"
merge $ids using tst
tab _merge
drop _merge
sort $ids
cd "$tempdata"
save tst, replace
 
keep if age>=15 & age~=.
sort $ids

cd "$tempdata"
save topcode, replace

******************** 
sort $ids
egen numwaves=max(wave)

* TOP CODES
* For the 1996 panel, assign mean above top code as given by Census
if $p==96 {
	gen race_tc = 3 if eorigin>=20 & eorigin<=28
	replace race_tc = 2 if erace==2 & race_tc==.
	replace race_tc = 1 if race_tc==.
	label define race_tc 1 "Nonblack, nonHispanic" 2 "Black, nonHispanic" 3 "Hispanic, any race"
	label values race_tc race_tc
	drop erace eorigin

	gen ft_ = 1 if esr==1
	sort id wave
	egen ftfulyr = sum(ft_), by(id wave jobno)
	recode ftfulyr 1 2 3=0 4=1
	drop ft_
	gen ft_ = rmhrswk==1
	sort id wave
	egen ft = sum(ft_), by(id wave jobno)
	recode ft 1 2=0 3 4=1
	replace ftfulyr = 0 if ft==0
	drop ft ft_

	gen tcvalue = 29660 if female==0 & race_tc==1 & ftfulyr==1
	replace tcvalue = 38270 if female==0 & race_tc==1 & ftfulyr==0 
	replace tcvalue = 17530 if female==0 & race_tc==2 & ftfulyr==1 
	replace tcvalue = 24015 if female==0 & race_tc==2 & ftfulyr==0 
	replace tcvalue = 26250 if female==0 & race_tc==3 & ftfulyr==1 
	replace tcvalue = 24015 if female==0 & race_tc==3 & ftfulyr==0 
	replace tcvalue = 21990 if female==1 & race_tc==1 & ftfulyr==1 
	replace tcvalue = 49450 if female==1 & race_tc==1 & ftfulyr==0 
	replace tcvalue = 24015 if female==1 & race_tc==2 & ftfulyr==1 
	replace tcvalue = 24015 if female==1 & race_tc==2 & ftfulyr==0 
	replace tcvalue = 24015 if female==1 & race_tc==3 & ftfulyr==1 
	replace tcvalue = 24015 if female==1 & race_tc==3 & ftfulyr==0 
	label var tcvalue "Mean value above topcodes"

	capture program drop tc
	program define tc
	local i = 1
	while `i'<=numwaves {
		replace tcvalue = (tcvalue)*1.019^(`i'-1) if wave==`i'
		local i = `i'+1
		}
	end

	tc
	drop race_tc ftfulyr numwaves
	compress

	gen earntc = earn
	replace earntc = tcvalue if earn>=12500 & earn~=.
	label var earntc "Top-coded earn with mean above topcode"
	gen selftc = selfinc
	replace selftc = tcvalue if selfinc>=12500 & selfinc~=.
	label var selftc "Top-coded self-employment income with mean above topcode"
	gen moontc = mooninc
	replace moontc = tcvalue if mooninc>=12500 & mooninc~=.
	label var moontc "Top-coded moonlighting with mean above topcode"
	
	drop tcvalue
	}

* Generate topcode indicator

if "$p" == "08" {
	gen byte earn_tc = earn>=16666.5 if earn~=.
	gen byte rate_tc = rate>=35.0 if rate~=.
	}
if "$p" == "04" {
	gen byte earn_tc = earn>=16666.5 if earn~=.
	gen byte rate_tc = rate>=28.5 if rate~=.
	}
if $p==01 {
	gen byte earn_tc = earn>=12500 if earn~=.
	gen byte rate_tc = rate>=29 if rate~=.
	}
if $p==96 {
	gen byte earn_tc = earn>=12500 if earn~=.
	gen byte rate_tc = rate>=30 if rate~=.
	}
*if $p==92 | $p==93 | $p==91 | $p==90 {
if $p==92 | $p==93 | $p==91 | $p==90 | $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	gen byte earn_tc = earn>=8333 if earn~=.
	gen byte rate_tc = rate>=30 if rate~=.
	}
label var earn_tc "Earnings topcoded"
label var rate_tc "Wages topcoded"
sum earn_tc rate_tc

* Estimate mean above topcode using lognormal and Pareto distributions
capture program drop topcodes
program define topcodes 
        * Run top code programs and generate adjusted vars
        global inc = "`1'"
        gen tc = `1'_tc
        
        /* Set top code for panel and earnings per month or rates */
        global topcode=`3'
                
        gen `1'tc_l = `1'
        label var `1'tc_l "`2' per month w/ log normal topcode"
        gen `1'tc_7 = `1'
        label var `1'tc_7 "`2' per month w/ Pareto 70th topcode"
        gen `1'tc_8 = `1'
        label var `1'tc_8 "`2' per month w/ Pareto 80th topcode"
        gen `1'tc_9 = `1'
        label var `1'tc_9 "`2' per month w/ Pareto 90th topcode"

        * Need to save both tst and tst2 in order to have tst2 sorted correctly.
        cd "$tempdata"
	save tst, replace
        sort $ids jobno
	cd "$tempdata"
        save tst2, replace
        
        local i = $y1
        while `i'<=$y2 {
		cd "$tempdata"
                use tst, clear
                keep if year==`i'
                keep $ids jobno wpfinwgt tc $inc *tc_*
                
		cd "$programs"
                do topc_lognormal.do
                replace `1'tc_l = $matcln if tc==1 
                
		cd "$programs"
                do topc_pareto.do
                replace `1'tc_7 = $matc7 if tc==1 
                replace `1'tc_8 = $matc8 if tc==1 
                replace `1'tc_9 = $matc9 if tc==1 
                
                drop tc
                
                sort $ids jobno
		cd "$tempdata"
                merge $ids jobno using tst2
                tab _merge
                drop _merge
                
                sort $ids jobno
		cd "$tempdata"
                save tst2, replace
                local i = `i'+1
                }
	drop tc
end

if $p==92 | $p==93 | $p==91 | $p==90 | $p==89 | $p==88 | $p==87 | $p==86 | $p==85 | $p==84 {
	topcodes earn "Earnings" 8333
	}
if $p==96 | $p==01 {
	topcodes earn "Earnings" 12500
	}
if "$p" == "04" | "$p" == "08" {
	topcodes earn "Earnings" 16666.5
}
if $p==96 | $p==92 | $p==93 | $p==91 | $p==90 {
	topcodes rate "Wages" 30
	}
if $p==01 {
	topcodes rate "Wages" 29
	}
if $p==04 {
	topcodes rate "Wages" 28.5
}
if $p==08 {
	topcodes rate "Wages" 35
}

keep $ids jobno *tc* female
sort $ids jobno
cd "$tempdata"
save topcode, replace

